// created by jay 0.7 (c) 1998 Axel.Schreiner@informatik.uni-osnabrueck.de

#line 2 "cs-parser.jay"
//
// cs-parser.jay: The Parser for the C# compiler
//
// Authors: Miguel de Icaza (miguel@gnome.org)
//          Ravi Pratap     (ravi@ximian.com)
//          Marek Safar	    (marek.safar@gmail.com)
//
// Dual Licensed under the terms of the GNU GPL and the MIT X11 license
//
// (C) 2001 Ximian, Inc (http://www.ximian.com)
// (C) 2004-2011 Novell, Inc
// Copyright 2011-2012 Xamarin Inc.
//

using System.Text;
using System.IO;
using System;
using System.Collections.Generic;

namespace Mono.CSharp
{
	/// <summary>
	///    The C# Parser
	/// </summary>
	public class CSharpParser
	{
		[Flags]
		enum ParameterModifierType
		{
			Ref		= 1 << 1,
			Out		= 1 << 2,
			This	= 1 << 3,
			Params	= 1 << 4,
			Arglist	= 1 << 5,
			DefaultValue = 1 << 6,
			
			All = Ref | Out | This | Params | Arglist | DefaultValue,
			PrimaryConstructor = Ref | Out | Params | DefaultValue
		}
		
		static readonly object ModifierNone = 0;
	
		NamespaceContainer current_namespace;
		TypeContainer current_container;
		TypeDefinition current_type;
		PropertyBase current_property;
		EventProperty current_event;
		EventField current_event_field;
		FieldBase current_field;
	
		/// <summary>
		///   Current block is used to add statements as we find
		///   them.  
		/// </summary>
		Block      current_block;
		
		BlockVariable current_variable;

		Delegate   current_delegate;
		
		AnonymousMethodExpression current_anonymous_method;

		/// <summary>
		///   This is used by the unary_expression code to resolve
		///   a name against a parameter.  
		/// </summary>
		
		// FIXME: This is very ugly and it's very hard to reset it correctly
		// on all places, especially when some parameters are autogenerated.
		ParametersCompiled current_local_parameters;

		bool parsing_anonymous_method;
		
		bool async_block;

		///
		/// An out-of-band stack.
		///
		Stack<object> oob_stack;

		///
		/// Controls the verbosity of the errors produced by the parser
		///
		int yacc_verbose_flag;

		/// 
		/// Used by the interactive shell, flags whether EOF was reached
		/// and an error was produced
		///
		public bool UnexpectedEOF;

		///
		/// The current file.
		///
		readonly CompilationSourceFile file;

		///
		/// Temporary Xml documentation cache.
		/// For enum types, we need one more temporary store.
		///
		string tmpComment;
		string enumTypeComment;
	       		
		/// Current attribute target
		string current_attr_target;
		
		ParameterModifierType valid_param_mod;
		
		bool default_parameter_used;

		/// When using the interactive parser, this holds the
		/// resulting expression
		public Class InteractiveResult;

		//
		// Keeps track of global data changes to undo on parser error
		//
		public Undo undo;

		bool? interactive_async;
		
		Stack<Linq.QueryBlock> linq_clause_blocks;

		ModuleContainer module;
		
		readonly CompilerContext compiler;
		readonly LanguageVersion lang_version;
		readonly bool doc_support;
		readonly CompilerSettings settings;
		readonly Report report;
		
		//
		// Instead of allocating carrier array everytime we
		// share the bucket for very common constructs which can never
		// be recursive
		//
		List<Parameter> parameters_bucket;
		
		//
		// Full AST support members
		//
		LocationsBag lbag;
		List<Tuple<Modifiers, Location>> mod_locations;
		Stack<Location> location_stack;
#line default

  /** error output stream.
      It should be changeable.
    */
  public System.IO.TextWriter ErrorOutput = System.Console.Out;

  /** simplified error message.
      @see <a href="#yyerror(java.lang.String, java.lang.String[])">yyerror</a>
    */
  public void yyerror (string message) {
    yyerror(message, null);
  }
#pragma warning disable 649
  /* An EOF token */
  public int eof_token;
#pragma warning restore 649
  /** (syntax) error message.
      Can be overwritten to control message format.
      @param message text to be displayed.
      @param expected vector of acceptable tokens, if available.
    */
  public void yyerror (string message, string[] expected) {
    if ((yacc_verbose_flag > 0) && (expected != null) && (expected.Length  > 0)) {
      ErrorOutput.Write (message+", expecting");
      for (int n = 0; n < expected.Length; ++ n)
        ErrorOutput.Write (" "+expected[n]);
        ErrorOutput.WriteLine ();
    } else
      ErrorOutput.WriteLine (message);
  }

  /** debugging support, requires the package jay.yydebug.
      Set to null to suppress debugging messages.
    */
//t  internal yydebug.yyDebug debug;

  protected const int yyFinal = 7;
//t // Put this array into a separate class so it is only initialized if debugging is actually used
//t // Use MarshalByRefObject to disable inlining
//t class YYRules : MarshalByRefObject {
//t  public static readonly string [] yyRule = {
//t    "$accept : compilation_unit",
//t    "compilation_unit : outer_declaration opt_EOF",
//t    "$$1 :",
//t    "compilation_unit : interactive_parsing $$1 opt_EOF",
//t    "compilation_unit : documentation_parsing",
//t    "outer_declaration : opt_extern_alias_directives opt_using_directives",
//t    "outer_declaration : opt_extern_alias_directives opt_using_directives namespace_or_type_declarations opt_attributes",
//t    "outer_declaration : opt_extern_alias_directives opt_using_directives attribute_sections",
//t    "outer_declaration : error",
//t    "opt_EOF :",
//t    "opt_EOF : EOF",
//t    "extern_alias_directives : extern_alias_directive",
//t    "extern_alias_directives : extern_alias_directives extern_alias_directive",
//t    "extern_alias_directive : EXTERN_ALIAS IDENTIFIER IDENTIFIER SEMICOLON",
//t    "extern_alias_directive : EXTERN_ALIAS error",
//t    "using_directives : using_directive",
//t    "using_directives : using_directives using_directive",
//t    "using_directive : using_namespace",
//t    "using_namespace : USING namespace_or_type_expr SEMICOLON",
//t    "using_namespace : USING IDENTIFIER ASSIGN namespace_or_type_expr SEMICOLON",
//t    "using_namespace : USING error",
//t    "$$2 :",
//t    "$$3 :",
//t    "namespace_declaration : opt_attributes NAMESPACE namespace_name $$2 OPEN_BRACE $$3 opt_extern_alias_directives opt_using_directives opt_namespace_or_type_declarations CLOSE_BRACE opt_semicolon_error",
//t    "namespace_declaration : opt_attributes NAMESPACE namespace_name",
//t    "opt_semicolon_error :",
//t    "opt_semicolon_error : SEMICOLON",
//t    "opt_semicolon_error : error",
//t    "namespace_name : IDENTIFIER",
//t    "namespace_name : namespace_name DOT IDENTIFIER",
//t    "namespace_name : error",
//t    "opt_semicolon :",
//t    "opt_semicolon : SEMICOLON",
//t    "opt_comma :",
//t    "opt_comma : COMMA",
//t    "opt_using_directives :",
//t    "opt_using_directives : using_directives",
//t    "opt_extern_alias_directives :",
//t    "opt_extern_alias_directives : extern_alias_directives",
//t    "opt_namespace_or_type_declarations :",
//t    "opt_namespace_or_type_declarations : namespace_or_type_declarations",
//t    "namespace_or_type_declarations : namespace_or_type_declaration",
//t    "namespace_or_type_declarations : namespace_or_type_declarations namespace_or_type_declaration",
//t    "namespace_or_type_declaration : type_declaration",
//t    "namespace_or_type_declaration : namespace_declaration",
//t    "namespace_or_type_declaration : attribute_sections CLOSE_BRACE",
//t    "type_declaration : class_declaration",
//t    "type_declaration : struct_declaration",
//t    "type_declaration : interface_declaration",
//t    "type_declaration : enum_declaration",
//t    "type_declaration : delegate_declaration",
//t    "opt_attributes :",
//t    "opt_attributes : attribute_sections",
//t    "attribute_sections : attribute_section",
//t    "attribute_sections : attribute_sections attribute_section",
//t    "$$4 :",
//t    "attribute_section : OPEN_BRACKET $$4 attribute_section_cont",
//t    "$$5 :",
//t    "attribute_section_cont : attribute_target COLON $$5 attribute_list opt_comma CLOSE_BRACKET",
//t    "attribute_section_cont : attribute_list opt_comma CLOSE_BRACKET",
//t    "attribute_section_cont : IDENTIFIER error",
//t    "attribute_section_cont : error",
//t    "attribute_target : IDENTIFIER",
//t    "attribute_target : EVENT",
//t    "attribute_target : RETURN",
//t    "attribute_list : attribute",
//t    "attribute_list : attribute_list COMMA attribute",
//t    "$$6 :",
//t    "attribute : attribute_name $$6 opt_attribute_arguments",
//t    "attribute_name : namespace_or_type_expr",
//t    "opt_attribute_arguments :",
//t    "opt_attribute_arguments : OPEN_PARENS attribute_arguments CLOSE_PARENS",
//t    "attribute_arguments :",
//t    "attribute_arguments : positional_or_named_argument",
//t    "attribute_arguments : named_attribute_argument",
//t    "attribute_arguments : attribute_arguments COMMA positional_or_named_argument",
//t    "attribute_arguments : attribute_arguments COMMA named_attribute_argument",
//t    "positional_or_named_argument : expression",
//t    "positional_or_named_argument : named_argument",
//t    "positional_or_named_argument : error",
//t    "$$7 :",
//t    "named_attribute_argument : IDENTIFIER ASSIGN $$7 expression",
//t    "named_argument : identifier_inside_body COLON opt_named_modifier expression_or_error",
//t    "opt_named_modifier :",
//t    "opt_named_modifier : REF",
//t    "opt_named_modifier : OUT",
//t    "opt_class_member_declarations :",
//t    "opt_class_member_declarations : class_member_declarations",
//t    "class_member_declarations : class_member_declaration",
//t    "class_member_declarations : class_member_declarations class_member_declaration",
//t    "class_member_declaration : constant_declaration",
//t    "class_member_declaration : field_declaration",
//t    "class_member_declaration : method_declaration",
//t    "class_member_declaration : property_declaration",
//t    "class_member_declaration : event_declaration",
//t    "class_member_declaration : indexer_declaration",
//t    "class_member_declaration : operator_declaration",
//t    "class_member_declaration : constructor_declaration",
//t    "class_member_declaration : primary_constructor_body",
//t    "class_member_declaration : destructor_declaration",
//t    "class_member_declaration : type_declaration",
//t    "class_member_declaration : attributes_without_members",
//t    "class_member_declaration : incomplete_member",
//t    "class_member_declaration : error",
//t    "$$8 :",
//t    "primary_constructor_body : OPEN_BRACE $$8 opt_statement_list block_end",
//t    "$$9 :",
//t    "$$10 :",
//t    "$$11 :",
//t    "$$12 :",
//t    "$$13 :",
//t    "struct_declaration : opt_attributes opt_modifiers opt_partial STRUCT $$9 type_declaration_name $$10 opt_primary_parameters opt_class_base opt_type_parameter_constraints_clauses $$11 OPEN_BRACE $$12 opt_class_member_declarations CLOSE_BRACE $$13 opt_semicolon",
//t    "struct_declaration : opt_attributes opt_modifiers opt_partial STRUCT error",
//t    "$$14 :",
//t    "constant_declaration : opt_attributes opt_modifiers CONST type IDENTIFIER $$14 constant_initializer opt_constant_declarators SEMICOLON",
//t    "constant_declaration : opt_attributes opt_modifiers CONST type error",
//t    "opt_constant_declarators :",
//t    "opt_constant_declarators : constant_declarators",
//t    "constant_declarators : constant_declarator",
//t    "constant_declarators : constant_declarators constant_declarator",
//t    "constant_declarator : COMMA IDENTIFIER constant_initializer",
//t    "$$15 :",
//t    "constant_initializer : ASSIGN $$15 constant_initializer_expr",
//t    "constant_initializer : error",
//t    "constant_initializer_expr : constant_expression",
//t    "constant_initializer_expr : array_initializer",
//t    "$$16 :",
//t    "field_declaration : opt_attributes opt_modifiers member_type IDENTIFIER $$16 opt_field_initializer opt_field_declarators SEMICOLON",
//t    "$$17 :",
//t    "field_declaration : opt_attributes opt_modifiers FIXED simple_type IDENTIFIER $$17 fixed_field_size opt_fixed_field_declarators SEMICOLON",
//t    "field_declaration : opt_attributes opt_modifiers FIXED simple_type error SEMICOLON",
//t    "opt_field_initializer :",
//t    "$$18 :",
//t    "opt_field_initializer : ASSIGN $$18 variable_initializer",
//t    "opt_field_declarators :",
//t    "opt_field_declarators : field_declarators",
//t    "field_declarators : field_declarator",
//t    "field_declarators : field_declarators field_declarator",
//t    "field_declarator : COMMA IDENTIFIER",
//t    "$$19 :",
//t    "field_declarator : COMMA IDENTIFIER ASSIGN $$19 variable_initializer",
//t    "opt_fixed_field_declarators :",
//t    "opt_fixed_field_declarators : fixed_field_declarators",
//t    "fixed_field_declarators : fixed_field_declarator",
//t    "fixed_field_declarators : fixed_field_declarators fixed_field_declarator",
//t    "fixed_field_declarator : COMMA IDENTIFIER fixed_field_size",
//t    "$$20 :",
//t    "fixed_field_size : OPEN_BRACKET $$20 expression CLOSE_BRACKET",
//t    "fixed_field_size : OPEN_BRACKET error",
//t    "variable_initializer : expression",
//t    "variable_initializer : array_initializer",
//t    "variable_initializer : error",
//t    "$$21 :",
//t    "method_declaration : method_header $$21 method_body_expression_block",
//t    "$$22 :",
//t    "$$23 :",
//t    "method_header : opt_attributes opt_modifiers member_type method_declaration_name OPEN_PARENS $$22 opt_formal_parameter_list CLOSE_PARENS $$23 opt_type_parameter_constraints_clauses",
//t    "$$24 :",
//t    "$$25 :",
//t    "$$26 :",
//t    "method_header : opt_attributes opt_modifiers PARTIAL VOID $$24 method_declaration_name OPEN_PARENS $$25 opt_formal_parameter_list CLOSE_PARENS $$26 opt_type_parameter_constraints_clauses",
//t    "method_header : opt_attributes opt_modifiers member_type modifiers method_declaration_name OPEN_PARENS opt_formal_parameter_list CLOSE_PARENS",
//t    "method_header : opt_attributes opt_modifiers member_type method_declaration_name error",
//t    "method_body_expression_block : method_body",
//t    "method_body_expression_block : expression_block",
//t    "method_body : block",
//t    "method_body : SEMICOLON",
//t    "$$27 :",
//t    "expression_block : ARROW $$27 expression SEMICOLON",
//t    "opt_formal_parameter_list :",
//t    "opt_formal_parameter_list : formal_parameter_list",
//t    "formal_parameter_list : fixed_parameters",
//t    "formal_parameter_list : fixed_parameters COMMA parameter_array",
//t    "formal_parameter_list : fixed_parameters COMMA arglist_modifier",
//t    "formal_parameter_list : parameter_array COMMA error",
//t    "formal_parameter_list : fixed_parameters COMMA parameter_array COMMA error",
//t    "formal_parameter_list : arglist_modifier COMMA error",
//t    "formal_parameter_list : fixed_parameters COMMA ARGLIST COMMA error",
//t    "formal_parameter_list : parameter_array",
//t    "formal_parameter_list : arglist_modifier",
//t    "formal_parameter_list : error",
//t    "fixed_parameters : fixed_parameter",
//t    "fixed_parameters : fixed_parameters COMMA fixed_parameter",
//t    "fixed_parameter : opt_attributes opt_parameter_modifier parameter_type identifier_inside_body",
//t    "fixed_parameter : opt_attributes opt_parameter_modifier parameter_type identifier_inside_body OPEN_BRACKET CLOSE_BRACKET",
//t    "fixed_parameter : attribute_sections error",
//t    "fixed_parameter : opt_attributes opt_parameter_modifier parameter_type error",
//t    "$$28 :",
//t    "fixed_parameter : opt_attributes opt_parameter_modifier parameter_type identifier_inside_body ASSIGN $$28 constant_expression",
//t    "opt_parameter_modifier :",
//t    "opt_parameter_modifier : parameter_modifiers",
//t    "parameter_modifiers : parameter_modifier",
//t    "parameter_modifiers : parameter_modifiers parameter_modifier",
//t    "parameter_modifier : REF",
//t    "parameter_modifier : OUT",
//t    "parameter_modifier : THIS",
//t    "parameter_array : opt_attributes params_modifier type IDENTIFIER",
//t    "parameter_array : opt_attributes params_modifier type IDENTIFIER ASSIGN constant_expression",
//t    "parameter_array : opt_attributes params_modifier type error",
//t    "params_modifier : PARAMS",
//t    "params_modifier : PARAMS parameter_modifier",
//t    "params_modifier : PARAMS params_modifier",
//t    "arglist_modifier : ARGLIST",
//t    "$$29 :",
//t    "$$30 :",
//t    "$$31 :",
//t    "$$32 :",
//t    "property_declaration : opt_attributes opt_modifiers member_type member_declaration_name $$29 OPEN_BRACE $$30 accessor_declarations $$31 CLOSE_BRACE $$32 opt_property_initializer",
//t    "$$33 :",
//t    "property_declaration : opt_attributes opt_modifiers member_type member_declaration_name $$33 expression_block",
//t    "opt_property_initializer :",
//t    "$$34 :",
//t    "opt_property_initializer : ASSIGN $$34 property_initializer SEMICOLON",
//t    "property_initializer : expression",
//t    "property_initializer : array_initializer",
//t    "$$35 :",
//t    "$$36 :",
//t    "indexer_declaration : opt_attributes opt_modifiers member_type indexer_declaration_name OPEN_BRACKET $$35 opt_formal_parameter_list CLOSE_BRACKET $$36 indexer_body",
//t    "indexer_body : OPEN_BRACE accessor_declarations CLOSE_BRACE",
//t    "indexer_body : expression_block",
//t    "accessor_declarations : get_accessor_declaration",
//t    "accessor_declarations : get_accessor_declaration accessor_declarations",
//t    "accessor_declarations : set_accessor_declaration",
//t    "accessor_declarations : set_accessor_declaration accessor_declarations",
//t    "accessor_declarations : error",
//t    "$$37 :",
//t    "get_accessor_declaration : opt_attributes opt_modifiers GET $$37 accessor_body",
//t    "$$38 :",
//t    "set_accessor_declaration : opt_attributes opt_modifiers SET $$38 accessor_body",
//t    "accessor_body : block",
//t    "accessor_body : SEMICOLON",
//t    "accessor_body : error",
//t    "$$39 :",
//t    "$$40 :",
//t    "$$41 :",
//t    "$$42 :",
//t    "interface_declaration : opt_attributes opt_modifiers opt_partial INTERFACE $$39 type_declaration_name $$40 opt_class_base opt_type_parameter_constraints_clauses $$41 OPEN_BRACE opt_interface_member_declarations CLOSE_BRACE $$42 opt_semicolon",
//t    "interface_declaration : opt_attributes opt_modifiers opt_partial INTERFACE error",
//t    "opt_interface_member_declarations :",
//t    "opt_interface_member_declarations : interface_member_declarations",
//t    "interface_member_declarations : interface_member_declaration",
//t    "interface_member_declarations : interface_member_declarations interface_member_declaration",
//t    "interface_member_declaration : constant_declaration",
//t    "interface_member_declaration : field_declaration",
//t    "interface_member_declaration : method_declaration",
//t    "interface_member_declaration : property_declaration",
//t    "interface_member_declaration : event_declaration",
//t    "interface_member_declaration : indexer_declaration",
//t    "interface_member_declaration : operator_declaration",
//t    "interface_member_declaration : constructor_declaration",
//t    "interface_member_declaration : type_declaration",
//t    "$$43 :",
//t    "operator_declaration : opt_attributes opt_modifiers operator_declarator $$43 method_body_expression_block",
//t    "operator_type : type_expression_or_array",
//t    "operator_type : VOID",
//t    "$$44 :",
//t    "operator_declarator : operator_type OPERATOR overloadable_operator OPEN_PARENS $$44 opt_formal_parameter_list CLOSE_PARENS",
//t    "operator_declarator : conversion_operator_declarator",
//t    "overloadable_operator : BANG",
//t    "overloadable_operator : TILDE",
//t    "overloadable_operator : OP_INC",
//t    "overloadable_operator : OP_DEC",
//t    "overloadable_operator : TRUE",
//t    "overloadable_operator : FALSE",
//t    "overloadable_operator : PLUS",
//t    "overloadable_operator : MINUS",
//t    "overloadable_operator : STAR",
//t    "overloadable_operator : DIV",
//t    "overloadable_operator : PERCENT",
//t    "overloadable_operator : BITWISE_AND",
//t    "overloadable_operator : BITWISE_OR",
//t    "overloadable_operator : CARRET",
//t    "overloadable_operator : OP_SHIFT_LEFT",
//t    "overloadable_operator : OP_SHIFT_RIGHT",
//t    "overloadable_operator : OP_EQ",
//t    "overloadable_operator : OP_NE",
//t    "overloadable_operator : OP_GT",
//t    "overloadable_operator : OP_LT",
//t    "overloadable_operator : OP_GE",
//t    "overloadable_operator : OP_LE",
//t    "$$45 :",
//t    "conversion_operator_declarator : IMPLICIT OPERATOR type OPEN_PARENS $$45 opt_formal_parameter_list CLOSE_PARENS",
//t    "$$46 :",
//t    "conversion_operator_declarator : EXPLICIT OPERATOR type OPEN_PARENS $$46 opt_formal_parameter_list CLOSE_PARENS",
//t    "conversion_operator_declarator : IMPLICIT error",
//t    "conversion_operator_declarator : EXPLICIT error",
//t    "constructor_declaration : constructor_declarator constructor_body",
//t    "$$47 :",
//t    "$$48 :",
//t    "constructor_declarator : opt_attributes opt_modifiers IDENTIFIER $$47 OPEN_PARENS opt_formal_parameter_list CLOSE_PARENS $$48 opt_constructor_initializer",
//t    "constructor_body : block_prepared",
//t    "constructor_body : SEMICOLON",
//t    "opt_constructor_initializer :",
//t    "opt_constructor_initializer : constructor_initializer",
//t    "$$49 :",
//t    "constructor_initializer : COLON BASE OPEN_PARENS $$49 opt_argument_list CLOSE_PARENS",
//t    "$$50 :",
//t    "constructor_initializer : COLON THIS OPEN_PARENS $$50 opt_argument_list CLOSE_PARENS",
//t    "constructor_initializer : COLON error",
//t    "constructor_initializer : error",
//t    "$$51 :",
//t    "destructor_declaration : opt_attributes opt_modifiers TILDE $$51 IDENTIFIER OPEN_PARENS CLOSE_PARENS method_body",
//t    "$$52 :",
//t    "event_declaration : opt_attributes opt_modifiers EVENT type member_declaration_name $$52 opt_event_initializer opt_event_declarators SEMICOLON",
//t    "$$53 :",
//t    "$$54 :",
//t    "event_declaration : opt_attributes opt_modifiers EVENT type member_declaration_name OPEN_BRACE $$53 event_accessor_declarations $$54 CLOSE_BRACE",
//t    "event_declaration : opt_attributes opt_modifiers EVENT type error",
//t    "opt_event_initializer :",
//t    "$$55 :",
//t    "opt_event_initializer : ASSIGN $$55 event_variable_initializer",
//t    "opt_event_declarators :",
//t    "opt_event_declarators : event_declarators",
//t    "event_declarators : event_declarator",
//t    "event_declarators : event_declarators event_declarator",
//t    "event_declarator : COMMA IDENTIFIER",
//t    "$$56 :",
//t    "event_declarator : COMMA IDENTIFIER ASSIGN $$56 event_variable_initializer",
//t    "$$57 :",
//t    "event_variable_initializer : $$57 variable_initializer",
//t    "event_accessor_declarations : add_accessor_declaration remove_accessor_declaration",
//t    "event_accessor_declarations : remove_accessor_declaration add_accessor_declaration",
//t    "event_accessor_declarations : add_accessor_declaration",
//t    "event_accessor_declarations : remove_accessor_declaration",
//t    "event_accessor_declarations : error",
//t    "$$58 :",
//t    "add_accessor_declaration : opt_attributes opt_modifiers ADD $$58 event_accessor_block",
//t    "$$59 :",
//t    "remove_accessor_declaration : opt_attributes opt_modifiers REMOVE $$59 event_accessor_block",
//t    "event_accessor_block : opt_semicolon",
//t    "event_accessor_block : block",
//t    "attributes_without_members : attribute_sections CLOSE_BRACE",
//t    "incomplete_member : opt_attributes opt_modifiers member_type CLOSE_BRACE",
//t    "$$60 :",
//t    "$$61 :",
//t    "$$62 :",
//t    "enum_declaration : opt_attributes opt_modifiers ENUM type_declaration_name opt_enum_base $$60 OPEN_BRACE $$61 opt_enum_member_declarations $$62 CLOSE_BRACE opt_semicolon",
//t    "opt_enum_base :",
//t    "opt_enum_base : COLON type",
//t    "opt_enum_base : COLON error",
//t    "opt_enum_member_declarations :",
//t    "opt_enum_member_declarations : enum_member_declarations",
//t    "opt_enum_member_declarations : enum_member_declarations COMMA",
//t    "enum_member_declarations : enum_member_declaration",
//t    "enum_member_declarations : enum_member_declarations COMMA enum_member_declaration",
//t    "enum_member_declaration : opt_attributes IDENTIFIER",
//t    "$$63 :",
//t    "enum_member_declaration : opt_attributes IDENTIFIER $$63 ASSIGN constant_expression",
//t    "enum_member_declaration : opt_attributes IDENTIFIER error",
//t    "enum_member_declaration : attributes_without_members",
//t    "$$64 :",
//t    "$$65 :",
//t    "$$66 :",
//t    "delegate_declaration : opt_attributes opt_modifiers DELEGATE member_type type_declaration_name OPEN_PARENS $$64 opt_formal_parameter_list CLOSE_PARENS $$65 opt_type_parameter_constraints_clauses $$66 SEMICOLON",
//t    "opt_nullable :",
//t    "opt_nullable : INTERR_NULLABLE",
//t    "namespace_or_type_expr : member_name",
//t    "namespace_or_type_expr : qualified_alias_member IDENTIFIER opt_type_argument_list",
//t    "namespace_or_type_expr : qualified_alias_member IDENTIFIER generic_dimension",
//t    "member_name : simple_name_expr",
//t    "member_name : namespace_or_type_expr DOT IDENTIFIER opt_type_argument_list",
//t    "member_name : namespace_or_type_expr DOT IDENTIFIER generic_dimension",
//t    "simple_name_expr : IDENTIFIER opt_type_argument_list",
//t    "simple_name_expr : IDENTIFIER generic_dimension",
//t    "opt_type_argument_list :",
//t    "opt_type_argument_list : OP_GENERICS_LT type_arguments OP_GENERICS_GT",
//t    "opt_type_argument_list : OP_GENERICS_LT error",
//t    "type_arguments : type",
//t    "type_arguments : type_arguments COMMA type",
//t    "$$67 :",
//t    "type_declaration_name : IDENTIFIER $$67 opt_type_parameter_list",
//t    "member_declaration_name : method_declaration_name",
//t    "method_declaration_name : type_declaration_name",
//t    "method_declaration_name : explicit_interface IDENTIFIER opt_type_parameter_list",
//t    "indexer_declaration_name : THIS",
//t    "indexer_declaration_name : explicit_interface THIS",
//t    "explicit_interface : IDENTIFIER opt_type_argument_list DOT",
//t    "explicit_interface : qualified_alias_member IDENTIFIER opt_type_argument_list DOT",
//t    "explicit_interface : explicit_interface IDENTIFIER opt_type_argument_list DOT",
//t    "opt_type_parameter_list :",
//t    "opt_type_parameter_list : OP_GENERICS_LT_DECL type_parameters OP_GENERICS_GT",
//t    "type_parameters : type_parameter",
//t    "type_parameters : type_parameters COMMA type_parameter",
//t    "type_parameter : opt_attributes opt_type_parameter_variance IDENTIFIER",
//t    "type_parameter : error",
//t    "type_and_void : type_expression_or_array",
//t    "type_and_void : VOID",
//t    "member_type : type_and_void",
//t    "type : type_expression_or_array",
//t    "type : VOID",
//t    "simple_type : type_expression",
//t    "simple_type : VOID",
//t    "parameter_type : type_expression_or_array",
//t    "parameter_type : VOID",
//t    "type_expression_or_array : type_expression",
//t    "type_expression_or_array : type_expression rank_specifiers",
//t    "type_expression : namespace_or_type_expr opt_nullable",
//t    "type_expression : namespace_or_type_expr pointer_stars",
//t    "type_expression : builtin_types opt_nullable",
//t    "type_expression : builtin_types pointer_stars",
//t    "type_expression : VOID pointer_stars",
//t    "type_list : base_type_name",
//t    "type_list : type_list COMMA base_type_name",
//t    "base_type_name : type",
//t    "builtin_types : OBJECT",
//t    "builtin_types : STRING",
//t    "builtin_types : BOOL",
//t    "builtin_types : DECIMAL",
//t    "builtin_types : FLOAT",
//t    "builtin_types : DOUBLE",
//t    "builtin_types : integral_type",
//t    "integral_type : SBYTE",
//t    "integral_type : BYTE",
//t    "integral_type : SHORT",
//t    "integral_type : USHORT",
//t    "integral_type : INT",
//t    "integral_type : UINT",
//t    "integral_type : LONG",
//t    "integral_type : ULONG",
//t    "integral_type : CHAR",
//t    "primary_expression : primary_expression_or_type",
//t    "primary_expression : literal",
//t    "primary_expression : array_creation_expression",
//t    "primary_expression : parenthesized_expression",
//t    "primary_expression : default_value_expression",
//t    "primary_expression : invocation_expression",
//t    "primary_expression : element_access",
//t    "primary_expression : this_access",
//t    "primary_expression : base_access",
//t    "primary_expression : post_increment_expression",
//t    "primary_expression : post_decrement_expression",
//t    "primary_expression : object_or_delegate_creation_expression",
//t    "primary_expression : anonymous_type_expression",
//t    "primary_expression : typeof_expression",
//t    "primary_expression : sizeof_expression",
//t    "primary_expression : checked_expression",
//t    "primary_expression : unchecked_expression",
//t    "primary_expression : pointer_member_access",
//t    "primary_expression : anonymous_method_expression",
//t    "primary_expression : undocumented_expressions",
//t    "primary_expression_or_type : simple_name_expr",
//t    "primary_expression_or_type : IDENTIFIER GENERATE_COMPLETION",
//t    "primary_expression_or_type : member_access",
//t    "literal : boolean_literal",
//t    "literal : LITERAL",
//t    "literal : NULL",
//t    "boolean_literal : TRUE",
//t    "boolean_literal : FALSE",
//t    "open_parens_any : OPEN_PARENS",
//t    "open_parens_any : OPEN_PARENS_CAST",
//t    "close_parens : CLOSE_PARENS",
//t    "close_parens : COMPLETE_COMPLETION",
//t    "parenthesized_expression : OPEN_PARENS expression CLOSE_PARENS",
//t    "parenthesized_expression : OPEN_PARENS expression COMPLETE_COMPLETION",
//t    "member_access : primary_expression DOT identifier_inside_body opt_type_argument_list",
//t    "member_access : primary_expression DOT identifier_inside_body generic_dimension",
//t    "member_access : primary_expression INTERR_OPERATOR DOT identifier_inside_body opt_type_argument_list",
//t    "member_access : builtin_types DOT identifier_inside_body opt_type_argument_list",
//t    "member_access : BASE DOT identifier_inside_body opt_type_argument_list",
//t    "member_access : AWAIT DOT identifier_inside_body opt_type_argument_list",
//t    "member_access : qualified_alias_member identifier_inside_body opt_type_argument_list",
//t    "member_access : qualified_alias_member identifier_inside_body generic_dimension",
//t    "member_access : primary_expression DOT GENERATE_COMPLETION",
//t    "member_access : primary_expression DOT IDENTIFIER GENERATE_COMPLETION",
//t    "member_access : builtin_types DOT GENERATE_COMPLETION",
//t    "member_access : builtin_types DOT IDENTIFIER GENERATE_COMPLETION",
//t    "invocation_expression : primary_expression open_parens_any opt_argument_list close_parens",
//t    "invocation_expression : primary_expression open_parens_any argument_list error",
//t    "invocation_expression : primary_expression open_parens_any error",
//t    "opt_object_or_collection_initializer :",
//t    "opt_object_or_collection_initializer : object_or_collection_initializer",
//t    "object_or_collection_initializer : OPEN_BRACE opt_member_initializer_list close_brace_or_complete_completion",
//t    "object_or_collection_initializer : OPEN_BRACE member_initializer_list COMMA CLOSE_BRACE",
//t    "opt_member_initializer_list :",
//t    "opt_member_initializer_list : member_initializer_list",
//t    "member_initializer_list : member_initializer",
//t    "member_initializer_list : member_initializer_list COMMA member_initializer",
//t    "member_initializer_list : member_initializer_list error",
//t    "member_initializer : IDENTIFIER ASSIGN initializer_value",
//t    "member_initializer : AWAIT ASSIGN initializer_value",
//t    "member_initializer : GENERATE_COMPLETION",
//t    "member_initializer : non_assignment_expression opt_COMPLETE_COMPLETION",
//t    "member_initializer : OPEN_BRACE expression_list CLOSE_BRACE",
//t    "member_initializer : OPEN_BRACKET_EXPR expression_list CLOSE_BRACKET ASSIGN initializer_value",
//t    "member_initializer : OPEN_BRACE CLOSE_BRACE",
//t    "initializer_value : expression",
//t    "initializer_value : object_or_collection_initializer",
//t    "opt_argument_list :",
//t    "opt_argument_list : argument_list",
//t    "argument_list : argument_or_named_argument",
//t    "argument_list : argument_list COMMA argument",
//t    "argument_list : argument_list COMMA named_argument",
//t    "argument_list : argument_list COMMA error",
//t    "argument_list : COMMA error",
//t    "argument : expression",
//t    "argument : non_simple_argument",
//t    "argument_or_named_argument : argument",
//t    "argument_or_named_argument : named_argument",
//t    "non_simple_argument : REF variable_reference",
//t    "non_simple_argument : OUT variable_reference",
//t    "non_simple_argument : ARGLIST OPEN_PARENS argument_list CLOSE_PARENS",
//t    "non_simple_argument : ARGLIST OPEN_PARENS CLOSE_PARENS",
//t    "variable_reference : expression",
//t    "element_access : primary_expression OPEN_BRACKET_EXPR expression_list_arguments CLOSE_BRACKET",
//t    "element_access : primary_expression INTERR_OPERATOR OPEN_BRACKET_EXPR expression_list_arguments CLOSE_BRACKET",
//t    "element_access : primary_expression OPEN_BRACKET_EXPR expression_list_arguments error",
//t    "element_access : primary_expression OPEN_BRACKET_EXPR error",
//t    "expression_list : expression_or_error",
//t    "expression_list : expression_list COMMA expression_or_error",
//t    "expression_list_arguments : expression_list_argument",
//t    "expression_list_arguments : expression_list_arguments COMMA expression_list_argument",
//t    "expression_list_argument : expression",
//t    "expression_list_argument : named_argument",
//t    "this_access : THIS",
//t    "base_access : BASE OPEN_BRACKET_EXPR expression_list_arguments CLOSE_BRACKET",
//t    "base_access : BASE OPEN_BRACKET error",
//t    "post_increment_expression : primary_expression OP_INC",
//t    "post_decrement_expression : primary_expression OP_DEC",
//t    "object_or_delegate_creation_expression : NEW new_expr_type open_parens_any opt_argument_list CLOSE_PARENS opt_object_or_collection_initializer",
//t    "object_or_delegate_creation_expression : NEW new_expr_type object_or_collection_initializer",
//t    "array_creation_expression : NEW new_expr_type OPEN_BRACKET_EXPR expression_list CLOSE_BRACKET opt_rank_specifier opt_array_initializer",
//t    "array_creation_expression : NEW new_expr_type rank_specifiers opt_array_initializer",
//t    "array_creation_expression : NEW rank_specifier array_initializer",
//t    "array_creation_expression : NEW new_expr_type OPEN_BRACKET CLOSE_BRACKET OPEN_BRACKET_EXPR error CLOSE_BRACKET",
//t    "array_creation_expression : NEW new_expr_type error",
//t    "$$68 :",
//t    "new_expr_type : $$68 simple_type",
//t    "anonymous_type_expression : NEW OPEN_BRACE anonymous_type_parameters_opt_comma CLOSE_BRACE",
//t    "anonymous_type_expression : NEW OPEN_BRACE GENERATE_COMPLETION",
//t    "anonymous_type_parameters_opt_comma : anonymous_type_parameters_opt",
//t    "anonymous_type_parameters_opt_comma : anonymous_type_parameters COMMA",
//t    "anonymous_type_parameters_opt :",
//t    "anonymous_type_parameters_opt : anonymous_type_parameters",
//t    "anonymous_type_parameters : anonymous_type_parameter",
//t    "anonymous_type_parameters : anonymous_type_parameters COMMA anonymous_type_parameter",
//t    "anonymous_type_parameters : COMPLETE_COMPLETION",
//t    "anonymous_type_parameters : anonymous_type_parameter COMPLETE_COMPLETION",
//t    "anonymous_type_parameter : identifier_inside_body ASSIGN variable_initializer",
//t    "anonymous_type_parameter : identifier_inside_body",
//t    "anonymous_type_parameter : member_access",
//t    "anonymous_type_parameter : error",
//t    "opt_rank_specifier :",
//t    "opt_rank_specifier : rank_specifiers",
//t    "rank_specifiers : rank_specifier",
//t    "rank_specifiers : rank_specifier rank_specifiers",
//t    "rank_specifier : OPEN_BRACKET CLOSE_BRACKET",
//t    "rank_specifier : OPEN_BRACKET dim_separators CLOSE_BRACKET",
//t    "dim_separators : COMMA",
//t    "dim_separators : dim_separators COMMA",
//t    "opt_array_initializer :",
//t    "opt_array_initializer : array_initializer",
//t    "array_initializer : OPEN_BRACE CLOSE_BRACE",
//t    "array_initializer : OPEN_BRACE variable_initializer_list opt_comma CLOSE_BRACE",
//t    "variable_initializer_list : variable_initializer",
//t    "variable_initializer_list : variable_initializer_list COMMA variable_initializer",
//t    "typeof_expression : TYPEOF open_parens_any typeof_type_expression CLOSE_PARENS",
//t    "typeof_type_expression : type_and_void",
//t    "typeof_type_expression : error",
//t    "generic_dimension : GENERIC_DIMENSION",
//t    "qualified_alias_member : IDENTIFIER DOUBLE_COLON",
//t    "sizeof_expression : SIZEOF open_parens_any type CLOSE_PARENS",
//t    "sizeof_expression : SIZEOF open_parens_any type error",
//t    "checked_expression : CHECKED open_parens_any expression CLOSE_PARENS",
//t    "checked_expression : CHECKED error",
//t    "unchecked_expression : UNCHECKED open_parens_any expression CLOSE_PARENS",
//t    "unchecked_expression : UNCHECKED error",
//t    "pointer_member_access : primary_expression OP_PTR IDENTIFIER opt_type_argument_list",
//t    "$$69 :",
//t    "anonymous_method_expression : DELEGATE opt_anonymous_method_signature $$69 block",
//t    "$$70 :",
//t    "anonymous_method_expression : ASYNC DELEGATE opt_anonymous_method_signature $$70 block",
//t    "opt_anonymous_method_signature :",
//t    "opt_anonymous_method_signature : anonymous_method_signature",
//t    "$$71 :",
//t    "anonymous_method_signature : OPEN_PARENS $$71 opt_formal_parameter_list CLOSE_PARENS",
//t    "default_value_expression : DEFAULT open_parens_any type CLOSE_PARENS",
//t    "unary_expression : primary_expression",
//t    "unary_expression : BANG prefixed_unary_expression",
//t    "unary_expression : TILDE prefixed_unary_expression",
//t    "unary_expression : OPEN_PARENS_CAST type CLOSE_PARENS prefixed_unary_expression",
//t    "unary_expression : AWAIT prefixed_unary_expression",
//t    "unary_expression : BANG error",
//t    "unary_expression : TILDE error",
//t    "unary_expression : OPEN_PARENS_CAST type CLOSE_PARENS error",
//t    "unary_expression : AWAIT error",
//t    "prefixed_unary_expression : unary_expression",
//t    "prefixed_unary_expression : PLUS prefixed_unary_expression",
//t    "prefixed_unary_expression : MINUS prefixed_unary_expression",
//t    "prefixed_unary_expression : OP_INC prefixed_unary_expression",
//t    "prefixed_unary_expression : OP_DEC prefixed_unary_expression",
//t    "prefixed_unary_expression : STAR prefixed_unary_expression",
//t    "prefixed_unary_expression : BITWISE_AND prefixed_unary_expression",
//t    "prefixed_unary_expression : PLUS error",
//t    "prefixed_unary_expression : MINUS error",
//t    "prefixed_unary_expression : OP_INC error",
//t    "prefixed_unary_expression : OP_DEC error",
//t    "prefixed_unary_expression : STAR error",
//t    "prefixed_unary_expression : BITWISE_AND error",
//t    "multiplicative_expression : prefixed_unary_expression",
//t    "multiplicative_expression : multiplicative_expression STAR prefixed_unary_expression",
//t    "multiplicative_expression : multiplicative_expression DIV prefixed_unary_expression",
//t    "multiplicative_expression : multiplicative_expression PERCENT prefixed_unary_expression",
//t    "multiplicative_expression : multiplicative_expression STAR error",
//t    "multiplicative_expression : multiplicative_expression DIV error",
//t    "multiplicative_expression : multiplicative_expression PERCENT error",
//t    "additive_expression : multiplicative_expression",
//t    "additive_expression : additive_expression PLUS multiplicative_expression",
//t    "additive_expression : additive_expression MINUS multiplicative_expression",
//t    "additive_expression : additive_expression AS type",
//t    "additive_expression : additive_expression IS type opt_identifier",
//t    "additive_expression : additive_expression PLUS error",
//t    "additive_expression : additive_expression MINUS error",
//t    "additive_expression : additive_expression AS error",
//t    "additive_expression : additive_expression IS error",
//t    "additive_expression : AWAIT IS type",
//t    "additive_expression : AWAIT AS type",
//t    "shift_expression : additive_expression",
//t    "shift_expression : shift_expression OP_SHIFT_LEFT additive_expression",
//t    "shift_expression : shift_expression OP_SHIFT_RIGHT additive_expression",
//t    "shift_expression : shift_expression OP_SHIFT_LEFT error",
//t    "shift_expression : shift_expression OP_SHIFT_RIGHT error",
//t    "relational_expression : shift_expression",
//t    "relational_expression : relational_expression OP_LT shift_expression",
//t    "relational_expression : relational_expression OP_GT shift_expression",
//t    "relational_expression : relational_expression OP_LE shift_expression",
//t    "relational_expression : relational_expression OP_GE shift_expression",
//t    "relational_expression : relational_expression OP_LT error",
//t    "relational_expression : relational_expression OP_GT error",
//t    "relational_expression : relational_expression OP_LE error",
//t    "relational_expression : relational_expression OP_GE error",
//t    "equality_expression : relational_expression",
//t    "equality_expression : equality_expression OP_EQ relational_expression",
//t    "equality_expression : equality_expression OP_NE relational_expression",
//t    "equality_expression : equality_expression OP_EQ error",
//t    "equality_expression : equality_expression OP_NE error",
//t    "and_expression : equality_expression",
//t    "and_expression : and_expression BITWISE_AND equality_expression",
//t    "and_expression : and_expression BITWISE_AND error",
//t    "exclusive_or_expression : and_expression",
//t    "exclusive_or_expression : exclusive_or_expression CARRET and_expression",
//t    "exclusive_or_expression : exclusive_or_expression CARRET error",
//t    "inclusive_or_expression : exclusive_or_expression",
//t    "inclusive_or_expression : inclusive_or_expression BITWISE_OR exclusive_or_expression",
//t    "inclusive_or_expression : inclusive_or_expression BITWISE_OR error",
//t    "conditional_and_expression : inclusive_or_expression",
//t    "conditional_and_expression : conditional_and_expression OP_AND inclusive_or_expression",
//t    "conditional_and_expression : conditional_and_expression OP_AND error",
//t    "conditional_or_expression : conditional_and_expression",
//t    "conditional_or_expression : conditional_or_expression OP_OR conditional_and_expression",
//t    "conditional_or_expression : conditional_or_expression OP_OR error",
//t    "null_coalescing_expression : conditional_or_expression",
//t    "null_coalescing_expression : conditional_or_expression OP_COALESCING null_coalescing_expression",
//t    "conditional_expression : null_coalescing_expression",
//t    "conditional_expression : null_coalescing_expression INTERR expression COLON expression",
//t    "conditional_expression : null_coalescing_expression INTERR expression error",
//t    "conditional_expression : null_coalescing_expression INTERR expression COLON error",
//t    "conditional_expression : null_coalescing_expression INTERR expression COLON CLOSE_BRACE",
//t    "assignment_expression : prefixed_unary_expression ASSIGN expression",
//t    "assignment_expression : prefixed_unary_expression OP_MULT_ASSIGN expression",
//t    "assignment_expression : prefixed_unary_expression OP_DIV_ASSIGN expression",
//t    "assignment_expression : prefixed_unary_expression OP_MOD_ASSIGN expression",
//t    "assignment_expression : prefixed_unary_expression OP_ADD_ASSIGN expression",
//t    "assignment_expression : prefixed_unary_expression OP_SUB_ASSIGN expression",
//t    "assignment_expression : prefixed_unary_expression OP_SHIFT_LEFT_ASSIGN expression",
//t    "assignment_expression : prefixed_unary_expression OP_SHIFT_RIGHT_ASSIGN expression",
//t    "assignment_expression : prefixed_unary_expression OP_AND_ASSIGN expression",
//t    "assignment_expression : prefixed_unary_expression OP_OR_ASSIGN expression",
//t    "assignment_expression : prefixed_unary_expression OP_XOR_ASSIGN expression",
//t    "lambda_parameter_list : lambda_parameter",
//t    "lambda_parameter_list : lambda_parameter_list COMMA lambda_parameter",
//t    "lambda_parameter : parameter_modifier parameter_type identifier_inside_body",
//t    "lambda_parameter : parameter_type identifier_inside_body",
//t    "lambda_parameter : IDENTIFIER",
//t    "lambda_parameter : AWAIT",
//t    "opt_lambda_parameter_list :",
//t    "opt_lambda_parameter_list : lambda_parameter_list",
//t    "$$72 :",
//t    "lambda_expression_body : $$72 expression",
//t    "lambda_expression_body : block",
//t    "lambda_expression_body : error",
//t    "expression_or_error : expression",
//t    "expression_or_error : error",
//t    "$$73 :",
//t    "lambda_expression : IDENTIFIER ARROW $$73 lambda_expression_body",
//t    "$$74 :",
//t    "lambda_expression : AWAIT ARROW $$74 lambda_expression_body",
//t    "$$75 :",
//t    "lambda_expression : ASYNC identifier_inside_body ARROW $$75 lambda_expression_body",
//t    "$$76 :",
//t    "$$77 :",
//t    "lambda_expression : OPEN_PARENS_LAMBDA $$76 opt_lambda_parameter_list CLOSE_PARENS ARROW $$77 lambda_expression_body",
//t    "$$78 :",
//t    "$$79 :",
//t    "lambda_expression : ASYNC OPEN_PARENS_LAMBDA $$78 opt_lambda_parameter_list CLOSE_PARENS ARROW $$79 lambda_expression_body",
//t    "expression : assignment_expression",
//t    "expression : non_assignment_expression",
//t    "non_assignment_expression : conditional_expression",
//t    "non_assignment_expression : lambda_expression",
//t    "non_assignment_expression : query_expression",
//t    "non_assignment_expression : ARGLIST",
//t    "undocumented_expressions : REFVALUE OPEN_PARENS non_assignment_expression COMMA type CLOSE_PARENS",
//t    "undocumented_expressions : REFTYPE open_parens_any expression CLOSE_PARENS",
//t    "undocumented_expressions : MAKEREF open_parens_any expression CLOSE_PARENS",
//t    "constant_expression : expression",
//t    "boolean_expression : expression",
//t    "opt_primary_parameters :",
//t    "opt_primary_parameters : primary_parameters",
//t    "primary_parameters : OPEN_PARENS opt_formal_parameter_list CLOSE_PARENS",
//t    "opt_primary_parameters_with_class_base :",
//t    "opt_primary_parameters_with_class_base : class_base",
//t    "opt_primary_parameters_with_class_base : primary_parameters",
//t    "opt_primary_parameters_with_class_base : primary_parameters class_base",
//t    "$$80 :",
//t    "opt_primary_parameters_with_class_base : primary_parameters class_base OPEN_PARENS $$80 opt_argument_list CLOSE_PARENS",
//t    "$$81 :",
//t    "$$82 :",
//t    "$$83 :",
//t    "$$84 :",
//t    "class_declaration : opt_attributes opt_modifiers opt_partial CLASS $$81 type_declaration_name $$82 opt_primary_parameters_with_class_base opt_type_parameter_constraints_clauses $$83 OPEN_BRACE opt_class_member_declarations CLOSE_BRACE $$84 opt_semicolon",
//t    "opt_partial :",
//t    "opt_partial : PARTIAL",
//t    "opt_modifiers :",
//t    "opt_modifiers : modifiers",
//t    "modifiers : modifier",
//t    "modifiers : modifiers modifier",
//t    "modifier : NEW",
//t    "modifier : PUBLIC",
//t    "modifier : PROTECTED",
//t    "modifier : INTERNAL",
//t    "modifier : PRIVATE",
//t    "modifier : ABSTRACT",
//t    "modifier : SEALED",
//t    "modifier : STATIC",
//t    "modifier : READONLY",
//t    "modifier : VIRTUAL",
//t    "modifier : OVERRIDE",
//t    "modifier : EXTERN",
//t    "modifier : VOLATILE",
//t    "modifier : UNSAFE",
//t    "modifier : ASYNC",
//t    "opt_class_base :",
//t    "opt_class_base : class_base",
//t    "class_base : COLON type_list",
//t    "class_base : COLON type_list error",
//t    "opt_type_parameter_constraints_clauses :",
//t    "opt_type_parameter_constraints_clauses : type_parameter_constraints_clauses",
//t    "type_parameter_constraints_clauses : type_parameter_constraints_clause",
//t    "type_parameter_constraints_clauses : type_parameter_constraints_clauses type_parameter_constraints_clause",
//t    "type_parameter_constraints_clause : WHERE IDENTIFIER COLON type_parameter_constraints",
//t    "type_parameter_constraints_clause : WHERE IDENTIFIER error",
//t    "type_parameter_constraints : type_parameter_constraint",
//t    "type_parameter_constraints : type_parameter_constraints COMMA type_parameter_constraint",
//t    "type_parameter_constraint : type",
//t    "type_parameter_constraint : NEW OPEN_PARENS CLOSE_PARENS",
//t    "type_parameter_constraint : CLASS",
//t    "type_parameter_constraint : STRUCT",
//t    "opt_type_parameter_variance :",
//t    "opt_type_parameter_variance : type_parameter_variance",
//t    "type_parameter_variance : OUT",
//t    "type_parameter_variance : IN",
//t    "$$85 :",
//t    "block : OPEN_BRACE $$85 opt_statement_list block_end",
//t    "block_end : CLOSE_BRACE",
//t    "block_end : COMPLETE_COMPLETION",
//t    "$$86 :",
//t    "block_prepared : OPEN_BRACE $$86 opt_statement_list CLOSE_BRACE",
//t    "opt_statement_list :",
//t    "opt_statement_list : statement_list",
//t    "statement_list : statement",
//t    "statement_list : statement_list statement",
//t    "statement : block_variable_declaration",
//t    "statement : valid_declaration_statement",
//t    "statement : labeled_statement",
//t    "statement : error",
//t    "interactive_statement_list : interactive_statement",
//t    "interactive_statement_list : interactive_statement_list interactive_statement",
//t    "interactive_statement : block_variable_declaration",
//t    "interactive_statement : interactive_valid_declaration_statement",
//t    "interactive_statement : labeled_statement",
//t    "valid_declaration_statement : block",
//t    "valid_declaration_statement : empty_statement",
//t    "valid_declaration_statement : expression_statement",
//t    "valid_declaration_statement : selection_statement",
//t    "valid_declaration_statement : iteration_statement",
//t    "valid_declaration_statement : jump_statement",
//t    "valid_declaration_statement : try_statement",
//t    "valid_declaration_statement : checked_statement",
//t    "valid_declaration_statement : unchecked_statement",
//t    "valid_declaration_statement : lock_statement",
//t    "valid_declaration_statement : using_statement",
//t    "valid_declaration_statement : unsafe_statement",
//t    "valid_declaration_statement : fixed_statement",
//t    "interactive_valid_declaration_statement : block",
//t    "interactive_valid_declaration_statement : empty_statement",
//t    "interactive_valid_declaration_statement : interactive_expression_statement",
//t    "interactive_valid_declaration_statement : selection_statement",
//t    "interactive_valid_declaration_statement : iteration_statement",
//t    "interactive_valid_declaration_statement : jump_statement",
//t    "interactive_valid_declaration_statement : try_statement",
//t    "interactive_valid_declaration_statement : checked_statement",
//t    "interactive_valid_declaration_statement : unchecked_statement",
//t    "interactive_valid_declaration_statement : lock_statement",
//t    "interactive_valid_declaration_statement : using_statement",
//t    "interactive_valid_declaration_statement : unsafe_statement",
//t    "interactive_valid_declaration_statement : fixed_statement",
//t    "embedded_statement : valid_declaration_statement",
//t    "embedded_statement : block_variable_declaration",
//t    "embedded_statement : labeled_statement",
//t    "embedded_statement : error",
//t    "empty_statement : SEMICOLON",
//t    "$$87 :",
//t    "labeled_statement : identifier_inside_body COLON $$87 statement",
//t    "variable_type : variable_type_simple",
//t    "variable_type : variable_type_simple rank_specifiers",
//t    "variable_type_simple : primary_expression_or_type opt_nullable",
//t    "variable_type_simple : primary_expression_or_type pointer_stars",
//t    "variable_type_simple : builtin_types opt_nullable",
//t    "variable_type_simple : builtin_types pointer_stars",
//t    "variable_type_simple : VOID pointer_stars",
//t    "variable_type_simple : VOID",
//t    "pointer_stars : pointer_star",
//t    "pointer_stars : pointer_star pointer_stars",
//t    "pointer_star : STAR",
//t    "identifier_inside_body : IDENTIFIER",
//t    "identifier_inside_body : AWAIT",
//t    "$$88 :",
//t    "block_variable_declaration : variable_type identifier_inside_body $$88 opt_local_variable_initializer opt_variable_declarators SEMICOLON",
//t    "$$89 :",
//t    "block_variable_declaration : CONST variable_type identifier_inside_body $$89 const_variable_initializer opt_const_declarators SEMICOLON",
//t    "opt_local_variable_initializer :",
//t    "opt_local_variable_initializer : ASSIGN block_variable_initializer",
//t    "opt_local_variable_initializer : error",
//t    "opt_variable_declarators :",
//t    "opt_variable_declarators : variable_declarators",
//t    "opt_using_or_fixed_variable_declarators :",
//t    "opt_using_or_fixed_variable_declarators : variable_declarators",
//t    "variable_declarators : variable_declarator",
//t    "variable_declarators : variable_declarators variable_declarator",
//t    "variable_declarator : COMMA identifier_inside_body",
//t    "variable_declarator : COMMA identifier_inside_body ASSIGN block_variable_initializer",
//t    "const_variable_initializer :",
//t    "const_variable_initializer : ASSIGN constant_initializer_expr",
//t    "opt_const_declarators :",
//t    "opt_const_declarators : const_declarators",
//t    "const_declarators : const_declarator",
//t    "const_declarators : const_declarators const_declarator",
//t    "const_declarator : COMMA identifier_inside_body ASSIGN constant_initializer_expr",
//t    "block_variable_initializer : variable_initializer",
//t    "block_variable_initializer : STACKALLOC simple_type OPEN_BRACKET_EXPR expression CLOSE_BRACKET",
//t    "block_variable_initializer : STACKALLOC simple_type",
//t    "expression_statement : statement_expression SEMICOLON",
//t    "expression_statement : statement_expression COMPLETE_COMPLETION",
//t    "expression_statement : statement_expression CLOSE_BRACE",
//t    "interactive_expression_statement : interactive_statement_expression SEMICOLON",
//t    "interactive_expression_statement : interactive_statement_expression COMPLETE_COMPLETION",
//t    "statement_expression : expression",
//t    "interactive_statement_expression : expression",
//t    "interactive_statement_expression : error",
//t    "selection_statement : if_statement",
//t    "selection_statement : switch_statement",
//t    "if_statement : IF open_parens_any boolean_expression CLOSE_PARENS embedded_statement",
//t    "if_statement : IF open_parens_any boolean_expression CLOSE_PARENS embedded_statement ELSE embedded_statement",
//t    "if_statement : IF open_parens_any boolean_expression error",
//t    "$$90 :",
//t    "switch_statement : SWITCH open_parens_any expression CLOSE_PARENS OPEN_BRACE $$90 opt_switch_sections CLOSE_BRACE",
//t    "switch_statement : SWITCH open_parens_any expression error",
//t    "opt_switch_sections :",
//t    "opt_switch_sections : switch_sections",
//t    "switch_sections : switch_section",
//t    "switch_sections : switch_sections switch_section",
//t    "switch_sections : error",
//t    "switch_section : switch_labels statement_list",
//t    "switch_labels : switch_label",
//t    "switch_labels : switch_labels switch_label",
//t    "switch_label : CASE constant_expression COLON",
//t    "switch_label : CASE constant_expression error",
//t    "switch_label : DEFAULT_COLON",
//t    "iteration_statement : while_statement",
//t    "iteration_statement : do_statement",
//t    "iteration_statement : for_statement",
//t    "iteration_statement : foreach_statement",
//t    "while_statement : WHILE open_parens_any boolean_expression CLOSE_PARENS embedded_statement",
//t    "while_statement : WHILE open_parens_any boolean_expression error",
//t    "do_statement : DO embedded_statement WHILE open_parens_any boolean_expression CLOSE_PARENS SEMICOLON",
//t    "do_statement : DO embedded_statement error",
//t    "do_statement : DO embedded_statement WHILE open_parens_any boolean_expression error",
//t    "$$91 :",
//t    "for_statement : FOR open_parens_any $$91 for_statement_cont",
//t    "$$92 :",
//t    "for_statement_cont : opt_for_initializer SEMICOLON $$92 for_condition_and_iterator_part embedded_statement",
//t    "for_statement_cont : error",
//t    "$$93 :",
//t    "for_condition_and_iterator_part : opt_for_condition SEMICOLON $$93 for_iterator_part",
//t    "for_condition_and_iterator_part : opt_for_condition close_parens_close_brace",
//t    "for_iterator_part : opt_for_iterator CLOSE_PARENS",
//t    "for_iterator_part : opt_for_iterator CLOSE_BRACE",
//t    "close_parens_close_brace : CLOSE_PARENS",
//t    "close_parens_close_brace : CLOSE_BRACE",
//t    "opt_for_initializer :",
//t    "opt_for_initializer : for_initializer",
//t    "$$94 :",
//t    "for_initializer : variable_type identifier_inside_body $$94 opt_local_variable_initializer opt_variable_declarators",
//t    "for_initializer : statement_expression_list",
//t    "opt_for_condition :",
//t    "opt_for_condition : boolean_expression",
//t    "opt_for_iterator :",
//t    "opt_for_iterator : for_iterator",
//t    "for_iterator : statement_expression_list",
//t    "statement_expression_list : statement_expression",
//t    "statement_expression_list : statement_expression_list COMMA statement_expression",
//t    "foreach_statement : FOREACH open_parens_any type error",
//t    "foreach_statement : FOREACH open_parens_any type identifier_inside_body error",
//t    "$$95 :",
//t    "foreach_statement : FOREACH open_parens_any type identifier_inside_body IN expression CLOSE_PARENS $$95 embedded_statement",
//t    "jump_statement : break_statement",
//t    "jump_statement : continue_statement",
//t    "jump_statement : goto_statement",
//t    "jump_statement : return_statement",
//t    "jump_statement : throw_statement",
//t    "jump_statement : yield_statement",
//t    "break_statement : BREAK SEMICOLON",
//t    "continue_statement : CONTINUE SEMICOLON",
//t    "continue_statement : CONTINUE error",
//t    "goto_statement : GOTO identifier_inside_body SEMICOLON",
//t    "goto_statement : GOTO CASE constant_expression SEMICOLON",
//t    "goto_statement : GOTO DEFAULT SEMICOLON",
//t    "return_statement : RETURN opt_expression SEMICOLON",
//t    "return_statement : RETURN expression error",
//t    "return_statement : RETURN error",
//t    "throw_statement : THROW opt_expression SEMICOLON",
//t    "throw_statement : THROW expression error",
//t    "throw_statement : THROW error",
//t    "yield_statement : identifier_inside_body RETURN opt_expression SEMICOLON",
//t    "yield_statement : identifier_inside_body RETURN expression error",
//t    "yield_statement : identifier_inside_body BREAK SEMICOLON",
//t    "opt_expression :",
//t    "opt_expression : expression",
//t    "try_statement : TRY block catch_clauses",
//t    "try_statement : TRY block FINALLY block",
//t    "try_statement : TRY block catch_clauses FINALLY block",
//t    "try_statement : TRY block error",
//t    "catch_clauses : catch_clause",
//t    "catch_clauses : catch_clauses catch_clause",
//t    "opt_identifier :",
//t    "opt_identifier : identifier_inside_body",
//t    "catch_clause : CATCH opt_catch_filter block",
//t    "$$96 :",
//t    "catch_clause : CATCH open_parens_any type opt_identifier CLOSE_PARENS $$96 opt_catch_filter block_prepared",
//t    "catch_clause : CATCH open_parens_any error",
//t    "catch_clause : CATCH open_parens_any type opt_identifier CLOSE_PARENS error",
//t    "opt_catch_filter :",
//t    "opt_catch_filter : IF open_parens_any expression CLOSE_PARENS",
//t    "checked_statement : CHECKED block",
//t    "unchecked_statement : UNCHECKED block",
//t    "$$97 :",
//t    "unsafe_statement : UNSAFE $$97 block",
//t    "lock_statement : LOCK open_parens_any expression CLOSE_PARENS embedded_statement",
//t    "lock_statement : LOCK open_parens_any expression error",
//t    "$$98 :",
//t    "$$99 :",
//t    "fixed_statement : FIXED open_parens_any variable_type identifier_inside_body $$98 using_or_fixed_variable_initializer opt_using_or_fixed_variable_declarators CLOSE_PARENS $$99 embedded_statement",
//t    "$$100 :",
//t    "$$101 :",
//t    "using_statement : USING open_parens_any variable_type identifier_inside_body $$100 using_initialization CLOSE_PARENS $$101 embedded_statement",
//t    "using_statement : USING open_parens_any expression CLOSE_PARENS embedded_statement",
//t    "using_statement : USING open_parens_any expression error",
//t    "using_initialization : using_or_fixed_variable_initializer opt_using_or_fixed_variable_declarators",
//t    "using_initialization : error",
//t    "using_or_fixed_variable_initializer :",
//t    "using_or_fixed_variable_initializer : ASSIGN variable_initializer",
//t    "query_expression : first_from_clause query_body",
//t    "query_expression : nested_from_clause query_body",
//t    "query_expression : first_from_clause COMPLETE_COMPLETION",
//t    "query_expression : nested_from_clause COMPLETE_COMPLETION",
//t    "first_from_clause : FROM_FIRST identifier_inside_body IN expression",
//t    "first_from_clause : FROM_FIRST type identifier_inside_body IN expression",
//t    "nested_from_clause : FROM identifier_inside_body IN expression",
//t    "nested_from_clause : FROM type identifier_inside_body IN expression",
//t    "$$102 :",
//t    "from_clause : FROM identifier_inside_body IN $$102 expression_or_error",
//t    "$$103 :",
//t    "from_clause : FROM type identifier_inside_body IN $$103 expression_or_error",
//t    "query_body : query_body_clauses select_or_group_clause opt_query_continuation",
//t    "query_body : select_or_group_clause opt_query_continuation",
//t    "query_body : query_body_clauses COMPLETE_COMPLETION",
//t    "query_body : query_body_clauses error",
//t    "query_body : error",
//t    "$$104 :",
//t    "select_or_group_clause : SELECT $$104 expression_or_error",
//t    "$$105 :",
//t    "$$106 :",
//t    "select_or_group_clause : GROUP $$105 expression_or_error $$106 by_expression",
//t    "by_expression : BY expression_or_error",
//t    "by_expression : error",
//t    "query_body_clauses : query_body_clause",
//t    "query_body_clauses : query_body_clauses query_body_clause",
//t    "query_body_clause : from_clause",
//t    "query_body_clause : let_clause",
//t    "query_body_clause : where_clause",
//t    "query_body_clause : join_clause",
//t    "query_body_clause : orderby_clause",
//t    "$$107 :",
//t    "let_clause : LET identifier_inside_body ASSIGN $$107 expression_or_error",
//t    "$$108 :",
//t    "where_clause : WHERE $$108 expression_or_error",
//t    "$$109 :",
//t    "$$110 :",
//t    "$$111 :",
//t    "join_clause : JOIN identifier_inside_body IN $$109 expression_or_error ON $$110 expression_or_error EQUALS $$111 expression_or_error opt_join_into",
//t    "$$112 :",
//t    "$$113 :",
//t    "$$114 :",
//t    "join_clause : JOIN type identifier_inside_body IN $$112 expression_or_error ON $$113 expression_or_error EQUALS $$114 expression_or_error opt_join_into",
//t    "opt_join_into :",
//t    "opt_join_into : INTO identifier_inside_body",
//t    "$$115 :",
//t    "orderby_clause : ORDERBY $$115 orderings",
//t    "orderings : order_by",
//t    "$$116 :",
//t    "orderings : order_by COMMA $$116 orderings_then_by",
//t    "orderings_then_by : then_by",
//t    "$$117 :",
//t    "orderings_then_by : orderings_then_by COMMA $$117 then_by",
//t    "order_by : expression",
//t    "order_by : expression ASCENDING",
//t    "order_by : expression DESCENDING",
//t    "then_by : expression",
//t    "then_by : expression ASCENDING",
//t    "then_by : expression DESCENDING",
//t    "opt_query_continuation :",
//t    "$$118 :",
//t    "opt_query_continuation : INTO identifier_inside_body $$118 query_body",
//t    "interactive_parsing : EVAL_STATEMENT_PARSER EOF",
//t    "interactive_parsing : EVAL_USING_DECLARATIONS_UNIT_PARSER using_directives opt_COMPLETE_COMPLETION",
//t    "$$119 :",
//t    "interactive_parsing : EVAL_STATEMENT_PARSER $$119 interactive_statement_list opt_COMPLETE_COMPLETION",
//t    "interactive_parsing : EVAL_COMPILATION_UNIT_PARSER interactive_compilation_unit",
//t    "interactive_compilation_unit : opt_extern_alias_directives opt_using_directives",
//t    "interactive_compilation_unit : opt_extern_alias_directives opt_using_directives namespace_or_type_declarations",
//t    "opt_COMPLETE_COMPLETION :",
//t    "opt_COMPLETE_COMPLETION : COMPLETE_COMPLETION",
//t    "close_brace_or_complete_completion : CLOSE_BRACE",
//t    "close_brace_or_complete_completion : COMPLETE_COMPLETION",
//t    "documentation_parsing : DOC_SEE doc_cref",
//t    "doc_cref : doc_type_declaration_name opt_doc_method_sig",
//t    "doc_cref : builtin_types opt_doc_method_sig",
//t    "doc_cref : VOID opt_doc_method_sig",
//t    "doc_cref : builtin_types DOT IDENTIFIER opt_doc_method_sig",
//t    "doc_cref : doc_type_declaration_name DOT THIS",
//t    "$$120 :",
//t    "doc_cref : doc_type_declaration_name DOT THIS OPEN_BRACKET $$120 opt_doc_parameters CLOSE_BRACKET",
//t    "doc_cref : EXPLICIT OPERATOR type opt_doc_method_sig",
//t    "doc_cref : IMPLICIT OPERATOR type opt_doc_method_sig",
//t    "doc_cref : OPERATOR overloadable_operator opt_doc_method_sig",
//t    "doc_type_declaration_name : type_declaration_name",
//t    "doc_type_declaration_name : doc_type_declaration_name DOT type_declaration_name",
//t    "opt_doc_method_sig :",
//t    "$$121 :",
//t    "opt_doc_method_sig : OPEN_PARENS $$121 opt_doc_parameters CLOSE_PARENS",
//t    "opt_doc_parameters :",
//t    "opt_doc_parameters : doc_parameters",
//t    "doc_parameters : doc_parameter",
//t    "doc_parameters : doc_parameters COMMA doc_parameter",
//t    "doc_parameter : opt_parameter_modifier parameter_type",
//t  };
//t public static string getRule (int index) {
//t    return yyRule [index];
//t }
//t}
  protected static readonly string [] yyNames = {    
    "end-of-file",null,null,null,null,null,null,null,null,null,null,null,
    null,null,null,null,null,null,null,null,null,null,null,null,null,null,
    null,null,null,null,null,null,null,null,null,null,null,null,null,null,
    null,null,null,null,null,null,null,null,null,null,null,null,null,null,
    null,null,null,null,null,null,null,null,null,null,null,null,null,null,
    null,null,null,null,null,null,null,null,null,null,null,null,null,null,
    null,null,null,null,null,null,null,null,null,null,null,null,null,null,
    null,null,null,null,null,null,null,null,null,null,null,null,null,null,
    null,null,null,null,null,null,null,null,null,null,null,null,null,null,
    null,null,null,null,null,null,null,null,null,null,null,null,null,null,
    null,null,null,null,null,null,null,null,null,null,null,null,null,null,
    null,null,null,null,null,null,null,null,null,null,null,null,null,null,
    null,null,null,null,null,null,null,null,null,null,null,null,null,null,
    null,null,null,null,null,null,null,null,null,null,null,null,null,null,
    null,null,null,null,null,null,null,null,null,null,null,null,null,null,
    null,null,null,null,null,null,null,null,null,null,null,null,null,null,
    null,null,null,null,null,null,null,null,null,null,null,null,null,null,
    null,null,null,null,null,null,null,null,null,null,null,null,null,null,
    null,null,null,null,null,null,null,"EOF","NONE","ERROR",
    "FIRST_KEYWORD","ABSTRACT","AS","ADD","BASE","BOOL","BREAK","BYTE",
    "CASE","CATCH","CHAR","CHECKED","CLASS","CONST","CONTINUE","DECIMAL",
    "DEFAULT","DELEGATE","DO","DOUBLE","ELSE","ENUM","EVENT","EXPLICIT",
    "EXTERN","FALSE","FINALLY","FIXED","FLOAT","FOR","FOREACH","GOTO",
    "IF","IMPLICIT","IN","INT","INTERFACE","INTERNAL","IS","LOCK","LONG",
    "NAMESPACE","NEW","NULL","OBJECT","OPERATOR","OUT","OVERRIDE",
    "PARAMS","PRIVATE","PROTECTED","PUBLIC","READONLY","REF","RETURN",
    "REMOVE","SBYTE","SEALED","SHORT","SIZEOF","STACKALLOC","STATIC",
    "STRING","STRUCT","SWITCH","THIS","THROW","TRUE","TRY","TYPEOF",
    "UINT","ULONG","UNCHECKED","UNSAFE","USHORT","USING","VIRTUAL","VOID",
    "VOLATILE","WHERE","WHILE","ARGLIST","PARTIAL","ARROW","FROM",
    "FROM_FIRST","JOIN","ON","EQUALS","SELECT","GROUP","BY","LET",
    "ORDERBY","ASCENDING","DESCENDING","INTO","INTERR_NULLABLE",
    "EXTERN_ALIAS","REFVALUE","REFTYPE","MAKEREF","ASYNC","AWAIT",
    "INTERR_OPERATOR","GET","SET","LAST_KEYWORD","OPEN_BRACE",
    "CLOSE_BRACE","OPEN_BRACKET","CLOSE_BRACKET","OPEN_PARENS",
    "CLOSE_PARENS","DOT","COMMA","COLON","SEMICOLON","TILDE","PLUS",
    "MINUS","BANG","ASSIGN","OP_LT","OP_GT","BITWISE_AND","BITWISE_OR",
    "STAR","PERCENT","DIV","CARRET","INTERR","DOUBLE_COLON","OP_INC",
    "OP_DEC","OP_SHIFT_LEFT","OP_SHIFT_RIGHT","OP_LE","OP_GE","OP_EQ",
    "OP_NE","OP_AND","OP_OR","OP_MULT_ASSIGN","OP_DIV_ASSIGN",
    "OP_MOD_ASSIGN","OP_ADD_ASSIGN","OP_SUB_ASSIGN",
    "OP_SHIFT_LEFT_ASSIGN","OP_SHIFT_RIGHT_ASSIGN","OP_AND_ASSIGN",
    "OP_XOR_ASSIGN","OP_OR_ASSIGN","OP_PTR","OP_COALESCING",
    "OP_GENERICS_LT","OP_GENERICS_LT_DECL","OP_GENERICS_GT","LITERAL",
    "IDENTIFIER","OPEN_PARENS_LAMBDA","OPEN_PARENS_CAST",
    "GENERIC_DIMENSION","DEFAULT_COLON","OPEN_BRACKET_EXPR",
    "EVAL_STATEMENT_PARSER","EVAL_COMPILATION_UNIT_PARSER",
    "EVAL_USING_DECLARATIONS_UNIT_PARSER","DOC_SEE","GENERATE_COMPLETION",
    "COMPLETE_COMPLETION","UMINUS",
  };

  /** index-checked interface to yyNames[].
      @param token single character or %token value.
      @return token name or [illegal] or [unknown].
    */
//t  public static string yyname (int token) {
//t    if ((token < 0) || (token > yyNames.Length)) return "[illegal]";
//t    string name;
//t    if ((name = yyNames[token]) != null) return name;
//t    return "[unknown]";
//t  }

#pragma warning disable 414
  int yyExpectingState;
#pragma warning restore 414
  /** computes list of expected tokens on error by tracing the tables.
      @param state for which to compute the list.
      @return list of token names.
    */
  protected int [] yyExpectingTokens (int state){
    int token, n, len = 0;
    bool[] ok = new bool[yyNames.Length];
    if ((n = yySindex[state]) != 0)
      for (token = n < 0 ? -n : 0;
           (token < yyNames.Length) && (n+token < yyTable.Length); ++ token)
        if (yyCheck[n+token] == token && !ok[token] && yyNames[token] != null) {
          ++ len;
          ok[token] = true;
        }
    if ((n = yyRindex[state]) != 0)
      for (token = n < 0 ? -n : 0;
           (token < yyNames.Length) && (n+token < yyTable.Length); ++ token)
        if (yyCheck[n+token] == token && !ok[token] && yyNames[token] != null) {
          ++ len;
          ok[token] = true;
        }
    int [] result = new int [len];
    for (n = token = 0; n < len;  ++ token)
      if (ok[token]) result[n++] = token;
    return result;
  }
  protected string[] yyExpecting (int state) {
    int [] tokens = yyExpectingTokens (state);
    string [] result = new string[tokens.Length];
    for (int n = 0; n < tokens.Length;  n++)
      result[n++] = yyNames[tokens [n]];
    return result;
  }

  /** the generated parser, with debugging messages.
      Maintains a state and a value stack, currently with fixed maximum size.
      @param yyLex scanner.
      @param yydebug debug message writer implementing yyDebug, or null.
      @return result of the last reduction, if any.
      @throws yyException on irrecoverable parse error.
    */
  internal Object yyparse (yyParser.yyInput yyLex, Object yyd)
				 {
//t    this.debug = (yydebug.yyDebug)yyd;
    return yyparse(yyLex);
  }

  /** initial size and increment of the state/value stack [default 256].
      This is not final so that it can be overwritten outside of invocations
      of yyparse().
    */
  protected int yyMax;

  /** executed at the beginning of a reduce action.
      Used as $$ = yyDefault($1), prior to the user-specified action, if any.
      Can be overwritten to provide deep copy, etc.
      @param first value for $1, or null.
      @return first.
    */
  protected Object yyDefault (Object first) {
    return first;
  }

	static int[] global_yyStates;
	static object[] global_yyVals;
#pragma warning disable 649
	protected bool use_global_stacks;
#pragma warning restore 649
	object[] yyVals;					// value stack
	object yyVal;						// value stack ptr
	int yyToken;						// current input
	int yyTop;

  /** the generated parser.
      Maintains a state and a value stack, currently with fixed maximum size.
      @param yyLex scanner.
      @return result of the last reduction, if any.
      @throws yyException on irrecoverable parse error.
    */
  internal Object yyparse (yyParser.yyInput yyLex)
  {
    if (yyMax <= 0) yyMax = 256;		// initial size
    int yyState = 0;                   // state stack ptr
    int [] yyStates;               	// state stack 
    yyVal = null;
    yyToken = -1;
    int yyErrorFlag = 0;				// #tks to shift
	if (use_global_stacks && global_yyStates != null) {
		yyVals = global_yyVals;
		yyStates = global_yyStates;
   } else {
		yyVals = new object [yyMax];
		yyStates = new int [yyMax];
		if (use_global_stacks) {
			global_yyVals = yyVals;
			global_yyStates = yyStates;
		}
	}

    /*yyLoop:*/ for (yyTop = 0;; ++ yyTop) {
      if (yyTop >= yyStates.Length) {			// dynamically increase
        global::System.Array.Resize (ref yyStates, yyStates.Length+yyMax);
        global::System.Array.Resize (ref yyVals, yyVals.Length+yyMax);
      }
      yyStates[yyTop] = yyState;
      yyVals[yyTop] = yyVal;
//t      if (debug != null) debug.push(yyState, yyVal);

      /*yyDiscarded:*/ while (true) {	// discarding a token does not change stack
        int yyN;
        if ((yyN = yyDefRed[yyState]) == 0) {	// else [default] reduce (yyN)
          if (yyToken < 0) {
            yyToken = yyLex.advance() ? yyLex.token() : 0;
//t            if (debug != null)
//t              debug.lex(yyState, yyToken, yyname(yyToken), yyLex.value());
          }
          if ((yyN = yySindex[yyState]) != 0 && ((yyN += yyToken) >= 0)
              && (yyN < yyTable.Length) && (yyCheck[yyN] == yyToken)) {
//t            if (debug != null)
//t              debug.shift(yyState, yyTable[yyN], yyErrorFlag-1);
            yyState = yyTable[yyN];		// shift to yyN
            yyVal = yyLex.value();
            yyToken = -1;
            if (yyErrorFlag > 0) -- yyErrorFlag;
            goto continue_yyLoop;
          }
          if ((yyN = yyRindex[yyState]) != 0 && (yyN += yyToken) >= 0
              && yyN < yyTable.Length && yyCheck[yyN] == yyToken)
            yyN = yyTable[yyN];			// reduce (yyN)
          else
            switch (yyErrorFlag) {
  
            case 0:
              yyExpectingState = yyState;
              // yyerror(String.Format ("syntax error, got token `{0}'", yyname (yyToken)), yyExpecting(yyState));
//t              if (debug != null) debug.error("syntax error");
              if (yyToken == 0 /*eof*/ || yyToken == eof_token) throw new yyParser.yyUnexpectedEof ();
              goto case 1;
            case 1: case 2:
              yyErrorFlag = 3;
              do {
                if ((yyN = yySindex[yyStates[yyTop]]) != 0
                    && (yyN += Token.yyErrorCode) >= 0 && yyN < yyTable.Length
                    && yyCheck[yyN] == Token.yyErrorCode) {
//t                  if (debug != null)
//t                    debug.shift(yyStates[yyTop], yyTable[yyN], 3);
                  yyState = yyTable[yyN];
                  yyVal = yyLex.value();
                  goto continue_yyLoop;
                }
//t                if (debug != null) debug.pop(yyStates[yyTop]);
              } while (-- yyTop >= 0);
//t              if (debug != null) debug.reject();
              throw new yyParser.yyException("irrecoverable syntax error");
  
            case 3:
              if (yyToken == 0) {
//t                if (debug != null) debug.reject();
                throw new yyParser.yyException("irrecoverable syntax error at end-of-file");
              }
//t              if (debug != null)
//t                debug.discard(yyState, yyToken, yyname(yyToken),
//t  							yyLex.value());
              yyToken = -1;
              goto continue_yyDiscarded;		// leave stack alone
            }
        }
        int yyV = yyTop + 1-yyLen[yyN];
//t        if (debug != null)
//t          debug.reduce(yyState, yyStates[yyV-1], yyN, YYRules.getRule (yyN), yyLen[yyN]);
        yyVal = yyV > yyTop ? null : yyVals[yyV]; // yyVal = yyDefault(yyV > yyTop ? null : yyVals[yyV]);
        switch (yyN) {
case 1:
#line 381 "cs-parser.jay"
  {
		Lexer.check_incorrect_doc_comment ();
	  }
  break;
case 2:
#line 382 "cs-parser.jay"
  { Lexer.CompleteOnEOF = false; }
  break;
case 6:
  case_6();
  break;
case 7:
#line 401 "cs-parser.jay"
  {
		module.AddAttributes ((Attributes) yyVals[0+yyTop], current_namespace);
	  }
  break;
case 8:
  case_8();
  break;
case 13:
  case_13();
  break;
case 14:
#line 446 "cs-parser.jay"
  {
		Error_SyntaxError (yyToken);
	  }
  break;
case 17:
  case_17();
  break;
case 18:
  case_18();
  break;
case 19:
  case_19();
  break;
case 20:
  case_20();
  break;
case 21:
  case_21();
  break;
case 22:
  case_22();
  break;
case 23:
  case_23();
  break;
case 24:
  case_24();
  break;
case 27:
  case_27();
  break;
case 28:
  case_28();
  break;
case 29:
  case_29();
  break;
case 30:
  case_30();
  break;
case 43:
  case_43();
  break;
case 44:
#line 631 "cs-parser.jay"
  {
		current_namespace.DeclarationFound = true;
	  }
  break;
case 45:
  case_45();
  break;
case 53:
  case_53();
  break;
case 54:
  case_54();
  break;
case 55:
  case_55();
  break;
case 56:
  case_56();
  break;
case 57:
  case_57();
  break;
case 58:
  case_58();
  break;
case 59:
  case_59();
  break;
case 60:
  case_60();
  break;
case 61:
  case_61();
  break;
case 62:
  case_62();
  break;
case 63:
#line 755 "cs-parser.jay"
  { yyVal = "event"; }
  break;
case 64:
#line 756 "cs-parser.jay"
  { yyVal = "return"; }
  break;
case 65:
#line 763 "cs-parser.jay"
  {
		yyVal = new List<Attribute> (4) { (Attribute) yyVals[0+yyTop] };
	  }
  break;
case 66:
  case_66();
  break;
case 67:
#line 780 "cs-parser.jay"
  {
		++lexer.parsing_block;
	  }
  break;
case 68:
  case_68();
  break;
case 70:
#line 799 "cs-parser.jay"
  { yyVal = null; }
  break;
case 71:
#line 803 "cs-parser.jay"
  {
		yyVal = yyVals[-1+yyTop];
	  }
  break;
case 72:
#line 808 "cs-parser.jay"
  { yyVal = null; }
  break;
case 73:
  case_73();
  break;
case 74:
  case_74();
  break;
case 75:
  case_75();
  break;
case 76:
  case_76();
  break;
case 77:
#line 850 "cs-parser.jay"
  {
	  	yyVal = new Argument ((Expression) yyVals[0+yyTop]);
	  }
  break;
case 79:
  case_79();
  break;
case 80:
#line 863 "cs-parser.jay"
  {
		++lexer.parsing_block;
	  }
  break;
case 81:
  case_81();
  break;
case 82:
  case_82();
  break;
case 83:
#line 889 "cs-parser.jay"
  { yyVal = null; }
  break;
case 84:
#line 893 "cs-parser.jay"
  { 
		yyVal = Argument.AType.Ref;
	  }
  break;
case 85:
#line 897 "cs-parser.jay"
  { 
		yyVal = Argument.AType.Out;
	  }
  break;
case 88:
  case_88();
  break;
case 89:
  case_89();
  break;
case 103:
  case_103();
  break;
case 104:
  case_104();
  break;
case 105:
  case_105();
  break;
case 106:
#line 974 "cs-parser.jay"
  {
	  }
  break;
case 107:
  case_107();
  break;
case 108:
  case_108();
  break;
case 109:
  case_109();
  break;
case 110:
  case_110();
  break;
case 111:
  case_111();
  break;
case 112:
#line 1024 "cs-parser.jay"
  {
		Error_SyntaxError (yyToken);
	  }
  break;
case 113:
  case_113();
  break;
case 114:
  case_114();
  break;
case 115:
  case_115();
  break;
case 118:
#line 1073 "cs-parser.jay"
  {
		current_field.AddDeclarator ((FieldDeclarator) yyVals[0+yyTop]);
	  }
  break;
case 119:
#line 1077 "cs-parser.jay"
  {
		current_field.AddDeclarator ((FieldDeclarator) yyVals[0+yyTop]);
	  }
  break;
case 120:
  case_120();
  break;
case 121:
#line 1093 "cs-parser.jay"
  {
		++lexer.parsing_block;
	  }
  break;
case 122:
  case_122();
  break;
case 123:
  case_123();
  break;
case 126:
  case_126();
  break;
case 127:
  case_127();
  break;
case 128:
  case_128();
  break;
case 129:
  case_129();
  break;
case 130:
#line 1171 "cs-parser.jay"
  {
		report.Error (1641, GetLocation (yyVals[-1+yyTop]), "A fixed size buffer field must have the array size specifier after the field name");
	  }
  break;
case 132:
  case_132();
  break;
case 133:
  case_133();
  break;
case 136:
#line 1201 "cs-parser.jay"
  {
		current_field.AddDeclarator ((FieldDeclarator) yyVals[0+yyTop]);
	  }
  break;
case 137:
#line 1205 "cs-parser.jay"
  {
		current_field.AddDeclarator ((FieldDeclarator) yyVals[0+yyTop]);
	  }
  break;
case 138:
  case_138();
  break;
case 139:
#line 1218 "cs-parser.jay"
  {
		++lexer.parsing_block;
	  }
  break;
case 140:
  case_140();
  break;
case 143:
#line 1237 "cs-parser.jay"
  {
		current_field.AddDeclarator ((FieldDeclarator) yyVals[0+yyTop]);
	  }
  break;
case 144:
#line 1241 "cs-parser.jay"
  {
		current_field.AddDeclarator ((FieldDeclarator) yyVals[0+yyTop]);
	  }
  break;
case 145:
  case_145();
  break;
case 146:
#line 1257 "cs-parser.jay"
  {
		++lexer.parsing_block;
	  }
  break;
case 147:
  case_147();
  break;
case 148:
  case_148();
  break;
case 151:
  case_151();
  break;
case 152:
  case_152();
  break;
case 153:
  case_153();
  break;
case 154:
#line 1324 "cs-parser.jay"
  {
		valid_param_mod = ParameterModifierType.All;
	  }
  break;
case 155:
  case_155();
  break;
case 156:
  case_156();
  break;
case 157:
#line 1364 "cs-parser.jay"
  {
		lexer.parsing_generic_declaration = true;
	  }
  break;
case 158:
  case_158();
  break;
case 159:
#line 1374 "cs-parser.jay"
  {
		lexer.ConstraintsParsing = true;
	  }
  break;
case 160:
  case_160();
  break;
case 161:
  case_161();
  break;
case 162:
  case_162();
  break;
case 166:
#line 1452 "cs-parser.jay"
  { yyVal = null; }
  break;
case 167:
  case_167();
  break;
case 168:
  case_168();
  break;
case 169:
#line 1476 "cs-parser.jay"
  { yyVal = ParametersCompiled.EmptyReadOnlyParameters; }
  break;
case 171:
  case_171();
  break;
case 172:
  case_172();
  break;
case 173:
  case_173();
  break;
case 174:
  case_174();
  break;
case 175:
  case_175();
  break;
case 176:
  case_176();
  break;
case 177:
  case_177();
  break;
case 178:
#line 1534 "cs-parser.jay"
  {
		yyVal = new ParametersCompiled (new Parameter[] { (Parameter) yyVals[0+yyTop] } );
	  }
  break;
case 179:
#line 1538 "cs-parser.jay"
  {
		yyVal = new ParametersCompiled (new Parameter [] { new ArglistParameter (GetLocation (yyVals[0+yyTop])) }, true);
	  }
  break;
case 180:
  case_180();
  break;
case 181:
  case_181();
  break;
case 182:
  case_182();
  break;
case 183:
  case_183();
  break;
case 184:
  case_184();
  break;
case 185:
  case_185();
  break;
case 186:
  case_186();
  break;
case 187:
#line 1616 "cs-parser.jay"
  {
	  	++lexer.parsing_block;
	  }
  break;
case 188:
  case_188();
  break;
case 189:
#line 1657 "cs-parser.jay"
  { yyVal = Parameter.Modifier.NONE; }
  break;
case 191:
#line 1665 "cs-parser.jay"
  {
		yyVal = yyVals[0+yyTop];
	  }
  break;
case 192:
  case_192();
  break;
case 193:
  case_193();
  break;
case 194:
  case_194();
  break;
case 195:
  case_195();
  break;
case 196:
  case_196();
  break;
case 197:
  case_197();
  break;
case 198:
  case_198();
  break;
case 199:
  case_199();
  break;
case 200:
  case_200();
  break;
case 201:
#line 1755 "cs-parser.jay"
  {
		Error_DuplicateParameterModifier (GetLocation (yyVals[-1+yyTop]), Parameter.Modifier.PARAMS);
	  }
  break;
case 202:
  case_202();
  break;
case 203:
  case_203();
  break;
case 204:
  case_204();
  break;
case 205:
  case_205();
  break;
case 206:
  case_206();
  break;
case 207:
#line 1805 "cs-parser.jay"
  {
		current_property = null;
	  }
  break;
case 208:
  case_208();
  break;
case 209:
  case_209();
  break;
case 211:
  case_211();
  break;
case 212:
  case_212();
  break;
case 215:
#line 1867 "cs-parser.jay"
  {
	  	valid_param_mod = ParameterModifierType.Params | ParameterModifierType.DefaultValue;
	  }
  break;
case 216:
  case_216();
  break;
case 217:
  case_217();
  break;
case 218:
#line 1913 "cs-parser.jay"
  {
		lbag.AppendToMember (current_property, GetLocation (yyVals[-2+yyTop]), GetLocation (yyVals[0+yyTop]));
	  }
  break;
case 219:
  case_219();
  break;
case 224:
  case_224();
  break;
case 225:
  case_225();
  break;
case 226:
  case_226();
  break;
case 227:
  case_227();
  break;
case 228:
  case_228();
  break;
case 230:
  case_230();
  break;
case 231:
  case_231();
  break;
case 232:
#line 2050 "cs-parser.jay"
  {
	  }
  break;
case 233:
  case_233();
  break;
case 234:
  case_234();
  break;
case 235:
  case_235();
  break;
case 236:
  case_236();
  break;
case 237:
#line 2090 "cs-parser.jay"
  {
		Error_SyntaxError (yyToken);	  
	  }
  break;
case 240:
  case_240();
  break;
case 241:
  case_241();
  break;
case 242:
#line 2115 "cs-parser.jay"
  {
		report.Error (525, GetLocation (yyVals[0+yyTop]), "Interfaces cannot contain fields or constants");
	  }
  break;
case 243:
#line 2119 "cs-parser.jay"
  {
		report.Error (525, GetLocation (yyVals[0+yyTop]), "Interfaces cannot contain fields or constants");
	  }
  break;
case 248:
#line 2127 "cs-parser.jay"
  {
	  	report.Error (567, GetLocation (yyVals[0+yyTop]), "Interfaces cannot contain operators");
	  }
  break;
case 249:
#line 2131 "cs-parser.jay"
  {
	  	report.Error (526, GetLocation (yyVals[0+yyTop]), "Interfaces cannot contain contructors");
	  }
  break;
case 250:
#line 2135 "cs-parser.jay"
  {
	  	report.Error (524, GetLocation (yyVals[0+yyTop]), "Interfaces cannot declare classes, structs, interfaces, delegates, or enumerations");
	  }
  break;
case 251:
#line 2141 "cs-parser.jay"
  {
	  }
  break;
case 252:
  case_252();
  break;
case 254:
  case_254();
  break;
case 255:
#line 2182 "cs-parser.jay"
  {
		valid_param_mod = ParameterModifierType.DefaultValue;
	  }
  break;
case 256:
  case_256();
  break;
case 258:
#line 2228 "cs-parser.jay"
  { yyVal = Operator.OpType.LogicalNot; }
  break;
case 259:
#line 2229 "cs-parser.jay"
  { yyVal = Operator.OpType.OnesComplement; }
  break;
case 260:
#line 2230 "cs-parser.jay"
  { yyVal = Operator.OpType.Increment; }
  break;
case 261:
#line 2231 "cs-parser.jay"
  { yyVal = Operator.OpType.Decrement; }
  break;
case 262:
#line 2232 "cs-parser.jay"
  { yyVal = Operator.OpType.True; }
  break;
case 263:
#line 2233 "cs-parser.jay"
  { yyVal = Operator.OpType.False; }
  break;
case 264:
#line 2235 "cs-parser.jay"
  { yyVal = Operator.OpType.Addition; }
  break;
case 265:
#line 2236 "cs-parser.jay"
  { yyVal = Operator.OpType.Subtraction; }
  break;
case 266:
#line 2238 "cs-parser.jay"
  { yyVal = Operator.OpType.Multiply; }
  break;
case 267:
#line 2239 "cs-parser.jay"
  {  yyVal = Operator.OpType.Division; }
  break;
case 268:
#line 2240 "cs-parser.jay"
  { yyVal = Operator.OpType.Modulus; }
  break;
case 269:
#line 2241 "cs-parser.jay"
  { yyVal = Operator.OpType.BitwiseAnd; }
  break;
case 270:
#line 2242 "cs-parser.jay"
  { yyVal = Operator.OpType.BitwiseOr; }
  break;
case 271:
#line 2243 "cs-parser.jay"
  { yyVal = Operator.OpType.ExclusiveOr; }
  break;
case 272:
#line 2244 "cs-parser.jay"
  { yyVal = Operator.OpType.LeftShift; }
  break;
case 273:
#line 2245 "cs-parser.jay"
  { yyVal = Operator.OpType.RightShift; }
  break;
case 274:
#line 2246 "cs-parser.jay"
  { yyVal = Operator.OpType.Equality; }
  break;
case 275:
#line 2247 "cs-parser.jay"
  { yyVal = Operator.OpType.Inequality; }
  break;
case 276:
#line 2248 "cs-parser.jay"
  { yyVal = Operator.OpType.GreaterThan; }
  break;
case 277:
#line 2249 "cs-parser.jay"
  { yyVal = Operator.OpType.LessThan; }
  break;
case 278:
#line 2250 "cs-parser.jay"
  { yyVal = Operator.OpType.GreaterThanOrEqual; }
  break;
case 279:
#line 2251 "cs-parser.jay"
  { yyVal = Operator.OpType.LessThanOrEqual; }
  break;
case 280:
#line 2258 "cs-parser.jay"
  {
		valid_param_mod = ParameterModifierType.DefaultValue;
	  }
  break;
case 281:
  case_281();
  break;
case 282:
#line 2281 "cs-parser.jay"
  {
		valid_param_mod = ParameterModifierType.DefaultValue;
	  }
  break;
case 283:
  case_283();
  break;
case 284:
  case_284();
  break;
case 285:
  case_285();
  break;
case 286:
  case_286();
  break;
case 287:
  case_287();
  break;
case 288:
  case_288();
  break;
case 289:
  case_289();
  break;
case 291:
#line 2391 "cs-parser.jay"
  { current_block = null; yyVal = null; }
  break;
case 294:
#line 2403 "cs-parser.jay"
  {
		++lexer.parsing_block;
	  }
  break;
case 295:
  case_295();
  break;
case 296:
#line 2413 "cs-parser.jay"
  {
		++lexer.parsing_block;
	  }
  break;
case 297:
  case_297();
  break;
case 298:
  case_298();
  break;
case 299:
  case_299();
  break;
case 300:
  case_300();
  break;
case 301:
  case_301();
  break;
case 302:
  case_302();
  break;
case 303:
  case_303();
  break;
case 304:
  case_304();
  break;
case 305:
  case_305();
  break;
case 306:
  case_306();
  break;
case 307:
  case_307();
  break;
case 309:
#line 2536 "cs-parser.jay"
  {
	  	++lexer.parsing_block;
	  }
  break;
case 310:
  case_310();
  break;
case 313:
#line 2553 "cs-parser.jay"
  {
		current_event_field.AddDeclarator ((FieldDeclarator) yyVals[0+yyTop]);
	  }
  break;
case 314:
#line 2557 "cs-parser.jay"
  {
		current_event_field.AddDeclarator ((FieldDeclarator) yyVals[0+yyTop]);
	  }
  break;
case 315:
  case_315();
  break;
case 316:
#line 2570 "cs-parser.jay"
  {
		++lexer.parsing_block;
	  }
  break;
case 317:
  case_317();
  break;
case 318:
  case_318();
  break;
case 319:
#line 2595 "cs-parser.jay"
  {
		yyVal = yyVals[0+yyTop];
	  }
  break;
case 322:
  case_322();
  break;
case 323:
  case_323();
  break;
case 324:
  case_324();
  break;
case 325:
  case_325();
  break;
case 326:
  case_326();
  break;
case 327:
  case_327();
  break;
case 328:
  case_328();
  break;
case 329:
  case_329();
  break;
case 331:
  case_331();
  break;
case 332:
  case_332();
  break;
case 333:
  case_333();
  break;
case 334:
  case_334();
  break;
case 335:
  case_335();
  break;
case 336:
  case_336();
  break;
case 338:
#line 2758 "cs-parser.jay"
  {
		yyVal = yyVals[0+yyTop];
	 }
  break;
case 339:
  case_339();
  break;
case 342:
#line 2772 "cs-parser.jay"
  {
	  	lbag.AddLocation (yyVals[-1+yyTop], GetLocation (yyVals[0+yyTop]));
	  }
  break;
case 344:
  case_344();
  break;
case 345:
  case_345();
  break;
case 346:
  case_346();
  break;
case 347:
  case_347();
  break;
case 348:
  case_348();
  break;
case 350:
#line 2846 "cs-parser.jay"
  {
		valid_param_mod = ParameterModifierType.Ref | ParameterModifierType.Out | ParameterModifierType.Params | ParameterModifierType.DefaultValue;
	  }
  break;
case 351:
  case_351();
  break;
case 352:
#line 2865 "cs-parser.jay"
  {
		lexer.ConstraintsParsing = false;
	  }
  break;
case 353:
  case_353();
  break;
case 355:
  case_355();
  break;
case 357:
  case_357();
  break;
case 358:
  case_358();
  break;
case 360:
  case_360();
  break;
case 361:
  case_361();
  break;
case 362:
  case_362();
  break;
case 363:
  case_363();
  break;
case 365:
  case_365();
  break;
case 366:
  case_366();
  break;
case 367:
  case_367();
  break;
case 368:
  case_368();
  break;
case 369:
#line 2984 "cs-parser.jay"
  {
		lexer.parsing_generic_declaration = true;
	  }
  break;
case 370:
  case_370();
  break;
case 371:
  case_371();
  break;
case 373:
  case_373();
  break;
case 374:
  case_374();
  break;
case 375:
  case_375();
  break;
case 376:
  case_376();
  break;
case 377:
  case_377();
  break;
case 378:
  case_378();
  break;
case 380:
  case_380();
  break;
case 381:
  case_381();
  break;
case 382:
  case_382();
  break;
case 383:
  case_383();
  break;
case 384:
  case_384();
  break;
case 386:
#line 3102 "cs-parser.jay"
  {
		yyVal = new TypeExpression (compiler.BuiltinTypes.Void, GetLocation (yyVals[0+yyTop]));
	  }
  break;
case 387:
#line 3109 "cs-parser.jay"
  {
		lexer.parsing_generic_declaration = true;
	  }
  break;
case 389:
  case_389();
  break;
case 391:
  case_391();
  break;
case 393:
  case_393();
  break;
case 395:
#line 3147 "cs-parser.jay"
  {
		yyVal = new ComposedCast ((FullNamedExpression) yyVals[-1+yyTop], (ComposedTypeSpecifier) yyVals[0+yyTop]);
	  }
  break;
case 396:
  case_396();
  break;
case 397:
#line 3166 "cs-parser.jay"
  {
		yyVal = new ComposedCast ((ATypeNameExpression) yyVals[-1+yyTop], (ComposedTypeSpecifier) yyVals[0+yyTop]);
	  }
  break;
case 398:
  case_398();
  break;
case 399:
#line 3175 "cs-parser.jay"
  {
		yyVal = new ComposedCast ((FullNamedExpression) yyVals[-1+yyTop], (ComposedTypeSpecifier) yyVals[0+yyTop]);
	  }
  break;
case 400:
#line 3179 "cs-parser.jay"
  {
		yyVal = new ComposedCast (new TypeExpression (compiler.BuiltinTypes.Void, GetLocation (yyVals[-1+yyTop])), (ComposedTypeSpecifier) yyVals[0+yyTop]);
	  }
  break;
case 401:
  case_401();
  break;
case 402:
  case_402();
  break;
case 403:
  case_403();
  break;
case 404:
#line 3212 "cs-parser.jay"
  { yyVal = new TypeExpression (compiler.BuiltinTypes.Object, GetLocation (yyVals[0+yyTop])); }
  break;
case 405:
#line 3213 "cs-parser.jay"
  { yyVal = new TypeExpression (compiler.BuiltinTypes.String, GetLocation (yyVals[0+yyTop])); }
  break;
case 406:
#line 3214 "cs-parser.jay"
  { yyVal = new TypeExpression (compiler.BuiltinTypes.Bool, GetLocation (yyVals[0+yyTop])); }
  break;
case 407:
#line 3215 "cs-parser.jay"
  { yyVal = new TypeExpression (compiler.BuiltinTypes.Decimal, GetLocation (yyVals[0+yyTop])); }
  break;
case 408:
#line 3216 "cs-parser.jay"
  { yyVal = new TypeExpression (compiler.BuiltinTypes.Float, GetLocation (yyVals[0+yyTop])); }
  break;
case 409:
#line 3217 "cs-parser.jay"
  { yyVal = new TypeExpression (compiler.BuiltinTypes.Double, GetLocation (yyVals[0+yyTop])); }
  break;
case 411:
#line 3222 "cs-parser.jay"
  { yyVal = new TypeExpression (compiler.BuiltinTypes.SByte, GetLocation (yyVals[0+yyTop])); }
  break;
case 412:
#line 3223 "cs-parser.jay"
  { yyVal = new TypeExpression (compiler.BuiltinTypes.Byte, GetLocation (yyVals[0+yyTop])); }
  break;
case 413:
#line 3224 "cs-parser.jay"
  { yyVal = new TypeExpression (compiler.BuiltinTypes.Short, GetLocation (yyVals[0+yyTop])); }
  break;
case 414:
#line 3225 "cs-parser.jay"
  { yyVal = new TypeExpression (compiler.BuiltinTypes.UShort, GetLocation (yyVals[0+yyTop])); }
  break;
case 415:
#line 3226 "cs-parser.jay"
  { yyVal = new TypeExpression (compiler.BuiltinTypes.Int, GetLocation (yyVals[0+yyTop])); }
  break;
case 416:
#line 3227 "cs-parser.jay"
  { yyVal = new TypeExpression (compiler.BuiltinTypes.UInt, GetLocation (yyVals[0+yyTop])); }
  break;
case 417:
#line 3228 "cs-parser.jay"
  { yyVal = new TypeExpression (compiler.BuiltinTypes.Long, GetLocation (yyVals[0+yyTop])); }
  break;
case 418:
#line 3229 "cs-parser.jay"
  { yyVal = new TypeExpression (compiler.BuiltinTypes.ULong, GetLocation (yyVals[0+yyTop])); }
  break;
case 419:
#line 3230 "cs-parser.jay"
  { yyVal = new TypeExpression (compiler.BuiltinTypes.Char, GetLocation (yyVals[0+yyTop])); }
  break;
case 441:
  case_441();
  break;
case 445:
#line 3273 "cs-parser.jay"
  { yyVal = new NullLiteral (GetLocation (yyVals[0+yyTop])); }
  break;
case 446:
#line 3277 "cs-parser.jay"
  { yyVal = new BoolLiteral (compiler.BuiltinTypes, true, GetLocation (yyVals[0+yyTop])); }
  break;
case 447:
#line 3278 "cs-parser.jay"
  { yyVal = new BoolLiteral (compiler.BuiltinTypes, false, GetLocation (yyVals[0+yyTop])); }
  break;
case 452:
  case_452();
  break;
case 453:
#line 3311 "cs-parser.jay"
  {
		yyVal = new ParenthesizedExpression ((Expression) yyVals[-1+yyTop], GetLocation (yyVals[-2+yyTop]));
	  }
  break;
case 454:
  case_454();
  break;
case 455:
  case_455();
  break;
case 456:
  case_456();
  break;
case 457:
  case_457();
  break;
case 458:
  case_458();
  break;
case 459:
  case_459();
  break;
case 460:
  case_460();
  break;
case 461:
  case_461();
  break;
case 462:
#line 3372 "cs-parser.jay"
  {
		yyVal = new CompletionMemberAccess ((Expression) yyVals[-2+yyTop], null,GetLocation (yyVals[0+yyTop]));
	  }
  break;
case 463:
  case_463();
  break;
case 464:
#line 3380 "cs-parser.jay"
  {
		yyVal = new CompletionMemberAccess ((Expression) yyVals[-2+yyTop], null, lexer.Location);
	  }
  break;
case 465:
  case_465();
  break;
case 466:
  case_466();
  break;
case 467:
  case_467();
  break;
case 468:
  case_468();
  break;
case 469:
#line 3410 "cs-parser.jay"
  { yyVal = null; }
  break;
case 471:
  case_471();
  break;
case 472:
  case_472();
  break;
case 473:
#line 3432 "cs-parser.jay"
  { yyVal = null; }
  break;
case 474:
#line 3436 "cs-parser.jay"
  {
		yyVal = yyVals[0+yyTop];
	}
  break;
case 475:
  case_475();
  break;
case 476:
  case_476();
  break;
case 477:
  case_477();
  break;
case 478:
  case_478();
  break;
case 479:
  case_479();
  break;
case 480:
#line 3474 "cs-parser.jay"
  {
		yyVal = new CompletionElementInitializer (null, GetLocation (yyVals[0+yyTop]));
	  }
  break;
case 481:
  case_481();
  break;
case 482:
  case_482();
  break;
case 483:
  case_483();
  break;
case 484:
  case_484();
  break;
case 487:
#line 3513 "cs-parser.jay"
  { yyVal = null; }
  break;
case 489:
  case_489();
  break;
case 490:
  case_490();
  break;
case 491:
  case_491();
  break;
case 492:
  case_492();
  break;
case 493:
  case_493();
  break;
case 494:
#line 3565 "cs-parser.jay"
  {
		yyVal = new Argument ((Expression) yyVals[0+yyTop]);
	  }
  break;
case 498:
  case_498();
  break;
case 499:
  case_499();
  break;
case 500:
  case_500();
  break;
case 501:
  case_501();
  break;
case 503:
  case_503();
  break;
case 504:
  case_504();
  break;
case 505:
  case_505();
  break;
case 506:
  case_506();
  break;
case 507:
  case_507();
  break;
case 508:
  case_508();
  break;
case 509:
  case_509();
  break;
case 510:
  case_510();
  break;
case 511:
#line 3667 "cs-parser.jay"
  {
	  	yyVal = new Argument ((Expression) yyVals[0+yyTop]);
	  }
  break;
case 513:
#line 3675 "cs-parser.jay"
  {
		yyVal = new This (GetLocation (yyVals[0+yyTop]));
	  }
  break;
case 514:
  case_514();
  break;
case 515:
  case_515();
  break;
case 516:
#line 3695 "cs-parser.jay"
  {
		yyVal = new UnaryMutator (UnaryMutator.Mode.PostIncrement, (Expression) yyVals[-1+yyTop], GetLocation (yyVals[0+yyTop]));
	  }
  break;
case 517:
#line 3702 "cs-parser.jay"
  {
		yyVal = new UnaryMutator (UnaryMutator.Mode.PostDecrement, (Expression) yyVals[-1+yyTop], GetLocation (yyVals[0+yyTop]));
	  }
  break;
case 518:
  case_518();
  break;
case 519:
  case_519();
  break;
case 520:
  case_520();
  break;
case 521:
  case_521();
  break;
case 522:
  case_522();
  break;
case 523:
  case_523();
  break;
case 524:
  case_524();
  break;
case 525:
#line 3769 "cs-parser.jay"
  {
		++lexer.parsing_type;
	  }
  break;
case 526:
  case_526();
  break;
case 527:
  case_527();
  break;
case 528:
#line 3791 "cs-parser.jay"
  {
		yyVal = new EmptyCompletion ();
	  }
  break;
case 531:
#line 3800 "cs-parser.jay"
  { yyVal = null; }
  break;
case 533:
  case_533();
  break;
case 534:
  case_534();
  break;
case 535:
#line 3820 "cs-parser.jay"
  {
		yyVal = new EmptyCompletion ();
	  }
  break;
case 536:
#line 3824 "cs-parser.jay"
  {
	  	yyVal = yyVals[-1+yyTop];
	  }
  break;
case 537:
  case_537();
  break;
case 538:
  case_538();
  break;
case 539:
  case_539();
  break;
case 540:
  case_540();
  break;
case 544:
  case_544();
  break;
case 545:
  case_545();
  break;
case 546:
  case_546();
  break;
case 547:
#line 3884 "cs-parser.jay"
  {
		yyVal = 2;
	  }
  break;
case 548:
#line 3888 "cs-parser.jay"
  {
		yyVal = ((int) yyVals[-1+yyTop]) + 1;
	  }
  break;
case 549:
#line 3895 "cs-parser.jay"
  {
		yyVal = null;
	  }
  break;
case 550:
#line 3899 "cs-parser.jay"
  {
		yyVal = yyVals[0+yyTop];
	  }
  break;
case 551:
  case_551();
  break;
case 552:
  case_552();
  break;
case 553:
  case_553();
  break;
case 554:
  case_554();
  break;
case 555:
  case_555();
  break;
case 557:
  case_557();
  break;
case 558:
  case_558();
  break;
case 559:
  case_559();
  break;
case 560:
  case_560();
  break;
case 561:
  case_561();
  break;
case 562:
  case_562();
  break;
case 563:
  case_563();
  break;
case 564:
  case_564();
  break;
case 565:
  case_565();
  break;
case 566:
  case_566();
  break;
case 567:
#line 4031 "cs-parser.jay"
  {
		start_anonymous (false, (ParametersCompiled) yyVals[0+yyTop], false, GetLocation (yyVals[-1+yyTop]));
	  }
  break;
case 568:
#line 4035 "cs-parser.jay"
  {
		yyVal = end_anonymous ((ParametersBlock) yyVals[0+yyTop]);
	  }
  break;
case 569:
#line 4039 "cs-parser.jay"
  {
		start_anonymous (false, (ParametersCompiled) yyVals[0+yyTop], true, GetLocation (yyVals[-2+yyTop]));
	  }
  break;
case 570:
#line 4043 "cs-parser.jay"
  {
		yyVal = end_anonymous ((ParametersBlock) yyVals[0+yyTop]);
	  }
  break;
case 571:
#line 4050 "cs-parser.jay"
  {
		yyVal = ParametersCompiled.Undefined;
	  }
  break;
case 573:
#line 4058 "cs-parser.jay"
  {
	  	valid_param_mod = ParameterModifierType.Ref | ParameterModifierType.Out;
	  }
  break;
case 574:
  case_574();
  break;
case 575:
  case_575();
  break;
case 577:
#line 4082 "cs-parser.jay"
  {
		yyVal = new Unary (Unary.Operator.LogicalNot, (Expression) yyVals[0+yyTop], GetLocation (yyVals[-1+yyTop]));
	  }
  break;
case 578:
#line 4086 "cs-parser.jay"
  {
		yyVal = new Unary (Unary.Operator.OnesComplement, (Expression) yyVals[0+yyTop], GetLocation (yyVals[-1+yyTop]));
	  }
  break;
case 579:
  case_579();
  break;
case 580:
  case_580();
  break;
case 581:
  case_581();
  break;
case 582:
  case_582();
  break;
case 583:
  case_583();
  break;
case 584:
  case_584();
  break;
case 586:
#line 4150 "cs-parser.jay"
  { 
	  	yyVal = new Unary (Unary.Operator.UnaryPlus, (Expression) yyVals[0+yyTop], GetLocation (yyVals[-1+yyTop]));
	  }
  break;
case 587:
#line 4154 "cs-parser.jay"
  { 
		yyVal = new Unary (Unary.Operator.UnaryNegation, (Expression) yyVals[0+yyTop], GetLocation (yyVals[-1+yyTop]));
	  }
  break;
case 588:
#line 4158 "cs-parser.jay"
  {
		yyVal = new UnaryMutator (UnaryMutator.Mode.PreIncrement, (Expression) yyVals[0+yyTop], GetLocation (yyVals[-1+yyTop]));
	  }
  break;
case 589:
#line 4162 "cs-parser.jay"
  {
		yyVal = new UnaryMutator (UnaryMutator.Mode.PreDecrement, (Expression) yyVals[0+yyTop], GetLocation (yyVals[-1+yyTop]));
	  }
  break;
case 590:
#line 4166 "cs-parser.jay"
  {
		yyVal = new Indirection ((Expression) yyVals[0+yyTop], GetLocation (yyVals[-1+yyTop]));
	  }
  break;
case 591:
#line 4170 "cs-parser.jay"
  {
		yyVal = new Unary (Unary.Operator.AddressOf, (Expression) yyVals[0+yyTop], GetLocation (yyVals[-1+yyTop]));
	  }
  break;
case 592:
  case_592();
  break;
case 593:
  case_593();
  break;
case 594:
  case_594();
  break;
case 595:
  case_595();
  break;
case 596:
  case_596();
  break;
case 597:
  case_597();
  break;
case 599:
  case_599();
  break;
case 600:
  case_600();
  break;
case 601:
  case_601();
  break;
case 602:
  case_602();
  break;
case 603:
  case_603();
  break;
case 604:
  case_604();
  break;
case 606:
  case_606();
  break;
case 607:
  case_607();
  break;
case 608:
#line 4264 "cs-parser.jay"
  {
		yyVal = new As ((Expression) yyVals[-2+yyTop], (Expression) yyVals[0+yyTop], GetLocation (yyVals[-1+yyTop]));
	  }
  break;
case 609:
  case_609();
  break;
case 610:
  case_610();
  break;
case 611:
  case_611();
  break;
case 612:
  case_612();
  break;
case 613:
  case_613();
  break;
case 614:
  case_614();
  break;
case 615:
  case_615();
  break;
case 617:
  case_617();
  break;
case 618:
  case_618();
  break;
case 619:
  case_619();
  break;
case 620:
  case_620();
  break;
case 622:
  case_622();
  break;
case 623:
  case_623();
  break;
case 624:
  case_624();
  break;
case 625:
  case_625();
  break;
case 626:
  case_626();
  break;
case 627:
  case_627();
  break;
case 628:
  case_628();
  break;
case 629:
  case_629();
  break;
case 631:
  case_631();
  break;
case 632:
  case_632();
  break;
case 633:
  case_633();
  break;
case 634:
  case_634();
  break;
case 636:
  case_636();
  break;
case 637:
  case_637();
  break;
case 639:
  case_639();
  break;
case 640:
  case_640();
  break;
case 642:
  case_642();
  break;
case 643:
  case_643();
  break;
case 645:
  case_645();
  break;
case 646:
  case_646();
  break;
case 648:
  case_648();
  break;
case 649:
  case_649();
  break;
case 651:
  case_651();
  break;
case 653:
  case_653();
  break;
case 654:
  case_654();
  break;
case 655:
  case_655();
  break;
case 656:
  case_656();
  break;
case 657:
  case_657();
  break;
case 658:
  case_658();
  break;
case 659:
  case_659();
  break;
case 660:
  case_660();
  break;
case 661:
  case_661();
  break;
case 662:
  case_662();
  break;
case 663:
  case_663();
  break;
case 664:
  case_664();
  break;
case 665:
  case_665();
  break;
case 666:
  case_666();
  break;
case 667:
  case_667();
  break;
case 668:
  case_668();
  break;
case 669:
  case_669();
  break;
case 670:
  case_670();
  break;
case 671:
  case_671();
  break;
case 672:
  case_672();
  break;
case 673:
  case_673();
  break;
case 674:
#line 4652 "cs-parser.jay"
  { yyVal = ParametersCompiled.EmptyReadOnlyParameters; }
  break;
case 675:
  case_675();
  break;
case 676:
#line 4662 "cs-parser.jay"
  {
		start_block (Location.Null);
	  }
  break;
case 677:
  case_677();
  break;
case 679:
  case_679();
  break;
case 681:
  case_681();
  break;
case 682:
  case_682();
  break;
case 683:
  case_683();
  break;
case 684:
  case_684();
  break;
case 685:
  case_685();
  break;
case 686:
  case_686();
  break;
case 687:
  case_687();
  break;
case 688:
#line 4729 "cs-parser.jay"
  {
	  	valid_param_mod = ParameterModifierType.Ref | ParameterModifierType.Out;
	  }
  break;
case 689:
  case_689();
  break;
case 690:
  case_690();
  break;
case 691:
#line 4743 "cs-parser.jay"
  {
	  	valid_param_mod = ParameterModifierType.Ref | ParameterModifierType.Out;	  
	  }
  break;
case 692:
  case_692();
  break;
case 693:
  case_693();
  break;
case 699:
#line 4768 "cs-parser.jay"
  {
		yyVal = new ArglistAccess (GetLocation (yyVals[0+yyTop]));
	  }
  break;
case 700:
  case_700();
  break;
case 701:
  case_701();
  break;
case 702:
  case_702();
  break;
case 704:
#line 4797 "cs-parser.jay"
  {
		yyVal = new BooleanExpression ((Expression) yyVals[0+yyTop]);
	  }
  break;
case 705:
#line 4804 "cs-parser.jay"
  {
	  	yyVal = null;
	  }
  break;
case 707:
  case_707();
  break;
case 708:
#line 4825 "cs-parser.jay"
  {
	  	yyVal = null;
	  }
  break;
case 709:
#line 4829 "cs-parser.jay"
  {
		yyVal = null;
	  }
  break;
case 710:
#line 4833 "cs-parser.jay"
  {
		yyVal = yyVals[0+yyTop];
	  }
  break;
case 711:
#line 4837 "cs-parser.jay"
  {
		yyVal = yyVals[-1+yyTop];
	  }
  break;
case 712:
  case_712();
  break;
case 713:
  case_713();
  break;
case 714:
#line 4862 "cs-parser.jay"
  {
	  }
  break;
case 715:
  case_715();
  break;
case 716:
  case_716();
  break;
case 717:
  case_717();
  break;
case 718:
  case_718();
  break;
case 719:
#line 4914 "cs-parser.jay"
  { yyVal = null; }
  break;
case 720:
#line 4916 "cs-parser.jay"
  { yyVal = yyVals[0+yyTop]; }
  break;
case 721:
  case_721();
  break;
case 722:
#line 4929 "cs-parser.jay"
  {
		lexer.parsing_modifiers = false;		
	  }
  break;
case 724:
  case_724();
  break;
case 725:
  case_725();
  break;
case 726:
  case_726();
  break;
case 727:
  case_727();
  break;
case 728:
  case_728();
  break;
case 729:
  case_729();
  break;
case 730:
  case_730();
  break;
case 731:
  case_731();
  break;
case 732:
  case_732();
  break;
case 733:
  case_733();
  break;
case 734:
  case_734();
  break;
case 735:
  case_735();
  break;
case 736:
  case_736();
  break;
case 737:
  case_737();
  break;
case 738:
  case_738();
  break;
case 739:
  case_739();
  break;
case 742:
#line 5044 "cs-parser.jay"
  {
		current_type.SetBaseTypes ((List<FullNamedExpression>) yyVals[0+yyTop]);
	 }
  break;
case 743:
  case_743();
  break;
case 745:
#line 5058 "cs-parser.jay"
  {
		yyVal = yyVals[0+yyTop];
	  }
  break;
case 746:
  case_746();
  break;
case 747:
  case_747();
  break;
case 748:
  case_748();
  break;
case 749:
  case_749();
  break;
case 750:
  case_750();
  break;
case 751:
  case_751();
  break;
case 752:
  case_752();
  break;
case 753:
  case_753();
  break;
case 754:
#line 5150 "cs-parser.jay"
  {
		yyVal = new SpecialContraintExpr (SpecialConstraint.Class, GetLocation (yyVals[0+yyTop]));
	  }
  break;
case 755:
#line 5154 "cs-parser.jay"
  {
		yyVal = new SpecialContraintExpr (SpecialConstraint.Struct, GetLocation (yyVals[0+yyTop]));
	  }
  break;
case 756:
#line 5161 "cs-parser.jay"
  {
		yyVal = null;
	  }
  break;
case 757:
  case_757();
  break;
case 758:
#line 5175 "cs-parser.jay"
  {
		yyVal = new VarianceDecl (Variance.Covariant, GetLocation (yyVals[0+yyTop]));
	  }
  break;
case 759:
#line 5179 "cs-parser.jay"
  {
		yyVal = new VarianceDecl (Variance.Contravariant, GetLocation (yyVals[0+yyTop]));
	  }
  break;
case 760:
  case_760();
  break;
case 761:
#line 5204 "cs-parser.jay"
  {
		yyVal = yyVals[0+yyTop];
	  }
  break;
case 762:
  case_762();
  break;
case 763:
  case_763();
  break;
case 764:
  case_764();
  break;
case 765:
  case_765();
  break;
case 770:
#line 5248 "cs-parser.jay"
  {
		current_block.AddStatement ((Statement) yyVals[0+yyTop]);
	  }
  break;
case 771:
#line 5252 "cs-parser.jay"
  {
		current_block.AddStatement ((Statement) yyVals[0+yyTop]);
	  }
  break;
case 773:
  case_773();
  break;
case 776:
#line 5276 "cs-parser.jay"
  {
		current_block.AddStatement ((Statement) yyVals[0+yyTop]);
	  }
  break;
case 777:
#line 5280 "cs-parser.jay"
  {
		current_block.AddStatement ((Statement) yyVals[0+yyTop]);
	  }
  break;
case 806:
  case_806();
  break;
case 807:
  case_807();
  break;
case 808:
  case_808();
  break;
case 809:
  case_809();
  break;
case 810:
  case_810();
  break;
case 813:
  case_813();
  break;
case 814:
  case_814();
  break;
case 815:
  case_815();
  break;
case 816:
  case_816();
  break;
case 817:
#line 5424 "cs-parser.jay"
  {
		yyVal = new ComposedCast ((FullNamedExpression) yyVals[-1+yyTop], (ComposedTypeSpecifier) yyVals[0+yyTop]);
	  }
  break;
case 818:
#line 5428 "cs-parser.jay"
  {
		yyVal = new ComposedCast (new TypeExpression (compiler.BuiltinTypes.Void, GetLocation (yyVals[-1+yyTop])), (ComposedTypeSpecifier) yyVals[0+yyTop]);
	  }
  break;
case 819:
  case_819();
  break;
case 821:
  case_821();
  break;
case 822:
#line 5449 "cs-parser.jay"
  {
		yyVal = ComposedTypeSpecifier.CreatePointer (GetLocation (yyVals[0+yyTop]));
	  }
  break;
case 824:
#line 5457 "cs-parser.jay"
  {
	  	yyVal = Error_AwaitAsIdentifier (yyVals[0+yyTop]);
	  }
  break;
case 825:
  case_825();
  break;
case 826:
  case_826();
  break;
case 827:
  case_827();
  break;
case 828:
  case_828();
  break;
case 830:
  case_830();
  break;
case 831:
  case_831();
  break;
case 835:
  case_835();
  break;
case 838:
  case_838();
  break;
case 839:
  case_839();
  break;
case 840:
#line 5557 "cs-parser.jay"
  {
		report.Error (145, lexer.Location, "A const field requires a value to be provided");
	  }
  break;
case 841:
#line 5561 "cs-parser.jay"
  {
		current_variable.Initializer = (Expression) yyVals[0+yyTop];
	  }
  break;
case 846:
  case_846();
  break;
case 848:
  case_848();
  break;
case 849:
  case_849();
  break;
case 850:
  case_850();
  break;
case 851:
#line 5606 "cs-parser.jay"
  { yyVal = yyVals[-1+yyTop]; }
  break;
case 852:
  case_852();
  break;
case 853:
#line 5616 "cs-parser.jay"
  { yyVal = yyVals[-1+yyTop]; }
  break;
case 854:
#line 5617 "cs-parser.jay"
  { yyVal = yyVals[-1+yyTop]; }
  break;
case 855:
  case_855();
  break;
case 856:
  case_856();
  break;
case 857:
  case_857();
  break;
case 860:
  case_860();
  break;
case 861:
  case_861();
  break;
case 862:
  case_862();
  break;
case 863:
#line 5689 "cs-parser.jay"
  {
		start_block (GetLocation (yyVals[0+yyTop]));
	  }
  break;
case 864:
  case_864();
  break;
case 865:
  case_865();
  break;
case 866:
#line 5709 "cs-parser.jay"
  {
		report.Warning (1522, 1, current_block.StartLocation, "Empty switch block"); 
	  }
  break;
case 870:
#line 5719 "cs-parser.jay"
  {
		Error_SyntaxError (yyToken);
	  }
  break;
case 872:
  case_872();
  break;
case 873:
#line 5736 "cs-parser.jay"
  {
		current_block.AddStatement ((Statement) yyVals[0+yyTop]);
	  }
  break;
case 874:
  case_874();
  break;
case 875:
  case_875();
  break;
case 876:
#line 5753 "cs-parser.jay"
  {
		yyVal = new SwitchLabel (null, GetLocation (yyVals[0+yyTop]));
	  }
  break;
case 881:
  case_881();
  break;
case 882:
  case_882();
  break;
case 883:
  case_883();
  break;
case 884:
  case_884();
  break;
case 885:
  case_885();
  break;
case 886:
  case_886();
  break;
case 887:
#line 5813 "cs-parser.jay"
  {
		yyVal = yyVals[0+yyTop];
	  }
  break;
case 888:
  case_888();
  break;
case 889:
  case_889();
  break;
case 890:
  case_890();
  break;
case 891:
  case_891();
  break;
case 892:
#line 5854 "cs-parser.jay"
  {
		yyVal = new Tuple<Location,Location> (GetLocation (yyVals[-2+yyTop]), (Location) yyVals[0+yyTop]);
	  }
  break;
case 893:
  case_893();
  break;
case 894:
  case_894();
  break;
case 895:
  case_895();
  break;
case 897:
#line 5882 "cs-parser.jay"
  { lexer.putback ('}'); }
  break;
case 898:
#line 5886 "cs-parser.jay"
  { yyVal = new EmptyStatement (lexer.Location); }
  break;
case 900:
  case_900();
  break;
case 901:
  case_901();
  break;
case 903:
#line 5910 "cs-parser.jay"
  { yyVal = null; }
  break;
case 905:
#line 5915 "cs-parser.jay"
  { yyVal = new EmptyStatement (lexer.Location); }
  break;
case 909:
  case_909();
  break;
case 910:
  case_910();
  break;
case 911:
  case_911();
  break;
case 912:
  case_912();
  break;
case 913:
  case_913();
  break;
case 920:
  case_920();
  break;
case 921:
  case_921();
  break;
case 922:
  case_922();
  break;
case 923:
  case_923();
  break;
case 924:
  case_924();
  break;
case 925:
  case_925();
  break;
case 926:
  case_926();
  break;
case 927:
  case_927();
  break;
case 928:
  case_928();
  break;
case 929:
  case_929();
  break;
case 930:
  case_930();
  break;
case 931:
  case_931();
  break;
case 932:
  case_932();
  break;
case 933:
  case_933();
  break;
case 934:
  case_934();
  break;
case 937:
#line 6139 "cs-parser.jay"
  {
		yyVal = new TryCatch ((Block) yyVals[-1+yyTop], (List<Catch>) yyVals[0+yyTop], GetLocation (yyVals[-2+yyTop]), false);
	  }
  break;
case 938:
  case_938();
  break;
case 939:
  case_939();
  break;
case 940:
  case_940();
  break;
case 941:
  case_941();
  break;
case 942:
  case_942();
  break;
case 945:
  case_945();
  break;
case 946:
  case_946();
  break;
case 947:
  case_947();
  break;
case 948:
  case_948();
  break;
case 949:
  case_949();
  break;
case 951:
  case_951();
  break;
case 952:
#line 6259 "cs-parser.jay"
  {
		yyVal = new Checked ((Block) yyVals[0+yyTop], GetLocation (yyVals[-1+yyTop]));
	  }
  break;
case 953:
#line 6266 "cs-parser.jay"
  {
		yyVal = new Unchecked ((Block) yyVals[0+yyTop], GetLocation (yyVals[-1+yyTop]));
	  }
  break;
case 954:
  case_954();
  break;
case 955:
#line 6276 "cs-parser.jay"
  {
		yyVal = new Unsafe ((Block) yyVals[0+yyTop], GetLocation (yyVals[-2+yyTop]));
	  }
  break;
case 956:
  case_956();
  break;
case 957:
  case_957();
  break;
case 958:
  case_958();
  break;
case 959:
  case_959();
  break;
case 960:
  case_960();
  break;
case 961:
  case_961();
  break;
case 962:
  case_962();
  break;
case 963:
  case_963();
  break;
case 964:
  case_964();
  break;
case 965:
  case_965();
  break;
case 967:
  case_967();
  break;
case 968:
#line 6380 "cs-parser.jay"
  {
		Error_MissingInitializer (lexer.Location);
	  }
  break;
case 969:
  case_969();
  break;
case 970:
  case_970();
  break;
case 971:
  case_971();
  break;
case 972:
  case_972();
  break;
case 973:
  case_973();
  break;
case 974:
  case_974();
  break;
case 975:
  case_975();
  break;
case 976:
  case_976();
  break;
case 977:
  case_977();
  break;
case 978:
#line 6484 "cs-parser.jay"
  {
		current_block = new Linq.QueryBlock (current_block, lexer.Location);
	  }
  break;
case 979:
  case_979();
  break;
case 980:
#line 6500 "cs-parser.jay"
  {
		current_block = new Linq.QueryBlock (current_block, lexer.Location);
	  }
  break;
case 981:
  case_981();
  break;
case 982:
  case_982();
  break;
case 983:
  case_983();
  break;
case 985:
  case_985();
  break;
case 986:
  case_986();
  break;
case 987:
#line 6564 "cs-parser.jay"
  {
	  	current_block = new Linq.QueryBlock (current_block, lexer.Location);
	  }
  break;
case 988:
  case_988();
  break;
case 989:
  case_989();
  break;
case 990:
  case_990();
  break;
case 991:
  case_991();
  break;
case 992:
#line 6603 "cs-parser.jay"
  {
	  	yyVal = new object[] { yyVals[0+yyTop], GetLocation (yyVals[-1+yyTop]) };
	  }
  break;
case 993:
  case_993();
  break;
case 995:
  case_995();
  break;
case 1001:
#line 6632 "cs-parser.jay"
  {
	  	current_block = new Linq.QueryBlock (current_block, lexer.Location);
	  }
  break;
case 1002:
  case_1002();
  break;
case 1003:
#line 6651 "cs-parser.jay"
  {
	  	current_block = new Linq.QueryBlock (current_block, lexer.Location);
	  }
  break;
case 1004:
  case_1004();
  break;
case 1005:
  case_1005();
  break;
case 1006:
  case_1006();
  break;
case 1007:
  case_1007();
  break;
case 1008:
  case_1008();
  break;
case 1009:
  case_1009();
  break;
case 1010:
  case_1010();
  break;
case 1011:
  case_1011();
  break;
case 1012:
  case_1012();
  break;
case 1014:
#line 6796 "cs-parser.jay"
  {
		yyVal = yyVals[0+yyTop];
	  }
  break;
case 1015:
#line 6803 "cs-parser.jay"
  {
		current_block = new Linq.QueryBlock (current_block, lexer.Location);
	  }
  break;
case 1016:
  case_1016();
  break;
case 1018:
  case_1018();
  break;
case 1019:
  case_1019();
  break;
case 1021:
  case_1021();
  break;
case 1022:
  case_1022();
  break;
case 1023:
#line 6849 "cs-parser.jay"
  {
		yyVal = new Linq.OrderByAscending ((Linq.QueryBlock) current_block, (Expression)yyVals[0+yyTop]);	
	  }
  break;
case 1024:
  case_1024();
  break;
case 1025:
  case_1025();
  break;
case 1026:
#line 6866 "cs-parser.jay"
  {
		yyVal = new Linq.ThenByAscending ((Linq.QueryBlock) current_block, (Expression)yyVals[0+yyTop]);	
	  }
  break;
case 1027:
  case_1027();
  break;
case 1028:
  case_1028();
  break;
case 1030:
  case_1030();
  break;
case 1031:
  case_1031();
  break;
case 1034:
  case_1034();
  break;
case 1035:
  case_1035();
  break;
case 1043:
#line 6991 "cs-parser.jay"
  {
		module.DocumentationBuilder.ParsedName = (MemberName) yyVals[0+yyTop];
	  }
  break;
case 1044:
#line 6998 "cs-parser.jay"
  {
		module.DocumentationBuilder.ParsedParameters = (List<DocumentationParameter>)yyVals[0+yyTop];
	  }
  break;
case 1045:
  case_1045();
  break;
case 1046:
  case_1046();
  break;
case 1047:
  case_1047();
  break;
case 1048:
#line 7021 "cs-parser.jay"
  {
		yyVal = new MemberName ((MemberName) yyVals[-2+yyTop], MemberCache.IndexerNameAlias, Location.Null);
	  }
  break;
case 1049:
#line 7025 "cs-parser.jay"
  {
		valid_param_mod = ParameterModifierType.Ref | ParameterModifierType.Out;
	  }
  break;
case 1050:
  case_1050();
  break;
case 1051:
  case_1051();
  break;
case 1052:
  case_1052();
  break;
case 1053:
  case_1053();
  break;
case 1055:
#line 7061 "cs-parser.jay"
  {
		yyVal = new MemberName (((MemberName) yyVals[-2+yyTop]), (MemberName) yyVals[0+yyTop]);
	  }
  break;
case 1057:
#line 7069 "cs-parser.jay"
  {
		valid_param_mod = ParameterModifierType.Ref | ParameterModifierType.Out;
	  }
  break;
case 1058:
#line 7073 "cs-parser.jay"
  {
		yyVal = yyVals[-1+yyTop];
	  }
  break;
case 1059:
#line 7080 "cs-parser.jay"
  {
		yyVal = new List<DocumentationParameter> (0);
	  }
  break;
case 1061:
  case_1061();
  break;
case 1062:
  case_1062();
  break;
case 1063:
  case_1063();
  break;
#line default
        }
        yyTop -= yyLen[yyN];
        yyState = yyStates[yyTop];
        int yyM = yyLhs[yyN];
        if (yyState == 0 && yyM == 0) {
//t          if (debug != null) debug.shift(0, yyFinal);
          yyState = yyFinal;
          if (yyToken < 0) {
            yyToken = yyLex.advance() ? yyLex.token() : 0;
//t            if (debug != null)
//t               debug.lex(yyState, yyToken,yyname(yyToken), yyLex.value());
          }
          if (yyToken == 0) {
//t            if (debug != null) debug.accept(yyVal);
            return yyVal;
          }
          goto continue_yyLoop;
        }
        if (((yyN = yyGindex[yyM]) != 0) && ((yyN += yyState) >= 0)
            && (yyN < yyTable.Length) && (yyCheck[yyN] == yyState))
          yyState = yyTable[yyN];
        else
          yyState = yyDgoto[yyM];
//t        if (debug != null) debug.shift(yyStates[yyTop], yyState);
	 goto continue_yyLoop;
      continue_yyDiscarded: ;	// implements the named-loop continue: 'continue yyDiscarded'
      }
    continue_yyLoop: ;		// implements the named-loop continue: 'continue yyLoop'
    }
  }

/*
 All more than 3 lines long rules are wrapped into a method
*/
void case_6()
#line 389 "cs-parser.jay"
{
		if (yyVals[0+yyTop] != null) {
			Attributes attrs = (Attributes) yyVals[0+yyTop];
			report.Error (1730, attrs.Attrs [0].Location,
				"Assembly and module attributes must precede all other elements except using clauses and extern alias declarations");

			current_namespace.UnattachedAttributes = attrs;
		}
	  }

void case_8()
#line 403 "cs-parser.jay"
{
		if (yyToken == Token.EXTERN_ALIAS)
			report.Error (439, lexer.Location, "An extern alias declaration must precede all other elements");
		else
			Error_SyntaxError (yyToken);
	  }

void case_13()
#line 423 "cs-parser.jay"
{
		var lt = (LocatedToken) yyVals[-2+yyTop];
		string s = lt.Value;
		if (s != "alias") {
			syntax_error (lt.Location, "`alias' expected");
		} else {
			if (lang_version == LanguageVersion.ISO_1)
				FeatureIsNotAvailable (lt.Location, "external alias");

			lt = (LocatedToken) yyVals[-1+yyTop];
			if (lt.Value == QualifiedAliasMember.GlobalAlias) {
				RootNamespace.Error_GlobalNamespaceRedefined (report, lt.Location);
			}
			
			var na = new UsingExternAlias (new SimpleMemberName (lt.Value, lt.Location), GetLocation (yyVals[-3+yyTop]));
			current_namespace.AddUsing (na);
			
			lbag.AddLocation (na, GetLocation (yyVals[-2+yyTop]), GetLocation (yyVals[0+yyTop]));
		}
	  }

void case_17()
#line 456 "cs-parser.jay"
{
		if (doc_support)
			Lexer.doc_state = XmlCommentState.Allowed;
	  }

void case_18()
#line 464 "cs-parser.jay"
{
		var un = new UsingNamespace ((ATypeNameExpression) yyVals[-1+yyTop], GetLocation (yyVals[-2+yyTop]));
		current_namespace.AddUsing (un);
		
		lbag.AddLocation (un, GetLocation (yyVals[0+yyTop]));
	  }

void case_19()
#line 471 "cs-parser.jay"
{
		var lt = (LocatedToken) yyVals[-3+yyTop];
		if (lang_version != LanguageVersion.ISO_1 && lt.Value == "global") {
			report.Warning (440, 2, lt.Location,
			 "An alias named `global' will not be used when resolving `global::'. The global namespace will be used instead");
		}

		var un = new UsingAliasNamespace (new SimpleMemberName (lt.Value, lt.Location), (ATypeNameExpression) yyVals[-1+yyTop], GetLocation (yyVals[-4+yyTop]));
		current_namespace.AddUsing (un);
		
		lbag.AddLocation (un, GetLocation (yyVals[-2+yyTop]), GetLocation (yyVals[0+yyTop]));
	  }

void case_20()
#line 484 "cs-parser.jay"
{
		Error_SyntaxError (yyToken);
		yyVal = null;
	 }

void case_21()
#line 497 "cs-parser.jay"
{
		Attributes attrs = (Attributes) yyVals[-2+yyTop];
		var name = (MemberName) yyVals[0+yyTop];
		if (attrs != null) {
			bool valid_global_attrs = true;
			if ((current_namespace.DeclarationFound || current_namespace != file)) {
				valid_global_attrs = false;
			} else {
				foreach (var a in attrs.Attrs) {
					if (a.ExplicitTarget == "assembly" || a.ExplicitTarget == "module")
						continue;
						
					valid_global_attrs = false;
					break;
				}
			}
			
			if (!valid_global_attrs)
				report.Error (1671, name.Location, "A namespace declaration cannot have modifiers or attributes");
		}
	
		module.AddAttributes (attrs, current_namespace);
		
		var ns = new NamespaceContainer (name, current_namespace);
		current_namespace.AddTypeContainer (ns);
		current_container = current_namespace = ns;
	  }

void case_22()
#line 525 "cs-parser.jay"
{
		if (doc_support)
			Lexer.doc_state = XmlCommentState.Allowed;
	  }

void case_23()
#line 530 "cs-parser.jay"
{
		if (yyVals[0+yyTop] != null)
			lbag.AddLocation (current_container, GetLocation (yyVals[-9+yyTop]), GetLocation (yyVals[-6+yyTop]), GetLocation (yyVals[-1+yyTop]), GetLocation (yyVals[0+yyTop]));
		else
			lbag.AddLocation (current_container, GetLocation (yyVals[-9+yyTop]), GetLocation (yyVals[-6+yyTop]), GetLocation (yyVals[-1+yyTop]));
	  
		current_container = current_namespace = current_namespace.Parent;
	  }

void case_24()
#line 539 "cs-parser.jay"
{
		report.Error (1514, lexer.Location, "Unexpected symbol `{0}', expecting `.' or `{{'", GetSymbolName (yyToken));

		var name = (MemberName) yyVals[0+yyTop];		
		var ns = new NamespaceContainer (name, current_namespace);
		lbag.AddLocation (ns, GetLocation (yyVals[-1+yyTop]));
		current_namespace.AddTypeContainer (ns);
	  }

void case_27()
#line 553 "cs-parser.jay"
{
		Error_SyntaxError (yyToken);
	  	yyVal = null;
	  }

void case_28()
#line 561 "cs-parser.jay"
{
		var lt = (LocatedToken) yyVals[0+yyTop];
		yyVal = new MemberName (lt.Value, lt.Location);
	  }

void case_29()
#line 566 "cs-parser.jay"
{
		var lt = (LocatedToken) yyVals[0+yyTop];
		yyVal = new MemberName ((MemberName) yyVals[-2+yyTop], lt.Value, lt.Location);		
		lbag.AddLocation (yyVal, GetLocation (yyVals[-1+yyTop]));
	  }

void case_30()
#line 572 "cs-parser.jay"
{
		Error_SyntaxError (yyToken);
		yyVal = new MemberName ("<invalid>", lexer.Location);
	  }

void case_43()
#line 610 "cs-parser.jay"
{
		if (yyVals[0+yyTop] != null) {
			TypeContainer ds = (TypeContainer)yyVals[0+yyTop];

			if ((ds.ModFlags & (Modifiers.PRIVATE | Modifiers.PROTECTED)) != 0){
				report.Error (1527, ds.Location, 
				"Namespace elements cannot be explicitly declared as private, protected or protected internal");
			}

			/* Here is a trick, for explicit attributes we don't know where they belong to until*/
			/* we parse succeeding declaration hence we parse them as normal and re-attach them*/
			/* when we know whether they are global (assembly:, module:) or local (type:).*/
			if (ds.OptAttributes != null) {
				ds.OptAttributes.ConvertGlobalAttributes (ds, current_namespace, !current_namespace.DeclarationFound && current_namespace == file);
			}
		}
		current_namespace.DeclarationFound = true;
	  }

void case_45()
#line 632 "cs-parser.jay"
{
		current_namespace.UnattachedAttributes = (Attributes) yyVals[-1+yyTop];
		report.Error (1518, lexer.Location, "Attributes must be attached to class, delegate, enum, interface or struct");
		lexer.putback ('}');
	  }

void case_53()
#line 665 "cs-parser.jay"
{
		var sect = (List<Attribute>) yyVals[0+yyTop];
		yyVal = new Attributes (sect);
	  }

void case_54()
#line 670 "cs-parser.jay"
{
		Attributes attrs = yyVals[-1+yyTop] as Attributes;
		var sect = (List<Attribute>) yyVals[0+yyTop];
		if (attrs == null)
			attrs = new Attributes (sect);
		else if (sect != null)
			attrs.AddAttributes (sect);
		yyVal = attrs;
	  }

void case_55()
#line 683 "cs-parser.jay"
{
	  	PushLocation (GetLocation (yyVals[0+yyTop]));
		lexer.parsing_attribute_section = true;
	  }

void case_56()
#line 688 "cs-parser.jay"
{
		lexer.parsing_attribute_section = false;
		yyVal = yyVals[0+yyTop];
	  }

void case_57()
#line 696 "cs-parser.jay"
{
		current_attr_target = (string) yyVals[-1+yyTop];
		if (current_attr_target == "assembly" || current_attr_target == "module") {
			Lexer.check_incorrect_doc_comment ();
		}
	  }

void case_58()
#line 703 "cs-parser.jay"
{
		/* when attribute target is invalid*/
		if (current_attr_target == string.Empty)
			yyVal = new List<Attribute> (0);
		else
			yyVal = yyVals[-2+yyTop];

		lbag.InsertLocation (yyVal, 0, PopLocation ());
		if (yyVals[-1+yyTop] != null) {
			lbag.AddLocation (yyVal, GetLocation (yyVals[-4+yyTop]), GetLocation (yyVals[-1+yyTop]), GetLocation (yyVals[0+yyTop]));
		} else {
			lbag.AddLocation (yyVal, GetLocation (yyVals[-4+yyTop]), GetLocation (yyVals[0+yyTop]));
		}

		current_attr_target = null;
		lexer.parsing_attribute_section = false;
 	  }

void case_59()
#line 721 "cs-parser.jay"
{
		yyVal = yyVals[-2+yyTop];

		lbag.InsertLocation (yyVal, 0, PopLocation ());
		if (yyVals[-1+yyTop] != null) {
			lbag.AddLocation (yyVal, GetLocation(yyVals[-1+yyTop]), GetLocation (yyVals[0+yyTop]));
		} else {
			lbag.AddLocation (yyVal, GetLocation(yyVals[0+yyTop]));
		}
	  }

void case_60()
#line 732 "cs-parser.jay"
{
		Error_SyntaxError (yyToken);

		var lt = (LocatedToken) yyVals[-1+yyTop];
		var tne = new SimpleName (lt.Value, null, lt.Location);

		yyVal = new List<Attribute> () {
			new Attribute (null, tne, null, GetLocation (yyVals[-1+yyTop]), false)
		};
	  }

void case_61()
#line 743 "cs-parser.jay"
{
 		CheckAttributeTarget (yyToken, GetTokenName (yyToken), GetLocation (yyVals[0+yyTop])); 
 		yyVal = null;
	  }

void case_62()
#line 751 "cs-parser.jay"
{
		var lt = (LocatedToken) yyVals[0+yyTop];
		yyVal = CheckAttributeTarget (yyToken, lt.Value, lt.Location);
	  }

void case_66()
#line 765 "cs-parser.jay"
{
		var attrs = (List<Attribute>) yyVals[-2+yyTop];
		if (attrs != null) {
			attrs.Add ((Attribute) yyVals[0+yyTop]);
	  		lbag.AppendTo (attrs, GetLocation (yyVals[-1+yyTop]));
	  	}

		yyVal = attrs;
	  }

void case_68()
#line 782 "cs-parser.jay"
{
		--lexer.parsing_block;
		
		var tne = (ATypeNameExpression) yyVals[-2+yyTop];
		if (tne.HasTypeArguments) {
			report.Error (404, tne.Location, "Attributes cannot be generic");
		}

		yyVal = new Attribute (current_attr_target, tne, (Arguments[]) yyVals[0+yyTop], GetLocation (yyVals[-2+yyTop]), lexer.IsEscapedIdentifier (tne));
	  }

void case_73()
#line 810 "cs-parser.jay"
{
	  	Arguments a = new Arguments (4);
		a.Add ((Argument) yyVals[0+yyTop]);
		yyVal = new Arguments [] { a, null };
	  }

void case_74()
#line 816 "cs-parser.jay"
{
	  	Arguments a = new Arguments (4);
		a.Add ((Argument) yyVals[0+yyTop]);  
		yyVal = new Arguments [] { null, a };
	  }

void case_75()
#line 822 "cs-parser.jay"
{
		Arguments[] o = (Arguments[]) yyVals[-2+yyTop];
		if (o [1] != null) {
			report.Error (1016, ((Argument) yyVals[0+yyTop]).Expr.Location, "Named attribute arguments must appear after the positional arguments");
			o [0] = new Arguments (4);
		}
		
		Arguments args = ((Arguments) o [0]);
		if (args.Count > 0 && !(yyVals[0+yyTop] is NamedArgument) && args [args.Count - 1] is NamedArgument)
			Error_NamedArgumentExpected ((NamedArgument) args [args.Count - 1]);
		
		args.Add ((Argument) yyVals[0+yyTop]);
	  }

void case_76()
#line 836 "cs-parser.jay"
{
		Arguments[] o = (Arguments[]) yyVals[-2+yyTop];
		if (o [1] == null) {
			o [1] = new Arguments (4);
		}

		((Arguments) o [1]).Add ((Argument) yyVals[0+yyTop]);
	  }

void case_79()
#line 853 "cs-parser.jay"
{
		Error_SyntaxError (yyToken);
		yyVal = null;
	  }

void case_81()
#line 865 "cs-parser.jay"
{
	  	--lexer.parsing_block;
	  	var lt = (LocatedToken) yyVals[-3+yyTop];
		yyVal = new NamedArgument (lt.Value, lt.Location, (Expression) yyVals[0+yyTop]);	  
		lbag.AddLocation (yyVal, GetLocation(yyVals[-2+yyTop]));
	  }

void case_82()
#line 875 "cs-parser.jay"
{
		if (lang_version <= LanguageVersion.V_3)
			FeatureIsNotAvailable (GetLocation (yyVals[-3+yyTop]), "named argument");
			
		/* Avoid boxing in common case (no modifier)*/
		var arg_mod = yyVals[-1+yyTop] == null ? Argument.AType.None : (Argument.AType) yyVals[-1+yyTop];
			
		var lt = (LocatedToken) yyVals[-3+yyTop];
		yyVal = new NamedArgument (lt.Value, lt.Location, (Expression) yyVals[0+yyTop], arg_mod);
		lbag.AddLocation (yyVal, GetLocation(yyVals[-2+yyTop]));
	  }

void case_88()
#line 907 "cs-parser.jay"
{
		lexer.parsing_modifiers = true;
		lexer.parsing_block = 0;
	  }

void case_89()
#line 912 "cs-parser.jay"
{
		lexer.parsing_modifiers = true;
		lexer.parsing_block = 0;
	  }

void case_103()
#line 933 "cs-parser.jay"
{
		report.Error (1519, lexer.Location, "Unexpected symbol `{0}' in class, struct, or interface member declaration",
			GetSymbolName (yyToken));
		yyVal = null;
		lexer.parsing_generic_declaration = false;
	  }

void case_104()
#line 943 "cs-parser.jay"
{
		current_local_parameters = current_type.PrimaryConstructorParameters;
		if (current_local_parameters == null) {
			report.Error (9010, GetLocation (yyVals[0+yyTop]), "Primary constructor body is not allowed");
			current_local_parameters = ParametersCompiled.EmptyReadOnlyParameters;
		}

		++lexer.parsing_block;
		start_block (GetLocation (yyVals[0+yyTop]));
	  }

void case_105()
#line 954 "cs-parser.jay"
{
		current_local_parameters = null;
		var t = current_type as ClassOrStruct;
		if (t != null) {
			var b = (ToplevelBlock) yyVals[0+yyTop];
			if (t.PrimaryConstructorBlock != null) {
				report.Error (8041, b.StartLocation, "Primary constructor already has a body");
			} else {
				t.PrimaryConstructorBlock = b;
			}
		}
	  }

void case_107()
#line 976 "cs-parser.jay"
{ 
		lexer.ConstraintsParsing = true;
		valid_param_mod = ParameterModifierType.PrimaryConstructor;
		push_current_container (new Struct (current_container, (MemberName) yyVals[0+yyTop], (Modifiers) yyVals[-4+yyTop], (Attributes) yyVals[-5+yyTop]), yyVals[-3+yyTop]);
	  }

void case_108()
#line 984 "cs-parser.jay"
{
		valid_param_mod = 0;
		lexer.ConstraintsParsing = false;

		if (yyVals[-2+yyTop] != null)
			current_type.PrimaryConstructorParameters = (ParametersCompiled) yyVals[-2+yyTop];

		if (yyVals[0+yyTop] != null)
			current_container.SetConstraints ((List<Constraints>) yyVals[0+yyTop]);

		if (doc_support)
			current_container.PartialContainer.DocComment = Lexer.consume_doc_comment ();

		lbag.AddMember (current_container, mod_locations, GetLocation (yyVals[-6+yyTop]));
		
		lexer.parsing_modifiers = true;
	  }

void case_109()
#line 1002 "cs-parser.jay"
{
		if (doc_support)
			Lexer.doc_state = XmlCommentState.Allowed;
	  }

void case_110()
#line 1007 "cs-parser.jay"
{
		--lexer.parsing_declaration;
		if (doc_support)
			Lexer.doc_state = XmlCommentState.Allowed;
	  }

void case_111()
#line 1013 "cs-parser.jay"
{
		if (yyVals[-1+yyTop] == null) {
			lbag.AppendToMember (current_container, GetLocation (yyVals[-5+yyTop]), GetLocation (yyVals[-2+yyTop]));
		} else {
			lbag.AppendToMember (current_container, GetLocation (yyVals[-5+yyTop]), GetLocation (yyVals[-2+yyTop]), GetLocation (yyVals[0+yyTop]));
		}
		yyVal = pop_current_class ();
	  }

void case_113()
#line 1031 "cs-parser.jay"
{
		var lt = (LocatedToken) yyVals[0+yyTop];
		var mod = (Modifiers) yyVals[-3+yyTop];
		current_field = new Const (current_type, (FullNamedExpression) yyVals[-1+yyTop], mod, new MemberName (lt.Value, lt.Location), (Attributes) yyVals[-4+yyTop]);
		current_type.AddMember (current_field);
		
		if ((mod & Modifiers.STATIC) != 0) {
			report.Error (504, current_field.Location, "The constant `{0}' cannot be marked static", current_field.GetSignatureForError ());
		}
		
		yyVal = current_field;
	  }

void case_114()
#line 1044 "cs-parser.jay"
{
		if (doc_support) {
			current_field.DocComment = Lexer.consume_doc_comment ();
			Lexer.doc_state = XmlCommentState.Allowed;
		}
		
		current_field.Initializer = (ConstInitializer) yyVals[-2+yyTop];
		lbag.AddMember (current_field, mod_locations, GetLocation (yyVals[-6+yyTop]), GetLocation (yyVals[0+yyTop]));
		current_field = null;
	  }

void case_115()
#line 1057 "cs-parser.jay"
{
		Error_SyntaxError (yyToken);

		current_type.AddMember (new Const (current_type, (FullNamedExpression) yyVals[-1+yyTop], (Modifiers) yyVals[-3+yyTop], MemberName.Null, (Attributes) yyVals[-4+yyTop]));
	  }

void case_120()
#line 1082 "cs-parser.jay"
{
		var lt = (LocatedToken) yyVals[-1+yyTop];
	  	yyVal = new FieldDeclarator (new SimpleMemberName (lt.Value, lt.Location), (ConstInitializer) yyVals[0+yyTop]);
	  	lbag.AddLocation (yyVal, GetLocation (yyVals[-2+yyTop]));
	  }

void case_122()
#line 1095 "cs-parser.jay"
{
		--lexer.parsing_block;
		yyVal = new ConstInitializer (current_field, (Expression) yyVals[0+yyTop], GetLocation (yyVals[-2+yyTop]));
	  }

void case_123()
#line 1100 "cs-parser.jay"
{
		report.Error (145, lexer.Location, "A const field requires a value to be provided");
		yyVal = null;
	  }

void case_126()
#line 1115 "cs-parser.jay"
{
	  	lexer.parsing_generic_declaration = false;

		FullNamedExpression type = (FullNamedExpression) yyVals[-1+yyTop];
		if (type.Type != null && type.Type.Kind == MemberKind.Void)
			report.Error (670, GetLocation (yyVals[-1+yyTop]), "Fields cannot have void type");
			
		var lt = (LocatedToken) yyVals[0+yyTop];
		current_field = new Field (current_type, type, (Modifiers) yyVals[-2+yyTop], new MemberName (lt.Value, lt.Location), (Attributes) yyVals[-3+yyTop]);
		current_type.AddField (current_field);
		yyVal = current_field;
	  }

void case_127()
#line 1130 "cs-parser.jay"
{ 
		if (doc_support) {
			current_field.DocComment = Lexer.consume_doc_comment ();
			Lexer.doc_state = XmlCommentState.Allowed;
		}
			
		lbag.AddMember (current_field, mod_locations, GetLocation (yyVals[0+yyTop]));
		yyVal = current_field;
		current_field = null;
	  }

void case_128()
#line 1143 "cs-parser.jay"
{ 
		if (lang_version < LanguageVersion.ISO_2)
			FeatureIsNotAvailable (GetLocation (yyVals[-2+yyTop]), "fixed size buffers");

		var lt = (LocatedToken) yyVals[0+yyTop];
		current_field = new FixedField (current_type, (FullNamedExpression) yyVals[-1+yyTop], (Modifiers) yyVals[-3+yyTop],
			new MemberName (lt.Value, lt.Location), (Attributes) yyVals[-4+yyTop]);
			
		current_type.AddField (current_field);
	  }

void case_129()
#line 1154 "cs-parser.jay"
{
		if (doc_support) {
			current_field.DocComment = Lexer.consume_doc_comment ();
			Lexer.doc_state = XmlCommentState.Allowed;
	    }

		current_field.Initializer = (ConstInitializer) yyVals[-2+yyTop];	    
		lbag.AddMember (current_field, mod_locations, GetLocation (yyVals[0+yyTop]));
		yyVal = current_field;
	    current_field = null;
	  }

void case_132()
#line 1177 "cs-parser.jay"
{
	  	++lexer.parsing_block;
		current_local_parameters = ParametersCompiled.EmptyReadOnlyParameters;
	  	start_block (GetLocation (yyVals[0+yyTop]));
	  }

void case_133()
#line 1183 "cs-parser.jay"
{
	  	--lexer.parsing_block;
		current_field.Initializer = (Expression) yyVals[0+yyTop];
		lbag.AppendToMember (current_field, GetLocation (yyVals[-2+yyTop]));
		end_block (lexer.Location);
		current_local_parameters = null;
	  }

void case_138()
#line 1210 "cs-parser.jay"
{
		var lt = (LocatedToken) yyVals[0+yyTop];
	  	yyVal = new FieldDeclarator (new SimpleMemberName (lt.Value, lt.Location), null);
	  	lbag.AddLocation (yyVal, GetLocation (yyVals[-1+yyTop]));
	  }

void case_140()
#line 1220 "cs-parser.jay"
{
		--lexer.parsing_block;
		var lt = (LocatedToken) yyVals[-3+yyTop];	  
	  	yyVal = new FieldDeclarator (new SimpleMemberName (lt.Value, lt.Location), (Expression) yyVals[0+yyTop]);
	  	lbag.AddLocation (yyVal, GetLocation (yyVals[-4+yyTop]), GetLocation (yyVals[-2+yyTop]));
	  }

void case_145()
#line 1246 "cs-parser.jay"
{
		var lt = (LocatedToken) yyVals[-1+yyTop];	  
		yyVal = new FieldDeclarator (new SimpleMemberName (lt.Value, lt.Location), (ConstInitializer) yyVals[0+yyTop]);
		lbag.AddLocation (yyVal, GetLocation (yyVals[-2+yyTop]));
	  }

void case_147()
#line 1259 "cs-parser.jay"
{
		--lexer.parsing_block;
		yyVal = new ConstInitializer (current_field, (Expression) yyVals[-1+yyTop], GetLocation (yyVals[-3+yyTop]));
		lbag.AddLocation (yyVal, GetLocation (yyVals[0+yyTop]));
	  }

void case_148()
#line 1265 "cs-parser.jay"
{
		report.Error (443, lexer.Location, "Value or constant expected");
		yyVal = null;
	  }

void case_151()
#line 1275 "cs-parser.jay"
{
		/* It has to be here for the parent to safely restore artificial block*/
	  	Error_SyntaxError (yyToken);
	  	yyVal = null;
	  }

void case_152()
#line 1284 "cs-parser.jay"
{
		if (doc_support)
			Lexer.doc_state = XmlCommentState.NotAllowed;

		/* Was added earlier in the case of body being eof for full ast*/
	  }

void case_153()
#line 1291 "cs-parser.jay"
{
		Method method = (Method) yyVals[-2+yyTop];
		method.Block = (ToplevelBlock) yyVals[0+yyTop];
		async_block = false;
		
		if (method.Block == null) {
			method.ParameterInfo.CheckParameters (method);

			if ((method.ModFlags & Modifiers.ASYNC) != 0) {
				report.Error (1994, method.Location, "`{0}': The async modifier can only be used with methods that have a body",
					method.GetSignatureForError ());
			}
		} else {
			if (current_container.Kind == MemberKind.Interface) {
				report.Error (531, method.Location, "`{0}': interface members cannot have a definition",
					method.GetSignatureForError ());
			}
		}

		current_local_parameters = null;

		if (doc_support)
			Lexer.doc_state = XmlCommentState.Allowed;
	  }

void case_155()
#line 1326 "cs-parser.jay"
{
		valid_param_mod = 0;
		MemberName name = (MemberName) yyVals[-4+yyTop];
		current_local_parameters = (ParametersCompiled) yyVals[-1+yyTop];

		var method = Method.Create (current_type, (FullNamedExpression) yyVals[-5+yyTop], (Modifiers) yyVals[-6+yyTop],
				     name, current_local_parameters, (Attributes) yyVals[-7+yyTop]);

		current_type.AddMember (method);

		async_block = (method.ModFlags & Modifiers.ASYNC) != 0;

		if (doc_support)
			method.DocComment = Lexer.consume_doc_comment ();

		lbag.AddMember (method, mod_locations, GetLocation (yyVals[-3+yyTop]), GetLocation (yyVals[0+yyTop]));

		yyVal = method;

		lexer.ConstraintsParsing = true;
	  }

void case_156()
#line 1348 "cs-parser.jay"
{
		lexer.ConstraintsParsing = false;

		if (yyVals[0+yyTop] != null) {
			var method = (Method) yyVals[-1+yyTop];
			method.SetConstraints ((List<Constraints>) yyVals[0+yyTop]);
		}

		yyVal = yyVals[-1+yyTop];
	  }

void case_158()
#line 1367 "cs-parser.jay"
{
		lexer.parsing_generic_declaration = false;
	  	valid_param_mod = ParameterModifierType.All;
	  }

void case_160()
#line 1376 "cs-parser.jay"
{
		lexer.ConstraintsParsing = false;
		valid_param_mod = 0;

		MemberName name = (MemberName) yyVals[-6+yyTop];
		current_local_parameters = (ParametersCompiled) yyVals[-3+yyTop];

		var modifiers = (Modifiers) yyVals[-10+yyTop];
		modifiers |= Modifiers.PARTIAL;

		var method = Method.Create (current_type, new TypeExpression (compiler.BuiltinTypes.Void, GetLocation (yyVals[-8+yyTop])),
				     modifiers, name, current_local_parameters, (Attributes) yyVals[-11+yyTop]);

		current_type.AddMember (method);

		async_block = (method.ModFlags & Modifiers.ASYNC) != 0;

		if (yyVals[0+yyTop] != null)
			method.SetConstraints ((List<Constraints>) yyVals[0+yyTop]);

		if (doc_support)
			method.DocComment = Lexer.consume_doc_comment ();

		StoreModifierLocation (Modifiers.PARTIAL, GetLocation (yyVals[-9+yyTop]));
		lbag.AddMember (method, mod_locations, GetLocation (yyVals[-5+yyTop]), GetLocation (yyVals[-2+yyTop]));
		yyVal = method;
	  }

void case_161()
#line 1407 "cs-parser.jay"
{
		MemberName name = (MemberName) yyVals[-3+yyTop];
		report.Error (1585, name.Location, 
			"Member modifier `{0}' must precede the member type and name", ModifiersExtensions.Name ((Modifiers) yyVals[-4+yyTop]));

		var method = Method.Create (current_type, (FullNamedExpression) yyVals[-5+yyTop],
					    0, name, (ParametersCompiled) yyVals[-1+yyTop], (Attributes) yyVals[-7+yyTop]);

		current_type.AddMember (method);

		current_local_parameters = (ParametersCompiled) yyVals[-1+yyTop];

		if (doc_support)
			method.DocComment = Lexer.consume_doc_comment ();

		yyVal = method;
	  }

void case_162()
#line 1428 "cs-parser.jay"
{
		Error_SyntaxError (yyToken);
		current_local_parameters = ParametersCompiled.Undefined;

		MemberName name = (MemberName) yyVals[-1+yyTop];
		var method = Method.Create (current_type, (FullNamedExpression) yyVals[-2+yyTop], (Modifiers) yyVals[-3+yyTop],
									name, current_local_parameters, (Attributes) yyVals[-4+yyTop]);

		current_type.AddMember (method);

		if (doc_support)
			method.DocComment = Lexer.consume_doc_comment ();

		yyVal = method;
	  }

void case_167()
#line 1457 "cs-parser.jay"
{
		if (lang_version < LanguageVersion.V_6) {
			FeatureIsNotAvailable (GetLocation (yyVals[0+yyTop]), "expression bodied members");
		}

		++lexer.parsing_block;
		start_block (GetLocation (yyVals[0+yyTop]));
	 }

void case_168()
#line 1466 "cs-parser.jay"
{
		lexer.parsing_block = 0;
		current_block.AddStatement (new ContextualReturn ((Expression) yyVals[-1+yyTop]));
		var b = end_block (GetLocation (yyVals[0+yyTop]));
		b.IsCompilerGenerated = true;
		yyVal = b;
	 }

void case_171()
#line 1482 "cs-parser.jay"
{
		var pars_list = (List<Parameter>) yyVals[0+yyTop];
	  	yyVal = new ParametersCompiled (pars_list.ToArray ());
	  }

void case_172()
#line 1487 "cs-parser.jay"
{
		var pars_list = (List<Parameter>) yyVals[-2+yyTop];
		pars_list.Add ((Parameter) yyVals[0+yyTop]);

		yyVal = new ParametersCompiled (pars_list.ToArray ()); 
	  }

void case_173()
#line 1494 "cs-parser.jay"
{
		var pars_list = (List<Parameter>) yyVals[-2+yyTop];
		pars_list.Add (new ArglistParameter (GetLocation (yyVals[0+yyTop])));
		yyVal = new ParametersCompiled (pars_list.ToArray (), true);
	  }

void case_174()
#line 1500 "cs-parser.jay"
{
		if (yyVals[-2+yyTop] != null)
			report.Error (231, ((Parameter) yyVals[-2+yyTop]).Location, "A params parameter must be the last parameter in a formal parameter list");

		yyVal = new ParametersCompiled (new Parameter[] { (Parameter) yyVals[-2+yyTop] } );			
	  }

void case_175()
#line 1507 "cs-parser.jay"
{
		if (yyVals[-2+yyTop] != null)
			report.Error (231, ((Parameter) yyVals[-2+yyTop]).Location, "A params parameter must be the last parameter in a formal parameter list");

		var pars_list = (List<Parameter>) yyVals[-4+yyTop];
		pars_list.Add (new ArglistParameter (GetLocation (yyVals[-2+yyTop])));

		yyVal = new ParametersCompiled (pars_list.ToArray (), true);
	  }

void case_176()
#line 1517 "cs-parser.jay"
{
		report.Error (257, GetLocation (yyVals[-2+yyTop]), "An __arglist parameter must be the last parameter in a formal parameter list");

		yyVal = new ParametersCompiled (new Parameter [] { new ArglistParameter (GetLocation (yyVals[-2+yyTop])) }, true);
	  }

void case_177()
#line 1523 "cs-parser.jay"
{
		report.Error (257, GetLocation (yyVals[-2+yyTop]), "An __arglist parameter must be the last parameter in a formal parameter list");

		var pars_list = (List<Parameter>) yyVals[-4+yyTop];
		pars_list.Add (new ArglistParameter (GetLocation (yyVals[-2+yyTop])));

		yyVal = new ParametersCompiled (pars_list.ToArray (), true);
	  }

void case_180()
#line 1540 "cs-parser.jay"
{
		Error_SyntaxError (yyToken);
		yyVal = ParametersCompiled.EmptyReadOnlyParameters;
	  }

void case_181()
#line 1548 "cs-parser.jay"
{
		parameters_bucket.Clear ();
		Parameter p = (Parameter) yyVals[0+yyTop];
		parameters_bucket.Add (p);
		
		default_parameter_used = p.HasDefaultValue;
		yyVal = parameters_bucket;
	  }

void case_182()
#line 1557 "cs-parser.jay"
{
		var pars = (List<Parameter>) yyVals[-2+yyTop];
		Parameter p = (Parameter) yyVals[0+yyTop];
		if (p != null) {
			if (p.HasExtensionMethodModifier)
				report.Error (1100, p.Location, "The parameter modifier `this' can only be used on the first parameter");
			else if (!p.HasDefaultValue && default_parameter_used)
				report.Error (1737, p.Location, "Optional parameter cannot precede required parameters");

			default_parameter_used |= p.HasDefaultValue;
			pars.Add (p);
			
			lbag.AddLocation (p, GetLocation (yyVals[-1+yyTop]));
		}
		
		yyVal = yyVals[-2+yyTop];
	  }

void case_183()
#line 1581 "cs-parser.jay"
{
		var lt = (LocatedToken) yyVals[0+yyTop];
		yyVal = new Parameter ((FullNamedExpression) yyVals[-1+yyTop], lt.Value, (Parameter.Modifier) yyVals[-2+yyTop], (Attributes) yyVals[-3+yyTop], lt.Location);
	  }

void case_184()
#line 1589 "cs-parser.jay"
{
		var lt = (LocatedToken) yyVals[-2+yyTop];
		report.Error (1552, lt.Location, "Array type specifier, [], must appear before parameter name");
		yyVal = new Parameter ((FullNamedExpression) yyVals[-3+yyTop], lt.Value, (Parameter.Modifier) yyVals[-4+yyTop], (Attributes) yyVals[-5+yyTop], lt.Location);
	  }

void case_185()
#line 1595 "cs-parser.jay"
{
		Error_SyntaxError (yyToken);
	  	Location l = GetLocation (yyVals[0+yyTop]);
		yyVal = new Parameter (null, null, Parameter.Modifier.NONE, (Attributes) yyVals[-1+yyTop], l);
	  }

void case_186()
#line 1604 "cs-parser.jay"
{
		Error_SyntaxError (yyToken);
	  	Location l = GetLocation (yyVals[0+yyTop]);
		yyVal = new Parameter ((FullNamedExpression) yyVals[-1+yyTop], null, (Parameter.Modifier) yyVals[-2+yyTop], (Attributes) yyVals[-3+yyTop], l);
	  }

void case_188()
#line 1618 "cs-parser.jay"
{
	  	--lexer.parsing_block;
		if (lang_version <= LanguageVersion.V_3) {
			FeatureIsNotAvailable (GetLocation (yyVals[-2+yyTop]), "optional parameter");
		}
		
		Parameter.Modifier mod = (Parameter.Modifier) yyVals[-5+yyTop];
		if (mod != Parameter.Modifier.NONE) {
			switch (mod) {
			case Parameter.Modifier.REF:
			case Parameter.Modifier.OUT:
				report.Error (1741, GetLocation (yyVals[-5+yyTop]), "Cannot specify a default value for the `{0}' parameter",
					Parameter.GetModifierSignature (mod));
				break;
				
			case Parameter.Modifier.This:
				report.Error (1743, GetLocation (yyVals[-5+yyTop]), "Cannot specify a default value for the `{0}' parameter",
					Parameter.GetModifierSignature (mod));
				break;
			default:
				throw new NotImplementedException (mod.ToString ());
			}
				
			mod = Parameter.Modifier.NONE;
		}
		
		if ((valid_param_mod & ParameterModifierType.DefaultValue) == 0)
			report.Error (1065, GetLocation (yyVals[-2+yyTop]), "Optional parameter is not valid in this context");
		
		var lt = (LocatedToken) yyVals[-3+yyTop];
		yyVal = new Parameter ((FullNamedExpression) yyVals[-4+yyTop], lt.Value, mod, (Attributes) yyVals[-6+yyTop], lt.Location);
		lbag.AddLocation (yyVal, GetLocation (yyVals[-2+yyTop]));
		
		if (yyVals[0+yyTop] != null)
			((Parameter) yyVal).DefaultValue = new DefaultParameterValueExpression ((Expression) yyVals[0+yyTop]);
	  }

void case_192()
#line 1667 "cs-parser.jay"
{
		Parameter.Modifier p2 = (Parameter.Modifier)yyVals[0+yyTop];
  		Parameter.Modifier mod = (Parameter.Modifier)yyVals[-1+yyTop] | p2;
  		if (((Parameter.Modifier)yyVals[-1+yyTop] & p2) == p2) {
  			Error_DuplicateParameterModifier (lexer.Location, p2);
  		} else {
	  		switch (mod & ~Parameter.Modifier.This) {
  				case Parameter.Modifier.REF:
					report.Error (1101, lexer.Location, "The parameter modifiers `this' and `ref' cannot be used altogether");
  					break;
   				case Parameter.Modifier.OUT:
					report.Error (1102, lexer.Location, "The parameter modifiers `this' and `out' cannot be used altogether");
  					break;
  				default:
 					report.Error (1108, lexer.Location, "A parameter cannot have specified more than one modifier");
 					break;
 			}
  		}
  		yyVal = mod;
	  }

void case_193()
#line 1691 "cs-parser.jay"
{
	  	if ((valid_param_mod & ParameterModifierType.Ref) == 0)
	  		Error_ParameterModifierNotValid ("ref", GetLocation (yyVals[0+yyTop]));
	  		
	  	yyVal = Parameter.Modifier.REF;
	  }

void case_194()
#line 1698 "cs-parser.jay"
{
	  	if ((valid_param_mod & ParameterModifierType.Out) == 0)
	  		Error_ParameterModifierNotValid ("out", GetLocation (yyVals[0+yyTop]));
	  
	  	yyVal = Parameter.Modifier.OUT;
	  }

void case_195()
#line 1705 "cs-parser.jay"
{
		if ((valid_param_mod & ParameterModifierType.This) == 0)
	  		Error_ParameterModifierNotValid ("this", GetLocation (yyVals[0+yyTop]));

	  	if (lang_version <= LanguageVersion.ISO_2)
	  		FeatureIsNotAvailable (GetLocation (yyVals[0+yyTop]), "extension methods");
	  			
		yyVal = Parameter.Modifier.This;
	  }

void case_196()
#line 1718 "cs-parser.jay"
{
		var lt = (LocatedToken) yyVals[0+yyTop];
		yyVal = new ParamsParameter ((FullNamedExpression) yyVals[-1+yyTop], lt.Value, (Attributes) yyVals[-3+yyTop], lt.Location);
	  }

void case_197()
#line 1723 "cs-parser.jay"
{
		report.Error (1751, GetLocation (yyVals[-4+yyTop]), "Cannot specify a default value for a parameter array");
		
		var lt = (LocatedToken) yyVals[-2+yyTop];
		yyVal = new ParamsParameter ((FullNamedExpression) yyVals[-3+yyTop], lt.Value, (Attributes) yyVals[-5+yyTop], lt.Location);		
	  }

void case_198()
#line 1730 "cs-parser.jay"
{
		Error_SyntaxError (yyToken);

		yyVal = new ParamsParameter ((FullNamedExpression) yyVals[-1+yyTop], null, (Attributes) yyVals[-3+yyTop], Location.Null);
	  }

void case_199()
#line 1739 "cs-parser.jay"
{
		if ((valid_param_mod & ParameterModifierType.Params) == 0)
			report.Error (1670, (GetLocation (yyVals[0+yyTop])), "The `params' modifier is not allowed in current context");
	  }

void case_200()
#line 1744 "cs-parser.jay"
{
		Parameter.Modifier mod = (Parameter.Modifier)yyVals[0+yyTop];
		if ((mod & Parameter.Modifier.This) != 0) {
			report.Error (1104, GetLocation (yyVals[-1+yyTop]), "The parameter modifiers `this' and `params' cannot be used altogether");
		} else {
			report.Error (1611, GetLocation (yyVals[-1+yyTop]), "The params parameter cannot be declared as ref or out");
		}	  
	  }

void case_202()
#line 1760 "cs-parser.jay"
{
	  	if ((valid_param_mod & ParameterModifierType.Arglist) == 0)
	  		report.Error (1669, GetLocation (yyVals[0+yyTop]), "__arglist is not valid in this context");
	  }

void case_203()
#line 1771 "cs-parser.jay"
{
		lexer.parsing_generic_declaration = false;
		if (doc_support)
			tmpComment = Lexer.consume_doc_comment ();
	  }

void case_204()
#line 1777 "cs-parser.jay"
{
		var type = (FullNamedExpression) yyVals[-3+yyTop];
		current_property = new Property (current_type, type, (Modifiers) yyVals[-4+yyTop],
			(MemberName) yyVals[-2+yyTop], (Attributes) yyVals[-5+yyTop]);
			
		if (type.Type != null && type.Type.Kind == MemberKind.Void)
			report.Error (547, GetLocation (yyVals[-3+yyTop]), "`{0}': property or indexer cannot have void type", current_property.GetSignatureForError ());					
			
		current_type.AddMember (current_property);
		lbag.AddMember (current_property, mod_locations, GetLocation (yyVals[0+yyTop]));
		
		lexer.PropertyParsing = true;
	  }

void case_205()
#line 1791 "cs-parser.jay"
{
		lexer.PropertyParsing = false;
		
		if (doc_support)
			current_property.DocComment = ConsumeStoredComment ();				
	  }

void case_206()
#line 1798 "cs-parser.jay"
{
		lbag.AppendToMember (current_property, GetLocation (yyVals[0+yyTop]));
		lexer.parsing_modifiers = true;
	  }

void case_208()
#line 1810 "cs-parser.jay"
{
		lexer.parsing_generic_declaration = false;
		if (doc_support)
			tmpComment = Lexer.consume_doc_comment ();
		current_local_parameters = ParametersCompiled.EmptyReadOnlyParameters;
	  }

void case_209()
#line 1817 "cs-parser.jay"
{
		var type = (FullNamedExpression) yyVals[-3+yyTop];
		var property = new Property (current_type, type, (Modifiers) yyVals[-4+yyTop],
			(MemberName) yyVals[-2+yyTop], (Attributes) yyVals[-5+yyTop]);

		property.Get = new Property.GetMethod (property, Modifiers.COMPILER_GENERATED, null, property.Location);
		property.Get.Block = (ToplevelBlock) yyVals[0+yyTop];

		if (current_container.Kind == MemberKind.Interface) {
			report.Error (531, property.Get.Block.StartLocation,
				"`{0}': interface members cannot have a definition", property.GetSignatureForError ());
		}

		if (type.Type != null && type.Type.Kind == MemberKind.Void)
			report.Error (547, GetLocation (yyVals[-3+yyTop]), "`{0}': property or indexer cannot have void type", property.GetSignatureForError ());

		current_type.AddMember (property);

		current_local_parameters = null;
	  }

void case_211()
#line 1842 "cs-parser.jay"
{
		++lexer.parsing_block;
		current_local_parameters = ParametersCompiled.EmptyReadOnlyParameters;
		start_block (GetLocation (yyVals[0+yyTop]));
	  }

void case_212()
#line 1848 "cs-parser.jay"
{
		--lexer.parsing_block;
		((Property)current_property).Initializer = (Expression) yyVals[-1+yyTop];
		lbag.AppendToMember (current_property, GetLocation (yyVals[-3+yyTop]), GetLocation (yyVals[0+yyTop]));
		end_block (GetLocation (yyVals[0+yyTop]));
		current_local_parameters = null;
	  }

void case_216()
#line 1869 "cs-parser.jay"
{
		valid_param_mod = 0;
		var type = (FullNamedExpression) yyVals[-5+yyTop];
		Indexer indexer = new Indexer (current_type, type, (MemberName) yyVals[-4+yyTop], (Modifiers) yyVals[-6+yyTop], (ParametersCompiled) yyVals[-1+yyTop], (Attributes) yyVals[-7+yyTop]);
			
		current_property = indexer;

  		current_type.AddIndexer (indexer);
		lbag.AddMember (current_property, mod_locations, GetLocation (yyVals[-3+yyTop]), GetLocation (yyVals[0+yyTop]));
  		
		if (type.Type != null && type.Type.Kind == MemberKind.Void)
			report.Error (620, GetLocation (yyVals[-5+yyTop]), "`{0}': indexer return type cannot be `void'", indexer.GetSignatureForError ());  		

		if (indexer.ParameterInfo.IsEmpty) {
			report.Error (1551, GetLocation (yyVals[-3+yyTop]), "Indexers must have at least one parameter");
		}

		if (doc_support) {
			tmpComment = Lexer.consume_doc_comment ();
			Lexer.doc_state = XmlCommentState.Allowed;
		}

		lexer.PropertyParsing = true;
		current_local_parameters = (ParametersCompiled) yyVals[-1+yyTop];
	  }

void case_217()
#line 1895 "cs-parser.jay"
{
 		lexer.PropertyParsing = false;
		current_local_parameters = null;

		if (current_property.AccessorFirst != null && current_property.AccessorFirst.Block == null)
			((Indexer) current_property).ParameterInfo.CheckParameters (current_property);
	  
		if (doc_support)
			current_property.DocComment = ConsumeStoredComment ();
			
		current_property = null;		
	  }

void case_219()
#line 1915 "cs-parser.jay"
{
		current_property.Get = new Indexer.GetIndexerMethod (current_property, Modifiers.COMPILER_GENERATED, current_local_parameters, null, current_property.Location);
		current_property.Get.Block = (ToplevelBlock) yyVals[0+yyTop];
	  }

void case_224()
#line 1927 "cs-parser.jay"
{
	  	if (yyToken == Token.CLOSE_BRACE) {
	  		report.Error (548, lexer.Location, "`{0}': property or indexer must have at least one accessor", current_property.GetSignatureForError ());
		} else {
			if (yyToken == Token.SEMICOLON)
				report.Error (1597, lexer.Location, "Semicolon after method or accessor block is not valid");
			else
				report.Error (1014, GetLocation (yyVals[0+yyTop]), "A get or set accessor expected");
		}
	  }

void case_225()
#line 1941 "cs-parser.jay"
{
		if (yyVals[-1+yyTop] != ModifierNone && lang_version == LanguageVersion.ISO_1) {
			FeatureIsNotAvailable (GetLocation (yyVals[-1+yyTop]), "access modifiers on properties");
		}
	  
		if (current_property.Get != null) {
			report.Error (1007, GetLocation (yyVals[0+yyTop]), "Property accessor already defined");
		}
		
		if (current_property is Indexer) {
			current_property.Get = new Indexer.GetIndexerMethod (current_property, (Modifiers) yyVals[-1+yyTop], ((Indexer)current_property).ParameterInfo.Clone (),
				(Attributes) yyVals[-2+yyTop], GetLocation (yyVals[0+yyTop]));
		} else {
			current_property.Get = new Property.GetMethod (current_property,
				(Modifiers) yyVals[-1+yyTop], (Attributes) yyVals[-2+yyTop], GetLocation (yyVals[0+yyTop]));
		}	
	  
		current_local_parameters = current_property.Get.ParameterInfo;	  
		lbag.AddMember (current_property.Get, mod_locations);
		lexer.PropertyParsing = false;
	  }

void case_226()
#line 1963 "cs-parser.jay"
{
	  	if (yyVals[0+yyTop] != null) {
	  		current_property.Get.Block = (ToplevelBlock) yyVals[0+yyTop];			
	  	
			if (current_container.Kind == MemberKind.Interface) {
				report.Error (531, current_property.Get.Block.StartLocation,
					"`{0}': interface members cannot have a definition", current_property.Get.GetSignatureForError ());
			}		
		}
	  
		current_local_parameters = null;
		lexer.PropertyParsing = true;

		if (doc_support)
			if (Lexer.doc_state == XmlCommentState.Error)
				Lexer.doc_state = XmlCommentState.NotAllowed;
	  }

void case_227()
#line 1984 "cs-parser.jay"
{
		if (yyVals[-1+yyTop] != ModifierNone && lang_version == LanguageVersion.ISO_1) {
			FeatureIsNotAvailable (GetLocation (yyVals[-1+yyTop]), "access modifiers on properties");
		}
		
		if (current_property.Set != null) {
			report.Error (1007, GetLocation (yyVals[0+yyTop]), "Property accessor already defined");
		}
	  
		if (current_property is Indexer) {
			current_property.Set = new Indexer.SetIndexerMethod (current_property, (Modifiers) yyVals[-1+yyTop],
				ParametersCompiled.MergeGenerated (compiler,
				((Indexer)current_property).ParameterInfo, true, new Parameter (
					current_property.TypeExpression, "value", Parameter.Modifier.NONE, null, GetLocation (yyVals[0+yyTop])),
					null),
				(Attributes) yyVals[-2+yyTop], GetLocation (yyVals[0+yyTop]));
		} else {
			current_property.Set = new Property.SetMethod (current_property, (Modifiers) yyVals[-1+yyTop], 
				ParametersCompiled.CreateImplicitParameter (current_property.TypeExpression, GetLocation (yyVals[0+yyTop])),
				(Attributes) yyVals[-2+yyTop], GetLocation (yyVals[0+yyTop]));
		}
		
		current_local_parameters = current_property.Set.ParameterInfo;	
		lbag.AddMember (current_property.Set, mod_locations);
		lexer.PropertyParsing = false;
	  }

void case_228()
#line 2011 "cs-parser.jay"
{
		if (yyVals[0+yyTop] != null) {		
			current_property.Set.Block = (ToplevelBlock) yyVals[0+yyTop];
		
			if (current_container.Kind == MemberKind.Interface) {
				report.Error (531, current_property.Set.Block.StartLocation,
					"`{0}': interface members cannot have a definition", current_property.Set.GetSignatureForError ());
			}
		}
		
		current_local_parameters = null;
		lexer.PropertyParsing = true;

		if (doc_support
			&& Lexer.doc_state == XmlCommentState.Error)
			Lexer.doc_state = XmlCommentState.NotAllowed;
	  }

void case_230()
#line 2033 "cs-parser.jay"
{
		/* TODO: lbag*/
	  	yyVal = null;
	  }

void case_231()
#line 2038 "cs-parser.jay"
{
	  	Error_SyntaxError (1043, yyToken, "Invalid accessor body");
	  	yyVal = null;
	  }

void case_233()
#line 2052 "cs-parser.jay"
{
		lexer.ConstraintsParsing = true;
		push_current_container (new Interface (current_container, (MemberName) yyVals[0+yyTop], (Modifiers) yyVals[-4+yyTop], (Attributes) yyVals[-5+yyTop]), yyVals[-3+yyTop]);
		lbag.AddMember (current_container, mod_locations, GetLocation (yyVals[-2+yyTop]));		
	  }

void case_234()
#line 2059 "cs-parser.jay"
{
		lexer.ConstraintsParsing = false;

		if (yyVals[0+yyTop] != null)
			current_container.SetConstraints ((List<Constraints>) yyVals[0+yyTop]);

		if (doc_support) {
			current_container.PartialContainer.DocComment = Lexer.consume_doc_comment ();
			Lexer.doc_state = XmlCommentState.Allowed;
		}
		
		lexer.parsing_modifiers = true;
	  }

void case_235()
#line 2073 "cs-parser.jay"
{
		--lexer.parsing_declaration;	  
		if (doc_support)
			Lexer.doc_state = XmlCommentState.Allowed;
	  }

void case_236()
#line 2079 "cs-parser.jay"
{
		if (yyVals[0+yyTop] == null) {
			lbag.AppendToMember (current_container, GetLocation (yyVals[-4+yyTop]), GetLocation (yyVals[-2+yyTop]));
		} else {
			lbag.AppendToMember (current_container, GetLocation (yyVals[-4+yyTop]), GetLocation (yyVals[-2+yyTop]), GetLocation (yyVals[0+yyTop]));
		}
		yyVal = pop_current_class ();
	  }

void case_240()
#line 2100 "cs-parser.jay"
{
		lexer.parsing_modifiers = true;
		lexer.parsing_block = 0;
	  }

void case_241()
#line 2105 "cs-parser.jay"
{
		lexer.parsing_modifiers = true;
		lexer.parsing_block = 0;
	  }

void case_252()
#line 2143 "cs-parser.jay"
{
		OperatorDeclaration decl = (OperatorDeclaration) yyVals[-2+yyTop];
		if (decl != null) {
			Operator op = new Operator (
				current_type, decl.optype, decl.ret_type, (Modifiers) yyVals[-3+yyTop], 
				current_local_parameters,
				(ToplevelBlock) yyVals[0+yyTop], (Attributes) yyVals[-4+yyTop], decl.location);
				
			if (op.Block == null)
				op.ParameterInfo.CheckParameters (op);

			if (doc_support) {
				op.DocComment = tmpComment;
				Lexer.doc_state = XmlCommentState.Allowed;
			}

			/* Note again, checking is done in semantic analysis*/
			current_type.AddOperator (op);

			lbag.AddMember (op, mod_locations, lbag.GetLocations (decl));
		}
		
		current_local_parameters = null;
	  }

void case_254()
#line 2172 "cs-parser.jay"
{
		report.Error (590, GetLocation (yyVals[0+yyTop]), "User-defined operators cannot return void");
		yyVal = new TypeExpression (compiler.BuiltinTypes.Void, GetLocation (yyVals[0+yyTop]));
	  }

void case_256()
#line 2184 "cs-parser.jay"
{
		valid_param_mod = 0;

		Location loc = GetLocation (yyVals[-5+yyTop]);
		Operator.OpType op = (Operator.OpType) yyVals[-4+yyTop];
		current_local_parameters = (ParametersCompiled)yyVals[-1+yyTop];
		
		int p_count = current_local_parameters.Count;
		if (p_count == 1) {
			if (op == Operator.OpType.Addition)
				op = Operator.OpType.UnaryPlus;
			else if (op == Operator.OpType.Subtraction)
				op = Operator.OpType.UnaryNegation;
		}
		
		if (IsUnaryOperator (op)) {
			if (p_count == 2) {
				report.Error (1020, loc, "Overloadable binary operator expected");
			} else if (p_count != 1) {
				report.Error (1535, loc, "Overloaded unary operator `{0}' takes one parameter",
					Operator.GetName (op));
			}
		} else {
			if (p_count == 1) {
				report.Error (1019, loc, "Overloadable unary operator expected");
			} else if (p_count != 2) {
				report.Error (1534, loc, "Overloaded binary operator `{0}' takes two parameters",
					Operator.GetName (op));
			}
		}
		
		if (doc_support) {
			tmpComment = Lexer.consume_doc_comment ();
			Lexer.doc_state = XmlCommentState.NotAllowed;
		}

		yyVal = new OperatorDeclaration (op, (FullNamedExpression) yyVals[-6+yyTop], loc);
		lbag.AddLocation (yyVal, GetLocation (yyVals[-5+yyTop]), GetLocation (yyVals[-4+yyTop]), GetLocation (yyVals[-3+yyTop]), GetLocation (yyVals[0+yyTop]));
	  }

void case_281()
#line 2260 "cs-parser.jay"
{
		valid_param_mod = 0;

		Location loc = GetLocation (yyVals[-5+yyTop]);
		current_local_parameters = (ParametersCompiled)yyVals[-1+yyTop];  

		if (current_local_parameters.Count != 1) {
			report.Error (1535, loc, "Overloaded unary operator `implicit' takes one parameter");
		}

		if (doc_support) {
			tmpComment = Lexer.consume_doc_comment ();
			Lexer.doc_state = XmlCommentState.NotAllowed;
		}

		yyVal = new OperatorDeclaration (Operator.OpType.Implicit, (FullNamedExpression) yyVals[-4+yyTop], loc);
		lbag.AddLocation (yyVal, GetLocation (yyVals[-6+yyTop]), GetLocation (yyVals[-5+yyTop]), GetLocation (yyVals[-3+yyTop]), GetLocation (yyVals[0+yyTop]));
	  }

void case_283()
#line 2283 "cs-parser.jay"
{
		valid_param_mod = 0;
		
		Location loc = GetLocation (yyVals[-5+yyTop]);
		current_local_parameters = (ParametersCompiled)yyVals[-1+yyTop];  

		if (current_local_parameters.Count != 1) {
			report.Error (1535, loc, "Overloaded unary operator `explicit' takes one parameter");
		}

		if (doc_support) {
			tmpComment = Lexer.consume_doc_comment ();
			Lexer.doc_state = XmlCommentState.NotAllowed;
		}

		yyVal = new OperatorDeclaration (Operator.OpType.Explicit, (FullNamedExpression) yyVals[-4+yyTop], loc);
		lbag.AddLocation (yyVal, GetLocation (yyVals[-6+yyTop]), GetLocation (yyVals[-5+yyTop]), GetLocation (yyVals[-3+yyTop]), GetLocation (yyVals[0+yyTop]));
	  }

void case_284()
#line 2302 "cs-parser.jay"
{
	  	Error_SyntaxError (yyToken);
		current_local_parameters = ParametersCompiled.EmptyReadOnlyParameters;
		yyVal = new OperatorDeclaration (Operator.OpType.Implicit, null, GetLocation (yyVals[-1+yyTop]));
	  }

void case_285()
#line 2308 "cs-parser.jay"
{
	  	Error_SyntaxError (yyToken);
		current_local_parameters = ParametersCompiled.EmptyReadOnlyParameters;
	  	yyVal = new OperatorDeclaration (Operator.OpType.Explicit, null, GetLocation (yyVals[-1+yyTop]));
	  }

void case_286()
#line 2318 "cs-parser.jay"
{ 
		Constructor c = (Constructor) yyVals[-1+yyTop];
		c.Block = (ToplevelBlock) yyVals[0+yyTop];
		
		if (doc_support)
			c.DocComment = ConsumeStoredComment ();

		current_local_parameters = null;
		if (doc_support)
			Lexer.doc_state = XmlCommentState.Allowed;
	  }

void case_287()
#line 2335 "cs-parser.jay"
{
		if (doc_support) {
			tmpComment = Lexer.consume_doc_comment ();
			Lexer.doc_state = XmlCommentState.Allowed;
		}
		
		valid_param_mod = ParameterModifierType.All;
	  }

void case_288()
#line 2344 "cs-parser.jay"
{
		valid_param_mod = 0;
		current_local_parameters = (ParametersCompiled) yyVals[-1+yyTop];
		
		var lt = (LocatedToken) yyVals[-4+yyTop];
		var mods = (Modifiers) yyVals[-5+yyTop];
		var c = new Constructor (current_type, lt.Value, mods, (Attributes) yyVals[-6+yyTop], current_local_parameters, lt.Location);

		if (lt.Value != current_container.MemberName.Name) {
			report.Error (1520, c.Location, "Class, struct, or interface method must have a return type");
		} else if ((mods & Modifiers.STATIC) != 0) {
			if ((mods & Modifiers.AccessibilityMask) != 0){
				report.Error (515, c.Location,
					"`{0}': static constructor cannot have an access modifier",
					c.GetSignatureForError ());
			}
		}

		current_type.AddConstructor (c);
		lbag.AddMember (c, mod_locations, GetLocation (yyVals[-2+yyTop]), GetLocation (yyVals[0+yyTop]));
		yyVal = c;

		/**/
		/* start block here, so possible anonymous methods inside*/
		/* constructor initializer can get correct parent block*/
		/**/
	  	start_block (lexer.Location);
	  }

void case_289()
#line 2373 "cs-parser.jay"
{
		if (yyVals[0+yyTop] != null) {
			var c = (Constructor) yyVals[-1+yyTop];
			c.Initializer = (ConstructorInitializer) yyVals[0+yyTop];
			
			if (c.IsStatic) {
				report.Error (514, c.Location,
					"`{0}': static constructor cannot have an explicit `this' or `base' constructor call",
					c.GetSignatureForError ());
			}
		}

		yyVal = yyVals[-1+yyTop];
	  }

void case_295()
#line 2405 "cs-parser.jay"
{
	  	--lexer.parsing_block;
		yyVal = new ConstructorBaseInitializer ((Arguments) yyVals[-1+yyTop], GetLocation (yyVals[-4+yyTop]));
		lbag.AddLocation (yyVal, GetLocation (yyVals[-5+yyTop]), GetLocation (yyVals[-3+yyTop]), GetLocation (yyVals[0+yyTop]));
	  }

void case_297()
#line 2415 "cs-parser.jay"
{
	  	--lexer.parsing_block;
		yyVal = new ConstructorThisInitializer ((Arguments) yyVals[-1+yyTop], GetLocation (yyVals[-4+yyTop]));
		lbag.AddLocation (yyVal, GetLocation (yyVals[-5+yyTop]), GetLocation (yyVals[-3+yyTop]), GetLocation (yyVals[0+yyTop]));
	  }

void case_298()
#line 2421 "cs-parser.jay"
{
		Error_SyntaxError (yyToken);	  
		yyVal = new ConstructorThisInitializer (null, GetLocation (yyVals[0+yyTop]));
		lbag.AddLocation (yyVal, GetLocation (yyVals[-1+yyTop]));
	  }

void case_299()
#line 2427 "cs-parser.jay"
{
		Error_SyntaxError (yyToken);
		yyVal = null;
	  }

void case_300()
#line 2435 "cs-parser.jay"
{
		if (doc_support) {
			tmpComment = Lexer.consume_doc_comment ();
			Lexer.doc_state = XmlCommentState.NotAllowed;
		}
		
		current_local_parameters = ParametersCompiled.EmptyReadOnlyParameters;
	  }

void case_301()
#line 2444 "cs-parser.jay"
{
		var lt = (LocatedToken) yyVals[-3+yyTop];
		if (lt.Value != current_container.MemberName.Name){
			report.Error (574, lt.Location, "Name of destructor must match name of class");
		} else if (current_container.Kind != MemberKind.Class){
			report.Error (575, lt.Location, "Only class types can contain destructor");
		}
		
		Destructor d = new Destructor (current_type, (Modifiers) yyVals[-6+yyTop],
			ParametersCompiled.EmptyReadOnlyParameters, (Attributes) yyVals[-7+yyTop], lt.Location);
		if (doc_support)
			d.DocComment = ConsumeStoredComment ();
		  
		d.Block = (ToplevelBlock) yyVals[0+yyTop];
		current_type.AddMember (d);
		lbag.AddMember (d, mod_locations, GetLocation (yyVals[-5+yyTop]), GetLocation (yyVals[-2+yyTop]), GetLocation (yyVals[-1+yyTop]));

		current_local_parameters = null;
	  }

void case_302()
#line 2469 "cs-parser.jay"
{
		current_event_field = new EventField (current_type, (FullNamedExpression) yyVals[-1+yyTop], (Modifiers) yyVals[-3+yyTop], (MemberName) yyVals[0+yyTop], (Attributes) yyVals[-4+yyTop]);
		current_type.AddMember (current_event_field);
		
		if (current_event_field.MemberName.ExplicitInterface != null) {
			report.Error (71, current_event_field.Location, "`{0}': An explicit interface implementation of an event must use property syntax",
			current_event_field.GetSignatureForError ());
		}
		
		yyVal = current_event_field;
	  }

void case_303()
#line 2483 "cs-parser.jay"
{
		if (doc_support) {
			current_event_field.DocComment = Lexer.consume_doc_comment ();
			Lexer.doc_state = XmlCommentState.Allowed;
		}
		
		lbag.AddMember (current_event_field, mod_locations, GetLocation (yyVals[-6+yyTop]), GetLocation (yyVals[0+yyTop]));
		current_event_field = null;
	  }

void case_304()
#line 2496 "cs-parser.jay"
{
		current_event = new EventProperty (current_type, (FullNamedExpression) yyVals[-2+yyTop], (Modifiers) yyVals[-4+yyTop], (MemberName) yyVals[-1+yyTop], (Attributes) yyVals[-5+yyTop]);
		current_type.AddMember (current_event);
		lbag.AddMember (current_event, mod_locations, GetLocation (yyVals[-3+yyTop]), GetLocation (yyVals[0+yyTop]));
		
		lexer.EventParsing = true;
	  }

void case_305()
#line 2504 "cs-parser.jay"
{
		if (current_container.Kind == MemberKind.Interface)
			report.Error (69, GetLocation (yyVals[-2+yyTop]), "Event in interface cannot have add or remove accessors");
	  
		lexer.EventParsing = false;
	  }

void case_306()
#line 2511 "cs-parser.jay"
{
		if (doc_support) {
			current_event.DocComment = Lexer.consume_doc_comment ();
			Lexer.doc_state = XmlCommentState.Allowed;
		}
		
		lbag.AppendToMember (current_event, GetLocation (yyVals[-1+yyTop]));
	  	current_event = null;	
		current_local_parameters = null;
	  }

void case_307()
#line 2524 "cs-parser.jay"
{
		Error_SyntaxError (yyToken);

		current_type.AddMember (new EventField (current_type, (FullNamedExpression) yyVals[-1+yyTop], (Modifiers) yyVals[-3+yyTop], MemberName.Null, (Attributes) yyVals[-4+yyTop]));
	  }

void case_310()
#line 2538 "cs-parser.jay"
{
	  	--lexer.parsing_block;
		current_event_field.Initializer = (Expression) yyVals[0+yyTop];
	  }

void case_315()
#line 2562 "cs-parser.jay"
{
		var lt = (LocatedToken) yyVals[0+yyTop];
	  	yyVal = new FieldDeclarator (new SimpleMemberName (lt.Value, lt.Location), null);
	  	lbag.AddLocation (yyVal, GetLocation (yyVals[-1+yyTop]));
	  }

void case_317()
#line 2572 "cs-parser.jay"
{
		--lexer.parsing_block;
		var lt = (LocatedToken) yyVals[-3+yyTop];	  
	  	yyVal = new FieldDeclarator (new SimpleMemberName (lt.Value, lt.Location), (Expression) yyVals[0+yyTop]);
	  	lbag.AddLocation (yyVal, GetLocation (yyVals[-4+yyTop]), GetLocation (yyVals[-2+yyTop]));
	  }

void case_318()
#line 2581 "cs-parser.jay"
{
		if (current_container.Kind == MemberKind.Interface) {
			report.Error (68, lexer.Location, "`{0}': event in interface cannot have an initializer",
				current_event_field.GetSignatureForError ());
		}
		
	  	if ((current_event_field.ModFlags & Modifiers.ABSTRACT) != 0) {
			report.Error (74, lexer.Location, "`{0}': abstract event cannot have an initializer",
				current_event_field.GetSignatureForError ());
	  	}		
	  }

void case_322()
#line 2602 "cs-parser.jay"
{
		report.Error (65, lexer.Location, "`{0}': event property must have both add and remove accessors",
			current_event.GetSignatureForError ());
	  }

void case_323()
#line 2607 "cs-parser.jay"
{
		report.Error (65, lexer.Location, "`{0}': event property must have both add and remove accessors",
			current_event.GetSignatureForError ());
	  }

void case_324()
#line 2612 "cs-parser.jay"
{ 
		report.Error (1055, GetLocation (yyVals[0+yyTop]), "An add or remove accessor expected");
		yyVal = null;
	  }

void case_325()
#line 2620 "cs-parser.jay"
{
	  	if (yyVals[-1+yyTop] != ModifierNone) {
			report.Error (1609, GetLocation (yyVals[-1+yyTop]), "Modifiers cannot be placed on event accessor declarations");
	  	}
	  	
	  	current_event.Add = new EventProperty.AddDelegateMethod (current_event, (Attributes) yyVals[-2+yyTop], GetLocation (yyVals[0+yyTop]));
		current_local_parameters = current_event.Add.ParameterInfo;
		
		lbag.AddMember (current_event.Add, mod_locations);
		lexer.EventParsing = false;		
	  }

void case_326()
#line 2632 "cs-parser.jay"
{
		lexer.EventParsing = true;
	  
	  	current_event.Add.Block = (ToplevelBlock) yyVals[0+yyTop];
		
		if (current_container.Kind == MemberKind.Interface) {
			report.Error (531, current_event.Add.Block.StartLocation,
				"`{0}': interface members cannot have a definition", current_event.Add.GetSignatureForError ());
		}
		
		current_local_parameters = null;
	  }

void case_327()
#line 2648 "cs-parser.jay"
{
	  	if (yyVals[-1+yyTop] != ModifierNone) {
			report.Error (1609, GetLocation (yyVals[-1+yyTop]), "Modifiers cannot be placed on event accessor declarations");
	  	}
	  	
	  	current_event.Remove = new EventProperty.RemoveDelegateMethod (current_event, (Attributes) yyVals[-2+yyTop], GetLocation (yyVals[0+yyTop]));
		current_local_parameters = current_event.Remove.ParameterInfo;

		lbag.AddMember (current_event.Remove, mod_locations);
		lexer.EventParsing = false;		
	  }

void case_328()
#line 2660 "cs-parser.jay"
{
		lexer.EventParsing = true;
	  
	  	current_event.Remove.Block = (ToplevelBlock) yyVals[0+yyTop];
		
		if (current_container.Kind == MemberKind.Interface) {
			report.Error (531, current_event.Remove.Block.StartLocation,
				"`{0}': interface members cannot have a definition", current_event.Remove.GetSignatureForError ());
		}
		
		current_local_parameters = null;
	  }

void case_329()
#line 2676 "cs-parser.jay"
{
		report.Error (73, lexer.Location, "An add or remove accessor must have a body");
		yyVal = null;
	  }

void case_331()
#line 2685 "cs-parser.jay"
{
		current_type.UnattachedAttributes = (Attributes) yyVals[-1+yyTop];
		report.Error (1519, GetLocation (yyVals[-1+yyTop]), "An attribute is missing member declaration");
		lexer.putback ('}');
	  }

void case_332()
#line 2696 "cs-parser.jay"
{
		report.Error (1519, lexer.Location, "Unexpected symbol `}' in class, struct, or interface member declaration");
 
		lexer.putback ('}');

	  	lexer.parsing_generic_declaration = false;
		FullNamedExpression type = (FullNamedExpression) yyVals[-1+yyTop];
		current_field = new Field (current_type, type, (Modifiers) yyVals[-2+yyTop], MemberName.Null, (Attributes) yyVals[-3+yyTop]);
		current_type.AddField (current_field);
		yyVal = current_field;
	  }

void case_333()
#line 2714 "cs-parser.jay"
{
		if (doc_support)
			enumTypeComment = Lexer.consume_doc_comment ();
	  }

void case_334()
#line 2719 "cs-parser.jay"
{
		if (doc_support)
			Lexer.doc_state = XmlCommentState.Allowed;

		MemberName name = (MemberName) yyVals[-3+yyTop];
		if (name.IsGeneric) {
			report.Error (1675, name.Location, "Enums cannot have type parameters");
		}
		
		push_current_container (new Enum (current_container, (FullNamedExpression) yyVals[-2+yyTop], (Modifiers) yyVals[-5+yyTop], name, (Attributes) yyVals[-6+yyTop]), null);
	  }

void case_335()
#line 2731 "cs-parser.jay"
{
		lexer.parsing_modifiers = true;
	  
	  	/* here will be evaluated after CLOSE_BLACE is consumed.*/
		if (doc_support)
			Lexer.doc_state = XmlCommentState.Allowed;
	  }

void case_336()
#line 2739 "cs-parser.jay"
{
		if (doc_support)
			current_container.DocComment = enumTypeComment;
			
		--lexer.parsing_declaration;

/*			if (doc_support)*/
/*				em.DocComment = ev.DocComment;*/

		lbag.AddMember (current_container, mod_locations, GetLocation (yyVals[-9+yyTop]), GetLocation (yyVals[-5+yyTop]), GetLocation (yyVals[-1+yyTop]));
		yyVal = pop_current_class ();
	  }

void case_339()
#line 2760 "cs-parser.jay"
{
	 	Error_TypeExpected (GetLocation (yyVals[-1+yyTop]));
		yyVal = null;
	 }

void case_344()
#line 2778 "cs-parser.jay"
{
	  	lbag.AddLocation (yyVals[-2+yyTop], GetLocation (yyVals[-1+yyTop]));
	  	yyVal = yyVals[0+yyTop];
	  }

void case_345()
#line 2786 "cs-parser.jay"
{
		var lt = (LocatedToken) yyVals[0+yyTop];
	  	var em = new EnumMember ((Enum) current_type, new MemberName (lt.Value, lt.Location), (Attributes) yyVals[-1+yyTop]);
	  	((Enum) current_type).AddEnumMember (em);

		if (doc_support) {
			em.DocComment = Lexer.consume_doc_comment ();
			Lexer.doc_state = XmlCommentState.Allowed;
		}

		yyVal = em;
	  }

void case_346()
#line 2799 "cs-parser.jay"
{
	  	++lexer.parsing_block;
		if (doc_support) {
			tmpComment = Lexer.consume_doc_comment ();
			Lexer.doc_state = XmlCommentState.NotAllowed;
		}
	  }

void case_347()
#line 2807 "cs-parser.jay"
{ 
		--lexer.parsing_block;
		
		var lt = (LocatedToken) yyVals[-3+yyTop];
	  	var em = new EnumMember ((Enum) current_type, new MemberName (lt.Value, lt.Location), (Attributes) yyVals[-4+yyTop]);
	  	em.Initializer = new ConstInitializer (em, (Expression) yyVals[0+yyTop], GetLocation (yyVals[-1+yyTop]));
	  	((Enum) current_type).AddEnumMember (em);
		
		if (doc_support)
			em.DocComment = ConsumeStoredComment ();

		yyVal = em;
	  }

void case_348()
#line 2821 "cs-parser.jay"
{
		Error_SyntaxError (yyToken);
	  
		var lt = (LocatedToken) yyVals[-1+yyTop];
	  	var em = new EnumMember ((Enum) current_type, new MemberName (lt.Value, lt.Location), (Attributes) yyVals[-2+yyTop]);
	  	((Enum) current_type).AddEnumMember (em);

		if (doc_support) {
			em.DocComment = Lexer.consume_doc_comment ();
			Lexer.doc_state = XmlCommentState.Allowed;
		}

		yyVal = em;
	  }

void case_351()
#line 2848 "cs-parser.jay"
{
		valid_param_mod = 0;

		ParametersCompiled p = (ParametersCompiled) yyVals[-1+yyTop];

		Delegate del = new Delegate (current_container, (FullNamedExpression) yyVals[-5+yyTop], (Modifiers) yyVals[-7+yyTop], (MemberName) yyVals[-4+yyTop], p, (Attributes) yyVals[-8+yyTop]);

		p.CheckParameters (del);

		current_container.AddTypeContainer (del);

		current_delegate = del;
		lexer.ConstraintsParsing = true;
	  }

void case_353()
#line 2867 "cs-parser.jay"
{
		if (doc_support) {
			current_delegate.DocComment = Lexer.consume_doc_comment ();
			Lexer.doc_state = XmlCommentState.Allowed;
		}
	  
		if (yyVals[-2+yyTop] != null)
			current_delegate.SetConstraints ((List<Constraints>) yyVals[-2+yyTop]);
		lbag.AddMember (current_delegate, mod_locations, GetLocation (yyVals[-10+yyTop]), GetLocation (yyVals[-7+yyTop]), GetLocation (yyVals[-4+yyTop]), GetLocation (yyVals[0+yyTop]));

		yyVal = current_delegate;

		current_delegate = null;
	  }

void case_355()
#line 2886 "cs-parser.jay"
{
		if (lang_version < LanguageVersion.ISO_2)
			FeatureIsNotAvailable (GetLocation (yyVals[0+yyTop]), "nullable types");
	  
	  	yyVal = ComposedTypeSpecifier.CreateNullable (GetLocation (yyVals[0+yyTop]));
	  }

void case_357()
#line 2897 "cs-parser.jay"
{
		var lt1 = (LocatedToken) yyVals[-2+yyTop];
		var lt2 = (LocatedToken) yyVals[-1+yyTop];
		
		yyVal = new QualifiedAliasMember (lt1.Value, lt2.Value, (TypeArguments) yyVals[0+yyTop], lt1.Location);
		lbag.AddLocation (yyVal, GetLocation (yyVals[-1+yyTop]));
	  }

void case_358()
#line 2905 "cs-parser.jay"
{
		var lt1 = (LocatedToken) yyVals[-2+yyTop];
		var lt2 = (LocatedToken) yyVals[-1+yyTop];

		yyVal = new QualifiedAliasMember (lt1.Value, lt2.Value, (int) yyVals[0+yyTop], lt1.Location);
		lbag.AddLocation (yyVal, GetLocation (yyVals[-1+yyTop]));
	  }

void case_360()
#line 2917 "cs-parser.jay"
{
		var lt = (LocatedToken) yyVals[-1+yyTop];
		yyVal = new MemberAccess ((Expression) yyVals[-3+yyTop], lt.Value, (TypeArguments) yyVals[0+yyTop], lt.Location);
		lbag.AddLocation (yyVal, GetLocation (yyVals[-2+yyTop]));
	  }

void case_361()
#line 2923 "cs-parser.jay"
{
		var lt = (LocatedToken) yyVals[-1+yyTop];
		yyVal = new MemberAccess ((Expression) yyVals[-3+yyTop], lt.Value, (int) yyVals[0+yyTop], lt.Location);
		lbag.AddLocation (yyVal, GetLocation (yyVals[-2+yyTop]));
	  }

void case_362()
#line 2932 "cs-parser.jay"
{
		var lt = (LocatedToken) yyVals[-1+yyTop];
		yyVal = new SimpleName (lt.Value, (TypeArguments)yyVals[0+yyTop], lt.Location);
	  }

void case_363()
#line 2937 "cs-parser.jay"
{  
		var lt = (LocatedToken) yyVals[-1+yyTop];
		yyVal = new SimpleName (lt.Value, (int) yyVals[0+yyTop], lt.Location);
	  }

void case_365()
#line 2949 "cs-parser.jay"
{
		if (lang_version < LanguageVersion.ISO_2)
			FeatureIsNotAvailable (GetLocation (yyVals[-2+yyTop]), "generics");	  
	  
		yyVal = yyVals[-1+yyTop];
	  }

void case_366()
#line 2956 "cs-parser.jay"
{
		Error_TypeExpected (lexer.Location);
		yyVal = new TypeArguments ();
	  }

void case_367()
#line 2964 "cs-parser.jay"
{
		TypeArguments type_args = new TypeArguments ();
		type_args.Add ((FullNamedExpression) yyVals[0+yyTop]);
		yyVal = type_args;
	  }

void case_368()
#line 2970 "cs-parser.jay"
{
		TypeArguments type_args = (TypeArguments) yyVals[-2+yyTop];
		type_args.Add ((FullNamedExpression) yyVals[0+yyTop]);
		yyVal = type_args;
	  }

void case_370()
#line 2986 "cs-parser.jay"
{
		lexer.parsing_generic_declaration = false;
		var lt = (LocatedToken) yyVals[-2+yyTop];
		yyVal = new MemberName (lt.Value, (TypeParameters)yyVals[0+yyTop], lt.Location);
	  }

void case_371()
#line 2995 "cs-parser.jay"
{
	  	MemberName mn = (MemberName)yyVals[0+yyTop];
	  	if (mn.TypeParameters != null)
	  		syntax_error (mn.Location, string.Format ("Member `{0}' cannot declare type arguments",
	  			mn.GetSignatureForError ()));
	  }

void case_373()
#line 3006 "cs-parser.jay"
{
		lexer.parsing_generic_declaration = false;	  
		var lt = (LocatedToken) yyVals[-1+yyTop];
		yyVal = new MemberName (lt.Value, (TypeParameters) yyVals[0+yyTop], (ATypeNameExpression) yyVals[-2+yyTop], lt.Location);
	  }

void case_374()
#line 3015 "cs-parser.jay"
{
		lexer.parsing_generic_declaration = false;	  
		yyVal = new MemberName (TypeDefinition.DefaultIndexerName, GetLocation (yyVals[0+yyTop]));
	  }

void case_375()
#line 3020 "cs-parser.jay"
{
		lexer.parsing_generic_declaration = false;
		yyVal = new MemberName (TypeDefinition.DefaultIndexerName, null, (ATypeNameExpression) yyVals[-1+yyTop], GetLocation (yyVals[0+yyTop]));
	  }

void case_376()
#line 3028 "cs-parser.jay"
{
		var lt = (LocatedToken) yyVals[-2+yyTop];
		yyVal = new SimpleName (lt.Value, (TypeArguments) yyVals[-1+yyTop], lt.Location);
		lbag.AddLocation (yyVal, GetLocation (yyVals[0+yyTop]));
	  }

void case_377()
#line 3034 "cs-parser.jay"
{
		var lt1 = (LocatedToken) yyVals[-3+yyTop];
		var lt2 = (LocatedToken) yyVals[-2+yyTop];

		yyVal = new QualifiedAliasMember (lt1.Value, lt2.Value, (TypeArguments) yyVals[-1+yyTop], lt1.Location);
		lbag.AddLocation (yyVal, GetLocation (yyVals[0+yyTop]));
	  }

void case_378()
#line 3042 "cs-parser.jay"
{
		var lt = (LocatedToken) yyVals[-2+yyTop];
		yyVal = new MemberAccess ((ATypeNameExpression) yyVals[-3+yyTop], lt.Value, (TypeArguments) yyVals[-1+yyTop], lt.Location);
		lbag.AddLocation (yyVal, GetLocation (yyVals[0+yyTop]));
	  }

void case_380()
#line 3052 "cs-parser.jay"
{
		if (lang_version < LanguageVersion.ISO_2)
			FeatureIsNotAvailable (GetLocation (yyVals[-2+yyTop]), "generics");
	  
		yyVal = yyVals[-1+yyTop];
		lbag.AddLocation (yyVal, GetLocation (yyVals[-2+yyTop]), GetLocation (yyVals[0+yyTop]));
	  }

void case_381()
#line 3063 "cs-parser.jay"
{
		var tparams = new TypeParameters ();
		tparams.Add ((TypeParameter)yyVals[0+yyTop]);
		yyVal = tparams;
	  }

void case_382()
#line 3069 "cs-parser.jay"
{
		var tparams = (TypeParameters) yyVals[-2+yyTop];
		tparams.Add ((TypeParameter)yyVals[0+yyTop]);
		yyVal = tparams;
		lbag.AddLocation (yyVals[0+yyTop], GetLocation (yyVals[0+yyTop]));
	  }

void case_383()
#line 3079 "cs-parser.jay"
{
		var lt = (LocatedToken)yyVals[0+yyTop];
		yyVal = new TypeParameter (new MemberName (lt.Value, lt.Location), (Attributes)yyVals[-2+yyTop], (VarianceDecl) yyVals[-1+yyTop]);
  	  }

void case_384()
#line 3084 "cs-parser.jay"
{
  	  	if (GetTokenName (yyToken) == "type")
			report.Error (81, GetLocation (yyVals[0+yyTop]), "Type parameter declaration must be an identifier not a type");
		else
			Error_SyntaxError (yyToken);
			
  	  	yyVal = new TypeParameter (MemberName.Null, null, null);
  	  }

void case_389()
#line 3118 "cs-parser.jay"
{
	  	Expression.Error_VoidInvalidInTheContext (GetLocation (yyVals[0+yyTop]), report);
		yyVal = new TypeExpression (compiler.BuiltinTypes.Void, GetLocation (yyVals[0+yyTop]));
	  }

void case_391()
#line 3127 "cs-parser.jay"
{
	  	Expression.Error_VoidInvalidInTheContext (GetLocation (yyVals[0+yyTop]), report);
		yyVal = new TypeExpression (compiler.BuiltinTypes.Void, GetLocation (yyVals[0+yyTop]));
	  }

void case_393()
#line 3136 "cs-parser.jay"
{
	  	report.Error (1536, GetLocation (yyVals[0+yyTop]), "Invalid parameter type `void'");
		yyVal = new TypeExpression (compiler.BuiltinTypes.Void, GetLocation (yyVals[0+yyTop]));
	  }

void case_396()
#line 3152 "cs-parser.jay"
{
		if (yyVals[0+yyTop] != null) {
			yyVal = new ComposedCast ((ATypeNameExpression) yyVals[-1+yyTop], (ComposedTypeSpecifier) yyVals[0+yyTop]);
		} else {
			var sn = yyVals[-1+yyTop] as SimpleName;
			if (sn != null && sn.Name == "var")
				yyVal = new VarExpr (sn.Location);
			else
				yyVal = yyVals[-1+yyTop];
		}
	  }

void case_398()
#line 3168 "cs-parser.jay"
{
		if (yyVals[0+yyTop] != null)
			yyVal = new ComposedCast ((FullNamedExpression) yyVals[-1+yyTop], (ComposedTypeSpecifier) yyVals[0+yyTop]);
	  }

void case_401()
#line 3184 "cs-parser.jay"
{
		var types = new List<FullNamedExpression> (2);
		types.Add ((FullNamedExpression) yyVals[0+yyTop]);
		yyVal = types;
	  }

void case_402()
#line 3190 "cs-parser.jay"
{
		var types = (List<FullNamedExpression>) yyVals[-2+yyTop];
		types.Add ((FullNamedExpression) yyVals[0+yyTop]);
		yyVal = types;
	  }

void case_403()
#line 3199 "cs-parser.jay"
{
		if (yyVals[0+yyTop] is ComposedCast) {
			report.Error (1521, GetLocation (yyVals[0+yyTop]), "Invalid base type `{0}'", ((ComposedCast)yyVals[0+yyTop]).GetSignatureForError ());
		}
		yyVal = yyVals[0+yyTop];
	  }

void case_441()
#line 3263 "cs-parser.jay"
{
		var lt = (LocatedToken) yyVals[-1+yyTop];
	       yyVal = new CompletionSimpleName (MemberName.MakeName (lt.Value, null), lt.Location);
	  }

void case_452()
#line 3304 "cs-parser.jay"
{
		yyVal = new ParenthesizedExpression ((Expression) yyVals[-1+yyTop], GetLocation (yyVals[-2+yyTop]));
		lbag.AddLocation (yyVal, GetLocation (yyVals[-2+yyTop]), GetLocation (yyVals[0+yyTop]));
	  }

void case_454()
#line 3316 "cs-parser.jay"
{
		var lt = (LocatedToken) yyVals[-1+yyTop];
		yyVal = new MemberAccess ((Expression) yyVals[-3+yyTop], lt.Value, (TypeArguments) yyVals[0+yyTop], lt.Location);
		lbag.AddLocation (yyVal, GetLocation (yyVals[-2+yyTop]));
	  }

void case_455()
#line 3322 "cs-parser.jay"
{
		var lt = (LocatedToken) yyVals[-1+yyTop];
		yyVal = new MemberAccess ((Expression) yyVals[-3+yyTop], lt.Value, (int) yyVals[0+yyTop], lt.Location);
		lbag.AddLocation (yyVal, GetLocation (yyVals[-2+yyTop]));
	  }

void case_456()
#line 3328 "cs-parser.jay"
{
		if (lang_version < LanguageVersion.V_6)
			FeatureIsNotAvailable (GetLocation (yyVals[-3+yyTop]), "null propagating operator");

		var lt = (LocatedToken) yyVals[-1+yyTop];
		yyVal = new ConditionalMemberAccess ((Expression) yyVals[-4+yyTop], lt.Value, (TypeArguments) yyVals[0+yyTop], lt.Location);
		lbag.AddLocation (yyVal, GetLocation (yyVals[-3+yyTop]), GetLocation (yyVals[-2+yyTop]));
	  }

void case_457()
#line 3337 "cs-parser.jay"
{
		var lt = (LocatedToken) yyVals[-1+yyTop];
		yyVal = new MemberAccess ((Expression) yyVals[-3+yyTop], lt.Value, (TypeArguments) yyVals[0+yyTop], lt.Location);
		lbag.AddLocation (yyVal, GetLocation (yyVals[-2+yyTop]));
	  }

void case_458()
#line 3343 "cs-parser.jay"
{
		var lt = (LocatedToken) yyVals[-1+yyTop];
		yyVal = new MemberAccess (new BaseThis (GetLocation (yyVals[-3+yyTop])), lt.Value, (TypeArguments) yyVals[0+yyTop], lt.Location);
		lbag.AddLocation (yyVal, GetLocation (yyVals[-2+yyTop]));
	  }

void case_459()
#line 3349 "cs-parser.jay"
{
		var lt = (LocatedToken) yyVals[-1+yyTop];
		yyVal = new MemberAccess (new SimpleName ("await", ((LocatedToken) yyVals[-3+yyTop]).Location), lt.Value, (TypeArguments) yyVals[0+yyTop], lt.Location);
		lbag.AddLocation (yyVal, GetLocation (yyVals[-2+yyTop]));
	  }

void case_460()
#line 3355 "cs-parser.jay"
{
		var lt1 = (LocatedToken) yyVals[-2+yyTop];
		var lt2 = (LocatedToken) yyVals[-1+yyTop];

		yyVal = new QualifiedAliasMember (lt1.Value, lt2.Value, (TypeArguments) yyVals[0+yyTop], lt1.Location);
		lbag.AddLocation (yyVal, GetLocation (yyVals[-1+yyTop]));
	  }

void case_461()
#line 3363 "cs-parser.jay"
{
		var lt1 = (LocatedToken) yyVals[-2+yyTop];
		var lt2 = (LocatedToken) yyVals[-1+yyTop];

		yyVal = new QualifiedAliasMember (lt1.Value, lt2.Value, (int) yyVals[0+yyTop], lt1.Location);
		lbag.AddLocation (yyVal, GetLocation (yyVals[-1+yyTop]));
	  }

void case_463()
#line 3373 "cs-parser.jay"
{
		var lt = (LocatedToken) yyVals[-1+yyTop];
		yyVal = new CompletionMemberAccess ((Expression) yyVals[-3+yyTop], lt.Value, lt.Location);
	  }

void case_465()
#line 3381 "cs-parser.jay"
{
		var lt = (LocatedToken) yyVals[-1+yyTop];
		yyVal = new CompletionMemberAccess ((Expression) yyVals[-3+yyTop], lt.Value, lt.Location);
 	  }

void case_466()
#line 3389 "cs-parser.jay"
{
		yyVal = new Invocation ((Expression) yyVals[-3+yyTop], (Arguments) yyVals[-1+yyTop]);
		lbag.AddLocation (yyVal, GetLocation (yyVals[-2+yyTop]), GetLocation (yyVals[0+yyTop]));
	  }

void case_467()
#line 3394 "cs-parser.jay"
{
		Error_SyntaxError (yyToken);

		yyVal = new Invocation ((Expression) yyVals[-3+yyTop], (Arguments) yyVals[-1+yyTop]);
		lbag.AddLocation (yyVal, GetLocation (yyVals[-2+yyTop]));
	  }

void case_468()
#line 3401 "cs-parser.jay"
{
		Error_SyntaxError (yyToken);

		yyVal = new Invocation ((Expression) yyVals[-2+yyTop], null);
		lbag.AddLocation (yyVal, GetLocation (yyVals[-1+yyTop]));
	  }

void case_471()
#line 3416 "cs-parser.jay"
{
	  	if (yyVals[-1+yyTop] == null) {
	  		yyVal = new CollectionOrObjectInitializers (GetLocation (yyVals[-2+yyTop]));
	  	} else {
	  		yyVal = new CollectionOrObjectInitializers ((List<Expression>) yyVals[-1+yyTop], GetLocation (yyVals[-2+yyTop]));
	  	}
 		lbag.AddLocation (yyVal, GetLocation (yyVals[0+yyTop]));
	  }

void case_472()
#line 3425 "cs-parser.jay"
{
	  	yyVal = new CollectionOrObjectInitializers ((List<Expression>) yyVals[-2+yyTop], GetLocation (yyVals[-3+yyTop]));
	  	lbag.AddLocation (yyVal, GetLocation (yyVals[-1+yyTop]), GetLocation (yyVals[0+yyTop]));
	  }

void case_475()
#line 3441 "cs-parser.jay"
{
	  	var a = new List<Expression> ();
	  	a.Add ((Expression) yyVals[0+yyTop]);
	  	yyVal = a;
	  }

void case_476()
#line 3447 "cs-parser.jay"
{
	  	var a = (List<Expression>)yyVals[-2+yyTop];
	  	a.Add ((Expression) yyVals[0+yyTop]);
	  	yyVal = a;
	  }

void case_477()
#line 3452 "cs-parser.jay"
{
	  	Error_SyntaxError (yyToken);
		yyVal = yyVals[-1+yyTop];
	  }

void case_478()
#line 3460 "cs-parser.jay"
{
	  	var lt = (LocatedToken) yyVals[-2+yyTop];
	  	yyVal = new ElementInitializer (lt.Value, (Expression)yyVals[0+yyTop], lt.Location);
	  	lbag.AddLocation (yyVal, GetLocation (yyVals[-1+yyTop]));
	  }

void case_479()
#line 3466 "cs-parser.jay"
{
	  	var lt = (LocatedToken) Error_AwaitAsIdentifier (yyVals[-2+yyTop]);
	  	yyVal = new ElementInitializer (lt.Value, (Expression)yyVals[0+yyTop], lt.Location);
	  	lbag.AddLocation (yyVal, GetLocation (yyVals[-1+yyTop]));
	  }

void case_481()
#line 3475 "cs-parser.jay"
{
		CompletionSimpleName csn = yyVals[-1+yyTop] as CompletionSimpleName;
		if (csn == null)
			yyVal = new CollectionElementInitializer ((Expression)yyVals[-1+yyTop]);
		else
			yyVal = new CompletionElementInitializer (csn.Prefix, csn.Location);
	  }

void case_482()
#line 3483 "cs-parser.jay"
{
		if (yyVals[-1+yyTop] == null)
			yyVal = new CollectionElementInitializer (GetLocation (yyVals[-2+yyTop]));
		else
	  		yyVal = new CollectionElementInitializer ((List<Expression>)yyVals[-1+yyTop], GetLocation (yyVals[-2+yyTop]));

		lbag.AddLocation (yyVal, GetLocation (yyVals[0+yyTop]));
	  }

void case_483()
#line 3492 "cs-parser.jay"
{
		if (lang_version < LanguageVersion.V_6)
			FeatureIsNotAvailable (GetLocation (yyVals[-4+yyTop]), "dictionary initializer");

		yyVal = new DictionaryElementInitializer ((List<Expression>)yyVals[-3+yyTop], (Expression) yyVals[0+yyTop], GetLocation (yyVals[-4+yyTop]));
		lbag.AddLocation (yyVal, GetLocation (yyVals[-2+yyTop]), GetLocation (yyVals[-1+yyTop]));
	  }

void case_484()
#line 3500 "cs-parser.jay"
{
	  	report.Error (1920, GetLocation (yyVals[-1+yyTop]), "An element initializer cannot be empty");
		yyVal = new CollectionElementInitializer (GetLocation (yyVals[-1+yyTop]));
		lbag.AddLocation (yyVal, GetLocation (yyVals[0+yyTop]));
	  }

void case_489()
#line 3519 "cs-parser.jay"
{ 
		Arguments list = new Arguments (4);
		list.Add ((Argument) yyVals[0+yyTop]);
		yyVal = list;
	  }

void case_490()
#line 3525 "cs-parser.jay"
{
		Arguments list = (Arguments) yyVals[-2+yyTop];
		if (list [list.Count - 1] is NamedArgument)
			Error_NamedArgumentExpected ((NamedArgument) list [list.Count - 1]);
		
		list.Add ((Argument) yyVals[0+yyTop]);
		yyVal = list;
	  }

void case_491()
#line 3534 "cs-parser.jay"
{
		Arguments list = (Arguments) yyVals[-2+yyTop];
		NamedArgument a = (NamedArgument) yyVals[0+yyTop];
		for (int i = 0; i < list.Count; ++i) {
			NamedArgument na = list [i] as NamedArgument;
			if (na != null && na.Name == a.Name)
				report.Error (1740, na.Location, "Named argument `{0}' specified multiple times",
					na.Name);
		}
		
		list.Add (a);
		yyVal = list;
	  }

void case_492()
#line 3548 "cs-parser.jay"
{
	  	if (lexer.putback_char == -1)
	  		lexer.putback (')'); /* TODO: Wrong but what can I do*/
		Error_SyntaxError (yyToken);
		yyVal = yyVals[-2+yyTop];
	  }

void case_493()
#line 3555 "cs-parser.jay"
{
	  	report.Error (839, GetLocation (yyVals[-1+yyTop]), "An argument is missing");
	  	yyVal = null;
	  }

void case_498()
#line 3576 "cs-parser.jay"
{ 
		yyVal = new Argument ((Expression) yyVals[0+yyTop], Argument.AType.Ref);
		lbag.AddLocation (yyVal, GetLocation (yyVals[-1+yyTop]));
	  }

void case_499()
#line 3581 "cs-parser.jay"
{ 
		yyVal = new Argument ((Expression) yyVals[0+yyTop], Argument.AType.Out);
		lbag.AddLocation (yyVal, GetLocation (yyVals[-1+yyTop]));
	  }

void case_500()
#line 3586 "cs-parser.jay"
{
		yyVal = new Argument (new Arglist ((Arguments) yyVals[-1+yyTop], GetLocation (yyVals[-3+yyTop])));
		lbag.AddLocation (yyVal, GetLocation (yyVals[-2+yyTop]), GetLocation (yyVals[0+yyTop]));
	  }

void case_501()
#line 3591 "cs-parser.jay"
{
		yyVal = new Argument (new Arglist (GetLocation (yyVals[-2+yyTop])));
		lbag.AddLocation (yyVal, GetLocation (yyVals[-1+yyTop]), GetLocation (yyVals[0+yyTop]));
	  }

void case_503()
#line 3603 "cs-parser.jay"
{
		yyVal = new ElementAccess ((Expression) yyVals[-3+yyTop], (Arguments) yyVals[-1+yyTop], GetLocation (yyVals[-2+yyTop]));
		lbag.AddLocation (yyVal, GetLocation (yyVals[0+yyTop]));
	  }

void case_504()
#line 3608 "cs-parser.jay"
{
		if (lang_version < LanguageVersion.V_6)
			FeatureIsNotAvailable (GetLocation (yyVals[-3+yyTop]), "null propagating operator");

		yyVal = new ElementAccess ((Expression) yyVals[-4+yyTop], (Arguments) yyVals[-1+yyTop], GetLocation (yyVals[-2+yyTop])) {
			ConditionalAccess = true
		};

		lbag.AddLocation (yyVal, GetLocation (yyVals[-3+yyTop]), GetLocation (yyVals[0+yyTop]));
	  }

void case_505()
#line 3619 "cs-parser.jay"
{
		Error_SyntaxError (yyToken);
		yyVal = new ElementAccess ((Expression) yyVals[-3+yyTop], (Arguments) yyVals[-1+yyTop], GetLocation (yyVals[-2+yyTop]));
	  }

void case_506()
#line 3624 "cs-parser.jay"
{
		Error_SyntaxError (yyToken);
		yyVal = new ElementAccess ((Expression) yyVals[-2+yyTop], null, GetLocation (yyVals[-1+yyTop]));
	  }

void case_507()
#line 3632 "cs-parser.jay"
{
		var list = new List<Expression> (4);
		list.Add ((Expression) yyVals[0+yyTop]);
		yyVal = list;
	  }

void case_508()
#line 3638 "cs-parser.jay"
{
		var list = (List<Expression>) yyVals[-2+yyTop];
		list.Add ((Expression) yyVals[0+yyTop]);
		yyVal = list;
	  }

void case_509()
#line 3647 "cs-parser.jay"
{
		Arguments args = new Arguments (4);
		args.Add ((Argument) yyVals[0+yyTop]);
		yyVal = args;
	  }

void case_510()
#line 3653 "cs-parser.jay"
{
		Arguments args = (Arguments) yyVals[-2+yyTop];
		if (args [args.Count - 1] is NamedArgument && !(yyVals[0+yyTop] is NamedArgument))
			Error_NamedArgumentExpected ((NamedArgument) args [args.Count - 1]);
	  
		args.Add ((Argument) yyVals[0+yyTop]);
		yyVal = args;	  
	  }

void case_514()
#line 3680 "cs-parser.jay"
{
	  	yyVal = new ElementAccess (new BaseThis (GetLocation (yyVals[-3+yyTop])), (Arguments) yyVals[-1+yyTop], GetLocation (yyVals[-2+yyTop]));
		lbag.AddLocation (yyVal, GetLocation (yyVals[0+yyTop]));
	  }

void case_515()
#line 3685 "cs-parser.jay"
{
	  	Error_SyntaxError (yyToken);
		yyVal = new ElementAccess (null, null, GetLocation (yyVals[-1+yyTop]));
	  }

void case_518()
#line 3707 "cs-parser.jay"
{
		if (yyVals[0+yyTop] != null) {
			if (lang_version <= LanguageVersion.ISO_2)
				FeatureIsNotAvailable (GetLocation (yyVals[-5+yyTop]), "object initializers");
				
			yyVal = new NewInitialize ((FullNamedExpression) yyVals[-4+yyTop], (Arguments) yyVals[-2+yyTop], (CollectionOrObjectInitializers) yyVals[0+yyTop], GetLocation (yyVals[-5+yyTop]));
		} else {
			yyVal = new New ((FullNamedExpression) yyVals[-4+yyTop], (Arguments) yyVals[-2+yyTop], GetLocation (yyVals[-5+yyTop]));
		}
		
		lbag.AddLocation (yyVal, GetLocation (yyVals[-3+yyTop]), GetLocation (yyVals[-1+yyTop]));
	  }

void case_519()
#line 3720 "cs-parser.jay"
{
		if (lang_version <= LanguageVersion.ISO_2)
			FeatureIsNotAvailable (GetLocation (yyVals[-2+yyTop]), "collection initializers");
	  
		yyVal = new NewInitialize ((FullNamedExpression) yyVals[-1+yyTop], null, (CollectionOrObjectInitializers) yyVals[0+yyTop], GetLocation (yyVals[-2+yyTop]));
	  }

void case_520()
#line 3732 "cs-parser.jay"
{
		yyVal = new ArrayCreation ((FullNamedExpression) yyVals[-5+yyTop], (List<Expression>) yyVals[-3+yyTop],
				new ComposedTypeSpecifier (((List<Expression>) yyVals[-3+yyTop]).Count, GetLocation (yyVals[-4+yyTop])) {
	  				Next = (ComposedTypeSpecifier) yyVals[-1+yyTop]
			  	}, (ArrayInitializer) yyVals[0+yyTop], GetLocation (yyVals[-6+yyTop]));
		lbag.AddLocation (yyVal, GetLocation (yyVals[-4+yyTop]), GetLocation (yyVals[-2+yyTop]));
	  }

void case_521()
#line 3740 "cs-parser.jay"
{
	  	if (yyVals[0+yyTop] == null)
	  		report.Error (1586, GetLocation (yyVals[-3+yyTop]), "Array creation must have array size or array initializer");

		yyVal = new ArrayCreation ((FullNamedExpression) yyVals[-2+yyTop], (ComposedTypeSpecifier) yyVals[-1+yyTop], (ArrayInitializer) yyVals[0+yyTop], GetLocation (yyVals[-3+yyTop]));
	  }

void case_522()
#line 3747 "cs-parser.jay"
{
		if (lang_version <= LanguageVersion.ISO_2)
			FeatureIsNotAvailable (GetLocation (yyVals[-2+yyTop]), "implicitly typed arrays");
	  
		yyVal = new ImplicitlyTypedArrayCreation ((ComposedTypeSpecifier) yyVals[-1+yyTop], (ArrayInitializer) yyVals[0+yyTop], GetLocation (yyVals[-2+yyTop]));
	  }

void case_523()
#line 3754 "cs-parser.jay"
{
		report.Error (178, GetLocation (yyVals[-1+yyTop]), "Invalid rank specifier, expecting `,' or `]'");
		yyVal = new ArrayCreation ((FullNamedExpression) yyVals[-5+yyTop], null, GetLocation (yyVals[-6+yyTop]));
	  }

void case_524()
#line 3759 "cs-parser.jay"
{
		Error_SyntaxError (yyToken);
		/* It can be any of new expression, create the most common one*/
		yyVal = new New ((FullNamedExpression) yyVals[-1+yyTop], null, GetLocation (yyVals[-2+yyTop]));
	  }

void case_526()
#line 3771 "cs-parser.jay"
{
		--lexer.parsing_type;
		yyVal = yyVals[0+yyTop];
	  }

void case_527()
#line 3779 "cs-parser.jay"
{
		if (lang_version <= LanguageVersion.ISO_2)
	  		FeatureIsNotAvailable (GetLocation (yyVals[-3+yyTop]), "anonymous types");

		yyVal = new NewAnonymousType ((List<AnonymousTypeParameter>) yyVals[-1+yyTop], current_container, GetLocation (yyVals[-3+yyTop]));
		
		/* TODO: lbag comma location*/
		lbag.AddLocation (yyVal, GetLocation (yyVals[-2+yyTop]), GetLocation (yyVals[0+yyTop]));
	  }

void case_533()
#line 3806 "cs-parser.jay"
{
	  	var a = new List<AnonymousTypeParameter> (4);
	  	a.Add ((AnonymousTypeParameter) yyVals[0+yyTop]);
	  	yyVal = a;
	  }

void case_534()
#line 3812 "cs-parser.jay"
{
	  	var a = (List<AnonymousTypeParameter>) yyVals[-2+yyTop];
	  	a.Add ((AnonymousTypeParameter) yyVals[0+yyTop]);
	  	yyVal = a;
	  }

void case_537()
#line 3829 "cs-parser.jay"
{
		var lt = (LocatedToken)yyVals[-2+yyTop];
	  	yyVal = new AnonymousTypeParameter ((Expression)yyVals[0+yyTop], lt.Value, lt.Location);
	  	lbag.AddLocation (yyVal, GetLocation (yyVals[-1+yyTop]));
	  }

void case_538()
#line 3835 "cs-parser.jay"
{
		var lt = (LocatedToken)yyVals[0+yyTop];
	  	yyVal = new AnonymousTypeParameter (new SimpleName (lt.Value, lt.Location),
	  		lt.Value, lt.Location);
	  }

void case_539()
#line 3841 "cs-parser.jay"
{
	  	MemberAccess ma = (MemberAccess) yyVals[0+yyTop];
	  	yyVal = new AnonymousTypeParameter (ma, ma.Name, ma.Location);
	  }

void case_540()
#line 3846 "cs-parser.jay"
{
		report.Error (746, lexer.Location,
			"Invalid anonymous type member declarator. Anonymous type members must be a member assignment, simple name or member access expression");
		yyVal = null;
	  }

void case_544()
#line 3861 "cs-parser.jay"
{
	  	((ComposedTypeSpecifier) yyVals[-1+yyTop]).Next = (ComposedTypeSpecifier) yyVals[0+yyTop];
	  	yyVal = yyVals[-1+yyTop];
	  }

void case_545()
#line 3869 "cs-parser.jay"
{
		yyVal = ComposedTypeSpecifier.CreateArrayDimension (1, GetLocation (yyVals[-1+yyTop]));
		lbag.AddLocation (yyVal, GetLocation (yyVals[0+yyTop]));
	  }

void case_546()
#line 3874 "cs-parser.jay"
{
		yyVal = ComposedTypeSpecifier.CreateArrayDimension ((int)yyVals[-1+yyTop], GetLocation (yyVals[-2+yyTop]));
		lbag.AddLocation (yyVal, GetLocation (yyVals[0+yyTop]));
	  }

void case_551()
#line 3904 "cs-parser.jay"
{
		var ai = new ArrayInitializer (0, GetLocation (yyVals[-1+yyTop]));
		ai.VariableDeclaration = current_variable;
		lbag.AddLocation (ai, GetLocation (yyVals[0+yyTop]));
		yyVal = ai;
	  }

void case_552()
#line 3911 "cs-parser.jay"
{
		var ai = new ArrayInitializer ((List<Expression>) yyVals[-2+yyTop], GetLocation (yyVals[-3+yyTop]));
		ai.VariableDeclaration = current_variable;
		if (yyVals[-1+yyTop] != null) {
			lbag.AddLocation (ai, GetLocation (yyVals[-1+yyTop]), GetLocation (yyVals[0+yyTop]));
		} else {
			lbag.AddLocation (ai, GetLocation (yyVals[0+yyTop]));
		}
		yyVal = ai;
	  }

void case_553()
#line 3925 "cs-parser.jay"
{
		var list = new List<Expression> (4);
		list.Add ((Expression) yyVals[0+yyTop]);
		yyVal = list;
	  }

void case_554()
#line 3931 "cs-parser.jay"
{
		var list = (List<Expression>) yyVals[-2+yyTop];
		list.Add ((Expression) yyVals[0+yyTop]);
		yyVal = list;
	  }

void case_555()
#line 3940 "cs-parser.jay"
{
		yyVal = new TypeOf ((FullNamedExpression) yyVals[-1+yyTop], GetLocation (yyVals[-3+yyTop]));
		lbag.AddLocation (yyVal, GetLocation (yyVals[-2+yyTop]), GetLocation (yyVals[0+yyTop]));
	  }

void case_557()
#line 3949 "cs-parser.jay"
{
	 	Error_TypeExpected (lexer.Location);
	 	yyVal = null;
	 }

void case_558()
#line 3957 "cs-parser.jay"
{
		if (lang_version < LanguageVersion.ISO_2)
			FeatureIsNotAvailable (GetLocation (yyVals[0+yyTop]), "generics");

		yyVal = yyVals[0+yyTop];
	  }

void case_559()
#line 3967 "cs-parser.jay"
{
		var lt = (LocatedToken) yyVals[-1+yyTop];
		if (lang_version == LanguageVersion.ISO_1)
			FeatureIsNotAvailable (lt.Location, "namespace alias qualifier");

		yyVal = lt;		
	  }

void case_560()
#line 3978 "cs-parser.jay"
{ 
		yyVal = new SizeOf ((Expression) yyVals[-1+yyTop], GetLocation (yyVals[-3+yyTop]));
		lbag.AddLocation (yyVal, GetLocation (yyVals[-2+yyTop]), GetLocation (yyVals[0+yyTop]));
	  }

void case_561()
#line 3983 "cs-parser.jay"
{
		Error_SyntaxError (yyToken);

		yyVal = new SizeOf ((Expression) yyVals[-1+yyTop], GetLocation (yyVals[-3+yyTop]));
		lbag.AddLocation (yyVal, GetLocation (yyVals[-2+yyTop]));
	  }

void case_562()
#line 3993 "cs-parser.jay"
{
		yyVal = new CheckedExpr ((Expression) yyVals[-1+yyTop], GetLocation (yyVals[-3+yyTop]));
		lbag.AddLocation (yyVal, GetLocation (yyVals[-2+yyTop]), GetLocation (yyVals[0+yyTop]));
	  }

void case_563()
#line 3998 "cs-parser.jay"
{
		Error_SyntaxError (yyToken);

		yyVal = new CheckedExpr (null, GetLocation (yyVals[-1+yyTop]));
	  }

void case_564()
#line 4007 "cs-parser.jay"
{
		yyVal = new UnCheckedExpr ((Expression) yyVals[-1+yyTop], GetLocation (yyVals[-3+yyTop]));
		lbag.AddLocation (yyVal, GetLocation (yyVals[-2+yyTop]), GetLocation (yyVals[0+yyTop]));
	  }

void case_565()
#line 4012 "cs-parser.jay"
{
		Error_SyntaxError (yyToken);

		yyVal = new UnCheckedExpr (null, GetLocation (yyVals[-1+yyTop]));
	  }

void case_566()
#line 4021 "cs-parser.jay"
{
		var lt = (LocatedToken) yyVals[-1+yyTop];
		yyVal = new MemberAccess (new Indirection ((Expression) yyVals[-3+yyTop], GetLocation (yyVals[-2+yyTop])), lt.Value, (TypeArguments) yyVals[0+yyTop], lt.Location);
	  }

void case_574()
#line 4060 "cs-parser.jay"
{
		valid_param_mod = 0;
	  	yyVal = yyVals[-1+yyTop];
	  }

void case_575()
#line 4068 "cs-parser.jay"
{
		if (lang_version < LanguageVersion.ISO_2)
			FeatureIsNotAvailable (GetLocation (yyVals[-3+yyTop]), "default value expression");

		yyVal = new DefaultValueExpression ((Expression) yyVals[-1+yyTop], GetLocation (yyVals[-3+yyTop]));
		lbag.AddLocation (yyVal, GetLocation (yyVals[-2+yyTop]), GetLocation (yyVals[0+yyTop]));
	  }

void case_579()
#line 4088 "cs-parser.jay"
{
		yyVal = new Cast ((FullNamedExpression) yyVals[-2+yyTop], (Expression) yyVals[0+yyTop], GetLocation (yyVals[-3+yyTop]));
		lbag.AddLocation (yyVal, GetLocation (yyVals[-1+yyTop]));
	  }

void case_580()
#line 4093 "cs-parser.jay"
{
		if (!async_block) {
			 if (current_anonymous_method is LambdaExpression) {
				report.Error (4034, GetLocation (yyVals[-1+yyTop]),
					"The `await' operator can only be used when its containing lambda expression is marked with the `async' modifier");
			} else if (current_anonymous_method != null) {
				report.Error (4035, GetLocation (yyVals[-1+yyTop]),
					"The `await' operator can only be used when its containing anonymous method is marked with the `async' modifier");
			} else if (interactive_async != null) {
				current_block.Explicit.RegisterAsyncAwait ();
				interactive_async = true;
			} else {
				report.Error (4033, GetLocation (yyVals[-1+yyTop]),
					"The `await' operator can only be used when its containing method is marked with the `async' modifier");
			}
		} else {
			current_block.Explicit.RegisterAsyncAwait ();
		}
		
		yyVal = new Await ((Expression) yyVals[0+yyTop], GetLocation (yyVals[-1+yyTop]));
	  }

void case_581()
#line 4115 "cs-parser.jay"
{
		Error_SyntaxError (yyToken);

		yyVal = new Unary (Unary.Operator.LogicalNot, null, GetLocation (yyVals[-1+yyTop]));
	  }

void case_582()
#line 4121 "cs-parser.jay"
{
		Error_SyntaxError (yyToken);

		yyVal = new Unary (Unary.Operator.OnesComplement, null, GetLocation (yyVals[-1+yyTop]));
	  }

void case_583()
#line 4127 "cs-parser.jay"
{
		Error_SyntaxError (yyToken);

		yyVal = new Cast ((FullNamedExpression) yyVals[-2+yyTop], null, GetLocation (yyVals[-3+yyTop]));
		lbag.AddLocation (yyVal, GetLocation (yyVals[-1+yyTop]));
	  }

void case_584()
#line 4134 "cs-parser.jay"
{
		Error_SyntaxError (yyToken);

		yyVal = new Await (null, GetLocation (yyVals[-1+yyTop]));
	  }

void case_592()
#line 4172 "cs-parser.jay"
{ 
		Error_SyntaxError (yyToken);

	  	yyVal = new Unary (Unary.Operator.UnaryPlus, null, GetLocation (yyVals[-1+yyTop]));
	  }

void case_593()
#line 4178 "cs-parser.jay"
{ 
		Error_SyntaxError (yyToken);

		yyVal = new Unary (Unary.Operator.UnaryNegation, null, GetLocation (yyVals[-1+yyTop]));
	  }

void case_594()
#line 4184 "cs-parser.jay"
{
		Error_SyntaxError (yyToken);

		yyVal = new UnaryMutator (UnaryMutator.Mode.PreIncrement, null, GetLocation (yyVals[-1+yyTop]));
	  }

void case_595()
#line 4190 "cs-parser.jay"
{
		Error_SyntaxError (yyToken);

		yyVal = new UnaryMutator (UnaryMutator.Mode.PreDecrement, null, GetLocation (yyVals[-1+yyTop]));
	  }

void case_596()
#line 4196 "cs-parser.jay"
{
		Error_SyntaxError (yyToken);

		yyVal = new Indirection (null, GetLocation (yyVals[-1+yyTop]));
	  }

void case_597()
#line 4202 "cs-parser.jay"
{
		Error_SyntaxError (yyToken);

		yyVal = new Unary (Unary.Operator.AddressOf, null, GetLocation (yyVals[-1+yyTop]));
	  }

void case_599()
#line 4212 "cs-parser.jay"
{
		yyVal = new Binary (Binary.Operator.Multiply, (Expression) yyVals[-2+yyTop], (Expression) yyVals[0+yyTop]);
		lbag.AddLocation (yyVal, GetLocation (yyVals[-1+yyTop]));
	  }

void case_600()
#line 4217 "cs-parser.jay"
{
		yyVal = new Binary (Binary.Operator.Division, (Expression) yyVals[-2+yyTop], (Expression) yyVals[0+yyTop]);
		lbag.AddLocation (yyVal, GetLocation (yyVals[-1+yyTop]));
	  }

void case_601()
#line 4222 "cs-parser.jay"
{
		yyVal = new Binary (Binary.Operator.Modulus, (Expression) yyVals[-2+yyTop], (Expression) yyVals[0+yyTop]);
		lbag.AddLocation (yyVal, GetLocation (yyVals[-1+yyTop]));
	  }

void case_602()
#line 4227 "cs-parser.jay"
{
		Error_SyntaxError (yyToken);

		yyVal = new Binary (Binary.Operator.Multiply, (Expression) yyVals[-2+yyTop], null);
		lbag.AddLocation (yyVal, GetLocation (yyVals[-1+yyTop]));
	  }

void case_603()
#line 4234 "cs-parser.jay"
{
		Error_SyntaxError (yyToken);

		yyVal = new Binary (Binary.Operator.Division, (Expression) yyVals[-2+yyTop], null);
		lbag.AddLocation (yyVal, GetLocation (yyVals[-1+yyTop]));
	  }

void case_604()
#line 4241 "cs-parser.jay"
{
		Error_SyntaxError (yyToken);

		yyVal = new Binary (Binary.Operator.Modulus, (Expression) yyVals[-2+yyTop], null);
		lbag.AddLocation (yyVal, GetLocation (yyVals[-1+yyTop]));
	  }

void case_606()
#line 4252 "cs-parser.jay"
{
		yyVal = new Binary (Binary.Operator.Addition, (Expression) yyVals[-2+yyTop], (Expression) yyVals[0+yyTop]);
		lbag.AddLocation (yyVal, GetLocation (yyVals[-1+yyTop]));
	  }

void case_607()
#line 4257 "cs-parser.jay"
{
		yyVal = new Binary (Binary.Operator.Subtraction, (Expression) yyVals[-2+yyTop], (Expression) yyVals[0+yyTop]);
		lbag.AddLocation (yyVal, GetLocation (yyVals[-1+yyTop]));
	  }

void case_609()
#line 4266 "cs-parser.jay"
{
		var is_expr = new Is ((Expression) yyVals[-3+yyTop], (Expression) yyVals[-1+yyTop], GetLocation (yyVals[-2+yyTop]));
		if (yyVals[0+yyTop] != null) {
			if (lang_version != LanguageVersion.Experimental)
				FeatureIsNotAvailable (GetLocation (yyVals[0+yyTop]), "type pattern matching");

			var lt = (LocatedToken) yyVals[0+yyTop];
			is_expr.Variable = new LocalVariable (current_block, lt.Value, lt.Location);
			current_block.AddLocalName (is_expr.Variable);
		}

		yyVal = is_expr;
	  }

void case_610()
#line 4280 "cs-parser.jay"
{
		Error_SyntaxError (yyToken);

		yyVal = new Binary (Binary.Operator.Addition, (Expression) yyVals[-2+yyTop], null);
		lbag.AddLocation (yyVal, GetLocation (yyVals[-1+yyTop]));
	  }

void case_611()
#line 4287 "cs-parser.jay"
{
		Error_SyntaxError (yyToken);

		yyVal = new Binary (Binary.Operator.Subtraction, (Expression) yyVals[-2+yyTop], null);
		lbag.AddLocation (yyVal, GetLocation (yyVals[-1+yyTop]));
	  }

void case_612()
#line 4294 "cs-parser.jay"
{
		Error_SyntaxError (yyToken);

		yyVal = new As ((Expression) yyVals[-2+yyTop], null, GetLocation (yyVals[-1+yyTop]));
	  }

void case_613()
#line 4300 "cs-parser.jay"
{
		Error_SyntaxError (yyToken);

		yyVal = new Is ((Expression) yyVals[-2+yyTop], null, GetLocation (yyVals[-1+yyTop]));
	  }

void case_614()
#line 4306 "cs-parser.jay"
{
		var lt = (LocatedToken) yyVals[-2+yyTop];
		yyVal = new Is (new SimpleName (lt.Value, lt.Location), (Expression) yyVals[0+yyTop], GetLocation (yyVals[-1+yyTop]));
	  }

void case_615()
#line 4311 "cs-parser.jay"
{
		var lt = (LocatedToken) yyVals[-2+yyTop];
		yyVal = new As (new SimpleName (lt.Value, lt.Location), (Expression) yyVals[0+yyTop], GetLocation (yyVals[-1+yyTop]));
	  }

void case_617()
#line 4320 "cs-parser.jay"
{
		yyVal = new Binary (Binary.Operator.LeftShift, (Expression) yyVals[-2+yyTop], (Expression) yyVals[0+yyTop]);
		lbag.AddLocation (yyVal, GetLocation (yyVals[-1+yyTop]));
	  }

void case_618()
#line 4325 "cs-parser.jay"
{
		yyVal = new Binary (Binary.Operator.RightShift, (Expression) yyVals[-2+yyTop], (Expression) yyVals[0+yyTop]);
		lbag.AddLocation (yyVal, GetLocation (yyVals[-1+yyTop]));
	  }

void case_619()
#line 4330 "cs-parser.jay"
{
		Error_SyntaxError (yyToken);

		yyVal = new Binary (Binary.Operator.LeftShift, (Expression) yyVals[-2+yyTop], null);
		lbag.AddLocation (yyVal, GetLocation (yyVals[-1+yyTop]));
	  }

void case_620()
#line 4337 "cs-parser.jay"
{
		Error_SyntaxError (yyToken);

		yyVal = new Binary (Binary.Operator.RightShift, (Expression) yyVals[-2+yyTop], null);
		lbag.AddLocation (yyVal, GetLocation (yyVals[-1+yyTop]));
	  }

void case_622()
#line 4348 "cs-parser.jay"
{
		yyVal = new Binary (Binary.Operator.LessThan, (Expression) yyVals[-2+yyTop], (Expression) yyVals[0+yyTop]);
		lbag.AddLocation (yyVal, GetLocation (yyVals[-1+yyTop]));
	  }

void case_623()
#line 4353 "cs-parser.jay"
{
		yyVal = new Binary (Binary.Operator.GreaterThan, (Expression) yyVals[-2+yyTop], (Expression) yyVals[0+yyTop]);
		lbag.AddLocation (yyVal, GetLocation (yyVals[-1+yyTop]));
	  }

void case_624()
#line 4358 "cs-parser.jay"
{
		yyVal = new Binary (Binary.Operator.LessThanOrEqual, (Expression) yyVals[-2+yyTop], (Expression) yyVals[0+yyTop]);
		lbag.AddLocation (yyVal, GetLocation (yyVals[-1+yyTop]));
	  }

void case_625()
#line 4363 "cs-parser.jay"
{
		yyVal = new Binary (Binary.Operator.GreaterThanOrEqual, (Expression) yyVals[-2+yyTop], (Expression) yyVals[0+yyTop]);
		lbag.AddLocation (yyVal, GetLocation (yyVals[-1+yyTop]));
	  }

void case_626()
#line 4368 "cs-parser.jay"
{
		Error_SyntaxError (yyToken);

		yyVal = new Binary (Binary.Operator.LessThan, (Expression) yyVals[-2+yyTop], null);
		lbag.AddLocation (yyVal, GetLocation (yyVals[-1+yyTop]));
	  }

void case_627()
#line 4375 "cs-parser.jay"
{
		Error_SyntaxError (yyToken);

		yyVal = new Binary (Binary.Operator.GreaterThan, (Expression) yyVals[-2+yyTop], null);
		lbag.AddLocation (yyVal, GetLocation (yyVals[-1+yyTop]));
	  }

void case_628()
#line 4382 "cs-parser.jay"
{
		Error_SyntaxError (yyToken);

		yyVal = new Binary (Binary.Operator.LessThanOrEqual, (Expression) yyVals[-2+yyTop], null);
		lbag.AddLocation (yyVal, GetLocation (yyVals[-1+yyTop]));
	  }

void case_629()
#line 4389 "cs-parser.jay"
{
		Error_SyntaxError (yyToken);

		yyVal = new Binary (Binary.Operator.GreaterThanOrEqual, (Expression) yyVals[-2+yyTop], null);
		lbag.AddLocation (yyVal, GetLocation (yyVals[-1+yyTop]));
	  }

void case_631()
#line 4400 "cs-parser.jay"
{
		yyVal = new Binary (Binary.Operator.Equality, (Expression) yyVals[-2+yyTop], (Expression) yyVals[0+yyTop]);
		lbag.AddLocation (yyVal, GetLocation (yyVals[-1+yyTop]));
	  }

void case_632()
#line 4405 "cs-parser.jay"
{
		yyVal = new Binary (Binary.Operator.Inequality, (Expression) yyVals[-2+yyTop], (Expression) yyVals[0+yyTop]);
		lbag.AddLocation (yyVal, GetLocation (yyVals[-1+yyTop]));
	  }

void case_633()
#line 4410 "cs-parser.jay"
{
		Error_SyntaxError (yyToken);

		yyVal = new Binary (Binary.Operator.Equality, (Expression) yyVals[-2+yyTop], null);
		lbag.AddLocation (yyVal, GetLocation (yyVals[-1+yyTop]));
	  }

void case_634()
#line 4417 "cs-parser.jay"
{
		Error_SyntaxError (yyToken);

		yyVal = new Binary (Binary.Operator.Inequality, (Expression) yyVals[-2+yyTop], null);
		lbag.AddLocation (yyVal, GetLocation (yyVals[-1+yyTop]));
	  }

void case_636()
#line 4428 "cs-parser.jay"
{
		yyVal = new Binary (Binary.Operator.BitwiseAnd, (Expression) yyVals[-2+yyTop], (Expression) yyVals[0+yyTop]);
		lbag.AddLocation (yyVal, GetLocation (yyVals[-1+yyTop]));
	  }

void case_637()
#line 4433 "cs-parser.jay"
{
		Error_SyntaxError (yyToken);

		yyVal = new Binary (Binary.Operator.BitwiseAnd, (Expression) yyVals[-2+yyTop], null);
		lbag.AddLocation (yyVal, GetLocation (yyVals[-1+yyTop]));
	  }

void case_639()
#line 4444 "cs-parser.jay"
{
		yyVal = new Binary (Binary.Operator.ExclusiveOr, (Expression) yyVals[-2+yyTop], (Expression) yyVals[0+yyTop]);
		lbag.AddLocation (yyVal, GetLocation (yyVals[-1+yyTop]));
	  }

void case_640()
#line 4449 "cs-parser.jay"
{
		Error_SyntaxError (yyToken);

		yyVal = new Binary (Binary.Operator.ExclusiveOr, (Expression) yyVals[-2+yyTop], null);
		lbag.AddLocation (yyVal, GetLocation (yyVals[-1+yyTop]));
	  }

void case_642()
#line 4460 "cs-parser.jay"
{
		yyVal = new Binary (Binary.Operator.BitwiseOr, (Expression) yyVals[-2+yyTop], (Expression) yyVals[0+yyTop]);
		lbag.AddLocation (yyVal, GetLocation (yyVals[-1+yyTop]));
	  }

void case_643()
#line 4465 "cs-parser.jay"
{
		Error_SyntaxError (yyToken);

		yyVal = new Binary (Binary.Operator.BitwiseOr, (Expression) yyVals[-2+yyTop], null);
		lbag.AddLocation (yyVal, GetLocation (yyVals[-1+yyTop]));
	  }

void case_645()
#line 4476 "cs-parser.jay"
{
		yyVal = new Binary (Binary.Operator.LogicalAnd, (Expression) yyVals[-2+yyTop], (Expression) yyVals[0+yyTop]);
		lbag.AddLocation (yyVal, GetLocation (yyVals[-1+yyTop]));
	  }

void case_646()
#line 4481 "cs-parser.jay"
{
		Error_SyntaxError (yyToken);

		yyVal = new Binary (Binary.Operator.LogicalAnd, (Expression) yyVals[-2+yyTop], null);
		lbag.AddLocation (yyVal, GetLocation (yyVals[-1+yyTop]));
	  }

void case_648()
#line 4492 "cs-parser.jay"
{
		yyVal = new Binary (Binary.Operator.LogicalOr, (Expression) yyVals[-2+yyTop], (Expression) yyVals[0+yyTop]);
		lbag.AddLocation (yyVal, GetLocation (yyVals[-1+yyTop]));
	  }

void case_649()
#line 4497 "cs-parser.jay"
{
		Error_SyntaxError (yyToken);

		yyVal = new Binary (Binary.Operator.LogicalOr, (Expression) yyVals[-2+yyTop], null);
		lbag.AddLocation (yyVal, GetLocation (yyVals[-1+yyTop]));
	  }

void case_651()
#line 4508 "cs-parser.jay"
{
		if (lang_version < LanguageVersion.ISO_2)
			FeatureIsNotAvailable (GetLocation (yyVals[-1+yyTop]), "null coalescing operator");
			
		yyVal = new Nullable.NullCoalescingOperator ((Expression) yyVals[-2+yyTop], (Expression) yyVals[0+yyTop]);
		lbag.AddLocation (yyVal, GetLocation (yyVals[-1+yyTop]));
	  }

void case_653()
#line 4520 "cs-parser.jay"
{
		yyVal = new Conditional (new BooleanExpression ((Expression) yyVals[-4+yyTop]), (Expression) yyVals[-2+yyTop], (Expression) yyVals[0+yyTop], GetLocation (yyVals[-3+yyTop]));
		lbag.AddLocation (yyVal, GetLocation (yyVals[-1+yyTop]));
	  }

void case_654()
#line 4525 "cs-parser.jay"
{
		Error_SyntaxError (yyToken);

		yyVal = new Conditional (new BooleanExpression ((Expression) yyVals[-3+yyTop]), (Expression) yyVals[-1+yyTop], null, GetLocation (yyVals[-2+yyTop]));
	  }

void case_655()
#line 4531 "cs-parser.jay"
{
		Error_SyntaxError (yyToken);

		yyVal = new Conditional (new BooleanExpression ((Expression) yyVals[-4+yyTop]), (Expression) yyVals[-2+yyTop], null, GetLocation (yyVals[-3+yyTop]));
		lbag.AddLocation (yyVal, GetLocation (yyVals[-1+yyTop]));
	  }

void case_656()
#line 4538 "cs-parser.jay"
{
		Error_SyntaxError (Token.CLOSE_BRACE);

		yyVal = new Conditional (new BooleanExpression ((Expression) yyVals[-4+yyTop]), (Expression) yyVals[-2+yyTop], null, GetLocation (yyVals[-3+yyTop]));
		lbag.AddLocation (yyVal, GetLocation (yyVals[-1+yyTop]));
		lexer.putback ('}');
	  }

void case_657()
#line 4549 "cs-parser.jay"
{
		yyVal = new SimpleAssign ((Expression) yyVals[-2+yyTop], (Expression) yyVals[0+yyTop]);
		lbag.AddLocation (yyVal, GetLocation (yyVals[-1+yyTop]));
	  }

void case_658()
#line 4554 "cs-parser.jay"
{
		yyVal = new CompoundAssign (Binary.Operator.Multiply, (Expression) yyVals[-2+yyTop], (Expression) yyVals[0+yyTop]);
		lbag.AddLocation (yyVal, GetLocation (yyVals[-1+yyTop]));
	  }

void case_659()
#line 4559 "cs-parser.jay"
{
		yyVal = new CompoundAssign (Binary.Operator.Division, (Expression) yyVals[-2+yyTop], (Expression) yyVals[0+yyTop]);
		lbag.AddLocation (yyVal, GetLocation (yyVals[-1+yyTop]));
	  }

void case_660()
#line 4564 "cs-parser.jay"
{
		yyVal = new CompoundAssign (Binary.Operator.Modulus, (Expression) yyVals[-2+yyTop], (Expression) yyVals[0+yyTop]);
		lbag.AddLocation (yyVal, GetLocation (yyVals[-1+yyTop]));
	  }

void case_661()
#line 4569 "cs-parser.jay"
{
		yyVal = new CompoundAssign (Binary.Operator.Addition, (Expression) yyVals[-2+yyTop], (Expression) yyVals[0+yyTop]);
		lbag.AddLocation (yyVal, GetLocation (yyVals[-1+yyTop]));
	  }

void case_662()
#line 4574 "cs-parser.jay"
{
		yyVal = new CompoundAssign (Binary.Operator.Subtraction, (Expression) yyVals[-2+yyTop], (Expression) yyVals[0+yyTop]);
		lbag.AddLocation (yyVal, GetLocation (yyVals[-1+yyTop]));
	  }

void case_663()
#line 4579 "cs-parser.jay"
{
		yyVal = new CompoundAssign (Binary.Operator.LeftShift, (Expression) yyVals[-2+yyTop], (Expression) yyVals[0+yyTop]);
		lbag.AddLocation (yyVal, GetLocation (yyVals[-1+yyTop]));
	  }

void case_664()
#line 4584 "cs-parser.jay"
{
		yyVal = new CompoundAssign (Binary.Operator.RightShift, (Expression) yyVals[-2+yyTop], (Expression) yyVals[0+yyTop]);
		lbag.AddLocation (yyVal, GetLocation (yyVals[-1+yyTop]));
	  }

void case_665()
#line 4589 "cs-parser.jay"
{
		yyVal = new CompoundAssign (Binary.Operator.BitwiseAnd, (Expression) yyVals[-2+yyTop], (Expression) yyVals[0+yyTop]);
		lbag.AddLocation (yyVal, GetLocation (yyVals[-1+yyTop]));
	  }

void case_666()
#line 4594 "cs-parser.jay"
{
		yyVal = new CompoundAssign (Binary.Operator.BitwiseOr, (Expression) yyVals[-2+yyTop], (Expression) yyVals[0+yyTop]);
		lbag.AddLocation (yyVal, GetLocation (yyVals[-1+yyTop]));
	  }

void case_667()
#line 4599 "cs-parser.jay"
{
		yyVal = new CompoundAssign (Binary.Operator.ExclusiveOr, (Expression) yyVals[-2+yyTop], (Expression) yyVals[0+yyTop]);
		lbag.AddLocation (yyVal, GetLocation (yyVals[-1+yyTop]));
	  }

void case_668()
#line 4607 "cs-parser.jay"
{
		var pars = new List<Parameter> (4);
		pars.Add ((Parameter) yyVals[0+yyTop]);

		yyVal = pars;
	  }

void case_669()
#line 4614 "cs-parser.jay"
{
		var pars = (List<Parameter>) yyVals[-2+yyTop];
		Parameter p = (Parameter)yyVals[0+yyTop];
		if (pars[0].GetType () != p.GetType ()) {
			report.Error (748, p.Location, "All lambda parameters must be typed either explicitly or implicitly");
		}
		
		pars.Add (p);
		yyVal = pars;
	  }

void case_670()
#line 4628 "cs-parser.jay"
{
		var lt = (LocatedToken) yyVals[0+yyTop];

		yyVal = new Parameter ((FullNamedExpression) yyVals[-1+yyTop], lt.Value, (Parameter.Modifier) yyVals[-2+yyTop], null, lt.Location);
	  }

void case_671()
#line 4634 "cs-parser.jay"
{
		var lt = (LocatedToken) yyVals[0+yyTop];

		yyVal = new Parameter ((FullNamedExpression) yyVals[-1+yyTop], lt.Value, Parameter.Modifier.NONE, null, lt.Location);
	  }

void case_672()
#line 4640 "cs-parser.jay"
{
	  	var lt = (LocatedToken) yyVals[0+yyTop];
		yyVal = new ImplicitLambdaParameter (lt.Value, lt.Location);
	  }

void case_673()
#line 4645 "cs-parser.jay"
{
	  	var lt = (LocatedToken) Error_AwaitAsIdentifier (yyVals[0+yyTop]);
		yyVal = new ImplicitLambdaParameter (lt.Value, lt.Location);
	  }

void case_675()
#line 4653 "cs-parser.jay"
{ 
		var pars_list = (List<Parameter>) yyVals[0+yyTop];
		yyVal = new ParametersCompiled (pars_list.ToArray ());
	  }

void case_677()
#line 4664 "cs-parser.jay"
{
		Block b = end_block (Location.Null);
		b.IsCompilerGenerated = true;
		b.AddStatement (new ContextualReturn ((Expression) yyVals[0+yyTop]));
		yyVal = b;
	  }

void case_679()
#line 4672 "cs-parser.jay"
{
	  	/* Handles only cases like foo = x.FirstOrDefault (l => );*/
	  	/* where we must restore current_variable*/
		Block b = end_block (Location.Null);
		b.IsCompilerGenerated = true;

		Error_SyntaxError (yyToken);
		yyVal = null;
	  }

void case_681()
#line 4686 "cs-parser.jay"
{
		Error_SyntaxError (yyToken);
		yyVal = null;
	  }

void case_682()
#line 4694 "cs-parser.jay"
{
		var lt = (LocatedToken) yyVals[-1+yyTop];	
		Parameter p = new ImplicitLambdaParameter (lt.Value, lt.Location);
		start_anonymous (true, new ParametersCompiled (p), false, lt.Location);
	  }

void case_683()
#line 4700 "cs-parser.jay"
{
		yyVal = end_anonymous ((ParametersBlock) yyVals[0+yyTop]);
		lbag.AddLocation (yyVal, GetLocation (yyVals[-2+yyTop]));
	  }

void case_684()
#line 4705 "cs-parser.jay"
{
		var lt = (LocatedToken) Error_AwaitAsIdentifier (yyVals[-1+yyTop]);
		Parameter p = new ImplicitLambdaParameter (lt.Value, lt.Location);
		start_anonymous (true, new ParametersCompiled (p), false, lt.Location);
	  }

void case_685()
#line 4711 "cs-parser.jay"
{
		yyVal = end_anonymous ((ParametersBlock) yyVals[0+yyTop]);
		lbag.AddLocation (yyVal, GetLocation (yyVals[-2+yyTop]));
	  }

void case_686()
#line 4716 "cs-parser.jay"
{
		var lt = (LocatedToken) yyVals[-1+yyTop];
		Parameter p = new ImplicitLambdaParameter (lt.Value, lt.Location);
		start_anonymous (true, new ParametersCompiled (p), true, lt.Location);
	  }

void case_687()
#line 4722 "cs-parser.jay"
{
		yyVal = end_anonymous ((ParametersBlock) yyVals[0+yyTop]);
		lbag.AddLocation (yyVal, GetLocation (yyVals[-4+yyTop]), GetLocation (yyVals[-2+yyTop]));
	  }

void case_689()
#line 4731 "cs-parser.jay"
{
	  	valid_param_mod = 0;
		start_anonymous (true, (ParametersCompiled) yyVals[-2+yyTop], false, GetLocation (yyVals[-4+yyTop]));
	  }

void case_690()
#line 4736 "cs-parser.jay"
{
		yyVal = end_anonymous ((ParametersBlock) yyVals[0+yyTop]);
		lbag.AddLocation (yyVal, GetLocation (yyVals[-6+yyTop]), GetLocation (yyVals[-3+yyTop]), GetLocation (yyVals[-2+yyTop]));
	  }

void case_692()
#line 4745 "cs-parser.jay"
{
	  	valid_param_mod = 0;
		start_anonymous (true, (ParametersCompiled) yyVals[-2+yyTop], true, GetLocation (yyVals[-5+yyTop]));
	  }

void case_693()
#line 4750 "cs-parser.jay"
{
		yyVal = end_anonymous ((ParametersBlock) yyVals[0+yyTop]);
		lbag.AddLocation (yyVal, GetLocation (yyVals[-7+yyTop]), GetLocation (yyVals[-6+yyTop]), GetLocation (yyVals[-3+yyTop]), GetLocation (yyVals[-2+yyTop]));
	  }

void case_700()
#line 4773 "cs-parser.jay"
{
		yyVal = new RefValueExpr ((Expression) yyVals[-3+yyTop], (FullNamedExpression) yyVals[-1+yyTop], GetLocation (yyVals[-5+yyTop]));
		lbag.AddLocation (yyVal, GetLocation (yyVals[-4+yyTop]), GetLocation (yyVals[-2+yyTop]), GetLocation (yyVals[0+yyTop]));
	  }

void case_701()
#line 4778 "cs-parser.jay"
{
		yyVal = new RefTypeExpr ((Expression) yyVals[-1+yyTop], GetLocation (yyVals[-3+yyTop]));
		lbag.AddLocation (yyVal, GetLocation (yyVals[-2+yyTop]), GetLocation (yyVals[0+yyTop]));
	  }

void case_702()
#line 4783 "cs-parser.jay"
{
		yyVal = new MakeRefExpr ((Expression) yyVals[-1+yyTop], GetLocation (yyVals[-3+yyTop]));
		lbag.AddLocation (yyVal, GetLocation (yyVals[-2+yyTop]), GetLocation (yyVals[0+yyTop]));	  
	  }

void case_707()
#line 4810 "cs-parser.jay"
{
		yyVal = yyVals[-1+yyTop];

		/* Cannot use opt_formal_parameter_list because it can be shared instance for empty parameters*/
	  	lbag.AppendToMember (current_container, GetLocation (yyVals[-2+yyTop]), GetLocation (yyVals[0+yyTop]));

		if (lang_version < LanguageVersion.V_6)
			FeatureIsNotAvailable (GetLocation (yyVals[-2+yyTop]), "primary constructor");
	  }

void case_712()
#line 4839 "cs-parser.jay"
{
		++lexer.parsing_block;
		current_type.PrimaryConstructorBaseArgumentsStart = GetLocation (yyVals[0+yyTop]);
	  }

void case_713()
#line 4844 "cs-parser.jay"
{
		lbag.AppendToMember (current_container, GetLocation (yyVals[0+yyTop]));
		current_type.PrimaryConstructorBaseArguments = (Arguments) yyVals[-1+yyTop];
		--lexer.parsing_block;

		yyVal = yyVals[-5+yyTop];
	  }

void case_715()
#line 4864 "cs-parser.jay"
{
		lexer.ConstraintsParsing = true;

		Class c = new Class (current_container, (MemberName) yyVals[0+yyTop], (Modifiers) yyVals[-4+yyTop], (Attributes) yyVals[-5+yyTop]);
		if (((c.ModFlags & Modifiers.STATIC) != 0) && lang_version == LanguageVersion.ISO_1) {
			FeatureIsNotAvailable (c.Location, "static classes");
		}
			
		push_current_container (c, yyVals[-3+yyTop]);
		valid_param_mod = ParameterModifierType.PrimaryConstructor;
	  }

void case_716()
#line 4877 "cs-parser.jay"
{
		valid_param_mod = 0;
		lexer.ConstraintsParsing = false;

		if (yyVals[-1+yyTop] != null)
			current_type.PrimaryConstructorParameters = (ParametersCompiled) yyVals[-1+yyTop];

		if (yyVals[0+yyTop] != null)
			current_container.SetConstraints ((List<Constraints>) yyVals[0+yyTop]);
		lbag.AddMember (current_container, mod_locations, GetLocation (yyVals[-5+yyTop]));

		if (doc_support) {
			current_container.PartialContainer.DocComment = Lexer.consume_doc_comment ();
			Lexer.doc_state = XmlCommentState.Allowed;
		}
		
		lexer.parsing_modifiers = true;
	  }

void case_717()
#line 4896 "cs-parser.jay"
{
		--lexer.parsing_declaration;
		if (doc_support)
			Lexer.doc_state = XmlCommentState.Allowed;
	  }

void case_718()
#line 4902 "cs-parser.jay"
{
		if (yyVals[0+yyTop] == null) {
			lbag.AppendToMember (current_container, GetLocation (yyVals[-4+yyTop]), GetLocation (yyVals[-2+yyTop]));
		} else {
			lbag.AppendToMember (current_container, GetLocation (yyVals[-4+yyTop]), GetLocation (yyVals[-2+yyTop]), GetLocation (yyVals[0+yyTop]));
		}
		yyVal = pop_current_class ();
	  }

void case_721()
#line 4921 "cs-parser.jay"
{
	    mod_locations = null;
		yyVal = ModifierNone;
		lexer.parsing_modifiers = false;
	  }

void case_724()
#line 4935 "cs-parser.jay"
{ 
		var m1 = (Modifiers) yyVals[-1+yyTop];
		var m2 = (Modifiers) yyVals[0+yyTop];

		if ((m1 & m2) != 0) {
			report.Error (1004, lexer.Location - ModifiersExtensions.Name (m2).Length,
				"Duplicate `{0}' modifier", ModifiersExtensions.Name (m2));
		} else if ((m2 & Modifiers.AccessibilityMask) != 0 && (m1 & Modifiers.AccessibilityMask) != 0 &&
			((m2 | m1 & Modifiers.AccessibilityMask) != (Modifiers.PROTECTED | Modifiers.INTERNAL))) {
			report.Error (107, lexer.Location - ModifiersExtensions.Name (m2).Length,
				"More than one protection modifier specified");
		}
		
		yyVal = m1 | m2;
	  }

void case_725()
#line 4954 "cs-parser.jay"
{
		yyVal = Modifiers.NEW;
		StoreModifierLocation (yyVal, GetLocation (yyVals[0+yyTop]));
		
		if (current_container.Kind == MemberKind.Namespace)
			report.Error (1530, GetLocation (yyVals[0+yyTop]), "Keyword `new' is not allowed on namespace elements");
	  }

void case_726()
#line 4962 "cs-parser.jay"
{
		yyVal = Modifiers.PUBLIC;
		StoreModifierLocation (yyVal, GetLocation (yyVals[0+yyTop]));
	  }

void case_727()
#line 4967 "cs-parser.jay"
{
		yyVal = Modifiers.PROTECTED;
		StoreModifierLocation (yyVal, GetLocation (yyVals[0+yyTop]));
	  }

void case_728()
#line 4972 "cs-parser.jay"
{
		yyVal = Modifiers.INTERNAL;
		StoreModifierLocation (yyVal, GetLocation (yyVals[0+yyTop]));
	  }

void case_729()
#line 4977 "cs-parser.jay"
{
		yyVal = Modifiers.PRIVATE;
		StoreModifierLocation (yyVal, GetLocation (yyVals[0+yyTop]));
	  }

void case_730()
#line 4982 "cs-parser.jay"
{
		yyVal = Modifiers.ABSTRACT;
		StoreModifierLocation (yyVal, GetLocation (yyVals[0+yyTop]));
	  }

void case_731()
#line 4987 "cs-parser.jay"
{
		yyVal = Modifiers.SEALED;
		StoreModifierLocation (yyVal, GetLocation (yyVals[0+yyTop]));
	  }

void case_732()
#line 4992 "cs-parser.jay"
{
		yyVal = Modifiers.STATIC;
		StoreModifierLocation (yyVal, GetLocation (yyVals[0+yyTop]));
	  }

void case_733()
#line 4997 "cs-parser.jay"
{
		yyVal = Modifiers.READONLY;
		StoreModifierLocation (yyVal, GetLocation (yyVals[0+yyTop]));
	  }

void case_734()
#line 5002 "cs-parser.jay"
{
		yyVal = Modifiers.VIRTUAL;
		StoreModifierLocation (yyVal, GetLocation (yyVals[0+yyTop]));
	  }

void case_735()
#line 5007 "cs-parser.jay"
{
		yyVal = Modifiers.OVERRIDE;
		StoreModifierLocation (yyVal, GetLocation (yyVals[0+yyTop]));
	  }

void case_736()
#line 5012 "cs-parser.jay"
{
		yyVal = Modifiers.EXTERN;
		StoreModifierLocation (yyVal, GetLocation (yyVals[0+yyTop]));
	  }

void case_737()
#line 5017 "cs-parser.jay"
{
		yyVal = Modifiers.VOLATILE;
		StoreModifierLocation (yyVal, GetLocation (yyVals[0+yyTop]));
	  }

void case_738()
#line 5022 "cs-parser.jay"
{
		yyVal = Modifiers.UNSAFE;
		StoreModifierLocation (yyVal, GetLocation (yyVals[0+yyTop]));
		if (!settings.Unsafe)
			Error_UnsafeCodeNotAllowed (GetLocation (yyVals[0+yyTop]));
	  }

void case_739()
#line 5029 "cs-parser.jay"
{
		yyVal = Modifiers.ASYNC;
		StoreModifierLocation (yyVal, GetLocation (yyVals[0+yyTop]));
	  }

void case_743()
#line 5046 "cs-parser.jay"
{
		Error_SyntaxError (yyToken);

		current_type.SetBaseTypes ((List<FullNamedExpression>) yyVals[-1+yyTop]);
	  }

void case_746()
#line 5063 "cs-parser.jay"
{
		var constraints = new List<Constraints> (1);
		constraints.Add ((Constraints) yyVals[0+yyTop]);
		yyVal = constraints;
	  }

void case_747()
#line 5069 "cs-parser.jay"
{
		var constraints = (List<Constraints>) yyVals[-1+yyTop];
		Constraints new_constraint = (Constraints)yyVals[0+yyTop];

		foreach (Constraints c in constraints) {
			if (new_constraint.TypeParameter.Value == c.TypeParameter.Value) {
				report.Error (409, new_constraint.Location,
					"A constraint clause has already been specified for type parameter `{0}'",
					new_constraint.TypeParameter.Value);
			}
		}

		constraints.Add (new_constraint);
		yyVal = constraints;
	  }

void case_748()
#line 5088 "cs-parser.jay"
{
		var lt = (LocatedToken) yyVals[-2+yyTop];
		yyVal = new Constraints (new SimpleMemberName (lt.Value, lt.Location), (List<FullNamedExpression>) yyVals[0+yyTop], GetLocation (yyVals[-3+yyTop]));
		lbag.AddLocation (yyVal, GetLocation (yyVals[-1+yyTop]));
	  }

void case_749()
#line 5094 "cs-parser.jay"
{
		Error_SyntaxError (yyToken);
	  
		var lt = (LocatedToken) yyVals[-1+yyTop];
		yyVal = new Constraints (new SimpleMemberName (lt.Value, lt.Location), null, GetLocation (yyVals[-2+yyTop]));
	  }

void case_750()
#line 5104 "cs-parser.jay"
{
		var constraints = new List<FullNamedExpression> (1);
		constraints.Add ((FullNamedExpression) yyVals[0+yyTop]);
		yyVal = constraints;
	  }

void case_751()
#line 5110 "cs-parser.jay"
{
		var constraints = (List<FullNamedExpression>) yyVals[-2+yyTop];
		var prev = constraints [constraints.Count - 1] as SpecialContraintExpr;
		if (prev != null && (prev.Constraint & SpecialConstraint.Constructor) != 0) {			
			report.Error (401, GetLocation (yyVals[-1+yyTop]), "The `new()' constraint must be the last constraint specified");
		}
		
		prev = yyVals[0+yyTop] as SpecialContraintExpr;
		if (prev != null) {
			if ((prev.Constraint & (SpecialConstraint.Class | SpecialConstraint.Struct)) != 0) {
				report.Error (449, prev.Location, "The `class' or `struct' constraint must be the first constraint specified");			
			} else {
			 	prev = constraints [0] as SpecialContraintExpr;
			 	if (prev != null && (prev.Constraint & SpecialConstraint.Struct) != 0) {			
					report.Error (451, GetLocation (yyVals[0+yyTop]), "The `new()' constraint cannot be used with the `struct' constraint");
				}
			}
		}

		constraints.Add ((FullNamedExpression) yyVals[0+yyTop]);
		yyVal = constraints;
	  }

void case_752()
#line 5136 "cs-parser.jay"
{
		if (yyVals[0+yyTop] is ComposedCast)
			report.Error (706, GetLocation (yyVals[0+yyTop]), "Invalid constraint type `{0}'", ((ComposedCast)yyVals[0+yyTop]).GetSignatureForError ());
	  
	  	yyVal = yyVals[0+yyTop];
	  }

void case_753()
#line 5143 "cs-parser.jay"
{
		yyVal = new SpecialContraintExpr (SpecialConstraint.Constructor, GetLocation (yyVals[-2+yyTop]));
		lbag.AddLocation (yyVal, GetLocation (yyVals[-1+yyTop]), GetLocation (yyVals[0+yyTop]));
	  }

void case_757()
#line 5163 "cs-parser.jay"
{
		if (lang_version <= LanguageVersion.V_3)
			FeatureIsNotAvailable (lexer.Location, "generic type variance");
		
		yyVal = yyVals[0+yyTop];
	  }

void case_760()
#line 5197 "cs-parser.jay"
{
		++lexer.parsing_block;
		start_block (GetLocation (yyVals[0+yyTop]));
	  }

void case_762()
#line 5209 "cs-parser.jay"
{
	 	--lexer.parsing_block;
		yyVal = end_block (GetLocation (yyVals[0+yyTop]));
	  }

void case_763()
#line 5214 "cs-parser.jay"
{
	 	--lexer.parsing_block;
		yyVal = end_block (lexer.Location);
	  }

void case_764()
#line 5223 "cs-parser.jay"
{
		++lexer.parsing_block;
		current_block.StartLocation = GetLocation (yyVals[0+yyTop]);
	  }

void case_765()
#line 5228 "cs-parser.jay"
{
		--lexer.parsing_block;
		yyVal = end_block (GetLocation (yyVals[0+yyTop]));
	  }

void case_773()
#line 5255 "cs-parser.jay"
{
		Error_SyntaxError (yyToken);
		yyVal = null;
	  }

void case_806()
#line 5319 "cs-parser.jay"
{
		  report.Error (1023, GetLocation (yyVals[0+yyTop]), "An embedded statement may not be a declaration or labeled statement");
		  yyVal = null;
	  }

void case_807()
#line 5324 "cs-parser.jay"
{
		  report.Error (1023, GetLocation (yyVals[0+yyTop]), "An embedded statement may not be a declaration or labeled statement");
		  yyVal = null;
	  }

void case_808()
#line 5329 "cs-parser.jay"
{
		Error_SyntaxError (yyToken);
		yyVal = new EmptyStatement (GetLocation (yyVals[0+yyTop]));
	  }

void case_809()
#line 5337 "cs-parser.jay"
{
		/* Uses lexer.Location because semicolon location is not kept in quick mode*/
		yyVal = new EmptyStatement (lexer.Location);
	  }

void case_810()
#line 5345 "cs-parser.jay"
{
		var lt = (LocatedToken) yyVals[-1+yyTop];
		LabeledStatement labeled = new LabeledStatement (lt.Value, current_block, lt.Location);
		lbag.AddLocation (labeled, GetLocation (yyVals[0+yyTop]));
		current_block.AddLabel (labeled);
		current_block.AddStatement (labeled);
	  }

void case_813()
#line 5358 "cs-parser.jay"
{
		if (yyVals[-1+yyTop] is VarExpr)
			yyVals[-1+yyTop] = new SimpleName ("var", ((VarExpr) yyVals[-1+yyTop]).Location);
	  
		yyVal = new ComposedCast ((FullNamedExpression) yyVals[-1+yyTop], (ComposedTypeSpecifier) yyVals[0+yyTop]);
	  }

void case_814()
#line 5374 "cs-parser.jay"
{ 
		/* Ok, the above "primary_expression" is there to get rid of*/
		/* both reduce/reduce and shift/reduces in the grammar, it should*/
		/* really just be "type_name".  If you use type_name, a reduce/reduce*/
		/* creeps up.  If you use namespace_or_type_name (which is all we need*/
		/* really) two shift/reduces appear.*/
		/* */

		/* So the super-trick is that primary_expression*/
		/* can only be either a SimpleName or a MemberAccess. */
		/* The MemberAccess case arises when you have a fully qualified type-name like :*/
		/* Foo.Bar.Blah i;*/
		/* SimpleName is when you have*/
		/* Blah i;*/
		
		Expression expr = (Expression) yyVals[-1+yyTop];
		if (yyVals[0+yyTop] == null) {
			SimpleName sn = expr as SimpleName;
			if (sn != null && sn.Name == "var")
				yyVal = new VarExpr (sn.Location);
			else
				yyVal = yyVals[-1+yyTop];
		} else if (expr is ATypeNameExpression) {
			yyVal = new ComposedCast ((ATypeNameExpression)expr, (ComposedTypeSpecifier) yyVals[0+yyTop]);
		} else {
			Error_ExpectingTypeName (expr);
			yyVal = null;
		}
	  }

void case_815()
#line 5404 "cs-parser.jay"
{
		ATypeNameExpression expr = yyVals[-1+yyTop] as ATypeNameExpression;

		if (expr != null) {
			yyVal = new ComposedCast (expr, (ComposedTypeSpecifier) yyVals[0+yyTop]);
		} else {
			Error_ExpectingTypeName ((Expression)yyVals[-1+yyTop]);
			yyVal = expr;
		}
	  }

void case_816()
#line 5415 "cs-parser.jay"
{
		if (yyVals[0+yyTop] == null)
			yyVal = yyVals[-1+yyTop];
		else
			yyVal = new ComposedCast ((FullNamedExpression) yyVals[-1+yyTop], (ComposedTypeSpecifier) yyVals[0+yyTop]);
	  }

void case_819()
#line 5430 "cs-parser.jay"
{
		Expression.Error_VoidInvalidInTheContext (GetLocation (yyVals[0+yyTop]), report);
		yyVal = new TypeExpression (compiler.BuiltinTypes.Void, GetLocation (yyVals[0+yyTop]));
	  }

void case_821()
#line 5439 "cs-parser.jay"
{
	  	((ComposedTypeSpecifier) yyVals[-1+yyTop]).Next = (ComposedTypeSpecifier) yyVals[0+yyTop];
	  	yyVal = yyVals[-1+yyTop];
	  }

void case_825()
#line 5462 "cs-parser.jay"
{
		var lt = (LocatedToken) yyVals[0+yyTop];
		var li = new LocalVariable (current_block, lt.Value, lt.Location);
		current_block.AddLocalName (li);
		current_variable = new BlockVariable ((FullNamedExpression) yyVals[-1+yyTop], li);
	  }

void case_826()
#line 5469 "cs-parser.jay"
{
		yyVal = current_variable;
		current_variable = null;
		if (yyVals[-2+yyTop] != null)
			lbag.AddLocation (yyVal, PopLocation (), GetLocation (yyVals[0+yyTop]));
		else
			lbag.AddLocation (yyVal, GetLocation (yyVals[0+yyTop]));
	  }

void case_827()
#line 5478 "cs-parser.jay"
{
		var lt = (LocatedToken) yyVals[0+yyTop];
		var li = new LocalVariable (current_block, lt.Value, LocalVariable.Flags.Constant, lt.Location);
		current_block.AddLocalName (li);
		current_variable = new BlockConstant ((FullNamedExpression) yyVals[-1+yyTop], li);
	  }

void case_828()
#line 5485 "cs-parser.jay"
{
		yyVal = current_variable;
		current_variable = null;
		lbag.AddLocation (yyVal, GetLocation (yyVals[-6+yyTop]), GetLocation (yyVals[0+yyTop]));
	  }

void case_830()
#line 5495 "cs-parser.jay"
{
		current_variable.Initializer = (Expression) yyVals[0+yyTop];
		PushLocation (GetLocation (yyVals[-1+yyTop]));
		yyVal = current_variable;
	  }

void case_831()
#line 5501 "cs-parser.jay"
{
	  	if (yyToken == Token.OPEN_BRACKET_EXPR) {
			report.Error (650, lexer.Location,
				"Syntax error, bad array declarator. To declare a managed array the rank specifier precedes the variable's identifier. To declare a fixed size buffer field, use the fixed keyword before the field type");
		} else {
			Error_SyntaxError (yyToken);
		}
	  }

void case_835()
#line 5519 "cs-parser.jay"
{
		foreach (var d in current_variable.Declarators) {
			if (d.Initializer == null)
				Error_MissingInitializer (d.Variable.Location);
		}
	  }

void case_838()
#line 5534 "cs-parser.jay"
{
		var lt = (LocatedToken) yyVals[0+yyTop];	  
		var li = new LocalVariable (current_variable.Variable, lt.Value, lt.Location);
		var d = new BlockVariableDeclarator (li, null);
		current_variable.AddDeclarator (d);
		current_block.AddLocalName (li);
	  	lbag.AddLocation (d, GetLocation (yyVals[-1+yyTop]));
	  }

void case_839()
#line 5543 "cs-parser.jay"
{
		var lt = (LocatedToken) yyVals[-2+yyTop];	  
		var li = new LocalVariable (current_variable.Variable, lt.Value, lt.Location);
		var d = new BlockVariableDeclarator (li, (Expression) yyVals[0+yyTop]);
		current_variable.AddDeclarator (d);
		current_block.AddLocalName (li);
	  	lbag.AddLocation (d, GetLocation (yyVals[-3+yyTop]), GetLocation (yyVals[-1+yyTop]));
	  }

void case_846()
#line 5576 "cs-parser.jay"
{
		var lt = (LocatedToken) yyVals[-2+yyTop];	  
		var li = new LocalVariable (current_block, lt.Value, LocalVariable.Flags.Constant, lt.Location);
		var d = new BlockVariableDeclarator (li, (Expression) yyVals[0+yyTop]);
		current_variable.AddDeclarator (d);
		current_block.AddLocalName (li);
	  	lbag.AddLocation (d, GetLocation (yyVals[-3+yyTop]), GetLocation (yyVals[-1+yyTop]));
	  }

void case_848()
#line 5589 "cs-parser.jay"
{
		yyVal = new StackAlloc ((Expression) yyVals[-3+yyTop], (Expression) yyVals[-1+yyTop], GetLocation (yyVals[-4+yyTop]));
		lbag.AddLocation (yyVal, GetLocation (yyVals[-2+yyTop]), GetLocation (yyVals[0+yyTop]));
	  }

void case_849()
#line 5594 "cs-parser.jay"
{
		report.Error (1575, GetLocation (yyVals[-1+yyTop]), "A stackalloc expression requires [] after type");
		yyVal = new StackAlloc ((Expression) yyVals[0+yyTop], null, GetLocation (yyVals[-1+yyTop]));		
	  }

void case_850()
#line 5602 "cs-parser.jay"
{
		yyVal = yyVals[-1+yyTop];
		lbag.AddStatement (yyVal, GetLocation (yyVals[0+yyTop]));
	  }

void case_852()
#line 5608 "cs-parser.jay"
{
		yyVal = yyVals[-1+yyTop];
		report.Error (1002, GetLocation (yyVals[0+yyTop]), "; expected");
		lexer.putback ('}');
	  }

void case_855()
#line 5626 "cs-parser.jay"
{
		ExpressionStatement s = yyVals[0+yyTop] as ExpressionStatement;
		if (s == null) {
			var expr = yyVals[0+yyTop] as Expression;
			yyVal = new StatementErrorExpression (expr);
		} else {
			yyVal = new StatementExpression (s);
		}
	  }

void case_856()
#line 5639 "cs-parser.jay"
{
		Expression expr = (Expression) yyVals[0+yyTop];
		yyVal = new StatementExpression (new OptionalAssign (expr, lexer.Location));
	  }

void case_857()
#line 5644 "cs-parser.jay"
{
		Error_SyntaxError (yyToken);
		yyVal = new EmptyStatement (GetLocation (yyVals[0+yyTop]));
	  }

void case_860()
#line 5658 "cs-parser.jay"
{ 
		if (yyVals[0+yyTop] is EmptyStatement)
			Warning_EmptyStatement (GetLocation (yyVals[0+yyTop]));
		
		yyVal = new If ((BooleanExpression) yyVals[-2+yyTop], (Statement) yyVals[0+yyTop], GetLocation (yyVals[-4+yyTop]));
		lbag.AddStatement (yyVal, GetLocation (yyVals[-3+yyTop]), GetLocation (yyVals[-1+yyTop]));
	  }

void case_861()
#line 5667 "cs-parser.jay"
{
		yyVal = new If ((BooleanExpression) yyVals[-4+yyTop], (Statement) yyVals[-2+yyTop], (Statement) yyVals[0+yyTop], GetLocation (yyVals[-6+yyTop]));
		lbag.AddStatement (yyVal, GetLocation (yyVals[-5+yyTop]), GetLocation (yyVals[-3+yyTop]), GetLocation (yyVals[-1+yyTop]));
		
		if (yyVals[-2+yyTop] is EmptyStatement)
			Warning_EmptyStatement (GetLocation (yyVals[-2+yyTop]));
		if (yyVals[0+yyTop] is EmptyStatement)
			Warning_EmptyStatement (GetLocation (yyVals[0+yyTop]));
	  }

void case_862()
#line 5677 "cs-parser.jay"
{
		Error_SyntaxError (yyToken);
		
		yyVal = new If ((BooleanExpression) yyVals[-1+yyTop], null, GetLocation (yyVals[-3+yyTop]));
		lbag.AddStatement (yyVal, GetLocation (yyVals[-2+yyTop]));
	  }

void case_864()
#line 5691 "cs-parser.jay"
{
		yyVal = new Switch ((Expression) yyVals[-5+yyTop], (ExplicitBlock) current_block.Explicit, GetLocation (yyVals[-7+yyTop]));	
		end_block (GetLocation (yyVals[0+yyTop]));
		lbag.AddStatement (yyVal, GetLocation (yyVals[-6+yyTop]), GetLocation (yyVals[-4+yyTop]));
	  }

void case_865()
#line 5697 "cs-parser.jay"
{
		Error_SyntaxError (yyToken);
	  
		yyVal = new Switch ((Expression) yyVals[-1+yyTop], null, GetLocation (yyVals[-3+yyTop]));	
		lbag.AddStatement (yyVal, GetLocation (yyVals[-2+yyTop]));
	  }

void case_872()
#line 5728 "cs-parser.jay"
{
	  	var label = (SwitchLabel) yyVals[0+yyTop];
	  	label.SectionStart = true;
		current_block.AddStatement (label);
	  }

void case_874()
#line 5741 "cs-parser.jay"
{
	 	yyVal = new SwitchLabel ((Expression) yyVals[-1+yyTop], GetLocation (yyVals[-2+yyTop]));
	 	lbag.AddLocation (yyVal, GetLocation (yyVals[0+yyTop]));
	 }

void case_875()
#line 5746 "cs-parser.jay"
{
		Error_SyntaxError (yyToken);
		yyVal = new SwitchLabel ((Expression) yyVals[-1+yyTop], GetLocation (yyVals[-2+yyTop]));
	  }

void case_881()
#line 5765 "cs-parser.jay"
{
		if (yyVals[0+yyTop] is EmptyStatement && lexer.peek_token () == Token.OPEN_BRACE)
			Warning_EmptyStatement (GetLocation (yyVals[0+yyTop]));
	  
		yyVal = new While ((BooleanExpression) yyVals[-2+yyTop], (Statement) yyVals[0+yyTop], GetLocation (yyVals[-4+yyTop]));
		lbag.AddStatement (yyVal, GetLocation (yyVals[-3+yyTop]), GetLocation (yyVals[-1+yyTop]));
	  }

void case_882()
#line 5773 "cs-parser.jay"
{
		Error_SyntaxError (yyToken);
		
		yyVal = new While ((BooleanExpression) yyVals[-1+yyTop], null, GetLocation (yyVals[-3+yyTop]));
		lbag.AddStatement (yyVal, GetLocation (yyVals[-2+yyTop]));
	  }

void case_883()
#line 5783 "cs-parser.jay"
{
		yyVal = new Do ((Statement) yyVals[-5+yyTop], (BooleanExpression) yyVals[-2+yyTop], GetLocation (yyVals[-6+yyTop]), GetLocation (yyVals[-4+yyTop]));
		lbag.AddStatement (yyVal, GetLocation (yyVals[-4+yyTop]), GetLocation (yyVals[-3+yyTop]), GetLocation (yyVals[-1+yyTop]), GetLocation (yyVals[0+yyTop]));
	  }

void case_884()
#line 5788 "cs-parser.jay"
{
		Error_SyntaxError (yyToken);
		yyVal = new Do ((Statement) yyVals[-1+yyTop], null, GetLocation (yyVals[-2+yyTop]), Location.Null);
	  }

void case_885()
#line 5793 "cs-parser.jay"
{
		Error_SyntaxError (yyToken);
	  
		yyVal = new Do ((Statement) yyVals[-4+yyTop], (BooleanExpression) yyVals[-1+yyTop], GetLocation (yyVals[-5+yyTop]), GetLocation (yyVals[-3+yyTop]));
		lbag.AddStatement (yyVal, GetLocation (yyVals[-3+yyTop]), GetLocation (yyVals[-2+yyTop]));
	  }

void case_886()
#line 5803 "cs-parser.jay"
{
		start_block (GetLocation (yyVals[0+yyTop]));
		current_block.IsCompilerGenerated = true;
		For f = new For (GetLocation (yyVals[-1+yyTop]));
		current_block.AddStatement (f);
		yyVal = f;
	  }

void case_888()
#line 5819 "cs-parser.jay"
{
		((For) yyVals[-2+yyTop]).Initializer = (Statement) yyVals[-1+yyTop];

		/* Pass the "For" object to the iterator_part4*/
		oob_stack.Push (yyVals[-2+yyTop]);
	  }

void case_889()
#line 5827 "cs-parser.jay"
{
		var locations = (Tuple<Location,Location>) yyVals[-1+yyTop];
		oob_stack.Pop ();
		if (yyVals[0+yyTop] is EmptyStatement && lexer.peek_token () == Token.OPEN_BRACE)
			Warning_EmptyStatement (GetLocation (yyVals[0+yyTop]));
	  
		For f = ((For) yyVals[-5+yyTop]);
		f.Statement = (Statement) yyVals[0+yyTop];
		lbag.AddStatement (f, current_block.StartLocation, GetLocation (yyVals[-3+yyTop]), GetLocation (locations.Item1), GetLocation (locations.Item2));

		yyVal = end_block (GetLocation (yyVals[-3+yyTop]));
	  }

void case_890()
#line 5840 "cs-parser.jay"
{
		Error_SyntaxError (yyToken);
		yyVal = end_block (current_block.StartLocation);
	  }

void case_891()
#line 5848 "cs-parser.jay"
{
		For f = (For) oob_stack.Peek ();
		f.Condition = (BooleanExpression) yyVals[-1+yyTop];
	  }

void case_893()
#line 5858 "cs-parser.jay"
{
		report.Error (1525, GetLocation (yyVals[0+yyTop]), "Unexpected symbol `}'");
		For f = (For) oob_stack.Peek ();
		f.Condition = (BooleanExpression) yyVals[-1+yyTop];
		yyVal = new Tuple<Location,Location> (GetLocation (yyVals[0+yyTop]), GetLocation (yyVals[0+yyTop]));
	  }

void case_894()
#line 5867 "cs-parser.jay"
{
	  	For f = (For) oob_stack.Peek ();
		f.Iterator = (Statement) yyVals[-1+yyTop];
		yyVal = GetLocation (yyVals[0+yyTop]);
	  }

void case_895()
#line 5872 "cs-parser.jay"
{
		report.Error (1525, GetLocation (yyVals[0+yyTop]), "Unexpected symbol expected ')'");
		For f = (For) oob_stack.Peek ();
		f.Iterator = (Statement) yyVals[-1+yyTop];
		yyVal = GetLocation (yyVals[0+yyTop]);
	  }

void case_900()
#line 5892 "cs-parser.jay"
{
		var lt = (LocatedToken) yyVals[0+yyTop];
		var li = new LocalVariable (current_block, lt.Value, lt.Location);
		current_block.AddLocalName (li);
		current_variable = new BlockVariable ((FullNamedExpression) yyVals[-1+yyTop], li);
	  }

void case_901()
#line 5899 "cs-parser.jay"
{
		yyVal = current_variable;
		if (yyVals[-1+yyTop] != null)
			lbag.AddLocation (current_variable, PopLocation ());

		current_variable = null;
	  }

void case_909()
#line 5926 "cs-parser.jay"
{
	  	var sl = yyVals[-2+yyTop] as StatementList;
	  	if (sl == null) {
	  		sl = new StatementList ((Statement) yyVals[-2+yyTop], (Statement) yyVals[0+yyTop]);
			lbag.AddStatement (sl, GetLocation (yyVals[-1+yyTop]));
	  	} else {
	  		sl.Add ((Statement) yyVals[0+yyTop]);
	  		lbag.AppendTo (sl, GetLocation (yyVals[-1+yyTop]));
	  	}
	  		
		yyVal = sl;
	  }

void case_910()
#line 5942 "cs-parser.jay"
{
		report.Error (230, GetLocation (yyVals[-3+yyTop]), "Type and identifier are both required in a foreach statement");

		start_block (GetLocation (yyVals[-2+yyTop]));
		current_block.IsCompilerGenerated = true;
		
		Foreach f = new Foreach ((Expression) yyVals[-1+yyTop], null, null, null, null, GetLocation (yyVals[-3+yyTop]));
		current_block.AddStatement (f);
		
		lbag.AddStatement (f, GetLocation (yyVals[-2+yyTop]));
		yyVal = end_block (GetLocation (yyVals[0+yyTop]));
	  }

void case_911()
#line 5955 "cs-parser.jay"
{
		Error_SyntaxError (yyToken);
	
		start_block (GetLocation (yyVals[-3+yyTop]));
		current_block.IsCompilerGenerated = true;
		
		var lt = (LocatedToken) yyVals[-1+yyTop];
		var li = new LocalVariable (current_block, lt.Value, LocalVariable.Flags.ForeachVariable | LocalVariable.Flags.Used, lt.Location);
		current_block.AddLocalName (li);
		
		Foreach f = new Foreach ((Expression) yyVals[-2+yyTop], li, null, null, null, GetLocation (yyVals[-4+yyTop]));
		current_block.AddStatement (f);
		
		lbag.AddStatement (f, GetLocation (yyVals[-3+yyTop]));
		yyVal = end_block (GetLocation (yyVals[0+yyTop]));
	  }

void case_912()
#line 5972 "cs-parser.jay"
{
		start_block (GetLocation (yyVals[-5+yyTop]));
		current_block.IsCompilerGenerated = true;
		
		var lt = (LocatedToken) yyVals[-3+yyTop];
		var li = new LocalVariable (current_block, lt.Value, LocalVariable.Flags.ForeachVariable | LocalVariable.Flags.Used, lt.Location);
		current_block.AddLocalName (li);
		yyVal = li;
	  }

void case_913()
#line 5982 "cs-parser.jay"
{
		if (yyVals[0+yyTop] is EmptyStatement && lexer.peek_token () == Token.OPEN_BRACE)
			Warning_EmptyStatement (GetLocation (yyVals[0+yyTop]));
		
		Foreach f = new Foreach ((Expression) yyVals[-6+yyTop], (LocalVariable) yyVals[-1+yyTop], (Expression) yyVals[-3+yyTop], (Statement) yyVals[0+yyTop], current_block, GetLocation (yyVals[-8+yyTop]));
		lbag.AddStatement (f, GetLocation (yyVals[-7+yyTop]), GetLocation (yyVals[-4+yyTop]), GetLocation (yyVals[-2+yyTop]));
		end_block (GetLocation (yyVals[-2+yyTop]));
		
		yyVal = f;
	  }

void case_920()
#line 6005 "cs-parser.jay"
{
		yyVal = new Break (GetLocation (yyVals[-1+yyTop]));
		lbag.AddStatement (yyVal, GetLocation (yyVals[0+yyTop]));
	  }

void case_921()
#line 6013 "cs-parser.jay"
{
		yyVal = new Continue (GetLocation (yyVals[-1+yyTop]));
		lbag.AddStatement (yyVal, GetLocation (yyVals[0+yyTop]));
	  }

void case_922()
#line 6018 "cs-parser.jay"
{
		Error_SyntaxError (yyToken);
		yyVal = new Continue (GetLocation (yyVals[-1+yyTop]));
	  }

void case_923()
#line 6026 "cs-parser.jay"
{
		var lt = (LocatedToken) yyVals[-1+yyTop];
		yyVal = new Goto (lt.Value, GetLocation (yyVals[-2+yyTop]));
		lbag.AddStatement (yyVal, GetLocation (yyVals[-1+yyTop]), GetLocation (yyVals[0+yyTop]));
	  }

void case_924()
#line 6032 "cs-parser.jay"
{
		yyVal = new GotoCase ((Expression) yyVals[-1+yyTop], GetLocation (yyVals[-3+yyTop]));
		lbag.AddStatement (yyVal, GetLocation (yyVals[-2+yyTop]), GetLocation (yyVals[0+yyTop]));
	  }

void case_925()
#line 6037 "cs-parser.jay"
{
		yyVal = new GotoDefault (GetLocation (yyVals[-2+yyTop]));
		lbag.AddStatement (yyVal, GetLocation (yyVals[-1+yyTop]), GetLocation (yyVals[0+yyTop]));
	  }

void case_926()
#line 6045 "cs-parser.jay"
{
		yyVal = new Return ((Expression) yyVals[-1+yyTop], GetLocation (yyVals[-2+yyTop]));
		lbag.AddStatement (yyVal, GetLocation (yyVals[0+yyTop]));
	  }

void case_927()
#line 6050 "cs-parser.jay"
{
		Error_SyntaxError (yyToken);
		yyVal = new Return ((Expression) yyVals[-1+yyTop], GetLocation (yyVals[-2+yyTop]));
	  }

void case_928()
#line 6055 "cs-parser.jay"
{
		Error_SyntaxError (yyToken);
		yyVal = new Return (null, GetLocation (yyVals[-1+yyTop]));
	  }

void case_929()
#line 6063 "cs-parser.jay"
{
		yyVal = new Throw ((Expression) yyVals[-1+yyTop], GetLocation (yyVals[-2+yyTop]));
		lbag.AddStatement (yyVal, GetLocation (yyVals[0+yyTop]));
	  }

void case_930()
#line 6068 "cs-parser.jay"
{
		Error_SyntaxError (yyToken);
		yyVal = new Throw ((Expression) yyVals[-1+yyTop], GetLocation (yyVals[-2+yyTop]));
	  }

void case_931()
#line 6073 "cs-parser.jay"
{
		Error_SyntaxError (yyToken);
		yyVal = new Throw (null, GetLocation (yyVals[-1+yyTop]));
	  }

void case_932()
#line 6081 "cs-parser.jay"
{
		var lt = (LocatedToken) yyVals[-3+yyTop];
		string s = lt.Value;
		if (s != "yield"){
			report.Error (1003, lt.Location, "; expected");
		} else if (yyVals[-1+yyTop] == null) {
			report.Error (1627, GetLocation (yyVals[0+yyTop]), "Expression expected after yield return");
		} else if (lang_version == LanguageVersion.ISO_1){
			FeatureIsNotAvailable (lt.Location, "iterators");
		}
		
		current_block.Explicit.RegisterIteratorYield ();
		yyVal = new Yield ((Expression) yyVals[-1+yyTop], lt.Location);
		lbag.AddStatement (yyVal, GetLocation (yyVals[-2+yyTop]), GetLocation (yyVals[0+yyTop]));
	  }

void case_933()
#line 6097 "cs-parser.jay"
{
		Error_SyntaxError (yyToken);

		var lt = (LocatedToken) yyVals[-3+yyTop];
		string s = lt.Value;
		if (s != "yield"){
			report.Error (1003, lt.Location, "; expected");
		} else if (yyVals[-1+yyTop] == null) {
			report.Error (1627, GetLocation (yyVals[0+yyTop]), "Expression expected after yield return");
		} else if (lang_version == LanguageVersion.ISO_1){
			FeatureIsNotAvailable (lt.Location, "iterators");
		}
		
		current_block.Explicit.RegisterIteratorYield ();
		yyVal = new Yield ((Expression) yyVals[-1+yyTop], lt.Location);
		lbag.AddStatement (yyVal, GetLocation (yyVals[-2+yyTop]));
	  }

void case_934()
#line 6115 "cs-parser.jay"
{
		var lt = (LocatedToken) yyVals[-2+yyTop];
		string s = lt.Value;
		if (s != "yield"){
			report.Error (1003, lt.Location, "; expected");
		} else if (lang_version == LanguageVersion.ISO_1){
			FeatureIsNotAvailable (lt.Location, "iterators");
		}
		
		current_block.ParametersBlock.TopBlock.IsIterator = true;
		yyVal = new YieldBreak (lt.Location);
		lbag.AddStatement (yyVal, GetLocation (yyVals[-1+yyTop]), GetLocation (yyVals[0+yyTop]));
	  }

void case_938()
#line 6141 "cs-parser.jay"
{
		yyVal = new TryFinally ((Statement) yyVals[-2+yyTop], (ExplicitBlock) yyVals[0+yyTop], GetLocation (yyVals[-3+yyTop]));
		lbag.AddStatement (yyVal, GetLocation (yyVals[-1+yyTop]));
	  }

void case_939()
#line 6146 "cs-parser.jay"
{
		yyVal = new TryFinally (new TryCatch ((Block) yyVals[-3+yyTop], (List<Catch>) yyVals[-2+yyTop], Location.Null, true), (ExplicitBlock) yyVals[0+yyTop], GetLocation (yyVals[-4+yyTop]));
		lbag.AddStatement (yyVal, GetLocation (yyVals[-1+yyTop]));
	  }

void case_940()
#line 6151 "cs-parser.jay"
{
		Error_SyntaxError (1524, yyToken);
		yyVal = new TryCatch ((Block) yyVals[-1+yyTop], null, GetLocation (yyVals[-2+yyTop]), false);
	  }

void case_941()
#line 6159 "cs-parser.jay"
{
		var l = new List<Catch> (2);

		l.Add ((Catch) yyVals[0+yyTop]);
		yyVal = l;
	  }

void case_942()
#line 6166 "cs-parser.jay"
{
		var l = (List<Catch>) yyVals[-1+yyTop];
		
		Catch c = (Catch) yyVals[0+yyTop];
		var prev_catch = l [l.Count - 1];
		if (prev_catch.IsGeneral && prev_catch.Filter == null) {
			report.Error (1017, c.loc, "Try statement already has an empty catch block");
		}
		
		l.Add (c);
		yyVal = l;
	  }

void case_945()
#line 6187 "cs-parser.jay"
{
	  	var c = new Catch ((ExplicitBlock) yyVals[0+yyTop], GetLocation (yyVals[-2+yyTop]));
	  	c.Filter = (CatchFilterExpression) yyVals[-1+yyTop];
	  	yyVal = c;
	  }

void case_946()
#line 6193 "cs-parser.jay"
{
		start_block (GetLocation (yyVals[-3+yyTop]));
		var c = new Catch ((ExplicitBlock) current_block, GetLocation (yyVals[-4+yyTop]));
		c.TypeExpression = (FullNamedExpression) yyVals[-2+yyTop];

		if (yyVals[-1+yyTop] != null) {
			var lt = (LocatedToken) yyVals[-1+yyTop];
			c.Variable = new LocalVariable (current_block, lt.Value, lt.Location);
			current_block.AddLocalName (c.Variable);
		}
		
		lbag.AddLocation (c, GetLocation (yyVals[-3+yyTop]), GetLocation (yyVals[0+yyTop]));
		yyVal = c;
	  }

void case_947()
#line 6208 "cs-parser.jay"
{
	  	((Catch) yyVals[-2+yyTop]).Filter = (CatchFilterExpression) yyVals[-1+yyTop];
		yyVal = yyVals[-2+yyTop];
	  }

void case_948()
#line 6213 "cs-parser.jay"
{
	  	if (yyToken == Token.CLOSE_PARENS) {
			report.Error (1015, lexer.Location,
				"A type that derives from `System.Exception', `object', or `string' expected");
		} else {
			Error_SyntaxError (yyToken);
		}
		
		yyVal = new Catch (null, GetLocation (yyVals[-2+yyTop]));
	  }

void case_949()
#line 6224 "cs-parser.jay"
{
		Error_SyntaxError (yyToken);

		/* Required otherwise missing block could not be detected because*/
		/* start_block is run early*/
		var c = new Catch (null, GetLocation (yyVals[-5+yyTop]));
		c.TypeExpression = (FullNamedExpression) yyVals[-3+yyTop];

		if (yyVals[-2+yyTop] != null) {
			var lt = (LocatedToken) yyVals[-2+yyTop];
			c.Variable = new LocalVariable (current_block, lt.Value, lt.Location);
		}

		lbag.AddLocation (c, GetLocation (yyVals[-4+yyTop]), GetLocation (yyVals[-1+yyTop]));

		yyVal = c;
	  }

void case_951()
#line 6246 "cs-parser.jay"
{
		if (lang_version <= LanguageVersion.V_5)
			FeatureIsNotAvailable (GetLocation (yyVals[-3+yyTop]), "exception filter");

	  	yyVal = new CatchFilterExpression ((Expression) yyVals[-1+yyTop], GetLocation (yyVals[-3+yyTop]));
	  	lbag.AddLocation (yyVal, GetLocation (yyVals[-2+yyTop]), GetLocation (yyVals[0+yyTop]));
	  }

void case_954()
#line 6271 "cs-parser.jay"
{
		if (!settings.Unsafe)
			Error_UnsafeCodeNotAllowed (GetLocation (yyVals[0+yyTop]));
	  }

void case_956()
#line 6281 "cs-parser.jay"
{
		if (yyVals[0+yyTop] is EmptyStatement && lexer.peek_token () == Token.OPEN_BRACE)
			Warning_EmptyStatement (GetLocation (yyVals[0+yyTop]));
	  
		yyVal = new Lock ((Expression) yyVals[-2+yyTop], (Statement) yyVals[0+yyTop], GetLocation (yyVals[-4+yyTop]));
		lbag.AddStatement (yyVal, GetLocation (yyVals[-3+yyTop]), GetLocation (yyVals[-1+yyTop]));
	  }

void case_957()
#line 6289 "cs-parser.jay"
{
		Error_SyntaxError (yyToken);

		yyVal = new Lock ((Expression) yyVals[-1+yyTop], null, GetLocation (yyVals[-3+yyTop]));
		lbag.AddStatement (yyVal, GetLocation (yyVals[-2+yyTop]));
	  }

void case_958()
#line 6299 "cs-parser.jay"
{
	    start_block (GetLocation (yyVals[-2+yyTop]));
	    
		current_block.IsCompilerGenerated = true;
		var lt = (LocatedToken) yyVals[0+yyTop];
		var li = new LocalVariable (current_block, lt.Value, LocalVariable.Flags.FixedVariable | LocalVariable.Flags.Used, lt.Location);
		current_block.AddLocalName (li);
		current_variable = new Fixed.VariableDeclaration ((FullNamedExpression) yyVals[-1+yyTop], li);
	  }

void case_959()
#line 6309 "cs-parser.jay"
{
		yyVal = current_variable;
		current_variable = null;
	  }

void case_960()
#line 6314 "cs-parser.jay"
{
		if (yyVals[0+yyTop] is EmptyStatement && lexer.peek_token () == Token.OPEN_BRACE)
			Warning_EmptyStatement (GetLocation (yyVals[0+yyTop]));
	  
		Fixed f = new Fixed ((Fixed.VariableDeclaration) yyVals[-1+yyTop], (Statement) yyVals[0+yyTop], GetLocation (yyVals[-9+yyTop]));
		current_block.AddStatement (f);
		lbag.AddStatement (f, GetLocation (yyVals[-8+yyTop]), GetLocation (yyVals[-2+yyTop]));
		yyVal = end_block (GetLocation (yyVals[-2+yyTop]));
	  }

void case_961()
#line 6327 "cs-parser.jay"
{
	    start_block (GetLocation (yyVals[-2+yyTop]));
	    
		current_block.IsCompilerGenerated = true;
		var lt = (LocatedToken) yyVals[0+yyTop];
		var li = new LocalVariable (current_block, lt.Value, LocalVariable.Flags.UsingVariable | LocalVariable.Flags.Used, lt.Location);
		current_block.AddLocalName (li);
		current_variable = new Using.VariableDeclaration ((FullNamedExpression) yyVals[-1+yyTop], li);
	  }

void case_962()
#line 6337 "cs-parser.jay"
{
		yyVal = current_variable;	  
		current_variable = null;
	  }

void case_963()
#line 6342 "cs-parser.jay"
{
		if (yyVals[0+yyTop] is EmptyStatement && lexer.peek_token () == Token.OPEN_BRACE)
			Warning_EmptyStatement (GetLocation (yyVals[0+yyTop]));
	  
		Using u = new Using ((Using.VariableDeclaration) yyVals[-1+yyTop], (Statement) yyVals[0+yyTop], GetLocation (yyVals[-8+yyTop]));
		current_block.AddStatement (u);
		yyVal = end_block (GetLocation (yyVals[-2+yyTop]));
	  }

void case_964()
#line 6351 "cs-parser.jay"
{
		if (yyVals[0+yyTop] is EmptyStatement && lexer.peek_token () == Token.OPEN_BRACE)
			Warning_EmptyStatement (GetLocation (yyVals[0+yyTop]));
	  
		yyVal = new Using ((Expression) yyVals[-2+yyTop], (Statement) yyVals[0+yyTop], GetLocation (yyVals[-4+yyTop]));
		lbag.AddStatement (yyVal, GetLocation (yyVals[-3+yyTop]), GetLocation (yyVals[-1+yyTop]));
	  }

void case_965()
#line 6359 "cs-parser.jay"
{
		Error_SyntaxError (yyToken);
		
		yyVal = new Using ((Expression) yyVals[-1+yyTop], null, GetLocation (yyVals[-3+yyTop]));
		lbag.AddStatement (yyVal, GetLocation (yyVals[-2+yyTop]));
	  }

void case_967()
#line 6370 "cs-parser.jay"
{
		/* It has to be here for the parent to safely restore artificial block*/
	  	Error_SyntaxError (yyToken);
	  }

void case_969()
#line 6382 "cs-parser.jay"
{
		current_variable.Initializer = (Expression) yyVals[0+yyTop];
		yyVal = current_variable;
	  }

void case_970()
#line 6393 "cs-parser.jay"
{
		lexer.query_parsing = false;
			
		Linq.AQueryClause from = yyVals[-1+yyTop] as Linq.AQueryClause;
			
		from.Tail.Next = (Linq.AQueryClause)yyVals[0+yyTop];
		yyVal = from;
		
		current_block.SetEndLocation (lexer.Location);
		current_block = current_block.Parent;
	  }

void case_971()
#line 6405 "cs-parser.jay"
{
		Linq.AQueryClause from = yyVals[-1+yyTop] as Linq.AQueryClause;
			
		from.Tail.Next = (Linq.AQueryClause)yyVals[0+yyTop];
		yyVal = from;
		
		current_block.SetEndLocation (lexer.Location);
		current_block = current_block.Parent;
	  }

void case_972()
#line 6416 "cs-parser.jay"
{
	        lexer.query_parsing = false;
		yyVal = yyVals[-1+yyTop];

		current_block.SetEndLocation (lexer.Location);
		current_block = current_block.Parent;
	  }

void case_973()
#line 6423 "cs-parser.jay"
{
	        yyVal = yyVals[-1+yyTop];
		current_block.SetEndLocation (lexer.Location);
		current_block = current_block.Parent;
	  }

void case_974()
#line 6432 "cs-parser.jay"
{
		current_block = new Linq.QueryBlock (current_block, lexer.Location);
	  
		var lt = (LocatedToken) yyVals[-2+yyTop];
		var rv = new Linq.RangeVariable (lt.Value, lt.Location);
		var clause = new Linq.QueryStartClause ((Linq.QueryBlock)current_block, (Expression)yyVals[0+yyTop], rv, GetLocation (yyVals[-3+yyTop]));
		lbag.AddLocation (clause, GetLocation (yyVals[-1+yyTop]));
		yyVal = new Linq.QueryExpression (clause);
	  }

void case_975()
#line 6442 "cs-parser.jay"
{
		current_block = new Linq.QueryBlock (current_block, lexer.Location);
	  
		var lt = (LocatedToken) yyVals[-2+yyTop];
		var rv = new Linq.RangeVariable (lt.Value, lt.Location);
		var clause = new Linq.QueryStartClause ((Linq.QueryBlock)current_block, (Expression)yyVals[0+yyTop], rv, GetLocation (yyVals[-4+yyTop])) {
				IdentifierType = (FullNamedExpression)yyVals[-3+yyTop]
		};
		lbag.AddLocation (clause, GetLocation (yyVals[-1+yyTop]));
		yyVal = new Linq.QueryExpression (clause);
	  }

void case_976()
#line 6457 "cs-parser.jay"
{
		current_block = new Linq.QueryBlock (current_block, lexer.Location);
	  
		var lt = (LocatedToken) yyVals[-2+yyTop];
		var rv = new Linq.RangeVariable (lt.Value, lt.Location);
		var clause = new Linq.QueryStartClause ((Linq.QueryBlock)current_block, (Expression)yyVals[0+yyTop], rv, GetLocation (yyVals[-3+yyTop]));
		lbag.AddLocation (clause, GetLocation (yyVals[-1+yyTop]));
		yyVal = new Linq.QueryExpression (clause);
	  }

void case_977()
#line 6467 "cs-parser.jay"
{
		current_block = new Linq.QueryBlock (current_block, lexer.Location);
	  
		var lt = (LocatedToken) yyVals[-2+yyTop];
		var rv = new Linq.RangeVariable (lt.Value, lt.Location);
		var clause = new Linq.QueryStartClause ((Linq.QueryBlock)current_block, (Expression)yyVals[0+yyTop], rv, GetLocation (yyVals[-4+yyTop])) {
				IdentifierType = (FullNamedExpression)yyVals[-3+yyTop]
		};
		lbag.AddLocation (clause, GetLocation (yyVals[-1+yyTop]));
		yyVal = new Linq.QueryExpression (clause);
	  }

void case_979()
#line 6486 "cs-parser.jay"
{
		var lt = (LocatedToken) yyVals[-3+yyTop];
		var sn = new Linq.RangeVariable (lt.Value, lt.Location);
		yyVal = new Linq.SelectMany ((Linq.QueryBlock)current_block, sn, (Expression)yyVals[0+yyTop], GetLocation (yyVals[-4+yyTop]));
		
		current_block.SetEndLocation (lexer.Location);
		current_block = current_block.Parent;
		
		((Linq.QueryBlock)current_block).AddRangeVariable (sn);
		lbag.AddLocation (yyVal, GetLocation (yyVals[-2+yyTop]));
	  }

void case_981()
#line 6502 "cs-parser.jay"
{
		var lt = (LocatedToken) yyVals[-3+yyTop];
		var sn = new Linq.RangeVariable (lt.Value, lt.Location);

		yyVal = new Linq.SelectMany ((Linq.QueryBlock)current_block, sn, (Expression)yyVals[0+yyTop], GetLocation (yyVals[-5+yyTop])) {
			IdentifierType = (FullNamedExpression)yyVals[-4+yyTop]
		};
		
		current_block.SetEndLocation (lexer.Location);
		current_block = current_block.Parent;
		
		((Linq.QueryBlock)current_block).AddRangeVariable (sn);
		
		lbag.AddLocation (yyVal, GetLocation (yyVals[-2+yyTop]));
	  }

void case_982()
#line 6521 "cs-parser.jay"
{
	  	Linq.AQueryClause head = (Linq.AQueryClause)yyVals[-1+yyTop];
		
		if (yyVals[0+yyTop] != null)
			head.Next = (Linq.AQueryClause)yyVals[0+yyTop];
				
		if (yyVals[-2+yyTop] != null) {
			Linq.AQueryClause clause = (Linq.AQueryClause)yyVals[-2+yyTop];
			clause.Tail.Next = head;
			head = clause;
		}
		
		yyVal = head;
	  }

void case_983()
#line 6536 "cs-parser.jay"
{
	  	Linq.AQueryClause head = (Linq.AQueryClause)yyVals[0+yyTop];

		if (yyVals[-1+yyTop] != null) {
			Linq.AQueryClause clause = (Linq.AQueryClause)yyVals[-1+yyTop];
			clause.Tail.Next = head;
			head = clause;
		}
		
		yyVal = head;
	  }

void case_985()
#line 6549 "cs-parser.jay"
{
		report.Error (742, GetLocation (yyVals[0+yyTop]), "Unexpected symbol `{0}'. A query body must end with select or group clause", GetSymbolName (yyToken));
		yyVal = yyVals[-1+yyTop];
	  }

void case_986()
#line 6554 "cs-parser.jay"
{
		Error_SyntaxError (yyToken);
		yyVal = null;
	  }

void case_988()
#line 6566 "cs-parser.jay"
{
		yyVal = new Linq.Select ((Linq.QueryBlock)current_block, (Expression)yyVals[0+yyTop], GetLocation (yyVals[-2+yyTop]));

		current_block.SetEndLocation (lexer.Location);
		current_block = current_block.Parent;
	  }

void case_989()
#line 6573 "cs-parser.jay"
{
	  	if (linq_clause_blocks == null)
	  		linq_clause_blocks = new Stack<Linq.QueryBlock> ();
	  		
	  	current_block = new Linq.QueryBlock (current_block, lexer.Location);
	  	linq_clause_blocks.Push ((Linq.QueryBlock)current_block);
	  }

void case_990()
#line 6581 "cs-parser.jay"
{
		current_block.SetEndLocation (lexer.Location);
		current_block = current_block.Parent;
	  
		current_block = new Linq.QueryBlock (current_block, lexer.Location);
	  }

void case_991()
#line 6588 "cs-parser.jay"
{
		var obj = (object[]) yyVals[0+yyTop];

		yyVal = new Linq.GroupBy ((Linq.QueryBlock)current_block, (Expression)yyVals[-2+yyTop], linq_clause_blocks.Pop (), (Expression)obj[0], GetLocation (yyVals[-4+yyTop]));
		lbag.AddLocation (yyVal, (Location) obj[1]);
		
		current_block.SetEndLocation (lexer.Location);
		current_block = current_block.Parent;
	  }

void case_993()
#line 6605 "cs-parser.jay"
{
		Error_SyntaxError (yyToken);
		yyVal = new object[2] { null, Location.Null };
	  }

void case_995()
#line 6614 "cs-parser.jay"
{
		((Linq.AQueryClause)yyVals[-1+yyTop]).Tail.Next = (Linq.AQueryClause)yyVals[0+yyTop];
		yyVal = yyVals[-1+yyTop];
	  }

void case_1002()
#line 6634 "cs-parser.jay"
{
		var lt = (LocatedToken) yyVals[-3+yyTop];
		var sn = new Linq.RangeVariable (lt.Value, lt.Location);
	  	yyVal = new Linq.Let ((Linq.QueryBlock) current_block, sn, (Expression)yyVals[0+yyTop], GetLocation (yyVals[-4+yyTop]));
		lbag.AddLocation (yyVal, GetLocation (yyVals[-2+yyTop]));
	  	
		current_block.SetEndLocation (lexer.Location);
		current_block = current_block.Parent;
		
		((Linq.QueryBlock)current_block).AddRangeVariable (sn);
	  }

void case_1004()
#line 6653 "cs-parser.jay"
{
		yyVal = new Linq.Where ((Linq.QueryBlock)current_block, (Expression)yyVals[0+yyTop], GetLocation (yyVals[-2+yyTop]));

		current_block.SetEndLocation (lexer.Location);
		current_block = current_block.Parent;
	  }

void case_1005()
#line 6663 "cs-parser.jay"
{
		if (linq_clause_blocks == null)
			linq_clause_blocks = new Stack<Linq.QueryBlock> ();
	  		
		current_block = new Linq.QueryBlock (current_block, lexer.Location);
		linq_clause_blocks.Push ((Linq.QueryBlock) current_block);
	  }

void case_1006()
#line 6671 "cs-parser.jay"
{
		current_block.SetEndLocation (lexer.Location);
		current_block = current_block.Parent;

		current_block = new Linq.QueryBlock (current_block, lexer.Location);
		linq_clause_blocks.Push ((Linq.QueryBlock) current_block);
	  }

void case_1007()
#line 6679 "cs-parser.jay"
{
		current_block.AddStatement (new ContextualReturn ((Expression) yyVals[-1+yyTop]));
		current_block.SetEndLocation (lexer.Location);
		current_block = current_block.Parent;

		current_block = new Linq.QueryBlock (current_block, lexer.Location);
	  }

void case_1008()
#line 6687 "cs-parser.jay"
{
		current_block.AddStatement (new ContextualReturn ((Expression) yyVals[-1+yyTop]));
		current_block.SetEndLocation (lexer.Location);
	  
		var outer_selector = linq_clause_blocks.Pop ();
		var block = linq_clause_blocks.Pop ();

		var lt = (LocatedToken) yyVals[-10+yyTop];	
		var sn = new Linq.RangeVariable (lt.Value, lt.Location);
		Linq.RangeVariable into;
		
		if (yyVals[0+yyTop] == null) {
			into = sn;
	  		yyVal = new Linq.Join (block, sn, (Expression)yyVals[-7+yyTop], outer_selector, (Linq.QueryBlock) current_block, GetLocation (yyVals[-11+yyTop]));
			lbag.AddLocation (yyVal, GetLocation (yyVals[-9+yyTop]), GetLocation (yyVals[-6+yyTop]), GetLocation (yyVals[-3+yyTop]));
		} else {
			/**/
			/* Set equals right side parent to beginning of linq query, it is not accessible therefore cannot cause name collisions*/
			/**/
			var parent = block.Parent;
			while (parent is Linq.QueryBlock) {
				parent = parent.Parent;
			}
			current_block.Parent = parent;
			
			((Linq.QueryBlock)current_block).AddRangeVariable (sn);
		
			lt = (LocatedToken) yyVals[0+yyTop];
			into = new Linq.RangeVariable (lt.Value, lt.Location);

			yyVal = new Linq.GroupJoin (block, sn, (Expression)yyVals[-7+yyTop], outer_selector, (Linq.QueryBlock) current_block, into, GetLocation (yyVals[-11+yyTop]));	
			lbag.AddLocation (yyVal, GetLocation (yyVals[-9+yyTop]), GetLocation (yyVals[-6+yyTop]), GetLocation (yyVals[-3+yyTop]), GetLocation (yyVals[0+yyTop]));
		}

		current_block = block.Parent;
		((Linq.QueryBlock)current_block).AddRangeVariable (into);
	  }

void case_1009()
#line 6725 "cs-parser.jay"
{
		if (linq_clause_blocks == null)
			linq_clause_blocks = new Stack<Linq.QueryBlock> ();
	  		
		current_block = new Linq.QueryBlock (current_block, lexer.Location);
		linq_clause_blocks.Push ((Linq.QueryBlock) current_block);
	  }

void case_1010()
#line 6733 "cs-parser.jay"
{
		current_block.SetEndLocation (lexer.Location);
		current_block = current_block.Parent;

		current_block = new Linq.QueryBlock (current_block, lexer.Location);
		linq_clause_blocks.Push ((Linq.QueryBlock) current_block);
	  }

void case_1011()
#line 6741 "cs-parser.jay"
{
		current_block.AddStatement (new ContextualReturn ((Expression) yyVals[-1+yyTop]));
		current_block.SetEndLocation (lexer.Location);
		current_block = current_block.Parent;

		current_block = new Linq.QueryBlock (current_block, lexer.Location);
	  }

void case_1012()
#line 6749 "cs-parser.jay"
{
		current_block.AddStatement (new ContextualReturn ((Expression) yyVals[-1+yyTop]));
		current_block.SetEndLocation (lexer.Location);
	  
		var outer_selector = linq_clause_blocks.Pop ();
		var block = linq_clause_blocks.Pop ();
		
		var lt = (LocatedToken) yyVals[-10+yyTop];
		var sn = new Linq.RangeVariable (lt.Value, lt.Location);
		Linq.RangeVariable into;
		
		if (yyVals[0+yyTop] == null) {
			into = sn;		
	  		yyVal = new Linq.Join (block, sn, (Expression)yyVals[-7+yyTop], outer_selector, (Linq.QueryBlock) current_block, GetLocation (yyVals[-12+yyTop])) {
	  			IdentifierType = (FullNamedExpression)yyVals[-11+yyTop]
	  		};
			lbag.AddLocation (yyVal, GetLocation (yyVals[-10+yyTop]), GetLocation (yyVals[-7+yyTop]), GetLocation (yyVals[-4+yyTop]));
		} else {
			/**/
			/* Set equals right side parent to beginning of linq query, it is not accessible therefore cannot cause name collisions*/
			/**/
			var parent = block.Parent;
			while (parent is Linq.QueryBlock) {
				parent = parent.Parent;
			}
			current_block.Parent = parent;
		
			((Linq.QueryBlock)current_block).AddRangeVariable (sn);
		
			lt = (LocatedToken) yyVals[0+yyTop];
			into = new Linq.RangeVariable (lt.Value, lt.Location); /* TODO:*/
			
			yyVal = new Linq.GroupJoin (block, sn, (Expression)yyVals[-7+yyTop], outer_selector, (Linq.QueryBlock) current_block, into, GetLocation (yyVals[-12+yyTop])) {
	  			IdentifierType = (FullNamedExpression)yyVals[-11+yyTop]
	  		};			
		}
		
		current_block = block.Parent;
		((Linq.QueryBlock)current_block).AddRangeVariable (into);		
	  }

void case_1016()
#line 6805 "cs-parser.jay"
{
		current_block.SetEndLocation (lexer.Location);
		current_block = current_block.Parent;
	  
		yyVal = yyVals[0+yyTop];
	  }

void case_1018()
#line 6816 "cs-parser.jay"
{
		current_block.SetEndLocation (lexer.Location);
		current_block = current_block.Parent;
	  
		current_block = new Linq.QueryBlock (current_block, lexer.Location);
	  }

void case_1019()
#line 6823 "cs-parser.jay"
{
		((Linq.AQueryClause)yyVals[-3+yyTop]).Next = (Linq.AQueryClause)yyVals[0+yyTop];
		yyVal = yyVals[-3+yyTop];
	  }

void case_1021()
#line 6832 "cs-parser.jay"
{
		current_block.SetEndLocation (lexer.Location);
		current_block = current_block.Parent;
	  
		current_block = new Linq.QueryBlock ((Linq.QueryBlock) current_block, lexer.Location);	 
	 }

void case_1022()
#line 6839 "cs-parser.jay"
{
		((Linq.AQueryClause)yyVals[-3+yyTop]).Tail.Next = (Linq.AQueryClause)yyVals[0+yyTop];
		yyVal = yyVals[-3+yyTop];
	 }

void case_1024()
#line 6851 "cs-parser.jay"
{
		yyVal = new Linq.OrderByAscending ((Linq.QueryBlock) current_block, (Expression)yyVals[-1+yyTop]);	
		lbag.AddLocation (yyVal, GetLocation (yyVals[0+yyTop]));
	  }

void case_1025()
#line 6856 "cs-parser.jay"
{
		yyVal = new Linq.OrderByDescending ((Linq.QueryBlock) current_block, (Expression)yyVals[-1+yyTop]);	
		lbag.AddLocation (yyVal, GetLocation (yyVals[0+yyTop]));
	  }

void case_1027()
#line 6868 "cs-parser.jay"
{
		yyVal = new Linq.ThenByAscending ((Linq.QueryBlock) current_block, (Expression)yyVals[-1+yyTop]);	
		lbag.AddLocation (yyVal, GetLocation (yyVals[0+yyTop]));
	  }

void case_1028()
#line 6873 "cs-parser.jay"
{
		yyVal = new Linq.ThenByDescending ((Linq.QueryBlock) current_block, (Expression)yyVals[-1+yyTop]);	
		lbag.AddLocation (yyVal, GetLocation (yyVals[0+yyTop]));
	  }

void case_1030()
#line 6883 "cs-parser.jay"
{
		/* query continuation block is not linked with query block but with block*/
		/* before. This means each query can use same range variable names for*/
		/* different identifiers.*/

		current_block.SetEndLocation (GetLocation (yyVals[-1+yyTop]));
		current_block = current_block.Parent;
	
		current_block = new Linq.QueryBlock (current_block, lexer.Location);
		
		if (linq_clause_blocks == null)
			linq_clause_blocks = new Stack<Linq.QueryBlock> ();
	  		
		linq_clause_blocks.Push ((Linq.QueryBlock) current_block);		
	  }

void case_1031()
#line 6899 "cs-parser.jay"
{
		var current_block = linq_clause_blocks.Pop ();	  
		var lt = (LocatedToken) yyVals[-2+yyTop];
		var rv = new Linq.RangeVariable (lt.Value, lt.Location);
  		yyVal = new Linq.QueryStartClause ((Linq.QueryBlock)current_block, null, rv, GetLocation (yyVals[-3+yyTop])) {
  			next = (Linq.AQueryClause)yyVals[0+yyTop]
  		};
	  }

void case_1034()
#line 6926 "cs-parser.jay"
{ 
		current_container = current_type = new Class (current_container, new MemberName ("<InteractiveExpressionClass>"), Modifiers.PUBLIC, null);

		/* (ref object retval)*/
		Parameter [] mpar = new Parameter [1];
		mpar [0] = new Parameter (new TypeExpression (compiler.BuiltinTypes.Object, Location.Null), "$retval", Parameter.Modifier.REF, null, Location.Null);

		ParametersCompiled pars = new ParametersCompiled (mpar);
		var mods = Modifiers.PUBLIC | Modifiers.STATIC;
		if (settings.Unsafe)
			mods |= Modifiers.UNSAFE;

		current_local_parameters = pars;
		var method = new InteractiveMethod (
			current_type,
			new TypeExpression (compiler.BuiltinTypes.Void, Location.Null),
			mods,
			pars);
			
		current_type.AddMember (method);			
		oob_stack.Push (method);

		interactive_async = false;

		++lexer.parsing_block;
		start_block (lexer.Location);
	  }

void case_1035()
#line 6954 "cs-parser.jay"
{
		--lexer.parsing_block;
		var method = (InteractiveMethod) oob_stack.Pop ();
		method.Block = (ToplevelBlock) end_block(lexer.Location);

		if (interactive_async == true) {
			method.ChangeToAsync ();
		}

		InteractiveResult = (Class) pop_current_class ();
		current_local_parameters = null;
	  }

void case_1045()
#line 7000 "cs-parser.jay"
{
		module.DocumentationBuilder.ParsedBuiltinType = (TypeExpression)yyVals[-1+yyTop];
		module.DocumentationBuilder.ParsedParameters = (List<DocumentationParameter>)yyVals[0+yyTop];
		yyVal = null;
	  }

void case_1046()
#line 7006 "cs-parser.jay"
{
		module.DocumentationBuilder.ParsedBuiltinType = new TypeExpression (compiler.BuiltinTypes.Void, GetLocation (yyVals[-1+yyTop]));
		module.DocumentationBuilder.ParsedParameters = (List<DocumentationParameter>)yyVals[0+yyTop];
		yyVal = null;
	  }

void case_1047()
#line 7012 "cs-parser.jay"
{
		module.DocumentationBuilder.ParsedBuiltinType = (TypeExpression)yyVals[-3+yyTop];
		module.DocumentationBuilder.ParsedParameters = (List<DocumentationParameter>)yyVals[0+yyTop];
		var lt = (LocatedToken) yyVals[-1+yyTop];
		yyVal = new MemberName (lt.Value);
	  }

void case_1050()
#line 7027 "cs-parser.jay"
{
		module.DocumentationBuilder.ParsedParameters = (List<DocumentationParameter>)yyVals[-1+yyTop];
		yyVal = new MemberName ((MemberName) yyVals[-6+yyTop], MemberCache.IndexerNameAlias, Location.Null);
	  }

void case_1051()
#line 7032 "cs-parser.jay"
{
		var p = (List<DocumentationParameter>)yyVals[0+yyTop] ?? new List<DocumentationParameter> (1);
		p.Add (new DocumentationParameter ((FullNamedExpression) yyVals[-1+yyTop]));
		module.DocumentationBuilder.ParsedParameters = p;
		module.DocumentationBuilder.ParsedOperator = Operator.OpType.Explicit;
		yyVal = null;
	  }

void case_1052()
#line 7040 "cs-parser.jay"
{
		var p = (List<DocumentationParameter>)yyVals[0+yyTop] ?? new List<DocumentationParameter> (1);
		p.Add (new DocumentationParameter ((FullNamedExpression) yyVals[-1+yyTop]));
		module.DocumentationBuilder.ParsedParameters = p;
		module.DocumentationBuilder.ParsedOperator = Operator.OpType.Implicit;
		yyVal = null;
	  }

void case_1053()
#line 7048 "cs-parser.jay"
{
		var p = (List<DocumentationParameter>)yyVals[0+yyTop];
		module.DocumentationBuilder.ParsedParameters = p;
		module.DocumentationBuilder.ParsedOperator = (Operator.OpType) yyVals[-1+yyTop];
		yyVal = null;
	  }

void case_1061()
#line 7086 "cs-parser.jay"
{
		var parameters = new List<DocumentationParameter> ();
		parameters.Add ((DocumentationParameter) yyVals[0+yyTop]);
		yyVal = parameters;
	  }

void case_1062()
#line 7092 "cs-parser.jay"
{
		var parameters = yyVals[-2+yyTop] as List<DocumentationParameter>;
		parameters.Add ((DocumentationParameter) yyVals[0+yyTop]);
		yyVal = parameters;
	  }

void case_1063()
#line 7101 "cs-parser.jay"
{
		if (yyVals[-1+yyTop] != null)
			yyVal = new DocumentationParameter ((Parameter.Modifier) yyVals[-1+yyTop], (FullNamedExpression) yyVals[0+yyTop]);
		else
			yyVal = new DocumentationParameter ((FullNamedExpression) yyVals[0+yyTop]);
	  }

#line default
   static readonly short [] yyLhs  = {              -1,
    0,    4,    0,    0,    1,    1,    1,    1,    2,    2,
   11,   11,   12,   12,   13,   13,   14,   15,   15,   15,
   19,   20,   17,   17,   22,   22,   22,   18,   18,   18,
   23,   23,   24,   24,    7,    7,    6,    6,   21,   21,
    8,    8,   25,   25,   25,   26,   26,   26,   26,   26,
    9,    9,   10,   10,   34,   32,   37,   33,   33,   33,
   33,   35,   35,   35,   36,   36,   41,   38,   39,   40,
   40,   42,   42,   42,   42,   42,   43,   43,   43,   47,
   44,   46,   49,   49,   49,   51,   51,   52,   52,   53,
   53,   53,   53,   53,   53,   53,   53,   53,   53,   53,
   53,   53,   53,   67,   62,   72,   74,   77,   78,   79,
   28,   28,   82,   54,   54,   83,   83,   84,   84,   85,
   87,   81,   81,   86,   86,   92,   55,   96,   55,   55,
   91,   99,   91,   93,   93,  100,  100,  101,  102,  101,
   97,   97,  103,  103,  104,  105,   95,   95,   98,   98,
   98,  108,   56,  111,  112,  106,  113,  114,  115,  106,
  106,  106,  107,  107,  117,  117,  120,  118,  110,  110,
  121,  121,  121,  121,  121,  121,  121,  121,  121,  121,
  122,  122,  125,  125,  125,  125,  128,  125,  126,  126,
  129,  129,  130,  130,  130,  123,  123,  123,  131,  131,
  131,  124,  133,  135,  136,  138,   57,  139,   57,  137,
  141,  137,  140,  140,  143,  145,   59,  144,  144,  134,
  134,  134,  134,  134,  149,  146,  150,  147,  148,  148,
  148,  151,  152,  153,  155,   29,   29,  154,  154,  156,
  156,  157,  157,  157,  157,  157,  157,  157,  157,  157,
  159,   60,  160,  160,  163,  158,  158,  162,  162,  162,
  162,  162,  162,  162,  162,  162,  162,  162,  162,  162,
  162,  162,  162,  162,  162,  162,  162,  162,  162,  165,
  164,  166,  164,  164,  164,   61,  169,  171,  167,  168,
  168,  170,  170,  175,  173,  176,  173,  173,  173,  177,
   63,  179,   58,  182,  183,   58,   58,  178,  185,  178,
  180,  180,  186,  186,  187,  188,  187,  189,  184,  181,
  181,  181,  181,  181,  193,  190,  194,  191,  192,  192,
   64,   65,  196,  198,  199,   30,  195,  195,  195,  197,
  197,  197,  200,  200,  201,  202,  201,  201,  201,  203,
  204,  205,   31,  206,  206,   16,   16,   16,  207,  207,
  207,  211,  211,  209,  209,  209,  212,  212,  214,   71,
  132,  109,  109,  142,  142,  215,  215,  215,  213,  213,
  216,  216,  217,  217,  219,  219,   90,   80,   80,   94,
   94,  127,  127,  161,  161,  220,  220,  220,  220,  220,
  224,  224,  225,  223,  223,  223,  223,  223,  223,  223,
  226,  226,  226,  226,  226,  226,  226,  226,  226,  227,
  227,  227,  227,  227,  227,  227,  227,  227,  227,  227,
  227,  227,  227,  227,  227,  227,  227,  227,  227,  228,
  228,  228,  229,  229,  229,  249,  249,  250,  250,  251,
  251,  231,  231,  248,  248,  248,  248,  248,  248,  248,
  248,  248,  248,  248,  248,  233,  233,  233,  253,  253,
  254,  254,  255,  255,  257,  257,  257,  258,  258,  258,
  258,  258,  258,  258,  259,  259,  174,  174,  252,  252,
  252,  252,  252,  264,  264,  263,  263,  265,  265,  265,
  265,  266,  234,  234,  234,  234,  262,  262,  267,  267,
  268,  268,  235,  236,  236,  237,  238,  239,  239,  230,
  230,  230,  230,  230,  273,  269,  240,  240,  274,  274,
  275,  275,  276,  276,  276,  276,  277,  277,  277,  277,
  270,  270,  221,  221,  272,  272,  278,  278,  271,  271,
   89,   89,  279,  279,  241,  280,  280,  210,  208,  242,
  242,  243,  243,  244,  244,  245,  282,  246,  283,  246,
  281,  281,  285,  284,  232,  286,  286,  286,  286,  286,
  286,  286,  286,  286,  287,  287,  287,  287,  287,  287,
  287,  287,  287,  287,  287,  287,  287,  288,  288,  288,
  288,  288,  288,  288,  289,  289,  289,  289,  289,  289,
  289,  289,  289,  289,  289,  291,  291,  291,  291,  291,
  292,  292,  292,  292,  292,  292,  292,  292,  292,  293,
  293,  293,  293,  293,  294,  294,  294,  295,  295,  295,
  296,  296,  296,  297,  297,  297,  298,  298,  298,  299,
  299,  300,  300,  300,  300,  300,  301,  301,  301,  301,
  301,  301,  301,  301,  301,  301,  301,  302,  302,  303,
  303,  303,  303,  304,  304,  306,  305,  305,  305,   50,
   50,  308,  307,  309,  307,  310,  307,  311,  312,  307,
  313,  314,  307,   45,   45,  260,  260,  260,  260,  247,
  247,  247,   88,  316,   73,   73,  317,  318,  318,  318,
  318,  320,  318,  321,  322,  323,  324,   27,   70,   70,
   69,   69,  116,  116,  325,  325,  325,  325,  325,  325,
  325,  325,  325,  325,  325,  325,  325,  325,  325,   75,
   75,  319,  319,   76,   76,  326,  326,  327,  327,  328,
  328,  329,  329,  329,  329,  218,  218,  330,  330,  331,
  119,   68,   68,  332,  172,   66,   66,  333,  333,  334,
  334,  334,  334,  338,  338,  339,  339,  339,  336,  336,
  336,  336,  336,  336,  336,  336,  336,  336,  336,  336,
  336,  340,  340,  340,  340,  340,  340,  340,  340,  340,
  340,  340,  340,  340,  354,  354,  354,  354,  341,  355,
  337,  356,  356,  357,  357,  357,  357,  357,  357,  222,
  222,  358,   48,   48,  360,  335,  363,  335,  359,  359,
  359,  361,  361,  367,  367,  366,  366,  368,  368,  362,
  362,  364,  364,  369,  369,  370,  365,  365,  365,  342,
  342,  342,  353,  353,  371,  372,  372,  343,  343,  373,
  373,  373,  376,  374,  374,  375,  375,  377,  377,  377,
  378,  379,  379,  380,  380,  380,  344,  344,  344,  344,
  381,  381,  382,  382,  382,  386,  383,  389,  385,  385,
  392,  388,  388,  391,  391,  393,  393,  387,  387,  396,
  395,  395,  390,  390,  394,  394,  398,  397,  397,  384,
  384,  399,  384,  345,  345,  345,  345,  345,  345,  400,
  401,  401,  402,  402,  402,  403,  403,  403,  404,  404,
  404,  405,  405,  405,  406,  406,  346,  346,  346,  346,
  407,  407,  290,  290,  408,  410,  408,  408,  408,  409,
  409,  347,  348,  411,  351,  349,  349,  413,  414,  352,
  416,  417,  350,  350,  350,  415,  415,  412,  412,  315,
  315,  315,  315,  418,  418,  420,  420,  422,  421,  423,
  421,  419,  419,  419,  419,  419,  427,  425,  428,  430,
  425,  429,  429,  424,  424,  431,  431,  431,  431,  431,
  436,  432,  437,  433,  438,  439,  440,  434,  442,  443,
  444,  434,  441,  441,  446,  435,  445,  449,  445,  448,
  451,  448,  447,  447,  447,  450,  450,  450,  426,  452,
  426,    3,    3,  453,    3,    3,  454,  454,  261,  261,
  256,  256,    5,  455,  455,  455,  455,  455,  459,  455,
  455,  455,  455,  456,  456,  457,  460,  457,  458,  458,
  461,  461,  462,
  };
   static readonly short [] yyLen = {           2,
    2,    0,    3,    1,    2,    4,    3,    1,    0,    1,
    1,    2,    4,    2,    1,    2,    1,    3,    5,    2,
    0,    0,   11,    3,    0,    1,    1,    1,    3,    1,
    0,    1,    0,    1,    0,    1,    0,    1,    0,    1,
    1,    2,    1,    1,    2,    1,    1,    1,    1,    1,
    0,    1,    1,    2,    0,    3,    0,    6,    3,    2,
    1,    1,    1,    1,    1,    3,    0,    3,    1,    0,
    3,    0,    1,    1,    3,    3,    1,    1,    1,    0,
    4,    4,    0,    1,    1,    0,    1,    1,    2,    1,
    1,    1,    1,    1,    1,    1,    1,    1,    1,    1,
    1,    1,    1,    0,    4,    0,    0,    0,    0,    0,
   17,    5,    0,    9,    5,    0,    1,    1,    2,    3,
    0,    3,    1,    1,    1,    0,    8,    0,    9,    6,
    0,    0,    3,    0,    1,    1,    2,    2,    0,    5,
    0,    1,    1,    2,    3,    0,    4,    2,    1,    1,
    1,    0,    3,    0,    0,   10,    0,    0,    0,   12,
    8,    5,    1,    1,    1,    1,    0,    4,    0,    1,
    1,    3,    3,    3,    5,    3,    5,    1,    1,    1,
    1,    3,    4,    6,    2,    4,    0,    7,    0,    1,
    1,    2,    1,    1,    1,    4,    6,    4,    1,    2,
    2,    1,    0,    0,    0,    0,   12,    0,    6,    0,
    0,    4,    1,    1,    0,    0,   10,    3,    1,    1,
    2,    1,    2,    1,    0,    5,    0,    5,    1,    1,
    1,    0,    0,    0,    0,   15,    5,    0,    1,    1,
    2,    1,    1,    1,    1,    1,    1,    1,    1,    1,
    0,    5,    1,    1,    0,    7,    1,    1,    1,    1,
    1,    1,    1,    1,    1,    1,    1,    1,    1,    1,
    1,    1,    1,    1,    1,    1,    1,    1,    1,    0,
    7,    0,    7,    2,    2,    2,    0,    0,    9,    1,
    1,    0,    1,    0,    6,    0,    6,    2,    1,    0,
    8,    0,    9,    0,    0,   10,    5,    0,    0,    3,
    0,    1,    1,    2,    2,    0,    5,    0,    2,    2,
    2,    1,    1,    1,    0,    5,    0,    5,    1,    1,
    2,    4,    0,    0,    0,   12,    0,    2,    2,    0,
    1,    2,    1,    3,    2,    0,    5,    3,    1,    0,
    0,    0,   13,    0,    1,    1,    3,    3,    1,    4,
    4,    2,    2,    0,    3,    2,    1,    3,    0,    3,
    1,    1,    3,    1,    2,    3,    4,    4,    0,    3,
    1,    3,    3,    1,    1,    1,    1,    1,    1,    1,
    1,    1,    1,    1,    2,    2,    2,    2,    2,    2,
    1,    3,    1,    1,    1,    1,    1,    1,    1,    1,
    1,    1,    1,    1,    1,    1,    1,    1,    1,    1,
    1,    1,    1,    1,    1,    1,    1,    1,    1,    1,
    1,    1,    1,    1,    1,    1,    1,    1,    1,    1,
    2,    1,    1,    1,    1,    1,    1,    1,    1,    1,
    1,    3,    3,    4,    4,    5,    4,    4,    4,    3,
    3,    3,    4,    3,    4,    4,    4,    3,    0,    1,
    3,    4,    0,    1,    1,    3,    2,    3,    3,    1,
    2,    3,    5,    2,    1,    1,    0,    1,    1,    3,
    3,    3,    2,    1,    1,    1,    1,    2,    2,    4,
    3,    1,    4,    5,    4,    3,    1,    3,    1,    3,
    1,    1,    1,    4,    3,    2,    2,    6,    3,    7,
    4,    3,    7,    3,    0,    2,    4,    3,    1,    2,
    0,    1,    1,    3,    1,    2,    3,    1,    1,    1,
    0,    1,    1,    2,    2,    3,    1,    2,    0,    1,
    2,    4,    1,    3,    4,    1,    1,    1,    2,    4,
    4,    4,    2,    4,    2,    4,    0,    4,    0,    5,
    0,    1,    0,    4,    4,    1,    2,    2,    4,    2,
    2,    2,    4,    2,    1,    2,    2,    2,    2,    2,
    2,    2,    2,    2,    2,    2,    2,    1,    3,    3,
    3,    3,    3,    3,    1,    3,    3,    3,    4,    3,
    3,    3,    3,    3,    3,    1,    3,    3,    3,    3,
    1,    3,    3,    3,    3,    3,    3,    3,    3,    1,
    3,    3,    3,    3,    1,    3,    3,    1,    3,    3,
    1,    3,    3,    1,    3,    3,    1,    3,    3,    1,
    3,    1,    5,    4,    5,    5,    3,    3,    3,    3,
    3,    3,    3,    3,    3,    3,    3,    1,    3,    3,
    2,    1,    1,    0,    1,    0,    2,    1,    1,    1,
    1,    0,    4,    0,    4,    0,    5,    0,    0,    7,
    0,    0,    8,    1,    1,    1,    1,    1,    1,    6,
    4,    4,    1,    1,    0,    1,    3,    0,    1,    1,
    2,    0,    6,    0,    0,    0,    0,   15,    0,    1,
    0,    1,    1,    2,    1,    1,    1,    1,    1,    1,
    1,    1,    1,    1,    1,    1,    1,    1,    1,    0,
    1,    2,    3,    0,    1,    1,    2,    4,    3,    1,
    3,    1,    3,    1,    1,    0,    1,    1,    1,    0,
    4,    1,    1,    0,    4,    0,    1,    1,    2,    1,
    1,    1,    1,    1,    2,    1,    1,    1,    1,    1,
    1,    1,    1,    1,    1,    1,    1,    1,    1,    1,
    1,    1,    1,    1,    1,    1,    1,    1,    1,    1,
    1,    1,    1,    1,    1,    1,    1,    1,    1,    0,
    4,    1,    2,    2,    2,    2,    2,    2,    1,    1,
    2,    1,    1,    1,    0,    6,    0,    7,    0,    2,
    1,    0,    1,    0,    1,    1,    2,    2,    4,    0,
    2,    0,    1,    1,    2,    4,    1,    5,    2,    2,
    2,    2,    2,    2,    1,    1,    1,    1,    1,    5,
    7,    4,    0,    8,    4,    0,    1,    1,    2,    1,
    2,    1,    2,    3,    3,    1,    1,    1,    1,    1,
    5,    4,    7,    3,    6,    0,    4,    0,    5,    1,
    0,    4,    2,    2,    2,    1,    1,    0,    1,    0,
    5,    1,    0,    1,    0,    1,    1,    1,    3,    4,
    5,    0,    9,    1,    1,    1,    1,    1,    1,    2,
    2,    2,    3,    4,    3,    3,    3,    2,    3,    3,
    2,    4,    4,    3,    0,    1,    3,    4,    5,    3,
    1,    2,    0,    1,    3,    0,    8,    3,    6,    0,
    4,    2,    2,    0,    3,    5,    4,    0,    0,   10,
    0,    0,    9,    5,    4,    2,    1,    0,    2,    2,
    2,    2,    2,    4,    5,    4,    5,    0,    5,    0,
    6,    3,    2,    2,    2,    1,    0,    3,    0,    0,
    5,    2,    1,    1,    2,    1,    1,    1,    1,    1,
    0,    5,    0,    3,    0,    0,    0,   12,    0,    0,
    0,   13,    0,    2,    0,    3,    1,    0,    4,    1,
    0,    4,    1,    2,    2,    1,    2,    2,    0,    0,
    4,    2,    3,    0,    4,    2,    2,    3,    0,    1,
    1,    1,    2,    2,    2,    2,    4,    3,    0,    7,
    4,    4,    3,    1,    3,    0,    0,    4,    0,    1,
    1,    3,    2,
  };
   static readonly short [] yyDefRed = {            0,
    8,    0,    0,    0,    0,    0,    0,    0,    2,    4,
    0,    0,   11,   14,    0, 1032,    0,    0, 1036,    0,
    0,   15,   17,  406,  412,  419,  407,  409,    0,  408,
    0,  415,  417,  404,    0,  411,  413,  405,  416,  418,
  414,    0,  369, 1054,    0,  410, 1043,    0,   10,    1,
    0,    0,    0,   12,    0,  857,    0,    0,    0,    0,
    0,    0,    0,    0,  447,    0,    0,    0,    0,    0,
    0,    0,  445,    0,    0,    0,  513,    0,  446,    0,
    0,    0,  954,    0,    0,    0,  699,    0,    0,    0,
    0,    0,    0,    0,  760,    0,  809,    0,    0,    0,
    0,    0,    0,    0,    0,  444,    0,  688,    0,  856,
    0,  792,    0,  440,    0,    0,    0,  421,  422,  423,
  424,  425,  426,  427,  428,  429,  430,  431,  432,  433,
  434,  435,  436,  437,  438,  439,  442,  443,  695,  585,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,  696,  694,  697,  698,  776,  778,    0,  774,
  777,  793,  795,  796,  797,  798,  799,  800,  801,  802,
  803,  804,  794,    0,    0,    0,  858,  859,  877,  878,
  879,  880,  914,  915,  916,  917,  918,  919,    0,    0,
    0,   20,    0,    0,  356,    0,  359, 1040,   16, 1033,
    0,    0,  263,  262,  259,  264,  265,  258,  277,  276,
  269,  270,  266,  268,  267,  271,  260,  261,  272,  273,
  279,  278,  274,  275,    0, 1057, 1046,    0,    0, 1045,
    0, 1044,    3,   55,    0,    0,    0,   44,   41,   43,
   46,   47,   48,   49,   50,   53,   13,    0,    0,    0,
  920,  563,  448,  449,  952,    0,    0,    0,    0,    0,
    0,    0,    0,  922,  921,    0,  573,  567,  572,  808,
  855,  779,  806,  805,  807,  780,  781,  782,  783,  784,
  785,  786,  787,  788,  789,  790,  791,    0,    0,    0,
  886,    0,    0,    0,  824,  823,    0,    0,    0,    0,
    0,    0,    0,    0,  928,    0,    0,    0,    0,  420,
    0,    0,    0,  931,    0,    0,    0,    0,  565,  953,
    0,    0,    0,  822,  818,    0,    0,    0,    0,    0,
    0,    0,  388,    0,    0,    0,    0,    0,    0,    0,
    0,  691,    0,  584,    0,    0,  684,    0,    0,  580,
    0,    0,  582,  578,  592,  586,  593,  587,  581,  577,
  597,  591,  596,  590,  594,  588,  595,  589,  682,  559,
    0,  558,  441,  362,  363,    0,    0,    0,    0,    0,
  810,    0,  355,    0,  816,  817,    0,    0,  516,  517,
    0,    0,    0,  814,  815,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0, 1035,  775,
  825,  813,    0,  853,  854,  986, 1003,    0,    0,  987,
  989,    0, 1015,  972,  970,  996,    0,    0,  994,  997,
  998,  999, 1000,  973,  971,    0,    0,    0,    0,   18,
    0,    0,    0, 1053,    0,    0,  370,    0,    0, 1055,
    0,    0,   42,  730,  736,  728,    0,  725,  735,  729,
  727,  726,  733,  731,  732,  738,  734,  737,  739,    0,
    0,  723,   45,   54,  515,    0,  511,  512,    0,    0,
  509,    0,  827,    0,    0,    0,  884,    0,  852,  850,
  851,    0,    0,    0,  703,    0,  925,  923,  704,    0,
    0,  540,    0,    0,  528,  535,    0,    0,    0,  529,
    0,    0,  545,  547,    0,  524,    0,    0,    0,    0,
    0,  519,    0,  522,    0,  526,  390,  927,  926,    0,
    0,  930,  929,  940,    0,    0,    0,  941,  557,    0,
  385,  556,    0,    0,  955,    0,    0,  821,    0,  400,
  396,  397,    0,    0,  395,  398,  399,    0,    0,    0,
  598,    0,    0,  569,    0,  686,  615,  614,    0,    0,
  773,    0,    0,  768,  770,  771,  772,  452,  453,    0,
  366,  367,    0,  194,  193,  195,    0,  673,    0,    0,
    0,  392,    0,  668,    0,    0,  934,    0,    0,    0,
  460,  461,    0,  464,    0,    0,    0,    0,  462,    0,
    0,  506,    0,  468,    0,    0,    0,    0,  494,  497,
    0,    0,  489,  496,  495,  657,  658,  659,  660,  661,
  662,  663,  664,  665,  667,  666,  602,  599,  604,  601,
  603,  600,  612,  608,  613,    0,  610,    0,  611,    0,
  619,    0,    0,  620,    0,  626,    0,  627,    0,  628,
    0,  629,    0,  633,    0,  634,    0,  637,    0,  640,
    0,  643,    0,  646,    0,  649,    0,  651,    0,    0,
  544,    0,    0,    0,    0,    0,    0,    0,    0,    0,
  985,  984,    0,  995,    0,  983,    0,    0,  357,  358,
 1051, 1052,    0,    0,  191,    0,    0, 1061,  384,    0,
    0,    0,  381, 1047, 1049,   61,   63,   64,    0,    0,
   56,    0,    0,   65,   67,   30,   28,    0,    0,    0,
  720,    0,  724,  458,    0,  514,    0,  562,    0,  575,
  180,  202,    0,    0,    0,  170,    0,    0,    0,  181,
  568,    0,  958,  890,    0,  908,  887,    0,  899,    0,
  910,    0,  924,  862,    0,  957,    0,    0,  527,    0,
  536,  546,  548,    0,    0,    0,    0,  480,    0,    0,
  475,    0,    0,  681,  680,  507,    0,  550,  521,    0,
    0,  151,  551,  149,  150,  553,    0,  561,  560,  865,
    0,    0,    0,    0,  938,    0,  942,  555,  564,  965,
    0,  961,  882,    0,  976,    0,  974,    0,    0,  701,
  702,    0,    0,    0,  679,  678,  685,    0,  459,  762,
  763,  761,  769,  683,    0,  365,  671,    0,    0,    0,
  583,  579,  933,  932,  811,  465,  457,    0,    0,  463,
  454,  455,  566,  505,  503,  502,  499,  498,    0,  493,
  450,  451,  466,  467,    0,  944,  609,  654,    0,  831,
    0,    0, 1004,  978,    0, 1005,    0,  988,  990, 1001,
    0, 1016,    0,  982, 1030,   19,  360,  361, 1063,  192,
 1058,    0,  759,  758,    0,  757,    0,  380,    0,   60,
   57,    0,    0,    0,    0,    0,    0,  387,    0,  714,
    0,    0,   85,   84,    0,  510,    0,    0,    0,    0,
    0,  185,  574,    0,    0,    0,    0,    0,  900,  888,
    0,  911,    0,    0,  956,  537,  534,    0,  484,    0,
    0,    0, 1041, 1042,  471,  477,    0,  481,    0,    0,
    0,    0,    0,    0,  863,    0,  948,    0,  945,  939,
  964,    0,  881,  977,  975,    0,  570,    0,  687,  677,
  368,  670,  669,  689,  456,  504,  501,    0,  492,  491,
  490,  655,  656,  653,    0,  847,  830,    0,    0,    0,
  836,    0,  980,    0, 1009,    0,    0, 1024, 1025, 1018,
    0, 1062,  383,  382,    0,    0,   66,   59,    0,   68,
   29,   22,    0,    0,  333,    0,  237,    0,  112,    0,
   82,  841,  124,  125,    0,    0,    0,  844,  200,  201,
    0,    0,    0,    0,  173,  182,  174,  176,  885,    0,
    0,    0,    0,    0,  909,    0,    0,  485,  486,  479,
  482,  478,    0,  472,  476,    0,  542,    0,  508,  518,
  470,  554,  552,    0,    0,    0,  967,    0,    0,  700,
  692,    0,  500,    0,    0,  826,  837,  979,    0,    0,
    0,  993,    0,  991, 1002,    0, 1031, 1050,    0,   79,
    0,    0,   73,   74,   77,   78,    0,  350,  339,  338,
    0,  715,  233,  107,    0,  828,  845,  186,    0,  198,
    0,    0,    0,  883,  969,    0,    0,    0,  904,    0,
    0,  912,  861,    0,  523,  520,  870,    0,  876,    0,
    0,  868,    0,  872,  951,    0,  966,  962,    0,  690,
    0,    0,  981, 1006,    0,  992,    0,    0, 1020,    0,
   80,   71,    0,    0,    0,  334,    0,    0,    0,    0,
    0,  187,    0,  177,  175,  959,  901,  889,  897,  896,
  891,  893,    0,  483,    0,  864,  869,    0,  873,  949,
    0,    0,  693,    0,  839,    0, 1010, 1027, 1028, 1021,
   58,    0,   75,   76,    0,    0,    0,    0,    0,    0,
    0,  709,    0,  741,    0,  706,  846,  184,    0,  197,
    0,    0,  913,  875,  874,    0,  963,  848,    0,    0,
    0,   81,    0,    0,  351,    0,    0,  349,  335,    0,
  343,    0,  403,    0,  401,    0,    0,  716,    0,  746,
  234,    0,  188,  960,  892,    0,    0,  906,  764,  947,
 1007,    0, 1022,    0,    0,    0,  331,    0,    0,  707,
  743,    0,  712,    0,    0,  747,    0,  108,  895,  894,
    0,    0, 1011,   27,   26,   23,  352,  348,    0,    0,
  344,  402,    0,  749,    0,    0,    0,    0,    0,    0,
    0,    0,    0,   32,  336,    0,  754,    0,  755,  752,
    0,  750,  103,  104,    0,  100,    0,    0,   88,   90,
   91,   92,   93,   94,   95,   96,   97,   98,   99,  101,
  102,  152,    0,    0,  250,  242,  243,  244,  245,  246,
  247,  248,  249,    0,    0,  240,  109,  765,    0, 1008,
    0,  353,  347,  713,    0,    0,    0,    0,  717,   89,
    0,  291,  286,  290,    0,  235,  241,    0, 1014, 1012,
  753,  751,    0,    0,    0,    0,    0,    0,    0,    0,
  300,    0,    0,  251,    0,    0,  257,    0,  167,  166,
  153,  163,  164,  165,    0,    0,    0,  105,    0,    0,
  285,    0,    0,  284,    0,  157,    0,    0,  374,  332,
    0,  372,    0,    0,    0,    0,    0,    0,    0,    0,
  718,    0,  236,  110,  115,  113,  307,    0,  371,    0,
    0,    0,    0,  128,    0,    0,    0,    0,    0,    0,
  162,  154,    0,    0,    0,  215,    0,  375,    0,  252,
    0,    0,    0,    0,  304,    0,  282,  130,    0,  280,
    0,    0,    0,  132,    0,  376,    0,    0,  204,  209,
    0,    0,    0,  373,  255,  168,  111,  123,  121,    0,
    0,  309,    0,    0,    0,    0,    0,  158,    0,  288,
    0,    0,    0,    0,  136,    0,    0,    0,    0,  377,
  378,    0,    0,    0,    0,    0,  118,  324,    0,  305,
    0,    0,  318,    0,    0,    0,  313,    0,  148,    0,
    0,    0,    0,  143,    0,    0,  301,    0,  133,    0,
  127,  137,  155,  161,  224,    0,  205,    0,    0,  216,
    0,  122,    0,  114,  119,    0,    0,    0,  320,    0,
  321,  310,    0,    0,  303,  314,  283,    0,    0,  129,
  144,  281,    0,  299,    0,  289,  293,  139,    0,    0,
    0,  221,  223,    0,  256,  120,  325,  327,  306,    0,
    0,  319,  316,  147,  145,  159,  298,    0,    0,    0,
  156,  225,  227,  206,    0,  219,  217,    0,    0,  318,
    0,  294,  296,  140,    0,    0,    0,    0,  329,  330,
  326,  328,  317,  160,    0,    0,  231,  230,  229,  226,
  228,  211,  207,  218,    0,    0,    0,  295,  297,  213,
  214,    0,  212,
  };
  protected static readonly short [] yyDgoto  = {             7,
    8,   50,    9,   51,   10,   11,   52,  235,  763,  764,
   12,   13,   53,   22,   23,  330,  238,  748,  926, 1117,
 1244, 1296, 1619,  923,  239,  240,  241,  242,  243,  244,
  245,  246,  741,  471,  742,  743, 1026,  744,  745, 1030,
  924, 1112, 1113, 1114,  271,  640, 1212,  111,  935,  806,
 1327, 1328, 1329, 1330, 1331, 1332, 1333, 1334, 1335, 1336,
 1337, 1338, 1339, 1340, 1341,  592, 1367,  852,  490,  752,
 1422, 1040, 1225, 1179, 1223, 1258, 1308, 1378, 1463, 1253,
 1490, 1464, 1515, 1516, 1517, 1042, 1513, 1043,  815,  927,
 1475, 1449, 1503,  546, 1496, 1469, 1532, 1006, 1501, 1504,
 1505, 1600, 1533, 1534, 1530, 1342, 1401, 1371, 1423,  765,
 1477, 1579, 1446, 1536, 1611,  491, 1402, 1403,  272, 1432,
  766,  767,  768,  769,  770,  723,  610, 1229,  724,  725,
  941, 1425, 1454, 1547, 1508, 1581, 1633, 1617, 1455, 1642,
 1637, 1426, 1481, 1607, 1584, 1548, 1549, 1630, 1615, 1616,
 1038, 1178, 1287, 1354, 1406, 1355, 1356, 1394, 1429, 1395,
  333,  225, 1512, 1397, 1497, 1494, 1343, 1373, 1418, 1576,
 1538, 1270, 1577,  641, 1625, 1626, 1417, 1493, 1466, 1525,
 1520, 1491, 1557, 1562, 1523, 1526, 1527, 1610, 1563, 1521,
 1522, 1621, 1608, 1609, 1035, 1121, 1249, 1217, 1278, 1250,
 1251, 1299, 1175, 1275, 1312,  385,  195,  113,  374,  375,
  114,  603,  467,  228, 1441,  732,  733,  915,  928,  334,
  432,  570,  309, 1254, 1255,   46,  116,  310,  118,  119,
  120,  121,  122,  123,  124,  125,  126,  127,  128,  129,
  130,  131,  132,  133,  134,  135,  136,  137,  138,  256,
  883,  811, 1080, 1069,  799,  965,  800,  801, 1070,  139,
  200,  807,  643,  644,  645,  877,  500,  501,  302, 1078,
  809,  433,  304,  529,  530,  531,  532,  535,  817,  563,
  268,  506,  842,  269,  505,  140,  141,  142,  143,  887,
  144,  145,  146,  147,  148,  149,  150,  151,  152,  153,
  154,  613,  614,  615,  847,  848,  155,  600,  589,  844,
  376, 1092,  585, 1159,  156,  520, 1220, 1221, 1224, 1303,
 1036, 1177, 1285, 1398,  492, 1259, 1260, 1321, 1322,  916,
  351, 1291,  593,  594,  273,  274,  275,  159,  160,  161,
  276,  277,  278,  279,  280,  281,  282,  283,  284,  285,
  286,  287,  173,  288,  620,  174,  175,  326,  892,  700,
 1009,  938,  759, 1046, 1007, 1010, 1137, 1011, 1047, 1048,
  289,  176,  177,  178, 1150, 1084, 1151, 1152, 1153, 1154,
  179,  180,  181,  182,  777,  513,  778, 1140, 1064, 1141,
 1265, 1232, 1192, 1266,  779, 1063,  780, 1268, 1193,  183,
  184,  185,  186,  187,  188,  311,  557,  558,  824, 1201,
  322, 1062,  948, 1231, 1089,  982, 1202,  189,  445,  190,
  446, 1012, 1099,  447,  448,  716,  707,  708, 1104, 1016,
  449,  450,  451,  452,  453, 1017,  702, 1014, 1206, 1292,
 1360, 1101, 1240, 1311,  902,  710,  903, 1168, 1106, 1169,
 1241, 1021,   17,   19,   47,   48,  227,  726,  919,  465,
  727,  728,
  };
  protected static readonly short [] yySindex = {            2,
    0, -153,  115,    1,  165,17631,    0,  277,    0,    0,
  165,    1,    0,    0,  158,    0, 7547,  165,    0, -147,
   -8,    0,    0,    0,    0,    0,    0,    0,  255,    0,
  366,    0,    0,    0, 2676,    0,    0,    0,    0,    0,
    0,  304,    0,    0,  682,    0,    0,  701,    0,    0,
  277,  383,  165,    0,  412,    0, -263,  427,   30,17077,
 -118,  375,  391, 7705,    0,  375,  375,  375,   50,  375,
  375,  781,    0, 9854,  375,  375,    0,10012,    0,  446,
  375,  111,    0,  375,  462,  375,    0,17714,17714,  492,
  375,  375,   71,10172,    0,16311,    0,11202,11334,11466,
11598,11730,11862,11994,12126,    0,  345,    0, 8789,    0,
  267,    0,  133,    0,  553, 1200,  -41,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
 1758,  854,  242,  587,  680,  668,  562,  521,  639,  613,
  493,  658,    0,    0,    0,    0,    0,    0, 3719,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,  133,  706, -276,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,  625,  761,
  383,    0,  540, -245,    0,  672,    0,    0,    0,    0,
 8789, 8789,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,  304,    0,    0,  693,  710,    0,
 -282,    0,    0,    0,  383,14930,  733,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,  892,  133,16448,
    0,    0,    0,    0,    0,16311, -128, -101,  884,  799,
  598, 1200,  133,    0,    0, 8789,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0, -154,  282,17077,
    0, 8789,16311,  777,    0,    0,  838,16311,16311, 5845,
  766,  181,  808, 8947,    0,10172,  345,  965,  859,    0,
  851, 8789,16311,    0,  997,  890,  643, 4131,    0,    0,
16311,  446,15900,    0,    0,  462,16311,  462,  594,  578,
  982,  133,    0,  706,  -41, 1001,  133,16311,16311,16311,
  391,    0,  918,    0, 8789, 8789,    0,11070,  133,    0,
 7863,   52,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
 4291,    0,    0,    0,    0,17481,  594,  914,  915,16311,
    0, -296,    0,  209,    0,    0,  291,  210,    0,    0,
  882,10304, 8179,    0,    0,16311,16311,16311,16311,16311,
16311,16311,16311,16311,16311,16311,12258,12390,12522, 4449,
 4611,12654,12786,12918,13050,13182,13314,13446,13578,13710,
13842,13974,14106,14238,14370,14502,16859,16311,    0,    0,
    0,    0,  706,    0,    0,    0,    0,17714,17714,    0,
    0,  133,    0,    0,    0,    0,  825,  948,    0,    0,
    0,    0,    0,    0,    0,  383,  733,  888,  895,    0,
 -296,  304,  304,    0,  737,  201,    0,  304,  928,    0,
 -204,14930,    0,    0,    0,    0, -141,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,  318,
18291,    0,    0,    0,    0,  902,    0,    0,  944,  771,
    0,  954,    0,  957,  187,  446,    0,  375,    0,    0,
    0,  133, 9088, -139,    0,  956,    0,    0,    0, -173,
  137,    0,  799,  598,    0,    0,  962,    0,  979,    0,
  989,  929,    0,    0,  811,    0, 8453,  812,10462,  808,
15763,    0, 8614,    0,  462,    0,    0,    0,    0,  147,
  164,    0,    0,    0, -241,  446, -156,    0,    0,  462,
    0,    0, 1003, 1019,    0,  168,  133,    0,  170,    0,
    0,    0,16311, 1076,    0,    0,    0,16311, 1101, 1033,
    0, 1043, 1044,    0,17481,    0,    0,    0,  149,  902,
    0,  197, 7863,    0,    0,    0,    0,    0,    0,  149,
    0,    0,  265,    0,    0,    0,  462,    0,  594,  133,
 9105,    0, 1050,    0, 1049,14634,    0, 1174, 1054, 7863,
    0,    0, 1004,    0,  902,  133,16448, 1010,    0, -296,
  902,    0,  114,    0,16311,16311, 1060, 1189,    0,    0,
  135,   69,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,  133,    0,  854,    0,  854,
    0,10938,  242,    0,  242,    0,  587,    0,  587,    0,
  587,    0,  587,    0,  680,    0,  680,    0,  668,    0,
  562,    0,  521,    0,  639,    0,  613,    0, -200, -207,
    0,10462, 1152,  133, 1153,  133,10462,10462, 1066,16311,
    0,    0,  948,    0,  133,    0,  656, -296,    0,    0,
    0,    0, 9105,  737,    0, 1078, 1074,    0,    0, -172,
  383,  472,    0,    0,    0,    0,    0,    0, -169, 1080,
    0, 1081, 1085,    0,    0,    0,    0, 1082, 9713, 1045,
    0,  431,    0,    0,  698,    0,16448,    0, 1083,    0,
    0,    0,  732,  243, 1089,    0, 1091, 1092, 1093,    0,
    0,16311,    0,    0,  133,    0,    0, 1096,    0, 1094,
    0,  514,    0,    0, 7705,    0, 7705, 9246,    0,14863,
    0,    0,    0, 9406, 9538,  302,10462,    0,  206,  102,
    0, 1040, 1052,    0,    0,    0,  819,    0,    0, 1105,
 1106,    0,    0,    0,    0,    0, 1107,    0,    0,    0,
 1112,  375, 4771,  446,    0,  446,    0,    0,    0,    0,
 7705,    0,    0, 7705,    0,16311,    0,16311, 8789,    0,
    0,  446, 1110,  149,    0,    0,    0,16311,    0,    0,
    0,    0,    0,    0, 8789,    0,    0,  133,17481, 1142,
    0,    0,    0,    0,    0,    0,    0,  902,  829,    0,
    0,    0,    0,    0,    0,    0,    0,    0,15626,    0,
    0,    0,    0,    0, 8772,    0,    0,    0, 9696,    0,
 8930, 1113,    0,    0, 1195,    0, 1197,    0,    0,    0,
  780,    0, 1118,    0,    0,    0,    0,    0,    0,    0,
    0,  737,    0,    0, 1073,    0,  201,    0,  737,    0,
    0,  888, 1123, 1125, 1084, 1127, 1045,    0, 1128,    0,
 1249, 1250,    0,    0,10462,    0,16037, 1132,  732, 9105,
 8789,    0,    0,  513, 1252, 1253,  185, 1129,    0,    0,
16311,    0,16311, 1232,    0,    0,    0,16174,    0,  510,
16174,  831,    0,    0,    0,    0, 8316,    0, 1266,  706,
10462, 1155, 9246, 1157,    0,16311,    0,  133,    0,    0,
    0, -198,    0,    0,    0, 1151,    0, 1184,    0,    0,
    0,    0,    0,    0,    0,    0,    0,  879,    0,    0,
    0,    0,    0,    0, 8947,    0,    0,  133, 1154, 1113,
    0,10462,    0,10462,    0,  154,10462,    0,    0,    0,
  386,    0,    0,    0, 1162,  888,    0,    0,10620,    0,
    0,    0, 1156, 4931,    0, 1045,    0, 1045,    0, 1045,
    0,    0,    0,    0,  133, 1163, 1132,    0,    0,    0,
  -78, -132, 1159, 1166,    0,    0,    0,    0,    0, 1165,
 9246, 1113, -207,16311,    0, 1170, 7705,    0,    0,    0,
    0,    0, 1167,    0,    0, 1173,    0,  808,    0,    0,
    0,    0,    0, -201, 1175, 1177,    0, 1113, 1178,    0,
    0,  149,    0, 1130, 1179,    0,    0,    0,10462, 1205,
10462,    0,10462,    0,    0,16311,    0,    0, 1085,    0,
  327,  889,    0,    0,    0,    0,    1,    0,    0,    0,
 1188,    0,    0,    0, 1181,    0,    0,    0, -249,    0,
 1183, 1291, 1301,    0,    0, 1113, 1187, 1113,    0, 7705,
  692,    0,    0,16174,    0,    0,    0,16311,    0, 1190,
 -176,    0, 7387,    0,    0, 1310,    0,    0,  149,    0,
16311, 8930,    0,    0, 1220,    0,  853, 1193,    0, 1204,
    0,    0,10620,  165,  187,    0,  627, 1201, 1199,16037,
 1207,    0,16311,    0,    0,    0,    0,    0,    0,    0,
    0,    0, 7705,    0, -174,    0,    0, 7863,    0,    0,
 1284, 7705,    0, 1208,    0,10462,    0,    0,    0,    0,
    0,16311,    0,    0,  383, 1209,  383,  187, 8789, 1201,
 1241,    0, 1241,    0, 1201,    0,    0,    0,16311,    0,
 7705,16311,    0,    0,    0, 1213,    0,    0, 1236,10462,
16311,    0,  383, 1216,    0, 1168,  877,    0,    0, 1211,
    0, 1217,    0,  136,    0, 1219, 1176,    0, 1241,    0,
    0, 1241,    0,    0,    0,  836, 1094,    0,    0,    0,
    0, 1244,    0,   55, 1241, 1333,    0, 1227,  383,    0,
    0, 8789,    0, -107, 1229,    0, 1230,    0,    0,    0,
 7863,10462,    0,    0,    0,    0,    0,    0, 1221, 1224,
    0,    0,15763,    0,17676,  208,  383, 1234, 1235, 1255,
10462, 1228,16311,    0,    0, 1239,    0, 1242,    0,    0,
 1240,    0,    0,    0,18291,    0, 1248,  208,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,  476,18291,    0,    0,    0,    0,    0,    0,
    0,    0,    0, 1254,  383,    0,    0,    0,  133,    0,
 1255,    0,    0,    0, 1246,17676, 7863,17281,    0,    0,
  581,    0,    0,    0,17349,    0,    0,  208,    0,    0,
    0,    0,  197, 8789, 8789, -162, 8947,  506,  462, 1285,
    0,  594, 3808,    0, 1320,    0,    0, 1224,    0,    0,
    0,    0,    0,    0, 2893, 1224, 1258,    0, -131, -129,
    0, 8789, -120,    0, 8789,    0, 1210, 1256,    0,    0,
 -280,    0,   98, 5088,    0, 1260, 1215,  182,  581, 2676,
    0,16311,    0,    0,    0,    0,    0, -280,    0, 1269,
 1222, 1267, 1261,    0, 1268, 1225, 1271,  187, 1263, 1272,
    0,    0, 1275, 1281, 1307,    0,  902,    0,  868,    0,
 1279, 1280, 1224, -181,    0, 1270,    0,    0, 1286,    0,
 1287, 1299, 1300,    0, 1302,    0,  187,  187,    0,    0,
  187, 1304, 1305,    0,    0,    0,    0,    0,    0, 1306,
  246,    0, 1309,  187, 1418, 1311,  187,    0,  602,    0,
 9246, 1273, 1298, 1302,    0, 1321, 1322,  253, 1325,    0,
    0,  187,16037, 1283, 1323, 1306,    0,    0,18291,    0,
  383,  383,    0, 1288, 1326, 1309,    0, 1331,    0,16311,
 1289, 1328, 1311,    0, 1337,  187,    0,  -93,    0, 1316,
    0,    0,    0,    0,    0,18291,    0,  253,  253,    0,
 1338,    0, -181,    0,    0,  252, 1313,18291,    0,18291,
    0,    0, 9246, 1324,    0,    0,    0, 1341, 1286,    0,
    0,    0, 1340,    0, -166,    0,    0,    0, 1241,  958,
 1346,    0,    0,  155,    0,    0,    0,    0,    0, 1401,
 1454,    0,    0,    0,    0,    0,    0, 1348, 1349, 9246,
    0,    0,    0,    0,  253,    0,    0,  616,  616,    0,
 1241,    0,    0,    0,   95,   95, 1336, 1354,    0,    0,
    0,    0,    0,    0,15763,15763,    0,    0,    0,    0,
    0,    0,    0,    0, 1352, 1356,16037,    0,    0,    0,
    0, 1350,    0,
  };
  protected static readonly short [] yyRindex = {         3152,
    0,    0, 8021, 3152,    0,    0,    0, 1730,    0,    0,
 3342, 1117,    0,    0,    0,    0,    0, 3342,    0,    0,
   41,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0, 1732,    0,    0, 1732,    0,    0, 1732,    0,    0,
 1730, 3425, 3219,    0,    0,    0,    0,    0,    0,    0,
    0,    0, 1363,    0,    0,    0,    0,    0,    0,    0,
    0, 9871,    0, 1357,    0,    0,    0, 1357,    0,    0,
    0,    0,    0,    0,  358,    0,    0,    0,    0,    0,
    0,    0,    0,  298,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0, 5090,    0,    0,    0,
    0,    0,    0,    0,  403, 5184, 5254,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
 5343, 5415, 3898, 6001, 6426, 6633, 6771, 6909, 7047, 7185,
 -182, 1314,    0,    0,    0,    0,    0,    0,   41,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,  281,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
 3468,    0,  674,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0, 1732,    0,    0,   99,    0,    0,
    0,    0,    0,    0, 3511,  406, 3554,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
 4130,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0, 1364,
    0,    0,    0,    0,    0,    0, 4130, 1358,    0,    0,
    0,    0,    0,    0, 1358,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0, 2343,    0, 2894,  237, 2474,
    0,    0,    0, 2621, 2474,    0,    0,    0,    0,    0,
 1363,    0,    0,    0,    0,    0,    0,    0,    0,    0,
  217,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0, 1365, 2746,    0,    0, 1357,
    0, 4130,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,  216,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0, 1876,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0, 1443,    0,    0,
    0,    0,    0,    0,    0, 3597, 3640,    0,    0,    0,
 1588, 1732, 1732,    0, 8196,   84,    0, 1732, 1736,    0,
    0,  273,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,  487,
17009,    0,    0,    0,    0, 4130,    0,    0,    0,    0,
    0,    0,    0,    0,17381,    0,    0,    0,    0,    0,
    0,    0, 1362,    0,    0,    0,    0,    0,    0,    0,
    0,    0,  376,  876,    0,    0,  251,  947,    0,    0,
 1372,  666,    0,    0,    0,    0,  234,    0,    0, 4610,
 1370,    0,    0,    0,  280,    0,    0,    0,    0,    0,
    0,    0,    0,    0, 1378,    0, 2045,    0,    0,  360,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0, 1365,    0,    0,    0,16585, 4130,
    0,    0,  256,    0,    0,    0,    0,    0,    0,16585,
    0,    0,    0,    0,    0,    0,  -42,    0,  418,    0,
    0,    0, 1380,    0,    0,    0,    0, 1358,    0,    0,
    0,    0, 3970,    0, 4130,    0,    0, 3809,    0, 4130,
 4770,    0,    0,    0,    0,    0, -163,    0,    0,    0,
    0,  268,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0, 5520,    0, 5592,    0, 5697,
    0,    0, 5847,    0, 5932,    0, 6070,    0, 6139,    0,
 6208,    0, 6277,    0, 6495,    0, 6564,    0, 6702,    0,
 6840,    0, 6978,    0, 7116,    0, 7254,    0,    0,  891,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0, 1443,    0,    0,    0,    0, 1588,    0,    0,
    0,    0,    0,10479,    0,    0,  900,    0,    0, 1339,
15066,    0,    0,    0,    0,    0,    0,    0,  747,  721,
    0,    0, 1384,    0,    0,    0,    0, 1774,    0,    0,
    0,    0,    0,    0,10778,    0,    0,    0,  897,    0,
    0,    0,10637,17554,    0,    0,  917,  920,  942,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0, 1379,
    0,    0,    0,    0,    0,    0,    0,    0,    0, 1390,
    0,    0,    0,    0,    0, 6339,    0,    0,    0,  262,
    0,   79, 4290,    0,    0,    0,    0,    0,    0,    0,
 1387,    0,    0,    0,    0,    0, 1393,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,16585,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0, 4130,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0, 1386,    0,    0,    0,    0,    0,    0,    0,    0,
 -133,    0,  993,    0,    0,    0,    0,    0,    0,    0,
    0,10637,    0,    0,    0,    0,   84,    0, 8631,    0,
    0, 1395,    0,  839,    0,    0,    0,    0, 1399,    0,
 1351, 1353,    0,    0,    0,    0,    0, 1391,14704,    0,
    0,    0,    0,17586,    0,    0,    0,  963,    0,    0,
    0,    0,    0, 2213,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0, 4450,
    0, 4930, 1402,    0,    0,    0,    0, 1089,    0,    0,
    0,  963,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0, 1398,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,  974,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0, 1403,    0,    0,    0,
    0,    0,  984,  985,    0,    0,    0,    0,    0,    0,
    0, 1406,  891,  739,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0, 4610,    0,    0,
    0,    0,    0, 1412,    0,    0,    0, 1406,    0,    0,
    0,16585,    0,  753,  763,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0, 1384,    0,
14911,    0,    0,    0,    0,    0,17777,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,  784,    0,
  828,    0,    0,    0,    0, 1410,    0, 1386,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
 1415,    0,    0,    0,    0, -212,    0,    0,16585,    0,
    0,    0,    0,    0,    0,    0,  538, 1047,    0,    0,
    0,    0,    0,17820,17381,    0,  558,  563,  340,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0, -187,    0,    0,
 1378,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,17964,    0,   -7,17381,    0,  589,
 1417,    0, 1417,    0,  563,    0,    0,    0,    0,    0,
    0,  861,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,18007,    0,    0,    0,15340,    0,    0, 1419,
    0,    0,    0,  491,    0,  624,    0,    0,  630,    0,
    0, 1417,    0,    0,    0,    0,  862,    0,    0,    0,
    0,    0,    0, 3299, 1422,  473,    0,    0,  261,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
 1432,    0,    0,    0,    0,    0,    0,    0,    0, 3053,
    0,    0, 1370,    0,    0,15172,15424,    0,    0, 1186,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
  633,    0,    0,    0,17181,    0,    0,15256,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,17249,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,15508,    0,    0,    0,    0,    0,
 1186,    0,    0,    0,    0,    0,  217,  487,    0,    0,
    0,    0,    0,    0,  487,    0,    0,15172,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0, 1440,  528,
    0,15550,    0,    0,    0, 1731,    0, 3053,    0,    0,
    0,    0,    0,    0,    0, 3053,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
  571,    0,  225,    0,  401,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,  526,    0,  548,
    0,    0,    0,    0,    0,    0,    0,17381,  992,    0,
    0,    0,    0,    0,    0,    0, 1429,    0,  845,    0,
    0,    0, 3053,    0,    0,  998,    0,    0,    0,    0,
    0,    0,    0,    0, 1427,    0,17381,17381,    0,    0,
17449,    0,    0,    0,    0,    0,    0,    0,    0, 1428,
18261,    0, 1430,17381,16722, 1431,17381,    0,    0,    0,
    0,    0,    0, 1433,    0,    0,    0,18200,    0,    0,
    0,17381,    0,    0,    0, 1434,    0,    0,  283,    0,
18130,18170,    0,    0,    0, 1436,    0,    0,    0,    0,
    0,    0, 1438,    0,    0,17381,    0,  628,    0, 1008,
    0,    0,    0,    0,    0,  986,    0,18050,18090,    0,
    0,    0,    0,    0,    0,    0,    0, 1491,    0, 1554,
    0,    0,    0, 1028,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,  651,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,18200,    0,    0,17864,17894,    0,
  651,    0,    0,    0,    0,    0,14784,    0,    0,    0,
    0,    0,    0,    0, 1370, 1370,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,
  };
  protected static readonly short [] yyGindex = {            0,
    0, 1771,    0,    0,    0,    3,  -12, -178,  -50,  -47,
    0, 1814, 1822,  805,    0,   -5,    0,    0,    0,    0,
    0,    0, -983, -779, -219, -793,    0,    0,    0,    0,
    0, -225,    0,    0,    0,  821,    0,  924,    0,    0,
    0,    0,  675,  678,  -17, -213,    0,    7,    0, -643,
  474,    0,  525, -557, -521, -517, -512, -498, -495, -475,
 -462,    0,    0, -786,    0, -797,    0,  471,-1255,    0,
   34,    0,    0,    0,  631,-1178,    0,    0,    0,  787,
  305,    0,    0,    0,  339,-1148,    0, -279, -302, -329,
    0,    0,    0, -969,  288,    0,    0, -534,    0,    0,
  356,    0,    0,  331,    0,    0,  436,    0, -585, -771,
    0,    0,    0,    0,    0, -730,  367,-1387,   -9,    0,
    0,    0,  923,  925,  927, 1111, -576,    0,    0, -330,
  936,  458,    0, -887,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,  271,    0,    0,
    0,    0,    0,    0,    0,    0,  522,    0,    0,    0,
 -271,  448,    0,    0,    0,    0,    0,    0,    0,    0,
    0,  541,    0, -531,    0,    0,    0,    0,    0,    0,
    0,    0,    0,  278,    0,    0,  355,    0,    0,  361,
  368,  285,    0,    0,    0,    0,    0,    0,    0,    0,
  612,    0,    0,    0,    0,  -51,    0,   -3, -278, -322,
  714,    0,  433,    0, -484,    0,  987,    0, 1578, -300,
 -281,   31,  495,    0,  619,    0,  -38,  478,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0, -272,    0,  159,
    0, -363,    0, -277,    0,    0,    0,  935, -913, -309,
 -136,  609,    0, 1018,    0, 1276, -353, 1149,    0,    0,
  830, 1839,    0,    0,    0,    0, 1124,    0,    0,    0,
 1574,    0,    0,    0,    0,    0, 1416,  967,  973,  938,
  820,  990, 1495, 1496, 1494, 1497, 1499,    0, 1493,    0,
    0,    0, 1064, 1343, -567,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0, -307,  750,    0,-1069,    0,
    0,    0,    0,    0, -473,    0,  671,    0,  580,    0,
    0,    0,  794, -566,  -14, -325,   -6,    0, 1789,    0,
   45,    0,   46,  101,  141,  143,  160,  173,  175,  179,
  190,  191,    0, -743,    0,  -29,    0,    0,  886,    0,
  814,    0,    0,    0,  792, -948,  867, -933,    0,  919,
 -489,    0,    0,    0,    0,    0,    0,  818,    0,  817,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,  744,    0,    0,    0,
    0,    0,    0,    0,    0,  -44,    0, 1420,  779,    0,
    0,  999,    0,    0,    0,    0,    0,    0, -171,    0,
    0,    0,    0,    0, 1535, 1278,    0,    0,    0,    0,
 1546,    0,    0,    0,    0,    0,    0,    0,    0,    0,
  634,    0,    0,    0,    0,    0,    0,    0,    0,  756,
    0,    0,    0,    0,    0,    0,   24, 1075,    0,    0,
    0, 1086,
  };
  protected static readonly short [] yyTable = {           110,
  544,  236,  157,  547,  237,  191,   18,  112,  816,  810,
  158,  494,  456,  516,  194,  473,  196,  753,  455,  569,
  540,  262,  429,  776,  542,  596,  853,  528,  580,  642,
  263, 1227,  854,  316,  858, 1094,  498,  974,  633,   44,
 1039,  954,  469,  955, 1261,  611,  561, 1072,  890,  255,
  822,  736,  575,  865, 1147,  888,  308, 1087,  893,  622,
  315,  162,  163,  898,  899,  394, 1148, 1480,  230, 1368,
  317,  232,  320,  650, 1488,  297, 1097,  737,  352,  946,
  871, 1234,  784, 1288,  196,  196,  920,  981, 1375, 1597,
  983, 1148,  699, 1411,  331,  336, 1297, 1598,  379,  343,
  434,  507,   14,  621,  612,  196,  248, 1222,  192,  738,
  249,  370,  555, 1136,  746,  325,  781,  164,  371,  382,
 1181,  913, 1023, 1130, 1435,  372, 1437,  252,  459,  826,
  253,  460, 1182,  914,  371, 1443,   43,  264,  720, 1136,
  236,  110, 1412,  457,  157,  386,  909,  395, 1304,  112,
 1256,  701,  158,  435,  319,  946,  650,  165, 1599,  166,
  250,  650, 1574,  650,  650,  650,  650,  650,  650,  650,
  650,  650,  650,  650,  891,  889,  167, 1128,  498,  254,
  431,  871,  719, 1061,  472,  508,  650,  457,  650,  168,
  650,  169,  650,  650,  650,  170, 1606,  196,  196,  785,
 1489, 1235, 1097,  162,  163, 1023,  171,  172,  650,  699,
 1023,  699, 1023,  393,  739, 1023, 1023,  754, 1023, 1023,
  266, 1149,  370,  295,  290,  291,  292,  802,  298,  299,
 1194,  494,  497,  312,  313,  871,  473,  808,  502,  318,
  321, 1023,  323,  253,  327,  371, 1149,  650,  464,  339,
  340,  262,  372,  956,  611,  496,  499,    1,  265,  164,
  512,  262,  196, 1556,  470,   15,  699,  596, 1305,  503,
  253,  193,    6,  869,  393,  515,  989,  747,  571,  296,
  519,  521, 1575,  576,  295,  252, 1131, 1436,  196, 1438,
 1580, 1041,  254,  567,  596,  551, 1023, 1039, 1444,  165,
  196,  166, 1590,  564, 1591,  566,  527,  872,  196,  519,
 1294,  849,  565,  612,  196,  383, 1315,  293,  167,  254,
  393,  582,  583, 1143,  884,  294,   20, 1079,  393, 1170,
  393,  168,  393,  169, 1039,  619,  595,  170,  574,  612,
  296,  196,  196,  579,  597,  324,  867,  341,  171,  172,
 1627,  871,  873, 1451,  379,  590,  568,  966,    2,    2,
  572,  340,  618, 1051, 1552,  577,  319,  196, 1098,  874,
 1100,   16,  196, 1105,  497,  639,  393,   51,  646,  647,
  648,  649,  650,  651,  652,  653,  654,  655,  656,   51,
  625, 1281,  786,  910,  630,  908, 1188,   95,  499,  499,
 1601,  253,  818, 1216,  845,  236,  196,  196,  457, 1102,
  699,   51,  295,  498, 1431,  730,  321, 1413,  731,  820,
  393,  198, 1433,  830,  598,  833,    3,    4,    5,    6,
 1248, 1295, 1624,  295,  196,  196,  536,  379, 1082,  907,
 1059,  379,  761,  885,  703,  705, 1252, 1039,  709, 1233,
  254,  612,  717, 1039,  196, 1163,  729, 1165, 1237, 1166,
  541, 1065,   95, 1323,  947,  740,  379,  196,  296, 1452,
  379, 1628,  379,  379,  379,  379,  967,  561,   95, 1487,
  379,  599,  253,  775,  875,  721,  722, 1264,  757,  296,
  342,  734, 1248, 1309,  117,  295,  771, 1399,  942,   20,
   45, 1518,   51,  410, 1103,  494, 1458,  881, 1545,  787,
 1282,  115, 1326, 1345, 1587,  998,   95,  528,  773,  819,
  782,  805, 1605,  639, 1160,  814, 1135,  762,  611,    6,
  823,  254,  379,   49, 1326,  391,  821,  117,  494,  411,
  831,  117,  834,  498,  721,  721,  825,  499,  537,  721,
  538,  296,  253,  721,  115,  835,  234, 1060,  115,  201,
  837, 1345, 1239,  824,  882,  850, 1588,  371,  721, 1383,
  234,  295,  295,  832,  963, 1324,   55,  234,  595,  846,
  380,  196,  335,  335, 1326,  766,  597,  612,  487,  995,
  846, 1203,  371,  364,  749,  721, 1272,  721,  750,  364,
 1459,  254,  473,  335,  539,  595,  364,  196, 1049,  497,
  364,  824,  234,  597,  721,  234,  857,  876,  876,  538,
  412,  413,  234,  364,  767,  538,  851,  623,  628,  342,
  474,  853,  868,  499, 1044,  964,  117,  624,  629,  855,
  488,  436,  381,  812,  369,  487,  766,  391, 1310,  391,
  509,  391,  391,  115,  391,  364,  391,  802,  510,  751,
 1582, 1583, 1424,  473,  626,  968,  772, 1361,  612,  369,
  202, 1000,  886,  824, 1424,  226, 1473,  721,  705,   51,
  538,  856,  721,  961,  805,  767,  721,  369, 1077,  805,
  805,  474,  901,  370, 1081,  335,  335,  488,  391,  812,
  391,  721,  930,  391,  547, 1506, 1507,  705, 1171, 1509,
  895,  511,  897,  823,  627,  705,  371, 1618,  370,  196,
  819,  905, 1528,  372,  437, 1535,  931,  819,  721,  438,
  373,  439,  386,  197,  440,  441,  370,  442,  443,  497,
 1551,  371,  776,  208,  824,  196,  253,  721,  372, 1346,
  824,  262,  234,  932,  519,  373, 1139,  824,  719,  371,
  335, 1414,  267,  499, 1573,  354,  372,  117,  203,  952,
  814, 1316,  354,  373,  364,  808,  819,  805,  386,  805,
  364,  949,  719,  929,  115, 1347,  335,  364,  247, 1348,
  672,  364,  672, 1026, 1349,  254,  527, 1346,  335,  720,
  117,  197,  197,  251,  364,  824,  335,  953, 1350,  719,
 1415, 1351,  335,   95,  979, 1116,  980,  115,  984,  196,
  985,  354,  197,  720, 1439,  199,  369,  596,  117,  742,
  990, 1352,  987, 1347,  846,  196,  364, 1348, 1453,  335,
  335,  345, 1349, 1269, 1353,  115,  917,  345,  324, 1107,
  720,  196, 1372, 1053,  346,  196, 1350,  199,  742, 1351,
 1471,  639,  742,  338,  992,  335,  730,  639, 1195,  731,
  335, 1004,  596,  814,  332,  337, 1026, 1044, 1071, 1352,
  436, 1026,  234, 1026,  971,  499, 1026, 1026,  918, 1026,
 1026,  499, 1353,  369,  426,  378,  708,  369,  554,  364,
  369,  740,  369, 1230,  335,  335,  427,  369, 1428,  383,
  423,  555, 1026,  369,  197,  197,  740,  805,  196,  515,
 1428,  458,  302, 1399,  302,  708,  384,  710,  556,  302,
  740,  370,  335,  335,  383, 1066,  196,  196,  369,  324,
 1068,  369,  369, 1068,  364,  126,  422,  126,   95, 1263,
  753,  459,  126,  805,  371,  814,  710, 1400, 1085, 1116,
 1033,  372,  711,  437,  324,  596, 1539, 1026,  438,   95,
  439,  748,  745,  440,  441,  748,  442,  443, 1400,  197,
  976,  414,  415,   95,  886,  370,  369,  462,  463,  370,
  117,  711, 1314,  744,  805,  292,  805,  745, 1218,  805,
  748,  196, 1219,  933,  292,  197,  745,  115,  371,  748,
  934, 1115,  371,  425, 1095,  372,  436,  197,  744,  372,
  740,  494,  196,  473,  424,  197,  373,  744, 1592,  459,
  196,  197,  906, 1363,  533,  499, 1243,  604, 1393,  939,
  533,  596,  604,  814,  605, 1405,  519,  364,  428,  605,
  364, 1125,  504,  226,  444,  229,  606, 1129,  197,  197,
 1189,  606,  416,  417, 1190, 1614,  420,  421, 1191, 1122,
  117, 1123,  226, 1124,  231,  301,  418,  419,  514,  335,
  711,  805,  846,  805,  197,  805,  547,  115, 1167,  197,
  461,   69,   69, 1635, 1636,   69, 1396,  117,  550,  437,
  379,  493,  234, 1396,  438,  335,  439,  903,  466,  440,
  441,  903,  442,  443,  115,  903,   38,  364,  364, 1174,
  364,  364,   62,  197,  197,  849, 1068,  849,  468,  849,
  515,  587,  588, 1018, 1019,  838,  533,  838,  595,  838,
  534,  756, 1450, 1204,  814,  757,  597,  495,  300,  846,
  301,  197,  197,  517,  183, 1115,  183,  602,  183, 1450,
  341, 1215,  515,  437,  236,  515, 1246,  457,  438, 1247,
  439,  197,  349,  440,  441,  543,  442,  443, 1482,  499,
 1483,  792,  803,  595,  197,  793,  534,  379,  805,  970,
  454,  597,  236,  971, 1242,  457,  664,  666,  196,  996,
  196, 1073,  196,  757, 1289,  971, 1208, 1209, 1290,   70,
 1044,  515,  379,   70,  518,  196,  379,  335,  364,  379,
  548,  379,  805, 1167,  704,  706,  379,  549, 1246,  905,
  907, 1247,  384,  905,  907,  677,  679,  681,  683,  364,
  407,  408,  409,  335,  823, 1277,  234,  364, 1017,  364,
  823, 1093,  552,  885,  712, 1325, 1344,  823, 1247,  731,
  586, 1172,  117, 1173,  117,  829,  553,  829,  364,  364,
 1060,  840, 1060,  840,  805,  573,  595, 1325,  196,  115,
 1247,  115,  371,  466,  597,  639,  616,  171,  364,  171,
  178,  617,  178,  805,  578,  515,  364,  735,  197,  364,
  631,  196, 1019,  715, 1344,  823,  377,  731,  117,  499,
  442,  117,  179,  718,  179,  539,  371,  335,  442,  755,
  442,  539, 1602, 1603,  197,  115,  758, 1325,  115,  760,
 1247, 1017,  783,  335, 1641,  968, 1017,  968, 1017,  442,
  442, 1017, 1017,  788, 1017, 1017,   72,  789,   72,  335,
  721,  721,  595,  335,  202,  172,  202,  172,  791,  442,
  597, 1404,  196,  790,  196, 1379,  131,  442,  131,  836,
  442,  196,  308,   38,  308,  828,  539,   38,  668,  670,
  196,  196,  138,  196,  138, 1019,  673,  675,   38, 1427,
 1019,  829, 1019,   38,  838, 1019, 1019,   38, 1019, 1019,
   38, 1427,  315,  960,  315,  962, 1427,  839,  196,  685,
  687,  196,   38,   38, 1462,  840,  841,   38,   38, 1404,
 1427,  860, 1017,   38,  859,   38,   38,   38,   38,  863,
  864,  879,  866,   38,  335,  335,  197,   38,  870,   38,
 1519, 1013, 1427,  731,  880,  894,  896,  900,  912,   38,
  911,   38,   38,  459,   38,  925,  921, 1546,   38,  922,
  731,  943,  197,   43,  937,  944,  945,  946,  951,  198,
 1558, 1560,  950,  731,  731,  969, 1019,  972,   38,  975,
  885,  973,  988,  814,  994,   38,   38, 1008, 1013, 1404,
 1015, 1023, 1020, 1028, 1032,  515, 1029, 1546, 1546,  335,
  731,  731, 1031, 1034, 1037, 1039, 1045, 1057, 1058,  350,
 1061, 1067, 1568,  354,  356,  358,  360,  362,  364,  366,
  368, 1076,  537, 1090, 1013, 1083, 1091, 1118,  335, 1013,
 1096, 1013, 1108, 1132, 1013, 1013,  197, 1013, 1013, 1126,
 1133, 1134, 1142, 1145,  117,  814, 1184, 1155, 1144, 1156,
 1158, 1164,  197, 1161, 1546, 1176, 1185,  731, 1196, 1186,
 1162,  115, 1180,  387, 1183, 1200, 1207, 1210,  197,  652,
 1218,  253,  197,  388, 1211,  822, 1219, 1228, 1238, 1257,
 1269, 1245,  814, 1271, 1274, 1279, 1276,  364, 1298, 1280,
 1283, 1293,  389,  390, 1284, 1300, 1306, 1307, 1620, 1620,
 1314, 1357, 1313, 1358, 1362, 1629, 1629,  639,  639,  978,
 1359, 1364,  391, 1365, 1366, 1013, 1369,  117, 1381, 1640,
  254, 1416, 1376,  392, 1430,  986, 1434, 1448, 1447, 1456,
  117,  499,  499, 1457,  115,  197, 1465, 1468, 1467, 1470,
 1459,  991, 1472, 1438, 1474, 1476, 1478,  115, 1479, 1399,
 1485, 1492,  652,  197,  197, 1495, 1486,  652, 1498,  652,
  652,  652,  652,  652,  652,  652,  652,  652,  652,  652,
  117, 1499, 1500, 1529, 1541,  117, 1502, 1510, 1511,  117,
 1514, 1589,  652, 1524,  652, 1531,  652,  115,  652,  652,
  652, 1540,  115, 1543, 1544, 1550,  115, 1578, 1029, 1554,
  386, 1553, 1565, 1567, 1570, 1593, 1564, 1569,  117, 1572,
 1585, 1594, 1596,  335, 1604, 1588, 1587, 1632,  197, 1612,
 1613,  350, 1634,  386, 1638,  115, 1643, 1052, 1639,    9,
  571, 1056,  531,  935,  936, 1048,  386,  674,  898,  197,
  532,  386,  487,  652,  254,  950,  386,  197,  386,  386,
  386,  386,  675,  581,   33,  902,  386,  756,  530,  488,
  386,   33,  832,  350,  386,   34,  337,  842,  117,  232,
   34,  106,  386,   24,  833,  386,  335,  386,  834,  843,
  866, 1029,  835,  867,  744,  115, 1029,  341, 1029, 1029,
 1029, 1029, 1029, 1029, 1029, 1029, 1029, 1029,  744,  335,
  766,  386,  364,  134,  116,  721,  311,  141,  386,  135,
  117, 1029,  312, 1029,  142, 1029,  721, 1029, 1029, 1029,
 1120,  233,  658,  660,  662,   54,   21,  581,  581,  581,
  581,  581,  581,  581,  581,  581,  581,  581,  581,  581,
  581,  581,  581,  364,  117, 1027, 1109, 1213,  364,  364,
 1214, 1407, 1370, 1408, 1555, 1262, 1595, 1586,  386, 1542,
  335,  115,  335, 1571, 1460, 1537, 1054, 1440, 1055,  335,
 1056,  364, 1029,  940, 1050,  543, 1377, 1461,  335,  335,
 1566,  335, 1561, 1374,  364,  364, 1631, 1623, 1559,  364,
 1301, 1484,  364, 1622,  364,  562,  364,  364,  364,  364,
 1302, 1075, 1001, 1024,  364,  936,  335, 1146,  364,  335,
  303,  878,  364,  957,  584, 1086,  689,  693,  691,  698,
  364,  695,  993,  364,  697,  364,  364,  843, 1226, 1286,
  364,  364,  197,  364,  364,  364,  364,  364,  364,  364,
  364,  364,  364,  364,  364, 1382, 1198,  430, 1138,  364,
  364, 1187,  581, 1205, 1157,  364,  364,  364,  364,  364,
  364,  364,  364,  364,  364, 1127,  364,  364, 1197, 1199,
  364,  364,  364,  364,  364, 1267,  827,  364,  364, 1236,
 1088,  713,  364,  364,  364,  364,  364,  364,  364,  364,
  904,  385,  714, 1025, 1380,  197, 1273, 1022,    0,    0,
    0,  364,    0,    0,  364,    0,  364,    0,  364,    0,
    0,  364,    0,    0,  385,    0,    0,  364,  197,    0,
    0,    0,    0,    0,    0,    0,    0,  385,    0,    0,
   24,  862,  385,    0,   24,  253,    0,  385,    0,  385,
  385,  385,  385,    0,  937,   24,    0,  385,    0,    0,
   24,  385,    0,    0,   24,  385,    0,   24,    0,    0,
    0,    0,    0,  385,    0,    0,  385,    0,  385,   24,
   24,    0,    0,    0,   24,   24,    0,    0,    0,  197,
   24,  197,   24,   24,   24,   24,    0,  350,  197,    0,
   24, 1320,  385,    0,   24,    0,   24,  197,  197,  385,
  197,    0,    0,    0,    0,    0,   24,    0,    0,   24,
    0,   24,    0,    0,    0,   24,    0,    0,    0,    0,
    0,    0,    0,    0,    0,  197,    0,    0,  197,    0,
    0,  543,    0,    0,    0,   24,  543,  543,    0,  396,
    0,   21,   24,   24,    0,    0,    0,    0,    0,  385,
    0,    0, 1320,    0,    0,    0,    0,    0,    0,  543,
  397,  398,  399,  400,  401,  402,  403,  404,  405,  406,
 1409, 1410,  543,  543,    0,    0,    0,  543,    0,    0,
  543,    0,  543,    0,  543,  543,  543,  543,    0,    0,
    0,    0,  543,    0,    0,    0,  543,    0, 1442,    0,
  543, 1445,    0,    0,    0,    0,    0,    0,  543,  350,
    0,  543,  860,  543,  543,    0,    0,    0,  543,  543,
    0,  543,  543,  543,  543,  543,  543,  543,  543,  543,
  543,  543,    0,    0,    0,    0,    0,  543,  543,  543,
    0,    0,    0,  543,  543,    0,  543,  543,  543,  543,
  543,  543,  543,    0,  543,  543,    0,  543,  543,  543,
  543,  543,  543,  543,  543,  543,  543,    0,  543,  543,
  543,  543,  543,  543,  543,  543,  543,  543,  543,  543,
  543,  543,  543,  543,  543,  543,  543,  543,  543,  543,
    0,    0,  543,    0,  543,    0,  543,    0,    0,  543,
  937,  937,    0,    0,    0,  543,    0,    0,  937,  937,
  937,  937,  937,    0,  937,  937,    0,  937,  937,  937,
  937,  937,  937,  937,  937,    0,    0,    0,    0,  937,
    0,  937,  937,  937,  937,  937,  937,    0,    0,  937,
    0,    0,  820,  937,  937,    0,  937,  937,  937,    0,
    0,    0,    0,    0,    0,    0,    0,    0,  937,    0,
  937,    0,  937,  937,    0,    0,  937,    0,  937,  937,
  937,  937,  937,  937,  937,  937,  937,  937,  937,  937,
    0,  937,  581,    0,  937,  937,    0,    0,  937,  937,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,  937,  937,  937,  937,  937,    0,    0,
    0,    0,  937,  937,    0,    0,  937,    0,    0,    0,
    0,  937,  937,  937,  937,  937,    0,    0,    0,  937,
    0,  937,    0,    0,    0,    0,    0,  937,  937,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,  937,  937,  937,  937,    0,  937,  860,  860,
    0,    0,    0,  354,  937,    0,  860,  860,  860,  860,
  860,    0,  860,  860,    0,  860,  860,  860,  860,  860,
  860,  860,    0,    0,    0,    0,    0,  860,    0,  860,
  860,  860,  860,  860,  860,    0,    0,  860,    0,    0,
    0,  860,  860,    0,  860,  860,  860,    0,    0,    0,
    0,    0,    0,    0,    0,    0,  860,    0,  860,    0,
  860,  860,    0,    0,  860,    0,  860,  860,  860,  860,
  860,  860,  860,  860,  860,  860,  860,  860,    0,  860,
    0,    0,  860,  860,    0,    0,  860,  860,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,  860,  860,  860,  860,  860,    0,    0,    0,    0,
  860,  860,    0,    0,  860,    0,    0,    0,    0,  860,
  860,  860,  860,  860,    0,    0,    0,  860,  820,  860,
    0,    0,    0,  820,  820,  860,  860,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
  394,    0,    0,    0,    0,    0,  820,    0,    0,    0,
  860,  860,  860,  860,    0,  860,    0,    0,    0,  820,
  820,    0,  860,    0,  820,    0,    0,  820,    0,  820,
    0,  820,  820,  820,  820,    0,    0,    0,    0,  820,
    0,    0,    0,  820,    0,    0,    0,  820,    0,    0,
    0,    0,    0,    0,    0,  820,    0,    0,  820,    0,
  820,  820,    0,    0,    0,  820,  820,    0,  820,  820,
  820,  820,  820,  820,  820,  820,  820,  820,  820,    0,
    0,    0,    0,    0,  820,  820,    0,    0,    0,    0,
  820,  820,  820,  820,  820,  820,    0,  820,  820,  820,
    0,  820,  820,    0,    0,  820,  820,  820,  820,  354,
    0,    0,  820,  820,  354,  354,    0,  820,  820,  820,
  820,  820,  820,  820,  820,  364,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,  820,  354,    0,  820,
    0,  820,    0,  820,    0,    0,  820,    0,    0,    0,
  354,  354,  820,    0,    0,  354,    0,    0,  354,    0,
  354,    0,  354,  354,  354,  354,    0,    0,    0,    0,
  354,    0,    0,    0,  354,    0,    0,    0,  354,    0,
    0,    0,    0,    0,    0,    0,  354,    0,    0,  354,
    0,  354,  354,    0,    0,    0,  354,  354,    0,  354,
  354,  354,  354,  354,  354,  354,  354,  354,  354,  354,
    0,    0,    0,    0,    0,  354,  354,    0,    0,    0,
    0,  354,  354,  354,  354,  354,  354,    0,  354,  354,
  354,    0,  354,  354,    0,    0,  354,  354,  354,  354,
    0,    0,    0,  354,  354,    0,    0,    0,  354,  354,
  354,  354,  354,  354,  354,  354,  394,    0,    0,    0,
    0,  394,  394,    0,    0,    0,    0,  354,    0,    0,
  354,    0,  354,  389,  354,    0,    0,  354,    0,    0,
    0,    0,    0,  354,  394,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,  394,  394,    0,
    0,    0,  394,    0,    0,  394,    0,  394,    0,  394,
  394,  394,  394,    0,    0,    0,    0,  394,    0,    0,
    0,  394,    0,    0,    0,  394,    0,    0,    0,    0,
    0,    0,    0,  394,    0,    0,  394,    0,  394,  394,
  203,    0,    0,  394,  394,    0,  394,  394,  394,  394,
  394,  394,  394,  394,  394,  394,  394,    0,    0,    0,
    0,    0,  394,  394,    0,    0,    0,    0,  394,  394,
    0,  394,  394,  394,    0,  394,  394,  394,    0,  394,
  394,  364,  204,  394,  394,  394,  394,  364,    0,    0,
  394,  394,    0,    0,    0,  394,  394,  394,  394,  394,
  394,  394,  394,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,  394,    0,    0,  394,    0,  394,
    0,    0,    0,  364,    0,    0,    0,    0,    0,    0,
  394,    0,   31,  205,  206,  207,  208,    0,  209,  210,
  211,  212,  213,  214,  215,  216,    0,    0,  217,  218,
  219,  220,  221,  222,  223,  224,    0,    0,    0,    0,
    0,    0,    0,    0,  364,    0,    0,    0,  364,  364,
    0,  364,  364,  364,  364,  364,  364,  364,  364,  364,
  364,  364,  364,    0,    0,    0,    0,    0,  364,    0,
    0,    0,    0,  364,  364,  364,  364,  364,  364,  364,
  364,  364,  364,    0,  364,  364,    0,    0,  364,  364,
  364,  364,  364,    0,    0,  364,  364,    0,    0,    0,
  364,  364,  364,  364,  364,  364,  364,  364,    0,  389,
    0,   37,    0,  474,    0,  389,    0,    0,    0,  364,
    0,    0,  364,    0,  364,    0,  364,    0,    0,  364,
    0,    0,    0,    0,    0,  364,  475,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,  476,
    0,  389,    0,    0,  478,    0,    0,    0,    0,  479,
    0,  480,  481,  482,  483,    0,    0,    0,    0,  484,
    0,    0,    0,  485,    0,    0,    0, 1419,   36,    0,
    0,    0,    0,    0,    0,  486,    0,    0,  487,    0,
  488,    0,  389,    0,    0,    0,  389,  389,    0,  389,
  389,  389,  389,  389,  389,  389,  389,  389,  389,  389,
    0,    0,    0,    0,  489,    0,  389,    0,    0,    0,
    0,  389,  389,    0,  389,  389,  389,    0,  389,  389,
  389,    0,  389,  389,    0,    0,  389,  389,  389,  389,
    0,    0,    0,  389,  389,    0,    0,    0,  389,  389,
  389,  389,  389,  389,  389,  389,    0,    0,   25,    0,
    0,    0,    0,    0,    0,    0,    0,  389,   31,   31,
  389, 1421,  389,   31,    0,    0,    0,   31,    0,   31,
    0,    0,   31,  389,   31,   31,    0,   31,    0,   31,
    0,   31,    0,   31,   31,   31,   31,    0,    0,   31,
   31,   35,    0,    0,    0,   31,    0,   31,   31,   31,
    0,    0,   31,   31,   31,    0,   31,    0,    0,   31,
    0,   31,   31,   31,   31,    0,    0,    0,   31,   31,
   31,    0,    0,   31,   31,   31,    0,    0,    0,    0,
    0,    0,   31,   31,    0,   31,   31,    0,   31,   31,
   31,    0,    0,    0,   31,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,   37,    0,
    0,    0,   37,    0,   31,    0,    0,    0,    0,    0,
   31,   31,   31,   37,    5,    0,    0,    0,   37,    0,
   31,    0,   37,    0,    0,   37,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,   37,   37,    0,
    0,    0,   37,   37,    0,    0,    0,    0,   37,    0,
   37,   37,   37,   37,    0,    0,    0, 1037,   37,    0,
    0,   31,   37,    0,   37,   36,    0,    0,    0,   36,
    0,    0,    0,    0,   37,    0,   37,   37,    0,   37,
   36,    0,    0,   37,    0,   36,    0,    0,    0,   36,
    0,    0,   36,    0,    0,    0,    0,    0,    0,    0,
   51,    0,    0,   37,   36,   36,    0,    0,    0,   36,
   36,   37,    0,    0,    0,   36,    0,   36,   36,   36,
   36,    0,    0,    0,    0,   36,    0,    0,    0,   36,
    0,   36,    0,    0,    0,    0,    0,    0,    0,    0,
    0,   36,    0,    7,   36,   25,   36,    0,    0,   25,
   36,    0,    0,    0,    0,    0,    0,    0,    0,    0,
   25,    0,    0,    0,    0,   25,    0,    0,    0,   25,
   36,    0,   25,    0,    0,    0,    0,   36,   36,    0,
    0,    0,    0,    0,   25,   25, 1038,    0,   35,   25,
   25,    0,   35,    0,    0,   25,    0,   25,   25,   25,
   25,    0,    0,   35,    0,   25,    0,    0,   35,   25,
    0,   25,   35,    0,    0,   35,    0,    0,    0,    0,
    0,   25,    0,    0,   25,    0,   25,   35,   35,   52,
   25,    0,   35,   35,    0,    0,    0,    0,   35,    0,
   35,   35,   35,   35,    0,    0,    0,    0,   35,    0,
   25,    0,   35,    0,   35,    0,    0,   25,   25,    0,
    0,    0,    0,    0,   35,    0,    0,   35,    0,   35,
    0,    5,    0,   35,    0,   51,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,   51,    0,    0,    0,
    0,   51,    0,   35,    0,   51,    0,    0,   51,    0,
    0,   35,    0,    0,    0,    0,    0,    0,    0,    0,
   51,   51,    0,    0, 1037,   51,   51,    0,   51,    0,
    0,   51,    0,   51,   51,   51,   51,    0,    0,   51,
    0,   51,    0,    0,   51,   51,    0,   51,   51,    0,
    0,   51,    0,    0,    0,    0,    0,   51,    0,    0,
   51,    0,   51,   51,   51,    0,   51,   51,   51,   51,
    0,   51,    0,    0,   51,    0,   51,   51,   51,   51,
    0,    0,   51,    0,   51,    0,   51,   51,   51,    0,
   51,   51,    0,    0,   51,    0,    0,    0,    0,    0,
   51,    0,    0,   51,    0,   51,   51,   51,    0,   51,
    7,   51,   51,    0,   52,    0,    0,   51,    0,   51,
   51,   51,   51,    0,    0,   52,    0,   51,    0,   51,
   52,   51,    0,   51,   52,    0,    0,   52,    0,    0,
    0,    0,    0,   51,    0,    0,   51,    0,   51,   52,
   52,    0,   51, 1038,   52,   52,    0,   51,    0,    0,
   52,    0,   52,   52,   52,   52,    0,    0,   51,    0,
   52,    0,   51,   51,   52,    0,   52,   51,    0,    0,
   51,    0,    0,    0,    0,    0,   52,    0,    0,   52,
    0,   52,   51,   51,    0,   52,   52,   51,   51,    0,
   52,    0,    0,   51,    0,   51,   51,   51,   51,    0,
    0,   52,    0,   51,    0,   52,   52,   51,    0,   51,
   52,    0,    0,   52,    0,    0,    0,    0,    0,   51,
    0,    0,   51,    0,   51,   52,   52,    0,   51,    0,
   52,   52,    0,    0,    0,    0,   52,    0,   52,   52,
   52,   52,    0,    0,    0,    0,   52,    0,   51,    0,
   52,    0,   52,    0,    0,    0,    0,    0,    0,    0,
    0,    0,   52,    0,   56,   52,    0,   52,    0,    0,
    0,   52,   57,   24,   58,   25,    0,    0,   26,   59,
    0,   60,   61,   27,   62,   63,   64,   28,    0,    0,
    0,   52,    0,   65,    0,   66,   30,   67,   68,   69,
   70,    0,    0,   32,    0,    0,    0,   71,   33,    0,
   72,   73,   34,    0,    0,    0,    0,    0,    0,    0,
    0,    0,   74,    0,   36,    0,   37,   75,    0,    0,
   38,    0,   76,   77,   78,   79,   80,   81,   39,   40,
   82,   83,   41,   84,    0,   85,    0,    0,   86,   87,
    0,    0,   88,   89,  823,    0,    0,    0,  474,    0,
  823,    0,    0,    0,    0,    0,    0,   90,   91,   92,
   93,   94,    0,    0,    0,    0,   95,    0,    0,    0,
   96,  475,    0,    0,    0,   97,   98,   99,  100,  101,
    0,    0,    0,  102,  476,  103,  823,    0,    0,  478,
    0,  104,  105,    0,  479,    0,  480,  481,  482,  483,
    0,    0,    0,    0,  484,    0,    0,    0,  485,    0,
    0,    0, 1419,    0,    0,    0,  106,  107,  108,  109,
  486,    0,    0,  487,    0,  488,    0,  823,  198,    0,
    0,    0,  823,  616,  823,  823,  823,  823,  823,  823,
  823,  823,  823,  823,  823,  823,    0,    0,    0,  489,
    0,  823,  823,    0,    0,    0, 1420,  823,  823,  823,
  823,  823,  823,  823,  823,  823,    0,  823,  823,    0,
  823,  823,  823,  823,  823,  823,  823,  823,  823,  823,
    0,  823,  823,  823,  823,  823,  823,  823,  823,  823,
  823,  823,  823,  823,  823,  823,  823,  823,  823,  823,
  823,  823,  823,  823,    0,  823, 1421,  823,    0,  823,
  823,  823,  823,    0,    0,    0,  616,    0,  823,    0,
    0,  616,    0,  616,  616,  616,  616,  616,  616,  616,
  616,  616,  616,  616,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,  616,  823,  616,    0,
  616,    0,  616,  616,  616,    0,    0,    0,    0,    0,
  616,  616,  616,  616,    0,    0,    0,  616,  616,    0,
    0,    0,  616,  616,  616,  616,  616,  616,  616,  616,
    0,    0,    0,    0,    0,    0,    0,    0,  823,    0,
    0,  616,    0,  823,    0,  823,  823,  823,  823,  823,
  823,  823,  823,  823,  823,  823,  823,  616,    0,    0,
    0,    0,  823,  823,    0,    0,    0,    0,  823,  823,
  823,  823,  823,  823,  823,  823,  823,    0,  823,  823,
    0,  823,  823,  823,  823,  823,  823,  823,  823,  823,
  823,    0,  823,  823,  823,  823,  823,  823,  823,  823,
  823,  823,  823,  823,  823,  823,  823,  823,  823,  823,
  823,  823,  823,  823,  823,  364,  559,    0,  823,    0,
  823,  364,    0,  823,    0,   24,    0,   25,    0,  823,
   26,    0,    0,    0,    0,   27,    0,    0,    0,   28,
    0,    0,    0,    0,    0,    0,    0,    0,   30,    0,
    0,    0,    0,    0,    0,   32,    0,  364,    0,    0,
   33,    0,    0,    0,   34,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,   36,    0,   37,    0,
    0,    0,   38,    0,    0,    0,    0,    0,    0,    0,
   39,   40,    0,    0,   41,    0,    0,  560,  364,    0,
    0,    0,    0,  364,    0,  364,  364,  364,  364,  364,
  364,  364,  364,  364,  364,  364,  364,    0,    0,    0,
    0,    0,  364,  364,    0,    0,    0,    0,  364,  364,
  364,  364,  364,  364,  364,  364,  364,    0,  364,  364,
    0,  364,  364,  364,  364,  364,  364,  364,  364,  364,
  364,    0,  364,  364,  364,  364,  364,  364,  364,  364,
  364,  364,  364,  364,  364,  364,  364,  364,  364,  364,
  364,  364,  364,  364,    0,  545,  601,    0,  364,  377,
  364,  545,    0,  364,    0,   24,    0,   25,    0,  364,
   26,    0,    0,    0,    0,   27,    0,    0,    0,   28,
    0,    0,    0,    0,    0,    0,    0,    0,   30,    0,
    0,    0,    0,    0,    0,   32,    0,  545,    0,    0,
   33,    0,    0,    0,   34,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,   36,    0,   37,    0,
    0,    0,   38,    0,    0,    0,    0,    0,    0,    0,
   39,   40,    0,    0,   41,    0,    0,  328,  545,    0,
    0,    0,    0,  545,    0,  545,  545,  545,  545,  545,
  545,  545,  545,  545,  545,  545,    0,    0,    0,    0,
    0,    0,    0,  545,    0,    0,    0,  545,  545,  545,
  545,  545,  545,  545,  545,  545,  545,    0,  545,  545,
    0,  545,  545,  545,  545,  545,  545,  545,  545,  545,
  545,    0,  545,  545,  545,  545,  545,  545,  545,  545,
  545,  545,  545,  545,  545,  545,  545,  545,  545,  545,
  545,  545,  545,  545,  663,  541,    0,    0,    0,  377,
  545,  541,    0,   24,    0,   25,    0,    0,   26,  545,
    0,    0,    0,   27,    0,    0,    0,   28,    0,    0,
    0,    0,    0,    0,    0,    0,   30,    0,    0,    0,
    0,    0,    0,   32,    0,    0,    0,  541,   33,    0,
    0,    0,   34,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,   36,    0,   37,    0,    0,    0,
   38,    0,    0,    0,    0,    0,    0,    0,   39,   40,
    0,    0,   41,    0,    0,  328,    0,    0,  541,    0,
    0,    0,    0,  541,    0,  541,  541,  541,  541,  541,
  541,  541,  541,  541,  541,  541,    0,    0,    0,    0,
    0,    0,    0,  541,    0,    0,    0,  541,  541,    0,
  541,  541,  541,  541,  541,  541,  541,    0,  541,  541,
    0,  541,  541,  541,  541,  541,  541,  541,  541,  541,
  541,    0,  541,  541,  541,  541,  541,  541,  541,  541,
  541,  541,  541,  541,  541,  541,  541,  541,  541,  541,
  541,  541,  541,  541,    0,  549,  665,  377,    0,    0,
  541,  549,    0,  541,    0,   24,    0,   25,    0,  541,
   26,    0,    0,    0,    0,   27,    0,    0,    0,   28,
    0,    0,    0,    0,    0,    0,    0,    0,   30,    0,
    0,    0,    0,    0,    0,   32,    0,  549,    0,    0,
   33,    0,    0,    0,   34,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,   36,    0,   37,    0,
    0,    0,   38,    0,    0,    0,    0,    0,    0,    0,
   39,   40,    0,    0,   41,    0,    0,  328,  549,    0,
    0,    0,    0,  549,    0,  549,  549,  549,  549,  549,
  549,  549,  549,  549,  549,  549,    0,    0,    0,    0,
    0,    0,    0,  549,    0,    0,    0,    0,  549,    0,
  549,  549,  549,  549,  549,  549,  549,    0,  549,  549,
    0,  549,  549,  549,  549,  549,  549,  549,  549,  549,
  549,    0,  549,  549,  549,  549,  549,  549,  549,  549,
  549,  549,  549,  549,  549,  549,  549,  549,  549,  549,
  549,  549,  549,  549,    0,  364,  977,    0,    0,  377,
  549,  364,    0,  549,    0,   24,    0,   25,    0,  549,
   26,    0,    0,    0,    0,   27,    0,    0,    0,   28,
    0,    0,    0,    0,    0,    0,    0,    0,   30,    0,
    0,    0,    0,    0,    0,   32,    0,  364,    0,    0,
   33,    0,    0,    0,   34,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,   36,    0,   37,    0,
    0,    0,   38,    0,    0,    0,    0,    0,    0,    0,
   39,   40,    0,    0,   41,    0,    0,  328,  364,    0,
    0,    0,    0,  364,    0,  364,  364,  364,  364,  364,
  364,  364,  364,  364,  364,  364,    0,    0,    0,    0,
    0,    0,    0,  364,    0,    0,    0,    0,  364,    0,
  364,  364,  364,  364,  364,  364,  364,    0,  364,  364,
    0,  364,  364,  364,  364,  364,  364,  364,  364,  364,
  364,    0,  364,  364,  364,  364,  364,  364,  364,  364,
  364,  364,  364,  364,  364,  364,  364,  364,  364,  364,
  364,  364,  364,  364,    0,  469, 1119,    0,    0,  377,
  364,  469,    0,  364,    0,   24,    0,   25,    0,  364,
   26,    0,    0,    0,    0,   27,    0,    0,    0,   28,
    0,    0,    0,    0,    0,    0,    0,    0,   30,    0,
    0,    0,    0,    0,    0,   32,    0,  469,    0,    0,
   33,    0,    0,    0,   34,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,   36,    0,   37,    0,
    0,    0,   38,    0,    0,    0,    0,    0,    0,    0,
   39,   40,    0,    0,   41,    0,    0,  328,  469,    0,
    0,    0,    0,  469,    0,  469,  469,  469,  469,  469,
  469,  469,  469,  469,  469,  469,    0,    0,    0,    0,
    0,    0,    0,  469,    0,    0,    0,    0,  469,    0,
  469,  469,  469,  469,  469,  469,  469,    0,  469,  469,
    0,  469,  469,  469,  469,  469,  469,  469,  469,  469,
  469,    0,  469,  469,  469,  469,  469,  469,  469,  469,
  469,  469,  469,  469,  469,  469,  469,  469,  469,  469,
  469,  469,  469,  469,    0,  364,    0,    0,  474,  377,
  469,  364,    0,  469,    0,  823,    0,    0,    0,  469,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,  475,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,  476,    0,    0,  364,    0,  478,
    0,    0,    0,    0,  479,    0,  480,  481,  482,  483,
    0,    0,    0,  823,  484,    0,    0,    0,  485,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
  486,    0,    0,  487,    0,  488,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,  576,
    0,    0,    0,    0,    0,  576,  364,    0,    0,  489,
    0,    0,  364,  364,    0,    0,    0,    0,  364,  364,
  364,  364,  364,  364,  364,  823,  364,    0,  364,  364,
    0,  364,  364,  364,  364,  364,  364,  364,  364,  364,
  364,  576,  364,  364,  364,  364,  364,  364,  364,  364,
  364,  364,  364,  364,  364,  364,  364,  364,  364,  364,
  364,  364,  364,  364,    0,    0, 1438,    0,  364,  420,
  364,    0,    0,  364,    0,  420,    0,    0,    0,  364,
    0,    0,  576,    0,    0,    0,    0,  576,    0,  576,
  576,  576,  576,  576,  576,  576,  576,  576,  576,  576,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,  420,  576,    0,  576,    0,  576,    0,  576,  576,
  576,    0,  576,  576,    0,  576,  576,  576,  576,  576,
  576,  576,  576,  576,  576,    0,    0,    0,  576,  576,
  576,  576,  576,  576,  576,  576,  576,  576,  576,  576,
  576,  576,  576,  576,  576,  576,    0,  576,  598,    0,
    0,    0,    0,    0,  598,    0,    0,    0,    0,    0,
    0,    0,    0,  576,    0,    0,  354,  420,    0,    0,
    0,    0,  420,  354,    0,  420,  420,  420,  420,    0,
  420,    0,  420,  420,    0,  420,  420,  420,  420,  420,
  598,  420,  420,  420,  420,    0,  420,  420,  420,  420,
  420,  420,  420,  420,  420,  420,  420,  420,  420,  420,
  420,  420,  420,  420,  420,  420,  420,  420,    0,    0,
  605,    0,  354,    0,  420,    0,  605,  420,    0,    0,
    0,  598,    0,  420,    0,    0,  598,    0,  598,  598,
  598,  598,  598,  598,  598,  598,  598,  598,  598,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,  598,  605,  598,    0,  598,    0,  598,  598,  598,
    0,  598,  598,    0,    0,  598,  598,  598,  598,  598,
  598,  598,  598,  598,    0,    0,    0,  598,  598,  598,
  598,  598,  598,  598,  598,    0,    0,    0,    0,    0,
    0,    0,    0,  605,    0,    0,  598,    0,  605,    0,
  605,  605,  605,  605,  605,  605,  605,  605,  605,  605,
  605,    0,  598,    0,    0,  943,    0,    0,    0,    0,
    0,  943,    0,  605,    0,  605,    0,  605,    0,  605,
  605,  605,    0,  605,  605,    0,    0,  605,  605,  605,
  605,    0,    0,    0,  605,  605,    0,    0,    0,  605,
  605,  605,  605,  605,  605,  605,  605,  943,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,  605,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,  605,    0,    0,  606,    0,    0,
    0,    0,    0,  606,    0,    0,    0,    0,  943,    0,
    0,    0,    0,  943,    0,  943,  943,  943,  943,  943,
  943,  943,  943,  943,  943,  943,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,  943,  606,
  943,    0,  943,    0,  943,  943,  943,    0,  943,  943,
    0,    0,  943,  943,  943,  943,    0,    0,    0,  943,
  943,    0,    0,    0,  943,  943,  943,  943,  943,  943,
  943,  943,    0,    0,    0,    0,    0,    0,    0,    0,
  606,    0,    0,  943,    0,  606,    0,  606,  606,  606,
  606,  606,  606,  606,  606,  606,  606,  606,    0,  943,
    0,    0,  607,    0,    0,    0,    0,    0,  607,    0,
  606,    0,  606,    0,  606,    0,  606,  606,  606,    0,
  606,  606,    0,    0,  606,  606,  606,  606,    0,    0,
    0,  606,  606,    0,    0,    0,  606,  606,  606,  606,
  606,  606,  606,  606,  607,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,  606,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,  606,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,  607,    0,    0,    0,    0,
  607,    0,  607,  607,  607,  607,  607,  607,  607,  607,
  607,  607,  607,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,  607,    0,  607,    0,  607,
    0,  607,  607,  607,    0,  607,  607,    0,    0,  607,
  607,  607,  607,    0,    0,    0,  607,  607,    0,    0,
    0,  607,  607,  607,  607,  607,  607,  607,  607,    0,
  522,    0,  617,    0,    0,    0,    0,    0,   57,   24,
  607,   25,    0,    0,   26,  257,    0,    0,    0,   27,
   62,   63,    0,   28,    0,    0,  607,    0,    0,   65,
    0,    0,   30,    0,    0,    0,    0,    0,    0,   32,
    0,    0,    0,    0,   33,    0,   72,   73,   34,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
   36,    0,   37,   75,    0,    0,   38,    0,    0,   77,
    0,   79,    0,   81,   39,   40,  258,    0,   41,    0,
    0,    0,    0,    0,    0,  617,    0,  618,    0,    0,
  617,    0,  617,  617,  617,  617,  617,  617,  617,  617,
  617,  617,  617,   90,   91,   92,  259,  523,    0,    0,
    0,    0,    0,    0,    0,  617,   96,  617,    0,  617,
    0,  617,  617,  617,    0,    0,    0,    0,    0,  617,
  617,  617,  617,    0,    0,    0,  617,  617,    0,    0,
    0,  617,  617,  617,  617,  617,  617,  617,  617,    0,
    0,    0,    0,    0,    0,    0,  621,    0,    0,    0,
  617,    0,  106,  524,    0,    0,    0,    0,    0,    0,
  618,    0,    0,  525,  526,  618,  617,  618,  618,  618,
  618,  618,  618,  618,  618,  618,  618,  618,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
  618,    0,  618,    0,  618,    0,  618,  618,  618,    0,
    0,    0,    0,    0,  618,  618,  618,  618,    0,    0,
    0,  618,  618,    0,    0,  622,  618,  618,  618,  618,
  618,  618,  618,  618,    0,    0,    0,    0,    0,  621,
    0,    0,    0,    0,  621,  618,  621,  621,  621,  621,
  621,  621,  621,  621,  621,  621,  621,    0,    0,    0,
    0,  618,    0,    0,    0,    0,    0,    0,    0,  621,
    0,  621,    0,  621,    0,  621,  621,  621,    0,    0,
    0,    0,    0,  621,  621,  621,  621,    0,    0,    0,
  621,  621,    0,    0,  623,    0,    0,  621,  621,  621,
  621,  621,  621,    0,    0,    0,    0,    0,  622,    0,
    0,    0,    0,  622,  621,  622,  622,  622,  622,  622,
  622,  622,  622,  622,  622,  622,    0,    0,    0,    0,
  621,    0,    0,    0,    0,    0,    0,    0,  622,    0,
  622,    0,  622,    0,  622,  622,  622,    0,    0,    0,
    0,    0,  622,  622,  622,  622,    0,    0,    0,  622,
  622,    0,    0,  624,    0,    0,  622,  622,  622,  622,
  622,  622,    0,    0,    0,    0,    0,  623,    0,    0,
    0,    0,  623,  622,  623,  623,  623,  623,  623,  623,
  623,  623,  623,  623,  623,    0,    0,    0,    0,  622,
    0,    0,    0,    0,    0,    0,    0,  623,    0,  623,
    0,  623,    0,  623,  623,  623,    0,    0,    0,    0,
    0,  623,  623,  623,  623,    0,    0,    0,  623,  623,
    0,    0,  625,    0,    0,  623,  623,  623,  623,  623,
  623,    0,    0,    0,    0,    0,  624,    0,    0,    0,
    0,  624,  623,  624,  624,  624,  624,  624,  624,  624,
  624,  624,  624,  624,    0,    0,    0,    0,  623,    0,
    0,    0,    0,    0,    0,    0,  624,    0,  624,    0,
  624,    0,  624,  624,  624,    0,    0,    0,    0,    0,
  624,  624,  624,  624,  364,    0,    0,  624,  624,    0,
  364,    0,    0,    0,  624,  624,  624,  624,  624,  624,
    0,    0,    0,    0,    0,  625,    0,    0,    0,    0,
  625,  624,  625,  625,  625,  625,  625,  625,  625,  625,
  625,  625,  625,    0,    0,    0,  364,  624,    0,    0,
    0,    0,    0,    0,    0,  625,    0,  625,    0,  625,
    0,  625,  625,  625,    0,    0,    0,    0,    0,  625,
  625,  625,  625,    0,    0,    0,  625,  625,    0,    0,
    0,    0,    0,  625,  625,  625,  625,  625,  625,    0,
    0,  630,    0,    0,    0,    0,    0,    0,    0,    0,
  625,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,  364,    0,    0,    0,  625,  364,    0,    0,
  364,    0,  364,  364,    0,    0,    0,  364,  364,    0,
    0,  364,  364,  364,  364,  364,  364,  364,  364,  364,
    0,  364,  364,  364,  364,  364,  364,  364,  364,  364,
  364,    0,    0,    0,    0,    0,    0,    0,    0,    0,
  631,  364,  364,    0,    0,    0,    0,    0,    0,  364,
    0,    0,  364,    0,  630,    0,    0,    0,  364,  630,
    0,  630,  630,  630,  630,  630,  630,  630,  630,  630,
  630,  630,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,  630,    0,  630,    0,  630,    0,
  630,  630,  630,    0,    0,    0,    0,    0,    0,    0,
  630,  630,    0,    0,    0,  630,  630,    0,    0,  632,
    0,    0,    0,    0,  630,  630,  630,  630,    0,    0,
    0,    0,    0,  631,    0,    0,    0,    0,  631,  630,
  631,  631,  631,  631,  631,  631,  631,  631,  631,  631,
  631,    0,    0,    0,    0,  630,    0,    0,    0,    0,
    0,    0,    0,  631,    0,  631,    0,  631,    0,  631,
  631,  631,    0,    0,    0,    0,    0,    0,    0,  631,
  631,    0,    0,    0,  631,  631,    0,    0,  635,    0,
    0,    0,    0,  631,  631,  631,  631,    0,    0,    0,
    0,    0,  632,    0,    0,    0,    0,  632,  631,  632,
  632,  632,  632,  632,  632,  632,  632,  632,  632,  632,
    0,    0,    0,    0,  631,    0,    0,    0,    0,    0,
    0,    0,  632,    0,  632,    0,  632,    0,  632,  632,
  632,    0,    0,    0,    0,    0,    0,    0,  632,  632,
    0,    0,    0,  632,  632,    0,    0,  636,    0,    0,
    0,    0,  632,  632,  632,  632,    0,    0,    0,    0,
    0,  635,    0,    0,    0,    0,  635,  632,  635,  635,
  635,  635,  635,  635,  635,  635,  635,  635,  635,    0,
    0,    0,    0,  632,    0,    0,    0,    0,    0,    0,
    0,  635,    0,  635,    0,  635,    0,  635,  635,  635,
    0,    0,    0,    0,    0,    0,    0,  635,  635,    0,
    0,    0,  635,  635,    0,    0,  638,    0,    0,    0,
    0,    0,    0,  635,  635,    0,    0,    0,    0,    0,
  636,    0,    0,    0,    0,  636,  635,  636,  636,  636,
  636,  636,  636,  636,  636,  636,  636,  636,    0,    0,
    0,    0,  635,    0,    0,    0,    0,    0,    0,    0,
  636,    0,  636,    0,  636,    0,  636,  636,  636,    0,
    0,    0,    0,    0,    0,    0,  636,  636,    0,    0,
    0,  636,  636,    0,    0,  639,    0,    0,    0,    0,
    0,    0,  636,  636,    0,    0,    0,    0,    0,  638,
    0,    0,    0,    0,  638,  636,  638,  638,  638,  638,
  638,  638,  638,  638,  638,  638,  638,    0,    0,    0,
    0,  636,    0,    0,    0,    0,    0,    0,    0,  638,
    0,  638,    0,  638,    0,  638,  638,  638,    0,    0,
    0,    0,    0,    0,    0,    0,  638,    0,    0,    0,
  638,  638,    0,    0,  641,    0,    0,    0,    0,    0,
    0,  638,  638,    0,    0,    0,    0,    0,  639,    0,
    0,    0,    0,  639,  638,  639,  639,  639,  639,  639,
  639,  639,  639,  639,  639,  639,    0,    0,    0,    0,
  638,    0,    0,    0,    0,    0,    0,    0,  639,    0,
  639,    0,  639,    0,  639,  639,  639,    0,    0,    0,
    0,    0,    0,    0,    0,  639,    0,    0,    0,  639,
  639,    0,    0,  642,    0,    0,    0,    0,    0,    0,
  639,  639,    0,    0,    0,    0,    0,  641,    0,    0,
    0,    0,  641,  639,  641,  641,  641,  641,  641,  641,
  641,  641,  641,  641,  641,    0,    0,    0,    0,  639,
    0,    0,    0,    0,    0,    0,    0,  641,    0,  641,
    0,  641,    0,  641,  641,  641,    0,    0,    0,    0,
    0,    0,    0,    0,  641,    0,    0,    0,    0,  641,
    0,    0,  644,    0,    0,    0,    0,    0,    0,  641,
  641,    0,    0,    0,    0,    0,  642,    0,    0,    0,
    0,  642,  641,  642,  642,  642,  642,  642,  642,  642,
  642,  642,  642,  642,    0,    0,    0,    0,  641,    0,
    0,    0,    0,    0,    0,    0,  642,    0,  642,    0,
  642,    0,  642,  642,  642,    0,    0,    0,    0,    0,
    0,    0,    0,  642,    0,    0,    0,    0,  642,    0,
    0,  645,    0,    0,    0,    0,    0,    0,  642,  642,
    0,    0,    0,    0,    0,  644,    0,    0,    0,    0,
  644,  642,  644,  644,  644,  644,  644,  644,  644,  644,
  644,  644,  644,    0,    0,    0,    0,  642,    0,    0,
    0,    0,    0,    0,    0,  644,    0,  644,    0,  644,
    0,  644,  644,  644,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,  644,    0,    0,
  647,    0,    0,    0,    0,    0,    0,  644,  644,    0,
    0,    0,    0,    0,  645,    0,    0,    0,    0,  645,
  644,  645,  645,  645,  645,  645,  645,  645,  645,  645,
  645,  645,    0,    0,    0,    0,  644,    0,    0,    0,
    0,    0,    0,    0,  645,    0,  645,    0,  645,    0,
  645,  645,  645,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,  645,    0,    0,  648,
    0,    0,    0,    0,    0,    0,  645,  645,    0,    0,
    0,    0,    0,  647,    0,    0,    0,    0,  647,  645,
  647,  647,  647,  647,  647,  647,  647,  647,  647,  647,
  647,    0,    0,    0,    0,  645,    0,    0,    0,    0,
    0,    0,    0,  647,    0,  647,    0,  647,    0,  647,
  647,  647,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,  647,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,  647,    0,    0,    0,
    0,    0,  648,    0,    0,    0,    0,  648,  647,  648,
  648,  648,  648,  648,  648,  648,  648,  648,  648,  648,
    0,    0,    0,    0,  647,    0,    0,    0,    0,    0,
    0,    0,  648,    0,  648,    0,  648,    0,  648,  648,
  648,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,  591,    0,  648,    0,    0,    0,    0,    0,
   57,   24,   58,   25, 1148,  648,   26,   59,    0,   60,
   61,   27,   62,   63,   64,   28,    0,  648,    0,    0,
    0,   65,    0,   66,   30,   67,   68,   69,   70,    0,
    0,   32,    0,  648,    0,   71,   33,    0,   72,   73,
   34,    0,    0,    0,    0,    0,    0,    0,    0,    0,
   74,    0,   36,    0,   37,   75,    0,    0,   38,    0,
   76,   77,   78,   79,   80,   81,   39,   40,   82,   83,
   41,   84,    0,   85,    0,    0,   86,   87,    0,    0,
   88,   89,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,   90,   91,   92,   93,   94,
    0,    0,    0,    0,   95,    0,    0,    0,   96,    0,
    0,    0,    0,   97,   98,   99,  100,  101,    0,    0,
    0,  102,    0,  103,    0,    0,    0,    0,    0,  104,
  105,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,   56,    0,  106,  107,  108,  109,    0, 1149,
   57,   24,   58,   25,    0,    0,   26,   59,    0,   60,
   61,   27,   62,   63,   64,   28,    0,    0,    0,    0,
    0,   65,    0,   66,   30,   67,   68,   69,   70,    0,
    0,   32,    0,    0,    0,   71,   33,    0,   72,   73,
   34,    0,    0,    0,    0,    0,    0,    0,    0,    0,
   74,    0,   36,    0,   37,   75,    0,    0,   38,    0,
   76,   77,   78,   79,   80,   81,   39,   40,   82,   83,
   41,   84,    0,   85,    0,    0,   86,   87,    0,    0,
   88,   89,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,   90,   91,   92,   93,   94,
    0,    0,    0,    0,   95,    0,    0,    0,   96,    0,
    0,    0,    0,   97,   98,   99,  100,  101,    0,    0,
    0,  102,    0,  103,    0,    0,    0,    0,    0,  104,
  105,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
  270,    0,    0,    0,  106,  107,  108,  109,   57,   24,
   58,   25,    0,    0,   26,   59,    0,   60,   61,   27,
   62,   63,   64,   28,    0,    0,    0,    0,    0,   65,
    0,   66,   30,   67,   68,   69,   70,    0,    0,   32,
    0,    0,    0,   71,   33,    0,   72,   73,   34,    0,
    0,    0,    0,    0,    0,    0,    0,    0,   74,    0,
   36,    0,   37,   75,    0,    0,   38,    0,   76,   77,
   78,   79,   80,   81,   39,   40,   82,   83,   41,   84,
    0,   85,    0,    0,   86,   87,    0,    0,   88,   89,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,   90,   91,   92,   93,   94,    0,    0,
    0,    0,   95,    0,    0,    0,   96,    0,    0,    0,
    0,   97,   98,   99,  100,  101,    0,    0,    0,  102,
    0,  103,    0,    0,    0,    0,    0,  104,  105,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,  591,    0,
    0,    0,  106,  107,  108,  109,   57,   24,   58,   25,
    0,    0,   26,   59,    0,   60,   61,   27,   62,   63,
   64,   28,    0,    0,    0,    0,    0,   65,    0,   66,
   30,   67,   68,   69,   70,    0,    0,   32,    0,    0,
    0,   71,   33,    0,   72,   73,   34,    0,    0,    0,
    0,    0,    0,    0,    0,    0,   74,    0,   36,    0,
   37,   75,    0,    0,   38,    0,   76,   77,   78,   79,
   80,   81,   39,   40,   82,   83,   41,   84,    0,   85,
    0,    0,   86,   87,    0,    0,   88,   89,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,   90,   91,   92,   93,   94,    0,    0,    0,    0,
   95,    0,    0,    0,   96,    0,    0,    0,    0,   97,
   98,   99,  100,  101,    0,    0,    0,  102,    0,  103,
    0,    0,    0,    0,    0,  104,  105,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0, 1034,    0,    0,    0,
  106,  107,  108,  109, 1034, 1034, 1034, 1034,    0,    0,
 1034, 1034,    0, 1034, 1034, 1034, 1034, 1034, 1034, 1034,
    0,    0,    0,    0,    0, 1034,    0, 1034, 1034, 1034,
 1034, 1034, 1034,    0,    0, 1034,    0,    0,    0, 1034,
 1034,    0, 1034, 1034, 1034,    0,    0,    0,    0,    0,
    0,    0,    0,    0, 1034,    0, 1034,    0, 1034, 1034,
    0,    0, 1034,    0, 1034, 1034, 1034, 1034, 1034, 1034,
 1034, 1034, 1034, 1034, 1034, 1034,    0, 1034,    0,    0,
 1034, 1034,    0,    0, 1034, 1034,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0, 1034,
 1034, 1034, 1034, 1034,    0,    0,    0,    0, 1034,    0,
    0,    0, 1034,    0,    0,    0,    0, 1034, 1034, 1034,
 1034, 1034,    0,    0,    0, 1034,    0, 1034,    0,    0,
    0,    0,    0, 1034, 1034,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,  634,    0,    0,    0, 1034, 1034,
 1034, 1034,   57,   24,    0,   25,    0,    0,   26,  257,
    0,    0,    0,   27,   62,   63,    0,   28,    0,    0,
  189,    0,  189,   65,    0,  189,   30,    0,    0,    0,
  189,    0,    0,   32,  189,    0,    0,    0,   33,    0,
   72,   73,   34,  189,  635,    0,    0,    0,    0,    0,
  189,  636,    0,    0,   36,  189,   37,   75,    0,  189,
   38,    0,    0,   77,    0,   79,    0,   81,   39,   40,
  258,  189,   41,  189,    0,    0,    0,  189,    0,  637,
    0,    0,   88,   89,    0,  189,  189,    0,    0,  189,
    0,    0,  189,    0,    0,    0,    0,   90,   91,   92,
   93,   94,    0,    0,    0,    0,    0,    0,    0,    0,
   96,    0,    0,  638,    0,    0,   98,   99,  100,  101,
    0,    0,    0,  102,    0,  103,    0,    0, 1059,    0,
    0,  104,  105,    0,    0,    0,    0,    0,    0,   57,
   24,    0,   25,    0,    0,   26,  257,    0,    0,    0,
   27,   62,   63,    0,   28,    0,  106,  107,  108,  109,
   65,    0,    0,   30,    0,    0,    0,    0,    0,    0,
   32,    0,    0,    0,  189,   33,    0,   72,   73,   34,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,   36,    0,   37,   75,    0,    0,   38,    0,    0,
   77,    0,   79,    0,   81,   39,   40,  258,    0,   41,
    0,    0,    0,    0,    0,    0,   87,    0,    0,   88,
   89,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,   90,   91,   92,   93,  794,    0,
    0,    0,    0,  795, 1074,    0,    0,   96,    0,    0,
    0,    0,    0,   98,   99,  100,  101,    0,    0,    0,
  102,    0,  103,    0,    0,    0,    0,    0,  104,  105,
    0,    0,    0,    0,    0,    0,   57,   24,    0,   25,
    0,    0,   26,  257,    0,    0,    0,   27,   62,   63,
    0,   28,    0,  106,  796,  108,  109,   65,    0,  797,
   30,    0,    0,    0,  798,    0,    0,   32,    0,    0,
    0,    0,   33,    0,   72,   73,   34,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,   36,    0,
   37,   75,    0,    0,   38,    0,    0,   77,    0,   79,
    0,   81,   39,   40,  258,    0,   41,    0,    0,    0,
    0,    0,    0,   87,    0,    0,   88,   89,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,   90,   91,   92,   93,  794,    0,    0,    0,    0,
  795,    0,    0,    0,   96,    0,    0,    0,    0,    0,
   98,   99,  100,  101,    0,    0,    0,  102,    0,  103,
    0,    0,    0,    0,    0,  104,  105,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,  812,
  106,  796,  108,  109,    0,    0,  797,   57,   24,    0,
   25,  798,    0,   26,  257,    0,    0,    0,   27,   62,
   63,    0,   28,    0,    0,  189,    0,  189,   65,    0,
  189,   30,    0,    0,    0,  189,    0,    0,   32,  189,
    0,    0,    0,   33,    0,   72,   73,   34,  189,    0,
    0,    0,    0,    0,    0,  189,    0,    0,    0,   36,
  189,   37,   75,    0,  189,   38,    0,    0,   77,    0,
   79,    0,   81,   39,   40,  258,  189,   41,  189,    0,
    0,    0,  189,    0,   87,    0,    0,   88,   89,    0,
  189,  189,    0,    0,  189,    0,    0,  189,    0,    0,
    0,    0,   90,   91,   92,   93,  306,    0,    0,    0,
    0,  543,  813,    0,    0,   96,    0,    0,    0,    0,
    0,   98,   99,  100,  101,    0,    0,    0,  102,    0,
  103, 1059,    0,    0,    0,    0,  104,  105,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,  999,    0,    0,
    0,  106,  307,  108,  109,   57,   24,    0,   25,    0,
    0,   26,  257,    0,    0,    0,   27,   62,   63,  189,
   28,    0,    0,   24,    0,   25,   65,    0,   26,   30,
    0,    0,    0,   27,    0,    0,   32,   28,    0,    0,
    0,   33,    0,   72,   73,   34,   30,  635,    0,    0,
    0,    0,    0,   32,  636,    0,    0,   36,   33,   37,
   75,    0,   34,   38,    0,    0,   77,    0,   79,    0,
   81,   39,   40,  258,   36,   41,   37,    0,    0,    0,
   38,    0,  637,    0,    0,   88,   89,    0,   39,   40,
    0,    0,   41,    0,    0,  328,    0,    0,    0,    0,
   90,   91,   92,   93,   94,    0,    0,    0,    0,    0,
    0,    0,    0,   96,    0,    0,    0,    0,    0,   98,
   99,  100,  101,    0,    0,    0,  102,    0,  103,    0,
    0,    0,    0,    0,  104,  105,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,  812,    0,    0,    0,  106,
  107,  108,  109,   57,   24,    0,   25,    0,    0,   26,
  257,    0,    0,    0,   27,   62,   63,  377,   28,    0,
    0,   24,    0,   25,   65,    0,   26,   30,    0,    0,
    0,   27,    0,    0,   32,   28,    0,    0,    0,   33,
    0,   72,   73,   34,   30,    0,    0,    0,    0,    0,
    0,   32,    0,    0,    0,   36,   33,   37,   75, 1005,
   34,   38,    0,    0,   77,    0,   79,    0,   81,   39,
   40,  258,   36,   41,   37,    0,    0,    0,   38,    0,
   87,    0,    0,   88,   89,    0,   39,   40,    0,    0,
   41,    0,    0,  545,    0,    0,    0,    0,   90,   91,
   92,   93,  306,    0,    0,    0,    0,  543,    0,    0,
    0,   96,    0,    0,    0,    0,    0,   98,   99,  100,
  101,    0,    0,    0,  102,    0,  103,    0,    0,    0,
    0,    0,  104,  105,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,  774,    0,    0,    0,  106,  307,  108,
  109,   57,   24,    0,   25,    0,    0,   26,  257,    0,
    0,    0,   27,   62,   63,  377,   28,    0,    0,   24,
    0,   25,   65,    0,   26,   30,    0,    0,    0,   27,
    0,    0,   32,   28,    0,    0,    0,   33,    0,   72,
   73,   34,   30,    0,    0,    0,    0,    0,    0,   32,
    0,    0,    0,   36,   33,   37,   75,    0,   34,   38,
    0,    0,   77,    0,   79,    0,   81,   39,   40,  258,
   36,   41,   37,    0,   85,    0,   38,    0,   87,    0,
    0,   88,   89,    0,   39,   40,    0,    0,   41,    0,
    0,  607,    0,    0,    0,    0,   90,   91,   92,   93,
  306,    0,    0,    0,    0,    0,    0,    0,    0,   96,
    0,    0,    0,    0,    0,   98,   99,  100,  101,    0,
    0,    0,  102,    0,  103,    0,    0,    0,    0,    0,
  104,  105,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,  812,    0,    0,    0,  106,  307,  108,  109,   57,
   24,    0,   25,    0,    0,   26,  257,    0,    0,    0,
   27,   62,   63,  377,   28,    0,    0,    0,    0,    0,
   65,    0,    0,   30,    0,    0,    0,    0,    0,    0,
   32,    0,    0,    0,    0,   33,    0,   72,   73,   34,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,   36,    0,   37,   75,    0,    0,   38,    0,    0,
   77,    0,   79,    0,   81,   39,   40,  258,    0,   41,
    0,    0,    0,    0,    0,    0,   87,    0,    0,   88,
   89,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,   90,   91,   92,   93,  306,    0,
    0,    0,    0,  543,    0,    0,    0,   96,    0,    0,
    0,    0,    0,   98,   99,  100,  101,    0,    0,    0,
  102,    0,  103,    0,    0,    0,    0,    0,  104,  105,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,  344,    0,  106,  307,  108,  109,  345,    0,   57,
   24,    0,   25,    0,    0,   26,  257,    0,    0,    0,
   27,   62,   63,    0,   28,    0,    0,    0,    0,    0,
   65,    0,    0,   30,    0,    0,    0,    0,    0,    0,
   32,    0,    0,  346,    0,   33,    0,   72,   73,   34,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,   36,    0,   37,   75,    0,    0,   38,    0,    0,
   77,    0,   79,    0,   81,   39,   40,  258,    0,   41,
    0,    0,    0,    0,    0,    0,    0,    0,  347,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,   90,   91,   92,  259,  348,    0,
    0,    0,    0,    0,    0,    0,    0,   96,    0,  349,
    0,    0,    0,   98,   99,  100,  101,  958,    0,    0,
  102,    0,  103,  804,    0,    0,    0,    0,  104,  105,
    0,   57,   24,    0,   25,    0,    0,   26,  257,    0,
    0,    0,   27,   62,   63,    0,   28,    0,    0,    0,
    0,    0,   65,  106,  261,   30,  109,    0,    0,    0,
    0,    0,   32,    0,    0,    0,    0,   33,    0,   72,
   73,   34,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,   36,    0,   37,   75,    0,    0,   38,
    0,    0,   77,    0,   79,    0,   81,   39,   40,  258,
    0,   41,    0,    0,    0,    0,    0,    0,   87,    0,
    0,   88,   89,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,   90,   91,   92,   93,
  306,    0,    0,    0,    0,    0,  959,    0,    0,   96,
    0,    0,    0,    0,    0,   98,   99,  100,  101,    0,
    0,    0,  102,    0,  103,    0,    0,    0,    0,    0,
  104,  105,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0, 1002,    0,    0,    0,  106,  307,  108,  109,   57,
   24,    0,   25,    0,    0,   26,  257,    0,    0,    0,
   27,   62,   63,    0,   28,    0,    0,   24,    0,   25,
   65,    0,   26,   30,    0,    0,    0,   27,    0,    0,
   32,   28,    0,    0,    0,   33,    0,   72,   73,   34,
   30,    0,    0,    0,    0,    0,    0,   32,    0,    0,
    0,   36,   33,   37,   75,    0,   34,   38,    0,    0,
   77,    0,   79,    0,   81,   39,   40,  258,   36,   41,
   37,    0,    0,    0,   38,    0,   87,    0,    0,   88,
   89,    0,   39,   40,    0,    0,   41,    0,    0,  560,
    0,    0,    0,    0,   90,   91,   92,   93,  306,    0,
    0,    0,    0,    0, 1003,    0,    0,   96,    0,    0,
    0,    0,    0,   98,   99,  100,  101,    0,    0,    0,
  102,    0,  103,    0,    0,    0,    0,    0,  104,  105,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,  305,
    0,    0,    0,  106,  307,  108,  109,   57,   24,    0,
   25,    0,    0,   26,  257,    0,    0,    0,   27,   62,
   63,  377,   28,    0,    0,  525,    0,  525,   65,    0,
  525,   30,    0,    0,    0,  525,    0,    0,   32,  525,
    0,    0,    0,   33,    0,   72,   73,   34,  525,    0,
    0,    0,    0,    0,    0,  525,    0,    0,    0,   36,
  525,   37,   75,    0,  525,   38,    0,    0,   77,    0,
   79,    0,   81,   39,   40,  258,  525,   41,  525,    0,
    0,    0,  525,    0,   87,    0,    0,   88,   89,    0,
  525,  525,    0,    0,  525,    0,    0,  525,    0,    0,
    0,    0,   90,   91,   92,   93,  306,    0,    0,    0,
    0,    0,    0,    0,    0,   96,    0,    0,    0,    0,
    0,   98,   99,  100,  101,    0,    0,    0,  102,    0,
  103,    0,    0,    0,    0,    0,  104,  105,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,  314,    0,    0,
    0,  106,  307,  108,  109,   57,   24,    0,   25,    0,
    0,   26,  257,    0,    0,    0,   27,   62,   63,  525,
   28,    0,    0,    0,    0,    0,   65,    0,    0,   30,
    0,    0,    0,    0,    0,    0,   32,    0,    0,    0,
    0,   33,    0,   72,   73,   34,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,   36,    0,   37,
   75,    0,    0,   38,    0,    0,   77,    0,   79,    0,
   81,   39,   40,  258,    0,   41,    0,    0,    0,    0,
    0,    0,   87,    0,    0,   88,   89,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
   90,   91,   92,   93,  306,    0,    0,    0,    0,    0,
    0,    0,    0,   96,    0,    0,    0,    0,    0,   98,
   99,  100,  101,    0,    0,    0,  102,    0,  103,    0,
    0,    0,    0,    0,  104,  105,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,  344,    0,  106,
  307,  108,  109,  345,    0,   57,   24,    0,   25,    0,
    0,   26,  257,    0,    0,    0,   27,   62,   63,    0,
   28,    0,    0,    0,    0,    0,   65,    0,    0,   30,
    0,    0,    0,    0,    0,    0,   32,    0,    0,  346,
    0,   33,    0,   72,   73,   34,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,   36,    0,   37,
   75,    0,    0,   38,    0,    0,   77,    0,   79,    0,
   81,   39,   40,  258,    0,   41,    0,    0,    0,    0,
    0,    0,    0,    0,  347,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
   90,   91,   92,  259,  348,    0,    0,    0,    0,    0,
    0,    0,    0,   96,    0,  349,    0,    0,    0,   98,
   99,  100,  101,    0,    0,    0,  102,    0,  103,  632,
    0,    0,    0,    0,  104,  105,    0,   57,   24,    0,
   25,    0,    0,   26,  257,    0,    0,    0,   27,   62,
   63,    0,   28,    0,    0,    0,    0,    0,   65,  106,
  261,   30,  109,    0,    0,    0,    0,    0,   32,    0,
    0,    0,    0,   33,    0,   72,   73,   34,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,   36,
    0,   37,   75,    0,    0,   38,    0,    0,   77,    0,
   79,    0,   81,   39,   40,  258,    0,   41,    0,    0,
    0,    0,    0,    0,   87,    0,    0,   88,   89,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,   90,   91,   92,   93,   94,    0,    0,    0,
    0,    0,    0,    0,    0,   96,    0,    0,    0,    0,
    0,   98,   99,  100,  101,    0,    0,    0,  102,    0,
  103,    0,    0,    0,    0,    0,  104,  105,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,  804,    0,    0,
    0,  106,  107,  108,  109,   57,   24,    0,   25,    0,
    0,   26,  257,    0,    0,    0,   27,   62,   63,    0,
   28,    0,    0,  190,    0,  190,   65,    0,  190,   30,
    0,    0,    0,  190,    0,    0,   32,  190,    0,    0,
    0,   33,    0,   72,   73,   34,  190,    0,    0,    0,
    0,    0,    0,  190,    0,    0,    0,   36,  190,   37,
   75,    0,  190,   38,    0,    0,   77,    0,   79,    0,
   81,   39,   40,  258,  190,   41,  190,    0,    0,    0,
  190,    0,   87,    0,    0,   88,   89,    0,  190,  190,
    0,    0,  190,    0,    0,  190,    0,    0,    0,    0,
   90,   91,   92,   93,  306,    0,    0,    0,    0,    0,
    0,    0,    0,   96,    0,    0,    0,    0,    0,   98,
   99,  100,  101,    0,    0,    0,  102,    0,  103,    0,
    0,    0,    0,    0,  104,  105,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0, 1110,    0,    0,    0,  106,
  307,  108,  109,   57,   24,    0,   25,    0,    0,   26,
  257,    0,    0,    0,   27,   62,   63,  190,   28,    0,
    0,  189,    0,  189,   65,    0,  189,   30,    0,    0,
    0,  189,    0,    0,   32,  189,    0,    0,    0,   33,
    0,   72,   73,   34,  189,    0,    0,    0,    0,    0,
    0,  189,    0,    0,    0,   36,  189,   37,   75,    0,
  189,   38,    0,    0,   77,    0,   79,    0,   81,   39,
   40,  258,  189,   41,  189,    0,    0,    0,  189,    0,
   87,    0,    0,   88,   89,    0,  189,  189,    0,    0,
  189,    0,    0,  189,    0,    0,    0,    0,   90,   91,
   92,   93,   94,    0,    0,    0,    0,    0,    0,    0,
    0,   96,    0,    0,    0,    0,    0,   98,   99,  100,
  101,    0,    0,    0,  102,    0,  103,    0,    0,    0,
    0,    0,  104,  105,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,   83,    0,    0,    0,  106, 1111,  108,
  109,   83,   83,    0,   83,    0,    0,   83,   83,    0,
    0,    0,   83,   83,   83,  189,   83,    0,    0,    0,
    0,    0,   83,    0,    0,   83,    0,    0,    0,    0,
    0,    0,   83,    0,    0,    0,    0,   83,    0,   83,
   83,   83,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,   83,    0,   83,   83,    0,    0,   83,
    0,    0,   83,    0,   83,    0,   83,   83,   83,   83,
    0,   83,    0,    0,    0,    0,    0,    0,   83,    0,
    0,   83,   83,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,   83,   83,   83,   83,
   83,    0,    0,    0,    0,    0,    0,    0,    0,   83,
    0,    0,    0,    0,    0,   83,   83,   83,   83,    0,
    0,    0,   83,    0,   83,    0,    0,    0,    0,    0,
   83,   83,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,  344,    0,   83,   83,   83,   83,  345,
    0,   57,   24,    0,   25,    0,    0,   26,  257,    0,
    0,    0,   27,   62,   63,    0,   28,    0,    0,    0,
    0,    0,   65,    0,    0,   30,    0,    0,    0,    0,
    0,    0,   32,    0,    0,  346,    0,   33,    0,   72,
   73,   34,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,   36,    0,   37,   75,    0,    0,   38,
    0,    0,   77,    0,   79,    0,   81,   39,   40,  258,
    0,   41,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,   90,   91,   92,  259,
  348,    0,    0,    0,    0,    0,    0,    0,    0,   96,
    0,  349,    0,    0,    0,   98,   99,  100,  101,    0,
    0,    0,  102,    0,  103,  344,    0,    0,    0,    0,
  104,  105,    0,   57,   24,    0,   25,    0,    0,   26,
  257,    0,    0,    0,   27,   62,   63,    0,   28,    0,
    0,    0,    0,    0,   65,  106,  261,   30,  109,    0,
    0,    0,    0,    0,   32,    0,    0,    0,    0,   33,
    0,   72,   73,   34,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,   36,    0,   37,   75,    0,
    0,   38,    0,    0,   77,    0,   79,    0,   81,   39,
   40,  258,    0,   41,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,   90,   91,
   92,  259,  348,    0,    0,    0,    0,    0,    0,    0,
    0,   96,    0,  349,    0,    0,    0,   98,   99,  100,
  101,    0,    0,    0,  102,    0,  103,  353,    0,    0,
    0,    0,  104,  105,    0,   57,   24,    0,   25,    0,
    0,   26,  257,    0,    0,    0,   27,   62,   63,    0,
   28,    0,    0,    0,    0,    0,   65,  106,  261,   30,
  109,    0,    0,    0,    0,    0,   32,    0,    0,    0,
    0,   33,    0,   72,   73,   34,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,   36,    0,   37,
   75,    0,    0,   38,    0,    0,   77,    0,   79,    0,
   81,   39,   40,  258,    0,   41,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
   90,   91,   92,  259,  348,    0,    0,    0,    0,    0,
    0,    0,    0,   96,    0,    0,    0,    0,    0,   98,
   99,  100,  101,    0,    0,    0,  102,    0,  103,  355,
    0,    0,    0,    0,  104,  105,    0,   57,   24,    0,
   25,    0,    0,   26,  257,    0,    0,    0,   27,   62,
   63,    0,   28,    0,    0,    0,    0,    0,   65,  106,
  261,   30,  109,    0,    0,    0,    0,    0,   32,    0,
    0,    0,    0,   33,    0,   72,   73,   34,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,   36,
    0,   37,   75,    0,    0,   38,    0,    0,   77,    0,
   79,    0,   81,   39,   40,  258,    0,   41,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,   90,   91,   92,  259,  348,    0,    0,    0,
    0,    0,    0,    0,    0,   96,    0,    0,    0,    0,
    0,   98,   99,  100,  101,    0,    0,    0,  102,    0,
  103,  357,    0,    0,    0,    0,  104,  105,    0,   57,
   24,    0,   25,    0,    0,   26,  257,    0,    0,    0,
   27,   62,   63,    0,   28,    0,    0,    0,    0,    0,
   65,  106,  261,   30,  109,    0,    0,    0,    0,    0,
   32,    0,    0,    0,    0,   33,    0,   72,   73,   34,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,   36,    0,   37,   75,    0,    0,   38,    0,    0,
   77,    0,   79,    0,   81,   39,   40,  258,    0,   41,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,   90,   91,   92,  259,  348,    0,
    0,    0,    0,    0,    0,    0,    0,   96,    0,    0,
    0,    0,    0,   98,   99,  100,  101,    0,    0,    0,
  102,    0,  103,  359,    0,    0,    0,    0,  104,  105,
    0,   57,   24,    0,   25,    0,    0,   26,  257,    0,
    0,    0,   27,   62,   63,    0,   28,    0,    0,    0,
    0,    0,   65,  106,  261,   30,  109,    0,    0,    0,
    0,    0,   32,    0,    0,    0,    0,   33,    0,   72,
   73,   34,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,   36,    0,   37,   75,    0,    0,   38,
    0,    0,   77,    0,   79,    0,   81,   39,   40,  258,
    0,   41,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,   90,   91,   92,  259,
  348,    0,    0,    0,    0,    0,    0,    0,    0,   96,
    0,    0,    0,    0,    0,   98,   99,  100,  101,    0,
    0,    0,  102,    0,  103,  361,    0,    0,    0,    0,
  104,  105,    0,   57,   24,    0,   25,    0,    0,   26,
  257,    0,    0,    0,   27,   62,   63,    0,   28,    0,
    0,    0,    0,    0,   65,  106,  261,   30,  109,    0,
    0,    0,    0,    0,   32,    0,    0,    0,    0,   33,
    0,   72,   73,   34,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,   36,    0,   37,   75,    0,
    0,   38,    0,    0,   77,    0,   79,    0,   81,   39,
   40,  258,    0,   41,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,   90,   91,
   92,  259,  348,    0,    0,    0,    0,    0,    0,    0,
    0,   96,    0,    0,    0,    0,    0,   98,   99,  100,
  101,    0,    0,    0,  102,    0,  103,  363,    0,    0,
    0,    0,  104,  105,    0,   57,   24,    0,   25,    0,
    0,   26,  257,    0,    0,    0,   27,   62,   63,    0,
   28,    0,    0,    0,    0,    0,   65,  106,  261,   30,
  109,    0,    0,    0,    0,    0,   32,    0,    0,    0,
    0,   33,    0,   72,   73,   34,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,   36,    0,   37,
   75,    0,    0,   38,    0,    0,   77,    0,   79,    0,
   81,   39,   40,  258,    0,   41,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
   90,   91,   92,  259,  348,    0,    0,    0,    0,    0,
    0,    0,    0,   96,    0,    0,    0,    0,    0,   98,
   99,  100,  101,    0,    0,    0,  102,    0,  103,  365,
    0,    0,    0,    0,  104,  105,    0,   57,   24,    0,
   25,    0,    0,   26,  257,    0,    0,    0,   27,   62,
   63,    0,   28,    0,    0,    0,    0,    0,   65,  106,
  261,   30,  109,    0,    0,    0,    0,    0,   32,    0,
    0,    0,    0,   33,    0,   72,   73,   34,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,   36,
    0,   37,   75,    0,    0,   38,    0,    0,   77,    0,
   79,    0,   81,   39,   40,  258,    0,   41,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,   90,   91,   92,  259,  348,    0,    0,    0,
    0,    0,    0,    0,    0,   96,    0,    0,    0,    0,
    0,   98,   99,  100,  101,    0,    0,    0,  102,    0,
  103,  367,    0,    0,    0,    0,  104,  105,    0,   57,
   24,    0,   25,    0,    0,   26,  257,    0,    0,    0,
   27,   62,   63,    0,   28,    0,    0,    0,    0,    0,
   65,  106,  261,   30,  109,    0,    0,    0,    0,    0,
   32,    0,    0,    0,    0,   33,    0,   72,   73,   34,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,   36,    0,   37,   75,    0,    0,   38,    0,    0,
   77,    0,   79,    0,   81,   39,   40,  258,    0,   41,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,   90,   91,   92,  259,  348,    0,
    0,    0,    0,    0,    0,    0,    0,   96,    0,    0,
    0,    0,    0,   98,   99,  100,  101,    0,    0,    0,
  102,    0,  103,  657,    0,    0,    0,    0,  104,  105,
    0,   57,   24,    0,   25,    0,    0,   26,  257,    0,
    0,    0,   27,   62,   63,    0,   28,    0,    0,    0,
    0,    0,   65,  106,  261,   30,  109,    0,    0,    0,
    0,    0,   32,    0,    0,    0,    0,   33,    0,   72,
   73,   34,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,   36,    0,   37,   75,    0,    0,   38,
    0,    0,   77,    0,   79,    0,   81,   39,   40,  258,
    0,   41,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,   90,   91,   92,  259,
  348,    0,    0,    0,    0,    0,    0,    0,    0,   96,
    0,    0,    0,    0,    0,   98,   99,  100,  101,    0,
    0,    0,  102,    0,  103,  659,    0,    0,    0,    0,
  104,  105,    0,   57,   24,    0,   25,    0,    0,   26,
  257,    0,    0,    0,   27,   62,   63,    0,   28,    0,
    0,    0,    0,    0,   65,  106,  261,   30,  109,    0,
    0,    0,    0,    0,   32,    0,    0,    0,    0,   33,
    0,   72,   73,   34,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,   36,    0,   37,   75,    0,
    0,   38,    0,    0,   77,    0,   79,    0,   81,   39,
   40,  258,    0,   41,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,   90,   91,
   92,  259,  348,    0,    0,    0,    0,    0,    0,    0,
    0,   96,    0,    0,    0,    0,    0,   98,   99,  100,
  101,    0,    0,    0,  102,    0,  103,  661,    0,    0,
    0,    0,  104,  105,    0,   57,   24,    0,   25,    0,
    0,   26,  257,    0,    0,    0,   27,   62,   63,    0,
   28,    0,    0,    0,    0,    0,   65,  106,  261,   30,
  109,    0,    0,    0,    0,    0,   32,    0,    0,    0,
    0,   33,    0,   72,   73,   34,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,   36,    0,   37,
   75,    0,    0,   38,    0,    0,   77,    0,   79,    0,
   81,   39,   40,  258,    0,   41,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
   90,   91,   92,  259,  348,    0,    0,    0,    0,    0,
    0,    0,    0,   96,    0,    0,    0,    0,    0,   98,
   99,  100,  101,    0,    0,    0,  102,    0,  103,  667,
    0,    0,    0,    0,  104,  105,    0,   57,   24,    0,
   25,    0,    0,   26,  257,    0,    0,    0,   27,   62,
   63,    0,   28,    0,    0,    0,    0,    0,   65,  106,
  261,   30,  109,    0,    0,    0,    0,    0,   32,    0,
    0,    0,    0,   33,    0,   72,   73,   34,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,   36,
    0,   37,   75,    0,    0,   38,    0,    0,   77,    0,
   79,    0,   81,   39,   40,  258,    0,   41,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,   90,   91,   92,  259,  348,    0,    0,    0,
    0,    0,    0,    0,    0,   96,    0,    0,    0,    0,
    0,   98,   99,  100,  101,    0,    0,    0,  102,    0,
  103,  669,    0,    0,    0,    0,  104,  105,    0,   57,
   24,    0,   25,    0,    0,   26,  257,    0,    0,    0,
   27,   62,   63,    0,   28,    0,    0,    0,    0,    0,
   65,  106,  261,   30,  109,    0,    0,    0,    0,    0,
   32,    0,    0,    0,    0,   33,    0,   72,   73,   34,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,   36,    0,   37,   75,    0,    0,   38,    0,    0,
   77,    0,   79,    0,   81,   39,   40,  258,    0,   41,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,   90,   91,   92,  259,  348,    0,
    0,    0,    0,    0,    0,    0,    0,   96,    0,    0,
    0,    0,    0,   98,   99,  100,  101,    0,    0,    0,
  102,    0,  103,  671,    0,    0,    0,    0,  104,  105,
    0,   57,   24,    0,   25,    0,    0,   26,  257,    0,
    0,    0,   27,   62,   63,    0,   28,    0,    0,    0,
    0,    0,   65,  106,  261,   30,  109,    0,    0,    0,
    0,    0,   32,    0,    0,    0,    0,   33,    0,   72,
   73,   34,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,   36,    0,   37,   75,    0,    0,   38,
    0,    0,   77,    0,   79,    0,   81,   39,   40,  258,
    0,   41,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,   90,   91,   92,  259,
  672,    0,    0,    0,    0,    0,    0,    0,    0,   96,
    0,    0,    0,    0,    0,   98,   99,  100,  101,    0,
    0,    0,  102,    0,  103,  674,    0,    0,    0,    0,
  104,  105,    0,   57,   24,    0,   25,    0,    0,   26,
  257,    0,    0,    0,   27,   62,   63,    0,   28,    0,
    0,    0,    0,    0,   65,  106,  261,   30,  109,    0,
    0,    0,    0,    0,   32,    0,    0,    0,    0,   33,
    0,   72,   73,   34,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,   36,    0,   37,   75,    0,
    0,   38,    0,    0,   77,    0,   79,    0,   81,   39,
   40,  258,    0,   41,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,   90,   91,
   92,  259,  672,    0,    0,    0,    0,    0,    0,    0,
    0,   96,    0,    0,    0,    0,    0,   98,   99,  100,
  101,    0,    0,    0,  102,    0,  103,  676,    0,    0,
    0,    0,  104,  105,    0,   57,   24,    0,   25,    0,
    0,   26,  257,    0,    0,    0,   27,   62,   63,    0,
   28,    0,    0,    0,    0,    0,   65,  106,  261,   30,
  109,    0,    0,    0,    0,    0,   32,    0,    0,    0,
    0,   33,    0,   72,   73,   34,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,   36,    0,   37,
   75,    0,    0,   38,    0,    0,   77,    0,   79,    0,
   81,   39,   40,  258,    0,   41,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
   90,   91,   92,  259,  672,    0,    0,    0,    0,    0,
    0,    0,    0,   96,    0,    0,    0,    0,    0,   98,
   99,  100,  101,    0,    0,    0,  102,    0,  103,  678,
    0,    0,    0,    0,  104,  105,    0,   57,   24,    0,
   25,    0,    0,   26,  257,    0,    0,    0,   27,   62,
   63,    0,   28,    0,    0,    0,    0,    0,   65,  106,
  261,   30,  109,    0,    0,    0,    0,    0,   32,    0,
    0,    0,    0,   33,    0,   72,   73,   34,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,   36,
    0,   37,   75,    0,    0,   38,    0,    0,   77,    0,
   79,    0,   81,   39,   40,  258,    0,   41,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,   90,   91,   92,  259,  672,    0,    0,    0,
    0,    0,    0,    0,    0,   96,    0,    0,    0,    0,
    0,   98,   99,  100,  101,    0,    0,    0,  102,    0,
  103,  680,    0,    0,    0,    0,  104,  105,    0,   57,
   24,    0,   25,    0,    0,   26,  257,    0,    0,    0,
   27,   62,   63,    0,   28,    0,    0,    0,    0,    0,
   65,  106,  261,   30,  109,    0,    0,    0,    0,    0,
   32,    0,    0,    0,    0,   33,    0,   72,   73,   34,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,   36,    0,   37,   75,    0,    0,   38,    0,    0,
   77,    0,   79,    0,   81,   39,   40,  258,    0,   41,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,   90,   91,   92,  259,  672,    0,
    0,    0,    0,    0,    0,    0,    0,   96,    0,    0,
    0,    0,    0,   98,   99,  100,  101,    0,    0,    0,
  102,    0,  103,  682,    0,    0,    0,    0,  104,  105,
    0,   57,   24,    0,   25,    0,    0,   26,  257,    0,
    0,    0,   27,   62,   63,    0,   28,    0,    0,    0,
    0,    0,   65,  106,  261,   30,  109,    0,    0,    0,
    0,    0,   32,    0,    0,    0,    0,   33,    0,   72,
   73,   34,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,   36,    0,   37,   75,    0,    0,   38,
    0,    0,   77,    0,   79,    0,   81,   39,   40,  258,
    0,   41,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,   90,   91,   92,  259,
  672,    0,    0,    0,    0,    0,    0,    0,    0,   96,
    0,    0,    0,    0,    0,   98,   99,  100,  101,    0,
    0,    0,  102,    0,  103,  684,    0,    0,    0,    0,
  104,  105,    0,   57,   24,    0,   25,    0,    0,   26,
  257,    0,    0,    0,   27,   62,   63,    0,   28,    0,
    0,    0,    0,    0,   65,  106,  261,   30,  109,    0,
    0,    0,    0,    0,   32,    0,    0,    0,    0,   33,
    0,   72,   73,   34,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,   36,    0,   37,   75,    0,
    0,   38,    0,    0,   77,    0,   79,    0,   81,   39,
   40,  258,    0,   41,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,   90,   91,
   92,  259,  672,    0,    0,    0,    0,    0,    0,    0,
    0,   96,    0,    0,    0,    0,    0,   98,   99,  100,
  101,    0,    0,    0,  102,    0,  103,  686,    0,    0,
    0,    0,  104,  105,    0,   57,   24,    0,   25,    0,
    0,   26,  257,    0,    0,    0,   27,   62,   63,    0,
   28,    0,    0,    0,    0,    0,   65,  106,  261,   30,
  109,    0,    0,    0,    0,    0,   32,    0,    0,    0,
    0,   33,    0,   72,   73,   34,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,   36,    0,   37,
   75,    0,    0,   38,    0,    0,   77,    0,   79,    0,
   81,   39,   40,  258,    0,   41,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
   90,   91,   92,  259,  672,    0,    0,    0,    0,    0,
    0,    0,    0,   96,    0,    0,    0,    0,    0,   98,
   99,  100,  101,    0,    0,    0,  102,    0,  103,  688,
    0,    0,    0,    0,  104,  105,    0,   57,   24,    0,
   25,    0,    0,   26,  257,    0,    0,    0,   27,   62,
   63,    0,   28,    0,    0,    0,    0,    0,   65,  106,
  261,   30,  109,    0,    0,    0,    0,    0,   32,    0,
    0,    0,    0,   33,    0,   72,   73,   34,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,   36,
    0,   37,   75,    0,    0,   38,    0,    0,   77,    0,
   79,    0,   81,   39,   40,  258,    0,   41,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,   90,   91,   92,  259,  672,    0,    0,    0,
    0,    0,    0,    0,    0,   96,    0,    0,    0,    0,
    0,   98,   99,  100,  101,    0,    0,    0,  102,    0,
  103,  690,    0,    0,    0,    0,  104,  105,    0,   57,
   24,    0,   25,    0,    0,   26,  257,    0,    0,    0,
   27,   62,   63,    0,   28,    0,    0,    0,    0,    0,
   65,  106,  261,   30,  109,    0,    0,    0,    0,    0,
   32,    0,    0,    0,    0,   33,    0,   72,   73,   34,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,   36,    0,   37,   75,    0,    0,   38,    0,    0,
   77,    0,   79,    0,   81,   39,   40,  258,    0,   41,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,   90,   91,   92,  259,  672,    0,
    0,    0,    0,    0,    0,    0,    0,   96,    0,    0,
    0,    0,    0,   98,   99,  100,  101,    0,    0,    0,
  102,    0,  103,  692,    0,    0,    0,    0,  104,  105,
    0,   57,   24,    0,   25,    0,    0,   26,  257,    0,
    0,    0,   27,   62,   63,    0,   28,    0,    0,    0,
    0,    0,   65,  106,  261,   30,  109,    0,    0,    0,
    0,    0,   32,    0,    0,    0,    0,   33,    0,   72,
   73,   34,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,   36,    0,   37,   75,    0,    0,   38,
    0,    0,   77,    0,   79,    0,   81,   39,   40,  258,
    0,   41,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,   90,   91,   92,  259,
  672,    0,    0,    0,    0,    0,    0,    0,    0,   96,
    0,    0,    0,    0,    0,   98,   99,  100,  101,    0,
    0,    0,  102,    0,  103,  694,    0,    0,    0,    0,
  104,  105,    0,   57,   24,    0,   25,    0,    0,   26,
  257,    0,    0,    0,   27,   62,   63,    0,   28,    0,
    0,    0,    0,    0,   65,  106,  261,   30,  109,    0,
    0,    0,    0,    0,   32,    0,    0,    0,    0,   33,
    0,   72,   73,   34,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,   36,    0,   37,   75,    0,
    0,   38,    0,    0,   77,    0,   79,    0,   81,   39,
   40,  258,    0,   41,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,   90,   91,
   92,  259,  672,    0,    0,    0,    0,    0,    0,    0,
    0,   96,    0,    0,    0,    0,    0,   98,   99,  100,
  101,    0,    0,    0,  102,    0,  103,  696,    0,    0,
    0,    0,  104,  105,    0,   57,   24,    0,   25,    0,
    0,   26,  257,    0,    0,    0,   27,   62,   63,    0,
   28,    0,    0,    0,    0,    0,   65,  106,  261,   30,
  109,    0,    0,    0,    0,    0,   32,    0,    0,    0,
    0,   33,    0,   72,   73,   34,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,   36,    0,   37,
   75,    0,    0,   38,    0,    0,   77,    0,   79,    0,
   81,   39,   40,  258,    0,   41,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
   90,   91,   92,  259,  672,    0,    0,    0,    0,    0,
    0,    0,    0,   96,    0,    0,    0,    0,    0,   98,
   99,  100,  101,    0,    0,    0,  102,    0,  103,  861,
    0,    0,    0,    0,  104,  105,    0,   57,   24,    0,
   25,    0,    0,   26,  257,    0,    0,    0,   27,   62,
   63,    0,   28,    0,    0,    0,    0,    0,   65,  106,
  261,   30,  109,    0,    0,    0,    0,    0,   32,    0,
    0,    0,    0,   33,    0,   72,   73,   34,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,   36,
    0,   37,   75,    0,    0,   38,    0,    0,   77,    0,
   79,    0,   81,   39,   40,  258,    0,   41,  199,    0,
  199,    0,    0,  199,    0,    0,    0,    0,  199,    0,
    0,    0,  199,    0,    0,    0,    0,    0,    0,    0,
    0,  199,   90,   91,   92,  259,  348,    0,  199,    0,
    0,    0,    0,  199,    0,   96,    0,  199,    0,    0,
    0,   98,   99,  100,  101,    0,    0,    0,  102,  199,
  103,  199,    0,    0,    0,  199,  104,  105,    0,    0,
    0,    0,    0,  199,  199,    0,    0,  199,    0,  210,
  199,    0,    0,    0,  210,    0,    0,    0,  210,    0,
  210,  106,  261,  210,  109,  210,  210,    0,  210,    0,
  210,    0,  210,    0,  210,  210,  210,  210,    0,    0,
  210,  210,    0,    0,    0,    0,  210,    0,  210,  210,
  210,    0,    0,  210,    0,  210,    0,  210,    0,    0,
  210,    0,  210,  210,  210,  210,    0,    0,    0,  210,
  210,  210,    0,    0,  210,  210,  210,    0,    0,    0,
    0,    0,    0,  210,  210,    0,  210,  210,  522,  210,
  210,  210,  199,    0,    0,  210,   57,   24,    0,   25,
    0,    0,   26,  257,    0,    0,    0,   27,   62,   63,
    0,   28,    0,    0,    0,  210,    0,   65,    0,    0,
   30,  210,  210,  210,    0,    0,    0,   32,    0,    0,
    0,  210,   33,    0,   72,   73,   34,    0,    0,    0,
    0,    0,  364,    0,    0,    0,    0,    0,   36,    0,
   37,   75,    0,    0,   38,    0,    0,   77,    0,   79,
  474,   81,   39,   40,  258,    0,   41,    0,    0,    0,
    0,    0,  210,    0,    0,    0,    0,    0,  364,    0,
    0,    0,    0,  475,    0,    0,    0,    0,    0,    0,
    0,   90,   91,   92,  259,  523,  476,    0,    0,    0,
  477,  478,    0,    0,   96,    0,  479,    0,  480,  481,
  482,  483,    0,    0,    0,    0,  484,    0,    0,    0,
  485,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,  486,    0,    0,  487,    0,  488,    0,    0,
    0,    0,    0,    0,  364,    0,    0,    0,    0,    0,
  106,  524,  364,  364,  364,  364,  823,    0,    0,  364,
  364,  489,    0,  364,  364,  364,  364,  364,  364,  364,
  364,  364,    0,  364,  364,  364,  364,  364,  364,  364,
  364,  364,  364,  364,  364,  364,  364,  364,  364,  364,
  364,  364,  364,  364,  364,    0,   52,    0,   52,    0,
   52,  364,   52,    0,  364,   52,    0,   52,   52,    0,
   52,    0,   52,    0,   52,    0,   52,   52,   52,   52,
    0,    0,   52,   52,    0,    0,    0,    0,   52,   52,
   52,   52,   52,    0,    0,   52,    0,   52,    0,   52,
    0,   52,   52,    0,   52,   52,   52,   52,    0,    0,
   52,   52,   52,   52,    0,    0,   52,   52,   52,    0,
    0,    0,    0,    0,    0,   52,   52,    0,   52,   52,
    0,   52,   52,   52,    0,    0,    0,   52,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,   52,    0,    0,
   52,   52,   51,    0,    0,    0,   51,    0,   51,    0,
    0,   51,    0,   51,   51,    0,   51,    0,   51,    0,
   51,    0,   51,   51,   51,   51,    0,    0,   51,   51,
    0,    0,    0,    0,   51,    0,   51,   51,   51,    0,
    0,   51,    0,   51,    0,   51,    0,    0,   51,    0,
   51,   51,   51,   51,   52,    0,    0,   51,   51,   51,
    0,    0,   51,   51,   51,    0,    0,    0,    0,    0,
    0,   51,   51,    0,   51,   51,    0,   51,   51,   51,
    0,    0,    0,   51,    0,    0,   51,    0,    0,    0,
   51,    0,   51,    0,    0,   51,    0,   51,   51,    0,
   51,    0,   51,   51,   51,    0,   51,   51,   51,   51,
   86,    0,   51,   51,    0,    0,    0,    0,   51,   51,
   51,   51,   51,    0,    0,   51,    0,   51,    0,   51,
    0,    0,   51,    0,   51,   51,   51,   51,    0,    0,
    0,   51,   51,   51,    0,    0,   51,   51,   51,    0,
    0,    0,    0,    0,    0,   51,   51,    0,   51,   51,
   51,   51,   51,   51,    0,    0,    0,   51,    0,    0,
   52,    0,    0,    0,   52,    0,   52,    0,    0,   52,
    0,   52,   52,    0,   52,    0,   52,   51,   52,    0,
   52,   52,   52,   52,   87,    0,   52,   52,    0,    0,
    0,    0,   52,   51,   52,   52,   52,    0,    0,   52,
    0,   52,    0,   52,    0,    0,   52,    0,   52,   52,
   52,   52,    0,    0,    0,   52,   52,   52,    0,    0,
   52,   52,   52,    0,    0,    0,    0,    0,    0,   52,
   52,    0,   52,   52,   51,   52,   52,   52,    0,    0,
    0,   52,    0,    0,   51,    0,    0,    0,   51,    0,
   51,    0,    0,   51,    0,   51,   51,    0,   51,    0,
   51,   52,   51,    0,   51,   51,   51,   51,    0,    0,
   51,   51,    0,    0,    0,    0,   51,   52,   51,   51,
   51,    0,    0,   51,    0,   51,    0,   51,    0,    0,
   51,    0,   51,   51,   51,   51,    0,    0,    0,   51,
   51,   51,    0,    0,   51,   51,   51,    0,    0,    0,
    0,    0,    0,   51,   51,    0,   51,   51,   52,   51,
   51,   51,    0,    0,    0,   51,    0,    0,   51,    0,
    0,    0,   51,    0,   51,    0,    0,   51,    0,   51,
   51,    0,   51,    0,   51,   51,   51,    0,   51,   51,
   51,   51,  238,    0,   51,   51,    0,    0,    0,    0,
   51,    0,   51,   51,   51,    0,    0,   51,    0,   51,
  364,   51,    0,    0,   51,    0,   51,   51,   51,   51,
    0,    0,    0,   51,   51,   51,    0,    0,   51,   51,
   51,    0,    0,  364,    0,    0,    0,   51,   51,    0,
   51,   51,   51,   51,   51,   51,  364,    0,    0,   51,
    0,  364,    0,    0,  364,    0,  364,    0,  364,  364,
  364,  364,    0,    0,    0,    0,  364,    0,    0,   51,
  364,    0,    0,    0,  364,    0,  239,    0,    0,    0,
    0,    0,  364,    0,    0,  364,    0,  364,    0,   57,
   24,    0,   25,    0,    0,   26,  257,    0,    0,    0,
   27,   62,   63,    0,   28,    0,  364,    0,    0,    0,
   65,  364,    0,   30,    0,    0,    0,    0,  364,  364,
   32,  287,    0,  364,    0,   33,   51,   72,   73,   34,
    0,  635,    0,    0,    0,    0,  364,    0,  636,    0,
    0,   36,    0,   37,   75,    0,    0,   38,    0,    0,
   77,    0,   79,    0,   81,   39,   40,  258,    0,   41,
    0,    0,    0,    0,    0,    0,  637,    0,  364,   88,
   89,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,   90,   91,   92,   93,   94,    0,
    0,    0,    0,    0,    0,    0,    0,   96,  997,    0,
  638,    0,    0,   98,   99,  100,  101,    0,    0,    0,
  102,    0,  103,    0,    0,    0,    0,    0,  104,  105,
    0,    0,    0,    0,    0,    0,   57,   24,    0,   25,
    0,    0,   26,  257,    0,    0,    0,   27,   62,   63,
    0,   28,    0,  106,  107,  108,  109,   65,    0,    0,
   30,    0,    0,    0,    0,    0,    0,   32,    0,    0,
    0,    0,   33,    0,   72,   73,   34,    0,  635,    0,
    0,    0,    0,    0,    0,  636,    0,    0,   36,    0,
   37,   75,    0,    0,   38,    0,    0,   77,    0,   79,
    0,   81,   39,   40,  258,    0,   41,    0,    0,    0,
    0,    0,    0,  637,    0,    0,   88,   89,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,   90,   91,   92,   93,   94,    0,    0,    0,    0,
    0,    0,    0,    0,   96,    0,    0,  638,    0,    0,
   98,   99,  100,  101,    0,    0,    0,  102,    0,  103,
    0,    0,    0,    0,    0,  104,  105,    0,    0,    0,
    0,    0,    0,   57,   24,    0,   25,    0,    0,   26,
  257,    0,    0,    0,   27,   62,   63,    0,   28,    0,
  106,  107,  108,  109,   65,    0,    0,   30,    0,    0,
    0,    0,    0,    0,   32,    0,    0,    0,    0,   33,
    0,   72,   73,   34,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,   36,    0,   37,   75,    0,
    0,   38,    0,    0,   77,    0,   79,    0,   81,   39,
   40,  258,    0,   41,    0,    0,   85,    0,    0,    0,
   87,    0,    0,   88,   89,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,   90,   91,
   92,   93,  306,    0,    0,    0,    0,    0,    0,    0,
    0,   96,    0,    0,    0,    0,    0,   98,   99,  100,
  101,    0,    0,    0,  102,    0,  103,    0,    0,    0,
    0,    0,  104,  105,    0,    0,    0,    0,    0,    0,
   57,   24,    0,   25,    0,    0,   26,  257,    0,    0,
    0,   27,   62,   63,    0,   28,    0,  106,  307,  108,
  109,   65,    0,    0,   30,    0,    0,    0,    0,    0,
    0,   32,    0,    0,    0,    0,   33,    0,   72,   73,
   34,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,   36,    0,   37,   75,    0,    0,   38,    0,
    0,   77,    0,   79,    0,   81,   39,   40,  258,    0,
   41,    0,    0,    0,    0,    0,    0,   87,    0,    0,
   88,   89,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,   90,   91,   92,   93,  306,
    0,    0,    0,    0,  543,    0,    0,    0,   96,    0,
    0,    0,    0,    0,   98,   99,  100,  101,    0,    0,
    0,  102,    0,  103,    0,    0,    0,    0,    0,  104,
  105,    0,    0,    0,    0,    0,    0,   57,   24,    0,
   25,    0,    0,   26,  257,    0,    0,    0,   27,   62,
   63,    0,   28,    0,  106,  307,  108,  109,   65,    0,
    0,   30,    0,    0,    0,    0,    0,    0,   32,    0,
    0,    0,    0,   33,    0,   72,   73,   34,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,   36,
    0,   37,   75,    0,    0,   38,    0,    0,   77,    0,
   79,    0,   81,   39,   40,  258,    0,   41,    0,    0,
    0,    0,    0,    0,   87,    0,    0,   88,   89,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,   90,   91,   92,   93,  306,    0,    0,    0,
    0,  537,    0,    0,    0,   96,    0,    0,    0,    0,
    0,   98,   99,  100,  101,    0,    0,    0,  102,    0,
  103,    0,    0,    0,    0,    0,  104,  105,    0,    0,
    0,    0,    0,    0,   57,   24,    0,   25,    0,    0,
   26,  257,    0,    0,    0,   27,   62,   63,    0,   28,
    0,  106,  307,  108,  109,   65,    0,    0,   30,    0,
    0,    0,    0,    0,    0,   32,    0,    0,    0,    0,
   33,    0,   72,   73,   34,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,   36,    0,   37,   75,
    0,    0,   38,    0,    0,   77,    0,   79,    0,   81,
   39,   40,  258,    0,   41,    0,    0,    0,    0,    0,
    0,   87,    0,    0,   88,   89,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,   90,
   91,   92,   93,  306,    0,    0,    0,    0,    0,    0,
    0,    0,   96,    0,    0,    0,    0,    0,   98,   99,
  100,  101,    0,    0,    0,  102,    0,  103,    0,    0,
    0,    0,    0,  104,  105,    0,    0,    0,    0,    0,
    0,   57,   24,    0,   25,    0,    0,   26,  257,    0,
    0,    0,   27,   62,   63,    0,   28,    0,  106,  307,
  108,  109,   65,    0,    0,   30,    0,    0,    0,    0,
    0,    0,   32,    0,    0,    0,    0,   33,    0,   72,
   73,   34,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,   36,    0,   37,   75,    0,    0,   38,
    0,    0,   77,    0,   79,    0,   81,   39,   40,  258,
    0,   41,    0,    0,    0,    0,    0,    0,   87,    0,
    0,   88,   89,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,   90,   91,   92,   93,
   94,    0,    0,    0,    0,    0,    0,    0,    0,   96,
    0,    0,    0,    0,    0,   98,   99,  100,  101,    0,
    0,    0,  102,    0,  103,    0,    0,    0,    0,    0,
  104,  105,    0,    0,    0,    0,    0,    0,  676,  676,
    0,  676,    0,    0,  676,  676,    0,    0,    0,  676,
  676,  676,    0,  676,    0,  106,  107,  108,  109,  676,
    0,    0,  676,    0,    0,    0,    0,    0,    0,  676,
    0,    0,    0,    0,  676,    0,  676,  676,  676,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
  676,    0,  676,  676,    0,    0,  676,    0,    0,  676,
    0,  676,    0,  676,  676,  676,  676,    0,  676,    0,
    0,    0,    0,    0,    0,  676,    0,    0,  676,  676,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,  676,  676,  676,  676,  676,    0,    0,
    0,    0,    0,    0,    0,    0,  676,    0,    0,    0,
    0,    0,  676,  676,  676,  676,    0,    0,    0,  676,
    0,  676,    0,    0,    0,    0,    0,  676,  676,    0,
    0,    0,    0,    0,    0,  146,  146,    0,  146,    0,
    0,  146,  146,    0,    0,    0,  146,  146,  146,    0,
  146,    0,  676,  676,  676,  676,  146,    0,    0,  146,
    0,    0,    0,    0,    0,    0,  146,    0,    0,    0,
    0,  146,    0,  146,  146,  146,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,  146,    0,  146,
  146,    0,    0,  146,    0,    0,  146,    0,  146,    0,
  146,  146,  146,  146,    0,  146,    0,    0,    0,    0,
    0,    0,  146,    0,    0,  146,  146,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
  146,  146,  146,  146,  146,    0,    0,    0,    0,    0,
    0,    0,    0,  146,    0,    0,    0,    0,    0,  146,
  146,  146,  146,    0,    0,    0,  146,    0,  146,    0,
    0,    0,    0,    0,  146,  146,    0,    0,    0,    0,
    0,    0,   57,   24,    0,   25,    0,    0,   26,  257,
    0,    0,    0,   27,   62,   63,    0,   28,    0,  146,
  146,  146,  146,   65,    0,    0,   30,    0,    0,    0,
    0,    0,    0,   32,    0,    0,    0,    0,   33,    0,
   72,   73,   34,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,   36,    0,   37,   75,    0,    0,
   38,    0,    0,   77,    0,   79,    0,   81,   39,   40,
  258,    0,   41,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,   90,   91,   92,
  259,  672,    0,    0,    0,    0,    0,    0,    0,    0,
   96,    0,    0,    0,    0,    0,   98,   99,  100,  101,
    0,    0,    0,  102,    0,  103,    0,    0,    0,    0,
    0,  104,  105,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,  722,    0,  722,    0,  722,  106,  261,  722,  109,
  722,  722,    0,  722,    0,  722,    0,  722,    0,  722,
  722,  722,    0,    0,    0,  722,  722,    0,    0,    0,
    0,  722,    0,  722,  722,    0,    0,    0,  722,    0,
    0,    0,  722,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,  722,  722,    0,  722,    0,    0,    0,
  722,  722,    0,    0,    0,    0,    0,    0,  722,  722,
   57,   24,  722,   25,    0,  722,   26,  257,    0,    0,
  722,   27,   62,   63,    0,   28,    0,    0,    0,    0,
    0,   65,    0,    0,   30,    0,    0,    0,    0,    0,
    0,   32,    0,  722,  722,    0,   33,    0,   72,   73,
   34,    0,    0,    0,    0,    0,  722,    0,    0,    0,
    0,    0,   36,    0,   37,   75,    0,    0,   38,    0,
    0,   77,    0,   79,    0,   81,   39,   40,  258,    0,
   41,    0,    0,   85,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,  722,    0,    0,
    0,    0,    0,    0,    0,   90,   91,   92,  259,  260,
    0,    0,    0,    0,    0,  721,    0,  721,   96,    0,
  721,    0,  721,  721,    0,  721,    0,  721,    0,  721,
    0,  721,  721,  721,    0,    0,    0,  721,  721,    0,
    0,    0,    0,  721,    0,  721,  721,    0,    0,    0,
  721,    0,    0,    0,  721,    0,    0,    0,    0,    0,
    0,    0,    0,    0,  106,  261,  721,    0,  721,    0,
    0,    0,  721,  721,    0,    0,    0,    0,    0,    0,
  721,  721,    0,  721,  721,  721,    0,  721,  721,    0,
  721,  721,  721,  721,    0,  721,    0,  721,    0,  721,
  721,  721,    0,    0,    0,  721,  721,    0,    0,    0,
    0,  721,    0,  721,  721,   24,    0,   25,  721,    0,
   26,    0,  721, 1384,    0,   27,    0,  749,  721,   28,
    0,  750, 1385, 1386,  721,    0,  721, 1387,   30,    0,
  721,  721,    0, 1388,    0,   32,    0,    0,  721,  721,
   33,    0,  721,    0,   34,  721,    0,    0,    0,    0,
  721,    0,    0,    0,    0,    0,   36,    0,   37,  721,
    0,    0,   38,    0,    0,    0,    0,    0,    0,    0,
   39,   40,    0,   24,   41,   25,    0, 1389,   26,    0,
    0, 1384, 1390,   27,    0,  749,    0,   28,    0,  750,
 1385, 1386,    0,    0,    0, 1387,   30,    0,    0,    0,
    0, 1388,    0,   32,    0,   51,    0,   51,   33,    0,
   51,    0,   34,    0,    0,   51,    0,    0, 1391,   51,
    0,    0,    0,    0,   36,    0,   37,  721,   51,    0,
   38,    0,    0,    0,    0,   51,    0,    0,   39,   40,
   51,    0,   41,    0,   51, 1389,   51,    0,   51,    0,
 1390,    0,    0,   51,    0,    0,   51,    0,   51, 1392,
    0,    0,   51,    0,    0,   51,    0,    0,    0,    0,
   51,   51,    0,   51,   51,   51,    0,   51,   51,    0,
    0,    0,    0,   51,    0,    0,    0,   51,    0,    0,
    0,    0,    0,    0,    0,    0,   51,    0,    0,    0,
    0,    0,    0,   51,    0,   24,    0,   25,   51,    0,
   26,    0,   51,  169,   51,   27,   51,    0,    0,   28,
    0,   51,    0,    0,   51,    0,   51, 1392,   30,    0,
   51,    0,    0,   51,    0,   32,    0,    0,   51,   51,
   33,    0,   51,    0,   34,   51,  604,    0,    0,    0,
    0,    0,    0,  605,    0,    0,   36,    0,   37,   51,
    0,    0,   38,    0,    0,  606,    0,    0,    0,    0,
   39,   40,    0,    0,   41,    0,    0,  607,   52,  169,
   52,    0,    0,   52,    0,    0,    0,    0,   52,    0,
    0,    0,   52,    0,    0,    0,    0,    0,    0,    0,
    0,   52,    0,  608,    0,    0,    0,    0,   52,    0,
   51,    0,   51,   52,    0,   51,    0,   52,    0,   52,
   51,   52,    0,    0,   51,    0,   52,   51,    0,   52,
    0,   52,    0,   51,    0,   52,    0,    0,   52,    0,
   51,    0,    0,   52,   52,   51,    0,   52,    0,   51,
   52,   51,    0,   51,    0,   24,    0,   25,   51,  609,
   26,   51,    0,   51,    0,   27,    0,   51,    0,   28,
   51,    0,    0,   29,    0,   51,   51,    0,   30,   51,
    0,    0,   51,   31,    0,   32,    0,    0,    0,    0,
   33,    0,    0,    0,   34,   35,    0,    0,    0,    0,
   24,    0,   25,    0,    0,   26,   36, 1317,   37,    0,
   27,    0,   38,    0,   28,    0,    0,    0,    0,    0,
   39,   40,    0,   30,   41,    0,    0,   42,    0,    0,
   32,    0,   52,    0,    0,   33,    0, 1318,   24,   34,
   25,    0,    0,   26,    0,    0,    0,    0,   27,    0,
    0,   36,   28,   37,    0,    0,    0,   38, 1319,    0,
    0,   30,    0,    0,   51,   39,   40,    0,   32,   41,
    0,    0,  328,   33,    0,    0,    0,   34,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,   36,
    0,   37,    0,    0,    0,   38,    0,   37,    0,    0,
    0,    0,    0,   39,   40,    0,    0,   41,   37,   43,
  328,    0,    0,   37,    0,    0,    0,   37,    0,    0,
   37,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,   37,   37,    0,    0,  295,   37,   37,    0,
   35,    0,    0,   37,    0,   37,   37,   37,   37,    0,
    0,   35,    0,   37,  377,    0,   35,   37,    0,   37,
   35,    0,    0,   35,    0,    0,    0,    0,    0,   37,
    0,   37,   37,    0,   37,   35,   35,    0,   37,    0,
   35,   35,    0,    0,   31,    0,   35,    0,   35,   35,
   35,   35,  329,    0,    0,    0,   35,    0,   37,    0,
   35,    0,   35,    0,    0,   37,   37,   31,    0,    0,
    0,    0,   35,    0,   31,   35,   31,   35,    0,    0,
   31,   35,    0,    0,    0,   31,    0,    0,    0,    0,
   31,    0,   31,   31,   31,   31,    0,   31,   31,    0,
   31,   35,    0,    0,   31,    0,    0,    0,   35,   35,
   31,    0,    0,    0,    0,   31,   31,    0,    0,   31,
   31,   31,   31,   31,   31,   31,    0,    0,    0,    0,
   31,    0,    0,    0,   31,    0,    0,    0,    0,    0,
    0,    0,    0,    0,   51,   31,   31,    0,    0,   31,
    0,   31,   31,   31,    0,   51,    0,    0,    0,    0,
   51,    0,    0,    0,   51,    0,    0,   51,    0,    0,
    0,    0,    0,    0,    0,   31,    0,    0,    0,   51,
   51,    0,   31,   31,   51,   51,    0,   51,    0,    0,
   51,    0,   51,   51,   51,   51,    0,    0,   51,    0,
   51,    0,    0,   51,   51,    0,   51,   51,    0,    0,
   51,    0,    0,    0,    0,    0,   51,    0,    0,   51,
    0,   51,   51,   51,    0,   51,    0,   51,   51,    0,
   51,    0,    0,   51,    0,   51,   51,   51,   51,    0,
    0,    0,    0,   51,    0,   51,    0,   51,    0,   51,
    0,    0,   39,   51,    0,    0,    0,    0,    0,   51,
    0,    0,   51,    0,   51,    0,   51,    0,   51,    0,
   51,   51,    0,    0,    0,    0,   51,    0,   51,   51,
   51,   51,    0,    0,    0,    0,   51,    0,   51,    0,
   51,    0,    0,   51,    0,   40,    0,    0,    0,    0,
    0,    0,   51,    0,    0,   51,   51,   51,    0,    0,
   51,   51,    0,    0,    0,    0,   51,    0,   51,   51,
   51,   51,    0,    0,    0,    0,   51,    0,    0,    0,
   51,   51,    0,   51,   51,   51,    0,    0,  220,    0,
    0,    0,   51,    0,    0,   51,   51,   51,    0,    0,
   51,   51,   51,    0,    0,    0,   51,    0,   51,   51,
   51,   51,    0,    0,   51,    0,   51,    0,    0,    0,
   51,   51,    0,   51,   51,   51,    0,    0,  222,    0,
   51,    0,   51,    0,    0,   51,   51,   51,    0,    0,
    0,   51,    0,    0,    0,    0,   51,    0,   51,   51,
   51,   51,    0,   51,    0,    0,   51,    0,    0,    0,
   51,   51,    0,    0,    0,    0,   51,    0,  322,    0,
    0,   51,   51,    0,    0,   51,   51,   51,   51,   51,
   51,   51,    0,    0,    0,    0,   51,    0,    0,    0,
   51,   51,    0,   51,    0,    0,    0,    0,    0,    0,
    0,   51,   51,    0,    0,   51,    0,   51,  323,    0,
    0,    0,    0,    0,   51,    0,    0,    0,    0,    0,
    0,  474,    0,    0,    0,    0,    0,   51,    0,    0,
    0,   51,   51,    0,   51,   51,    0,   51,    0,   51,
   51,   51,   51,    0,  475,   51,    0,   51,    0,    0,
    0,   51,    0,    0,    0,    0,    0,  476,    0,    0,
    0,    0,  478,   51,    0,    0,   51,  479,   51,  480,
  481,  482,  483,    0,    0,    0,    0,  484,    0,    0,
    0,  485,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,   51,  486,    0,    0,  487,    0,  488,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,  489,
  };
  protected static readonly short [] yyCheck = {            17,
  303,   52,   17,  304,   52,   18,    4,   17,  543,  541,
   17,  237,  191,  293,   20,  235,   20,  491,  190,  327,
  302,   60,  159,  513,  302,  351,  593,  300,  338,  393,
   60, 1180,  600,   78,  611, 1005,  250,  817,  392,    6,
    0,  785,  325,  787, 1223,  376,  318,  961,  256,   59,
  292,  256,  334,  620,  256,  256,   74,  256,  702,  382,
   78,   17,   17,  707,  708,  117,  268, 1455,   45, 1325,
   80,   48,   82,  256,  256,   69, 1010,  282,   96,  292,
  268,  256,  256, 1262,   88,   89,  256,  831, 1344,  256,
  834,  268,  256,  256,   88,   89, 1275,  264,    0,   93,
  377,  256,  256,  382,  376,  109,  370, 1177,  256,  314,
  374,  392,  269, 1062,  256,   85,  256,   17,  415,  113,
  370,  294,  256,  256,  256,  422,  256,  256,  374,  286,
  372,  377,  382,  306,  415,  256,  419,  256,  461, 1088,
  191,  159,  305,  191,  159,  115,  723,  117,  256,  159,
 1220,  433,  159,  430,  256,  368,  339,   17,  325,   17,
  424,  344,  256,  346,  347,  348,  349,  350,  351,  352,
  353,  354,  355,  356,  382,  376,   17,  256,  392,  421,
  174,  369,  461,  382,  235,  340,  369,  235,  371,   17,
  373,   17,  375,  376,  377,   17, 1584,  201,  202,  373,
  382,  376, 1136,  159,  159,  339,   17,   17,  391,  373,
  344,  375,  346,  256,  419,  349,  350,  496,  352,  353,
   62,  423,  392,  363,   66,   67,   68,  537,   70,   71,
 1144,  457,  250,   75,   76,  423,  456,  540,  256,   81,
   82,  375,   84,  372,   86,  415,  423,  430,  225,   91,
   92,  290,  422,  788,  585,  249,  250,  256,  377,  159,
  290,  300,  266, 1519,  231,  419,  430,  593,  376,  263,
  372,  419,    0,  627,  116,  293,  844,  419,  330,  419,
  298,  299,  376,  335,  363,  256,  419,  419,  292,  419,
 1546,  935,  421,  323,  620,  313,  430,  257,  419,  159,
  304,  159, 1558,  321, 1560,  323,  300,  630,  312,  327,
  256,  590,  322,  585,  318,  357, 1300,  268,  159,  421,
  363,  339,  340, 1067,  256,  276,  335,  971,  371, 1109,
  373,  159,  375,  159,  256,  380,  351,  159,  332,  611,
  419,  345,  346,  337,  351,  387,  625,  277,  159,  159,
  256,  630,  631,  256,  256,  349,  326,  256,  358,  358,
  330,  369,  380,  940, 1513,  335,  256,  371, 1012,  256,
 1014,  257,  376, 1017,  392,  393,  419,  294,  396,  397,
  398,  399,  400,  401,  402,  403,  404,  405,  406,  306,
  384,  256,  256,  724,  388,  718, 1140,  368,  392,  393,
 1579,  372,  256, 1175,  256,  456,  410,  411,  456,  256,
  428,  419,  363,  627, 1398,  466,  258, 1387,  466,  256,
  262,  430, 1406,  256,  373,  256,  425,  426,  427,  428,
 1217,  377, 1611,  363,  438,  439,  256,  339,  973,  718,
  256,  343,  256,  375,  438,  439, 1218,  369,  442, 1193,
  421,  723,  458,  375,  458, 1099,  256, 1101, 1202, 1103,
  302,  951,  368,  256,  772,  471,  368,  471,  419,  372,
  372,  377,  374,  375,  376,  377,  375,  749,  368, 1463,
  382,  430,  372,  513,  371,  462,  463, 1231,  375,  419,
  420,  468, 1279, 1291,   17,  363,  506,  343,  256,  335,
    6,  256,  419,  262,  351,  731,  325,  373,  256,  373,
  375,   17, 1306, 1307,  263,  879,  368,  790,  512,  373,
  514,  539,  368,  541, 1092,  543, 1061,  341,  859,  257,
  294,  421,  266,  257, 1328,  256,  373,   60,  764,  298,
  373,   64,  373,  757,  272,  263,  556,  541,  368,  277,
  370,  419,  372,  281,   60,  573,  370,  373,   64,  305,
  578, 1355, 1206,  266,  430,  369,  315,  343,  296, 1367,
  370,  363,  363,  567,  369,  368,  419,  370,  593,  589,
  314,  585,   88,   89, 1378,  369,  593,  859,  373,  868,
  600, 1159,  368,  357,  277,  323, 1240,  315,  281,  363,
  419,  421,  369,  109,  424,  620,  370,  611,  939,  627,
  374,  314,  370,  620,  342,  370,  610,  635,  636,  369,
  379,  380,  370,  387,  369,  375,  430,  419,  419,  369,
  369, 1198,  626,  627,  937,  430,  159,  429,  429,  375,
  373,  256,  376,  363,  343,  430,  430,  368, 1292,  370,
  369,  372,  373,  159,  375,  419,  377,  967,  377,  342,
 1548, 1549, 1393,  430,  374,  802,  508, 1311,  940,  343,
  305,  885,  666,  376, 1405,  372, 1448,  272,  339,  419,
  430,  417,  277,  382,  702,  430,  281,  343,  970,  707,
  708,  430,  710,  392,  972,  201,  202,  430,  419,  419,
  421,  296,  272,  424, 1005, 1477, 1478,  368,  382, 1481,
  704,  430,  706,  555,  424,  376,  415, 1605,  392,  723,
  363,  715, 1494,  422,  339, 1497,  296,  370,  323,  344,
  429,  346,  373,   20,  349,  350,  392,  352,  353,  757,
 1512,  415, 1232,  343,  369,  749,  372,  342,  422, 1307,
  375,  790,  370,  323,  772,  429, 1064,  382,  272,  415,
  266,  256,  372,  757, 1536,  363,  422,  290,  368,  256,
  788, 1303,  370,  429,  357, 1078,  419,  795,  419,  797,
  363,  775,  296,  750,  290, 1307,  292,  370,  377, 1307,
  373,  374,  375,  256, 1307,  421,  790, 1355,  304,  272,
  323,   88,   89,  377,  387,  430,  312,  294, 1307,  323,
  305, 1307,  318,  368,  824, 1029,  826,  323,  836,  823,
  838,  419,  109,  296, 1410,   21,  256, 1153,  351,  339,
  848, 1307,  842, 1355,  844,  839,  419, 1355, 1424,  345,
  346,  369, 1355,  368, 1307,  351,  375,  375,  387, 1021,
  323,  855,  377,  341,  382,  859, 1355,   53,  368, 1355,
 1446,  879,  372,  372,  858,  371,  917,  885, 1148,  917,
  376,  889, 1198,  891,   88,   89,  339, 1180,  369, 1355,
  256,  344,  370,  346,  375,  879,  349,  350,  417,  352,
  353,  885, 1355,  368,  402,  109,  339,  372,  256,  374,
  375,  339,  377, 1183,  410,  411,  414,  382, 1393,  357,
  390,  269,  375,  343,  201,  202,  922,  935,  922,  937,
 1405,  382,  375,  343,  377,  368,  374,  339,  286,  382,
  368,  392,  438,  439,  357,  953,  940,  941,  368,  387,
  958,  416,  372,  961,  374,  375,  385,  377,  368, 1229,
 1424,  374,  382,  971,  415,  973,  368,  377,  976, 1173,
  927,  422,  339,  339,  387, 1291, 1501,  430,  344,  368,
  346,  339,  343,  349,  350,  343,  352,  353,  377,  266,
  822,  395,  396,  368,  978,  392,  416,  201,  202,  392,
  513,  368,  377,  343, 1012,  368, 1014,  368,  372, 1017,
  368, 1005,  376,  306,  377,  292,  377,  513,  415,  377,
  313, 1029,  415,  401, 1008,  422,  256,  304,  368,  422,
 1026, 1247, 1026, 1243,  386,  312,  429,  377, 1563,  374,
 1034,  318,  377, 1313,  369, 1029, 1215,  306, 1368,  308,
  375, 1367,  306, 1061,  313, 1375, 1064,  374,  391,  313,
  377, 1045,  266,  372,  430,  374,  325, 1051,  345,  346,
  369,  325,  383,  384,  373, 1600,  399,  400,  377, 1036,
  593, 1038,  372, 1040,  374,  370,  397,  398,  292,  585,
  256, 1099, 1092, 1101,  371, 1103, 1387,  593, 1106,  376,
  419,  371,  372, 1625, 1626,  375, 1368,  620,  312,  339,
  256,  369,  370, 1375,  344,  611,  346,  369,  416,  349,
  350,  373,  352,  353,  620,  377,    0,  371,  372, 1117,
  374,  375,  376,  410,  411,  373, 1144,  375,  419,  377,
 1148,  345,  346,  354,  355,  373,  371,  375, 1153,  377,
  375,  371, 1421, 1161, 1162,  375, 1153,  256,  368, 1159,
  370,  438,  439,  377,  371, 1173,  373,  371,  375, 1438,
  277, 1174, 1180,  339, 1215, 1183, 1217, 1215,  344, 1217,
  346,  458,  374,  349,  350,  368,  352,  353, 1457, 1173,
 1459,  371,  371, 1198,  471,  375,  375,  343, 1206,  371,
  430, 1198, 1243,  375, 1212, 1243,  410,  411,  371,  371,
  373,  371,  375,  375,  369,  375,  354,  355,  373,  371,
 1513, 1229,  368,  375,  377, 1219,  372,  723,  374,  375,
  256,  377, 1240, 1241,  438,  439,  382,  377, 1279,  369,
  369, 1279,  374,  373,  373,  416,  417,  418,  419,  364,
  387,  388,  389,  749,  369,  369,  370,  372,  256,  374,
  375,  373,  256,  375,  430, 1306, 1307,  382, 1306, 1307,
  343,  373,  785,  375,  787,  375,  377,  377,  393,  394,
  371,  375,  373,  377, 1292,  294, 1291, 1328, 1282,  785,
 1328,  787,  415,  416, 1291, 1303,  373,  371,  413,  373,
  371,  377,  373, 1311,  294, 1313,  421,  370,  585,  424,
  419, 1305,  256,  356, 1355,  430,  419, 1355,  831, 1303,
  364,  834,  371,  419,  373,  369,  415,  823,  372,  376,
  374,  375,  365,  366,  611,  831,  373, 1378,  834,  373,
 1378,  339,  377,  839, 1637,  373,  344,  375,  346,  393,
  394,  349,  350,  382,  352,  353,  373,  369,  375,  855,
  365,  366, 1367,  859,  371,  371,  373,  373,  430,  413,
 1367, 1371, 1366,  375, 1368, 1359,  375,  421,  377,  294,
  424, 1375,  375,  257,  377,  373,  430,  261,  412,  413,
 1384, 1385,  375, 1387,  377,  339,  414,  415,  272, 1393,
  344,  373,  346,  277,  294,  349,  350,  281,  352,  353,
  284, 1405,  375,  795,  377,  797, 1410,  375, 1412,  420,
  421, 1415,  296,  297, 1432,  373,  373,  301,  302, 1429,
 1424,  373,  430,  307,  375,  309,  310,  311,  312,  256,
  377,  372,  429,  317,  940,  941,  723,  321,  429,  323,
 1491,  256, 1446, 1491,  256,  294,  294,  382,  375,  333,
  373,  335,  336,  374,  338,  374,  376, 1508,  342,  375,
 1508,  373,  749,  419,  382,  375,  375,  375,  375,  430,
 1521, 1522,  377, 1521, 1522,  424,  430,  373,  362,  368,
  375,  375,  373, 1501,  343,  369,  370,  375,  294, 1499,
  294,  419,  375,  371,  368, 1513,  372, 1548, 1549, 1005,
 1548, 1549,  419,  376,  256,  256,  375,  256,  256,   94,
  382,  280, 1530,   98,   99,  100,  101,  102,  103,  104,
  105,  256,  368,  373,  339,  369,  343,  372, 1034,  344,
  377,  346,  371,  375,  349,  350,  823,  352,  353,  377,
  375,  377,  373,  371, 1067, 1563,  256,  373,  382,  373,
  373,  347,  839,  424, 1605,  368,  256, 1605,  369,  373,
  382, 1067,  382,  364,  382,  256,  347,  375,  855,  256,
  372,  372,  859,  374,  371,  292,  376,  371,  371,  339,
  368,  373, 1600,  348,  369,  375,  419,    0,  256,  373,
  372,  348,  393,  394,  419,  369,  368,  368, 1608, 1609,
  377,  368,  382,  369,  377, 1615, 1616, 1625, 1626,  823,
  356,  373,  413,  372,  375,  430,  369, 1140,  373, 1637,
  421,  337,  369,  424,  305,  839,  369,  372,  419,  370,
 1153, 1625, 1626,  419, 1140,  922,  368,  377,  372,  372,
  419,  855,  372,  419,  382,  374,  372, 1153,  368,  343,
  372,  382,  339,  940,  941,  370,  377,  344,  372,  346,
  347,  348,  349,  350,  351,  352,  353,  354,  355,  356,
 1193,  373,  373,  256,  377, 1198,  375,  374,  374, 1202,
  375,  369,  369,  375,  371,  375,  373, 1193,  375,  376,
  377,  419, 1198,  373,  373,  371, 1202,  382,  256,  377,
  261,  419,  377,  373,  377,  382,  419,  419, 1231,  373,
  373,  371,  373, 1219,  369,  315,  263,  382, 1005,  372,
  372,  306,  369,  284,  373, 1231,  377,  941,  373,    0,
  368,    0,  369,  377,  377,    0,  297,  373,  377, 1026,
  369,  302,  373,  430,  305,  368,  307, 1034,  309,  310,
  311,  312,  373,  338,  371,  377,  317,  419,  369,  373,
  321,  369,  377,  348,  325,  371,  368,  377, 1291,  419,
  369,  419,  333,    0,  377,  336, 1282,  338,  373,  377,
  369,  339,  373,  369,  368, 1291,  344,  369,  346,  347,
  348,  349,  350,  351,  352,  353,  354,  355,  377, 1305,
  369,  362,  374,  377,  377,  315,  377,  377,  369,  377,
  377,  369,  377,  371,  377,  373,  263,  375,  376,  377,
 1034,   51,  407,  408,  409,   12,    5,  412,  413,  414,
  415,  416,  417,  418,  419,  420,  421,  422,  423,  424,
  425,  426,  427,  256, 1367,  922, 1026, 1173,  261,  262,
 1173, 1378, 1328, 1383, 1516, 1225, 1569, 1553,  419, 1504,
 1366, 1367, 1368, 1533, 1429, 1499,  944, 1410,  944, 1375,
  944,  284,  430,  763,  939,    0, 1355, 1430, 1384, 1385,
 1526, 1387, 1522, 1343,  297,  298, 1616, 1610, 1521,  302,
 1279, 1459,  305, 1609,  307,  318,  309,  310,  311,  312,
 1282,  967,  885,  917,  317,  757, 1412, 1078,  321, 1415,
   72,  636,  325,  790,  341,  978,  422,  424,  423,  427,
  333,  425,  859,  336,  426,  338,  339,  585, 1179, 1259,
  343,  344, 1219,  346,  347,  348,  349,  350,  351,  352,
  353,  354,  355,  356,  357, 1366, 1153,  159, 1063,  362,
  363, 1138,  537, 1162, 1088,  368,  369,  370,  371,  372,
  373,  374,  375,  376,  377, 1047,  379,  380, 1151, 1153,
  383,  384,  385,  386,  387, 1232,  557,  390,  391, 1201,
  982,  447,  395,  396,  397,  398,  399,  400,  401,  402,
  713,  261,  447,  919, 1361, 1282, 1241,  912,   -1,   -1,
   -1,  414,   -1,   -1,  417,   -1,  419,   -1,  421,   -1,
   -1,  424,   -1,   -1,  284,   -1,   -1,  430, 1305,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,  297,   -1,   -1,
  257,  616,  302,   -1,  261,  305,   -1,  307,   -1,  309,
  310,  311,  312,   -1,    0,  272,   -1,  317,   -1,   -1,
  277,  321,   -1,   -1,  281,  325,   -1,  284,   -1,   -1,
   -1,   -1,   -1,  333,   -1,   -1,  336,   -1,  338,  296,
  297,   -1,   -1,   -1,  301,  302,   -1,   -1,   -1, 1366,
  307, 1368,  309,  310,  311,  312,   -1,  672, 1375,   -1,
  317, 1305,  362,   -1,  321,   -1,  323, 1384, 1385,  369,
 1387,   -1,   -1,   -1,   -1,   -1,  333,   -1,   -1,  336,
   -1,  338,   -1,   -1,   -1,  342,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1, 1412,   -1,   -1, 1415,   -1,
   -1,  256,   -1,   -1,   -1,  362,  261,  262,   -1,  382,
   -1,  368,  369,  370,   -1,   -1,   -1,   -1,   -1,  419,
   -1,   -1, 1366,   -1,   -1,   -1,   -1,   -1,   -1,  284,
  403,  404,  405,  406,  407,  408,  409,  410,  411,  412,
 1384, 1385,  297,  298,   -1,   -1,   -1,  302,   -1,   -1,
  305,   -1,  307,   -1,  309,  310,  311,  312,   -1,   -1,
   -1,   -1,  317,   -1,   -1,   -1,  321,   -1, 1412,   -1,
  325, 1415,   -1,   -1,   -1,   -1,   -1,   -1,  333,  794,
   -1,  336,    0,  338,  339,   -1,   -1,   -1,  343,  344,
   -1,  346,  347,  348,  349,  350,  351,  352,  353,  354,
  355,  356,   -1,   -1,   -1,   -1,   -1,  362,  363,  364,
   -1,   -1,   -1,  368,  369,   -1,  371,  372,  373,  374,
  375,  376,  377,   -1,  379,  380,   -1,  382,  383,  384,
  385,  386,  387,  388,  389,  390,  391,   -1,  393,  394,
  395,  396,  397,  398,  399,  400,  401,  402,  403,  404,
  405,  406,  407,  408,  409,  410,  411,  412,  413,  414,
   -1,   -1,  417,   -1,  419,   -1,  421,   -1,   -1,  424,
  256,  257,   -1,   -1,   -1,  430,   -1,   -1,  264,  265,
  266,  267,  268,   -1,  270,  271,   -1,  273,  274,  275,
  276,  277,  278,  279,  280,   -1,   -1,   -1,   -1,  285,
   -1,  287,  288,  289,  290,  291,  292,   -1,   -1,  295,
   -1,   -1,    0,  299,  300,   -1,  302,  303,  304,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,  314,   -1,
  316,   -1,  318,  319,   -1,   -1,  322,   -1,  324,  325,
  326,  327,  328,  329,  330,  331,  332,  333,  334,  335,
   -1,  337,  967,   -1,  340,  341,   -1,   -1,  344,  345,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,  359,  360,  361,  362,  363,   -1,   -1,
   -1,   -1,  368,  369,   -1,   -1,  372,   -1,   -1,   -1,
   -1,  377,  378,  379,  380,  381,   -1,   -1,   -1,  385,
   -1,  387,   -1,   -1,   -1,   -1,   -1,  393,  394,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,  418,  419,  420,  421,   -1,  423,  256,  257,
   -1,   -1,   -1,    0,  430,   -1,  264,  265,  266,  267,
  268,   -1,  270,  271,   -1,  273,  274,  275,  276,  277,
  278,  279,   -1,   -1,   -1,   -1,   -1,  285,   -1,  287,
  288,  289,  290,  291,  292,   -1,   -1,  295,   -1,   -1,
   -1,  299,  300,   -1,  302,  303,  304,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,  314,   -1,  316,   -1,
  318,  319,   -1,   -1,  322,   -1,  324,  325,  326,  327,
  328,  329,  330,  331,  332,  333,  334,  335,   -1,  337,
   -1,   -1,  340,  341,   -1,   -1,  344,  345,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,  359,  360,  361,  362,  363,   -1,   -1,   -1,   -1,
  368,  369,   -1,   -1,  372,   -1,   -1,   -1,   -1,  377,
  378,  379,  380,  381,   -1,   -1,   -1,  385,  256,  387,
   -1,   -1,   -1,  261,  262,  393,  394,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
    0,   -1,   -1,   -1,   -1,   -1,  284,   -1,   -1,   -1,
  418,  419,  420,  421,   -1,  423,   -1,   -1,   -1,  297,
  298,   -1,  430,   -1,  302,   -1,   -1,  305,   -1,  307,
   -1,  309,  310,  311,  312,   -1,   -1,   -1,   -1,  317,
   -1,   -1,   -1,  321,   -1,   -1,   -1,  325,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,  333,   -1,   -1,  336,   -1,
  338,  339,   -1,   -1,   -1,  343,  344,   -1,  346,  347,
  348,  349,  350,  351,  352,  353,  354,  355,  356,   -1,
   -1,   -1,   -1,   -1,  362,  363,   -1,   -1,   -1,   -1,
  368,  369,  370,  371,  372,  373,   -1,  375,  376,  377,
   -1,  379,  380,   -1,   -1,  383,  384,  385,  386,  256,
   -1,   -1,  390,  391,  261,  262,   -1,  395,  396,  397,
  398,  399,  400,  401,  402,    0,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,  414,  284,   -1,  417,
   -1,  419,   -1,  421,   -1,   -1,  424,   -1,   -1,   -1,
  297,  298,  430,   -1,   -1,  302,   -1,   -1,  305,   -1,
  307,   -1,  309,  310,  311,  312,   -1,   -1,   -1,   -1,
  317,   -1,   -1,   -1,  321,   -1,   -1,   -1,  325,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,  333,   -1,   -1,  336,
   -1,  338,  339,   -1,   -1,   -1,  343,  344,   -1,  346,
  347,  348,  349,  350,  351,  352,  353,  354,  355,  356,
   -1,   -1,   -1,   -1,   -1,  362,  363,   -1,   -1,   -1,
   -1,  368,  369,  370,  371,  372,  373,   -1,  375,  376,
  377,   -1,  379,  380,   -1,   -1,  383,  384,  385,  386,
   -1,   -1,   -1,  390,  391,   -1,   -1,   -1,  395,  396,
  397,  398,  399,  400,  401,  402,  256,   -1,   -1,   -1,
   -1,  261,  262,   -1,   -1,   -1,   -1,  414,   -1,   -1,
  417,   -1,  419,    0,  421,   -1,   -1,  424,   -1,   -1,
   -1,   -1,   -1,  430,  284,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,  297,  298,   -1,
   -1,   -1,  302,   -1,   -1,  305,   -1,  307,   -1,  309,
  310,  311,  312,   -1,   -1,   -1,   -1,  317,   -1,   -1,
   -1,  321,   -1,   -1,   -1,  325,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,  333,   -1,   -1,  336,   -1,  338,  339,
  285,   -1,   -1,  343,  344,   -1,  346,  347,  348,  349,
  350,  351,  352,  353,  354,  355,  356,   -1,   -1,   -1,
   -1,   -1,  362,  363,   -1,   -1,   -1,   -1,  368,  369,
   -1,  371,  372,  373,   -1,  375,  376,  377,   -1,  379,
  380,  256,  327,  383,  384,  385,  386,  262,   -1,   -1,
  390,  391,   -1,   -1,   -1,  395,  396,  397,  398,  399,
  400,  401,  402,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,  414,   -1,   -1,  417,   -1,  419,
   -1,   -1,   -1,  298,   -1,   -1,   -1,   -1,   -1,   -1,
  430,   -1,    0,  378,  379,  380,  381,   -1,  383,  384,
  385,  386,  387,  388,  389,  390,   -1,   -1,  393,  394,
  395,  396,  397,  398,  399,  400,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,  339,   -1,   -1,   -1,  343,  344,
   -1,  346,  347,  348,  349,  350,  351,  352,  353,  354,
  355,  356,  357,   -1,   -1,   -1,   -1,   -1,  363,   -1,
   -1,   -1,   -1,  368,  369,  370,  371,  372,  373,  374,
  375,  376,  377,   -1,  379,  380,   -1,   -1,  383,  384,
  385,  386,  387,   -1,   -1,  390,  391,   -1,   -1,   -1,
  395,  396,  397,  398,  399,  400,  401,  402,   -1,  256,
   -1,    0,   -1,  261,   -1,  262,   -1,   -1,   -1,  414,
   -1,   -1,  417,   -1,  419,   -1,  421,   -1,   -1,  424,
   -1,   -1,   -1,   -1,   -1,  430,  284,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,  297,
   -1,  298,   -1,   -1,  302,   -1,   -1,   -1,   -1,  307,
   -1,  309,  310,  311,  312,   -1,   -1,   -1,   -1,  317,
   -1,   -1,   -1,  321,   -1,   -1,   -1,  325,    0,   -1,
   -1,   -1,   -1,   -1,   -1,  333,   -1,   -1,  336,   -1,
  338,   -1,  339,   -1,   -1,   -1,  343,  344,   -1,  346,
  347,  348,  349,  350,  351,  352,  353,  354,  355,  356,
   -1,   -1,   -1,   -1,  362,   -1,  363,   -1,   -1,   -1,
   -1,  368,  369,   -1,  371,  372,  373,   -1,  375,  376,
  377,   -1,  379,  380,   -1,   -1,  383,  384,  385,  386,
   -1,   -1,   -1,  390,  391,   -1,   -1,   -1,  395,  396,
  397,  398,  399,  400,  401,  402,   -1,   -1,    0,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,  414,  256,  257,
  417,  419,  419,  261,   -1,   -1,   -1,  265,   -1,  267,
   -1,   -1,  270,  430,  272,  273,   -1,  275,   -1,  277,
   -1,  279,   -1,  281,  282,  283,  284,   -1,   -1,  287,
  288,    0,   -1,   -1,   -1,  293,   -1,  295,  296,  297,
   -1,   -1,  300,  301,  302,   -1,  304,   -1,   -1,  307,
   -1,  309,  310,  311,  312,   -1,   -1,   -1,  316,  317,
  318,   -1,   -1,  321,  322,  323,   -1,   -1,   -1,   -1,
   -1,   -1,  330,  331,   -1,  333,  334,   -1,  336,  337,
  338,   -1,   -1,   -1,  342,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,  257,   -1,
   -1,   -1,  261,   -1,  362,   -1,   -1,   -1,   -1,   -1,
  368,  369,  370,  272,    0,   -1,   -1,   -1,  277,   -1,
  378,   -1,  281,   -1,   -1,  284,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,  296,  297,   -1,
   -1,   -1,  301,  302,   -1,   -1,   -1,   -1,  307,   -1,
  309,  310,  311,  312,   -1,   -1,   -1,    0,  317,   -1,
   -1,  419,  321,   -1,  323,  257,   -1,   -1,   -1,  261,
   -1,   -1,   -1,   -1,  333,   -1,  335,  336,   -1,  338,
  272,   -1,   -1,  342,   -1,  277,   -1,   -1,   -1,  281,
   -1,   -1,  284,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
    0,   -1,   -1,  362,  296,  297,   -1,   -1,   -1,  301,
  302,  370,   -1,   -1,   -1,  307,   -1,  309,  310,  311,
  312,   -1,   -1,   -1,   -1,  317,   -1,   -1,   -1,  321,
   -1,  323,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,  333,   -1,    0,  336,  257,  338,   -1,   -1,  261,
  342,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
  272,   -1,   -1,   -1,   -1,  277,   -1,   -1,   -1,  281,
  362,   -1,  284,   -1,   -1,   -1,   -1,  369,  370,   -1,
   -1,   -1,   -1,   -1,  296,  297,    0,   -1,  257,  301,
  302,   -1,  261,   -1,   -1,  307,   -1,  309,  310,  311,
  312,   -1,   -1,  272,   -1,  317,   -1,   -1,  277,  321,
   -1,  323,  281,   -1,   -1,  284,   -1,   -1,   -1,   -1,
   -1,  333,   -1,   -1,  336,   -1,  338,  296,  297,    0,
  342,   -1,  301,  302,   -1,   -1,   -1,   -1,  307,   -1,
  309,  310,  311,  312,   -1,   -1,   -1,   -1,  317,   -1,
  362,   -1,  321,   -1,  323,   -1,   -1,  369,  370,   -1,
   -1,   -1,   -1,   -1,  333,   -1,   -1,  336,   -1,  338,
   -1,  257,   -1,  342,   -1,  261,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,  272,   -1,   -1,   -1,
   -1,  277,   -1,  362,   -1,  281,   -1,   -1,  284,   -1,
   -1,  370,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
  296,  297,   -1,   -1,  257,  301,  302,   -1,  261,   -1,
   -1,  307,   -1,  309,  310,  311,  312,   -1,   -1,  272,
   -1,  317,   -1,   -1,  277,  321,   -1,  323,  281,   -1,
   -1,  284,   -1,   -1,   -1,   -1,   -1,  333,   -1,   -1,
  336,   -1,  338,  296,  297,   -1,  342,  257,  301,  302,
   -1,  261,   -1,   -1,  307,   -1,  309,  310,  311,  312,
   -1,   -1,  272,   -1,  317,   -1,  362,  277,  321,   -1,
  323,  281,   -1,   -1,  284,   -1,   -1,   -1,   -1,   -1,
  333,   -1,   -1,  336,   -1,  338,  296,  297,   -1,  342,
  257,  301,  302,   -1,  261,   -1,   -1,  307,   -1,  309,
  310,  311,  312,   -1,   -1,  272,   -1,  317,   -1,  362,
  277,  321,   -1,  323,  281,   -1,   -1,  284,   -1,   -1,
   -1,   -1,   -1,  333,   -1,   -1,  336,   -1,  338,  296,
  297,   -1,  342,  257,  301,  302,   -1,  261,   -1,   -1,
  307,   -1,  309,  310,  311,  312,   -1,   -1,  272,   -1,
  317,   -1,  362,  277,  321,   -1,  323,  281,   -1,   -1,
  284,   -1,   -1,   -1,   -1,   -1,  333,   -1,   -1,  336,
   -1,  338,  296,  297,   -1,  342,  257,  301,  302,   -1,
  261,   -1,   -1,  307,   -1,  309,  310,  311,  312,   -1,
   -1,  272,   -1,  317,   -1,  362,  277,  321,   -1,  323,
  281,   -1,   -1,  284,   -1,   -1,   -1,   -1,   -1,  333,
   -1,   -1,  336,   -1,  338,  296,  297,   -1,  342,   -1,
  301,  302,   -1,   -1,   -1,   -1,  307,   -1,  309,  310,
  311,  312,   -1,   -1,   -1,   -1,  317,   -1,  362,   -1,
  321,   -1,  323,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,  333,   -1,  256,  336,   -1,  338,   -1,   -1,
   -1,  342,  264,  265,  266,  267,   -1,   -1,  270,  271,
   -1,  273,  274,  275,  276,  277,  278,  279,   -1,   -1,
   -1,  362,   -1,  285,   -1,  287,  288,  289,  290,  291,
  292,   -1,   -1,  295,   -1,   -1,   -1,  299,  300,   -1,
  302,  303,  304,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,  314,   -1,  316,   -1,  318,  319,   -1,   -1,
  322,   -1,  324,  325,  326,  327,  328,  329,  330,  331,
  332,  333,  334,  335,   -1,  337,   -1,   -1,  340,  341,
   -1,   -1,  344,  345,  256,   -1,   -1,   -1,  261,   -1,
  262,   -1,   -1,   -1,   -1,   -1,   -1,  359,  360,  361,
  362,  363,   -1,   -1,   -1,   -1,  368,   -1,   -1,   -1,
  372,  284,   -1,   -1,   -1,  377,  378,  379,  380,  381,
   -1,   -1,   -1,  385,  297,  387,  298,   -1,   -1,  302,
   -1,  393,  394,   -1,  307,   -1,  309,  310,  311,  312,
   -1,   -1,   -1,   -1,  317,   -1,   -1,   -1,  321,   -1,
   -1,   -1,  325,   -1,   -1,   -1,  418,  419,  420,  421,
  333,   -1,   -1,  336,   -1,  338,   -1,  339,  430,   -1,
   -1,   -1,  344,  256,  346,  347,  348,  349,  350,  351,
  352,  353,  354,  355,  356,  357,   -1,   -1,   -1,  362,
   -1,  363,  364,   -1,   -1,   -1,  369,  369,  370,  371,
  372,  373,  374,  375,  376,  377,   -1,  379,  380,   -1,
  382,  383,  384,  385,  386,  387,  388,  389,  390,  391,
   -1,  393,  394,  395,  396,  397,  398,  399,  400,  401,
  402,  403,  404,  405,  406,  407,  408,  409,  410,  411,
  412,  413,  414,  415,   -1,  256,  419,  419,   -1,  421,
  422,  262,  424,   -1,   -1,   -1,  339,   -1,  430,   -1,
   -1,  344,   -1,  346,  347,  348,  349,  350,  351,  352,
  353,  354,  355,  356,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,  369,  298,  371,   -1,
  373,   -1,  375,  376,  377,   -1,   -1,   -1,   -1,   -1,
  383,  384,  385,  386,   -1,   -1,   -1,  390,  391,   -1,
   -1,   -1,  395,  396,  397,  398,  399,  400,  401,  402,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,  339,   -1,
   -1,  414,   -1,  344,   -1,  346,  347,  348,  349,  350,
  351,  352,  353,  354,  355,  356,  357,  430,   -1,   -1,
   -1,   -1,  363,  364,   -1,   -1,   -1,   -1,  369,  370,
  371,  372,  373,  374,  375,  376,  377,   -1,  379,  380,
   -1,  382,  383,  384,  385,  386,  387,  388,  389,  390,
  391,   -1,  393,  394,  395,  396,  397,  398,  399,  400,
  401,  402,  403,  404,  405,  406,  407,  408,  409,  410,
  411,  412,  413,  414,  415,  256,  256,   -1,  419,   -1,
  421,  262,   -1,  424,   -1,  265,   -1,  267,   -1,  430,
  270,   -1,   -1,   -1,   -1,  275,   -1,   -1,   -1,  279,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,  288,   -1,
   -1,   -1,   -1,   -1,   -1,  295,   -1,  298,   -1,   -1,
  300,   -1,   -1,   -1,  304,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,  316,   -1,  318,   -1,
   -1,   -1,  322,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
  330,  331,   -1,   -1,  334,   -1,   -1,  337,  339,   -1,
   -1,   -1,   -1,  344,   -1,  346,  347,  348,  349,  350,
  351,  352,  353,  354,  355,  356,  357,   -1,   -1,   -1,
   -1,   -1,  363,  364,   -1,   -1,   -1,   -1,  369,  370,
  371,  372,  373,  374,  375,  376,  377,   -1,  379,  380,
   -1,  382,  383,  384,  385,  386,  387,  388,  389,  390,
  391,   -1,  393,  394,  395,  396,  397,  398,  399,  400,
  401,  402,  403,  404,  405,  406,  407,  408,  409,  410,
  411,  412,  413,  414,   -1,  256,  256,   -1,  419,  419,
  421,  262,   -1,  424,   -1,  265,   -1,  267,   -1,  430,
  270,   -1,   -1,   -1,   -1,  275,   -1,   -1,   -1,  279,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,  288,   -1,
   -1,   -1,   -1,   -1,   -1,  295,   -1,  298,   -1,   -1,
  300,   -1,   -1,   -1,  304,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,  316,   -1,  318,   -1,
   -1,   -1,  322,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
  330,  331,   -1,   -1,  334,   -1,   -1,  337,  339,   -1,
   -1,   -1,   -1,  344,   -1,  346,  347,  348,  349,  350,
  351,  352,  353,  354,  355,  356,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,  364,   -1,   -1,   -1,  368,  369,  370,
  371,  372,  373,  374,  375,  376,  377,   -1,  379,  380,
   -1,  382,  383,  384,  385,  386,  387,  388,  389,  390,
  391,   -1,  393,  394,  395,  396,  397,  398,  399,  400,
  401,  402,  403,  404,  405,  406,  407,  408,  409,  410,
  411,  412,  413,  414,  256,  256,   -1,   -1,   -1,  419,
  421,  262,   -1,  265,   -1,  267,   -1,   -1,  270,  430,
   -1,   -1,   -1,  275,   -1,   -1,   -1,  279,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,  288,   -1,   -1,   -1,
   -1,   -1,   -1,  295,   -1,   -1,   -1,  298,  300,   -1,
   -1,   -1,  304,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,  316,   -1,  318,   -1,   -1,   -1,
  322,   -1,   -1,   -1,   -1,   -1,   -1,   -1,  330,  331,
   -1,   -1,  334,   -1,   -1,  337,   -1,   -1,  339,   -1,
   -1,   -1,   -1,  344,   -1,  346,  347,  348,  349,  350,
  351,  352,  353,  354,  355,  356,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,  364,   -1,   -1,   -1,  368,  369,   -1,
  371,  372,  373,  374,  375,  376,  377,   -1,  379,  380,
   -1,  382,  383,  384,  385,  386,  387,  388,  389,  390,
  391,   -1,  393,  394,  395,  396,  397,  398,  399,  400,
  401,  402,  403,  404,  405,  406,  407,  408,  409,  410,
  411,  412,  413,  414,   -1,  256,  256,  419,   -1,   -1,
  421,  262,   -1,  424,   -1,  265,   -1,  267,   -1,  430,
  270,   -1,   -1,   -1,   -1,  275,   -1,   -1,   -1,  279,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,  288,   -1,
   -1,   -1,   -1,   -1,   -1,  295,   -1,  298,   -1,   -1,
  300,   -1,   -1,   -1,  304,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,  316,   -1,  318,   -1,
   -1,   -1,  322,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
  330,  331,   -1,   -1,  334,   -1,   -1,  337,  339,   -1,
   -1,   -1,   -1,  344,   -1,  346,  347,  348,  349,  350,
  351,  352,  353,  354,  355,  356,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,  364,   -1,   -1,   -1,   -1,  369,   -1,
  371,  372,  373,  374,  375,  376,  377,   -1,  379,  380,
   -1,  382,  383,  384,  385,  386,  387,  388,  389,  390,
  391,   -1,  393,  394,  395,  396,  397,  398,  399,  400,
  401,  402,  403,  404,  405,  406,  407,  408,  409,  410,
  411,  412,  413,  414,   -1,  256,  256,   -1,   -1,  419,
  421,  262,   -1,  424,   -1,  265,   -1,  267,   -1,  430,
  270,   -1,   -1,   -1,   -1,  275,   -1,   -1,   -1,  279,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,  288,   -1,
   -1,   -1,   -1,   -1,   -1,  295,   -1,  298,   -1,   -1,
  300,   -1,   -1,   -1,  304,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,  316,   -1,  318,   -1,
   -1,   -1,  322,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
  330,  331,   -1,   -1,  334,   -1,   -1,  337,  339,   -1,
   -1,   -1,   -1,  344,   -1,  346,  347,  348,  349,  350,
  351,  352,  353,  354,  355,  356,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,  364,   -1,   -1,   -1,   -1,  369,   -1,
  371,  372,  373,  374,  375,  376,  377,   -1,  379,  380,
   -1,  382,  383,  384,  385,  386,  387,  388,  389,  390,
  391,   -1,  393,  394,  395,  396,  397,  398,  399,  400,
  401,  402,  403,  404,  405,  406,  407,  408,  409,  410,
  411,  412,  413,  414,   -1,  256,  256,   -1,   -1,  419,
  421,  262,   -1,  424,   -1,  265,   -1,  267,   -1,  430,
  270,   -1,   -1,   -1,   -1,  275,   -1,   -1,   -1,  279,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,  288,   -1,
   -1,   -1,   -1,   -1,   -1,  295,   -1,  298,   -1,   -1,
  300,   -1,   -1,   -1,  304,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,  316,   -1,  318,   -1,
   -1,   -1,  322,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
  330,  331,   -1,   -1,  334,   -1,   -1,  337,  339,   -1,
   -1,   -1,   -1,  344,   -1,  346,  347,  348,  349,  350,
  351,  352,  353,  354,  355,  356,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,  364,   -1,   -1,   -1,   -1,  369,   -1,
  371,  372,  373,  374,  375,  376,  377,   -1,  379,  380,
   -1,  382,  383,  384,  385,  386,  387,  388,  389,  390,
  391,   -1,  393,  394,  395,  396,  397,  398,  399,  400,
  401,  402,  403,  404,  405,  406,  407,  408,  409,  410,
  411,  412,  413,  414,   -1,  256,   -1,   -1,  261,  419,
  421,  262,   -1,  424,   -1,  266,   -1,   -1,   -1,  430,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,  284,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,  297,   -1,   -1,  298,   -1,  302,
   -1,   -1,   -1,   -1,  307,   -1,  309,  310,  311,  312,
   -1,   -1,   -1,  314,  317,   -1,   -1,   -1,  321,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
  333,   -1,   -1,  336,   -1,  338,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,  256,
   -1,   -1,   -1,   -1,   -1,  262,  357,   -1,   -1,  362,
   -1,   -1,  363,  364,   -1,   -1,   -1,   -1,  369,  370,
  371,  372,  373,  374,  375,  376,  377,   -1,  379,  380,
   -1,  382,  383,  384,  385,  386,  387,  388,  389,  390,
  391,  298,  393,  394,  395,  396,  397,  398,  399,  400,
  401,  402,  403,  404,  405,  406,  407,  408,  409,  410,
  411,  412,  413,  414,   -1,   -1,  419,   -1,  419,  256,
  421,   -1,   -1,  424,   -1,  262,   -1,   -1,   -1,  430,
   -1,   -1,  339,   -1,   -1,   -1,   -1,  344,   -1,  346,
  347,  348,  349,  350,  351,  352,  353,  354,  355,  356,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,  298,  369,   -1,  371,   -1,  373,   -1,  375,  376,
  377,   -1,  379,  380,   -1,  382,  383,  384,  385,  386,
  387,  388,  389,  390,  391,   -1,   -1,   -1,  395,  396,
  397,  398,  399,  400,  401,  402,  403,  404,  405,  406,
  407,  408,  409,  410,  411,  412,   -1,  414,  256,   -1,
   -1,   -1,   -1,   -1,  262,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,  430,   -1,   -1,  363,  364,   -1,   -1,
   -1,   -1,  369,  370,   -1,  372,  373,  374,  375,   -1,
  377,   -1,  379,  380,   -1,  382,  383,  384,  385,  386,
  298,  388,  389,  390,  391,   -1,  393,  394,  395,  396,
  397,  398,  399,  400,  401,  402,  403,  404,  405,  406,
  407,  408,  409,  410,  411,  412,  413,  414,   -1,   -1,
  256,   -1,  419,   -1,  421,   -1,  262,  424,   -1,   -1,
   -1,  339,   -1,  430,   -1,   -1,  344,   -1,  346,  347,
  348,  349,  350,  351,  352,  353,  354,  355,  356,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,  369,  298,  371,   -1,  373,   -1,  375,  376,  377,
   -1,  379,  380,   -1,   -1,  383,  384,  385,  386,  387,
  388,  389,  390,  391,   -1,   -1,   -1,  395,  396,  397,
  398,  399,  400,  401,  402,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,  339,   -1,   -1,  414,   -1,  344,   -1,
  346,  347,  348,  349,  350,  351,  352,  353,  354,  355,
  356,   -1,  430,   -1,   -1,  256,   -1,   -1,   -1,   -1,
   -1,  262,   -1,  369,   -1,  371,   -1,  373,   -1,  375,
  376,  377,   -1,  379,  380,   -1,   -1,  383,  384,  385,
  386,   -1,   -1,   -1,  390,  391,   -1,   -1,   -1,  395,
  396,  397,  398,  399,  400,  401,  402,  298,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,  414,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,  430,   -1,   -1,  256,   -1,   -1,
   -1,   -1,   -1,  262,   -1,   -1,   -1,   -1,  339,   -1,
   -1,   -1,   -1,  344,   -1,  346,  347,  348,  349,  350,
  351,  352,  353,  354,  355,  356,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,  369,  298,
  371,   -1,  373,   -1,  375,  376,  377,   -1,  379,  380,
   -1,   -1,  383,  384,  385,  386,   -1,   -1,   -1,  390,
  391,   -1,   -1,   -1,  395,  396,  397,  398,  399,  400,
  401,  402,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
  339,   -1,   -1,  414,   -1,  344,   -1,  346,  347,  348,
  349,  350,  351,  352,  353,  354,  355,  356,   -1,  430,
   -1,   -1,  256,   -1,   -1,   -1,   -1,   -1,  262,   -1,
  369,   -1,  371,   -1,  373,   -1,  375,  376,  377,   -1,
  379,  380,   -1,   -1,  383,  384,  385,  386,   -1,   -1,
   -1,  390,  391,   -1,   -1,   -1,  395,  396,  397,  398,
  399,  400,  401,  402,  298,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,  414,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,  430,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,  339,   -1,   -1,   -1,   -1,
  344,   -1,  346,  347,  348,  349,  350,  351,  352,  353,
  354,  355,  356,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,  369,   -1,  371,   -1,  373,
   -1,  375,  376,  377,   -1,  379,  380,   -1,   -1,  383,
  384,  385,  386,   -1,   -1,   -1,  390,  391,   -1,   -1,
   -1,  395,  396,  397,  398,  399,  400,  401,  402,   -1,
  256,   -1,  256,   -1,   -1,   -1,   -1,   -1,  264,  265,
  414,  267,   -1,   -1,  270,  271,   -1,   -1,   -1,  275,
  276,  277,   -1,  279,   -1,   -1,  430,   -1,   -1,  285,
   -1,   -1,  288,   -1,   -1,   -1,   -1,   -1,   -1,  295,
   -1,   -1,   -1,   -1,  300,   -1,  302,  303,  304,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
  316,   -1,  318,  319,   -1,   -1,  322,   -1,   -1,  325,
   -1,  327,   -1,  329,  330,  331,  332,   -1,  334,   -1,
   -1,   -1,   -1,   -1,   -1,  339,   -1,  256,   -1,   -1,
  344,   -1,  346,  347,  348,  349,  350,  351,  352,  353,
  354,  355,  356,  359,  360,  361,  362,  363,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,  369,  372,  371,   -1,  373,
   -1,  375,  376,  377,   -1,   -1,   -1,   -1,   -1,  383,
  384,  385,  386,   -1,   -1,   -1,  390,  391,   -1,   -1,
   -1,  395,  396,  397,  398,  399,  400,  401,  402,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,  256,   -1,   -1,   -1,
  414,   -1,  418,  419,   -1,   -1,   -1,   -1,   -1,   -1,
  339,   -1,   -1,  429,  430,  344,  430,  346,  347,  348,
  349,  350,  351,  352,  353,  354,  355,  356,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
  369,   -1,  371,   -1,  373,   -1,  375,  376,  377,   -1,
   -1,   -1,   -1,   -1,  383,  384,  385,  386,   -1,   -1,
   -1,  390,  391,   -1,   -1,  256,  395,  396,  397,  398,
  399,  400,  401,  402,   -1,   -1,   -1,   -1,   -1,  339,
   -1,   -1,   -1,   -1,  344,  414,  346,  347,  348,  349,
  350,  351,  352,  353,  354,  355,  356,   -1,   -1,   -1,
   -1,  430,   -1,   -1,   -1,   -1,   -1,   -1,   -1,  369,
   -1,  371,   -1,  373,   -1,  375,  376,  377,   -1,   -1,
   -1,   -1,   -1,  383,  384,  385,  386,   -1,   -1,   -1,
  390,  391,   -1,   -1,  256,   -1,   -1,  397,  398,  399,
  400,  401,  402,   -1,   -1,   -1,   -1,   -1,  339,   -1,
   -1,   -1,   -1,  344,  414,  346,  347,  348,  349,  350,
  351,  352,  353,  354,  355,  356,   -1,   -1,   -1,   -1,
  430,   -1,   -1,   -1,   -1,   -1,   -1,   -1,  369,   -1,
  371,   -1,  373,   -1,  375,  376,  377,   -1,   -1,   -1,
   -1,   -1,  383,  384,  385,  386,   -1,   -1,   -1,  390,
  391,   -1,   -1,  256,   -1,   -1,  397,  398,  399,  400,
  401,  402,   -1,   -1,   -1,   -1,   -1,  339,   -1,   -1,
   -1,   -1,  344,  414,  346,  347,  348,  349,  350,  351,
  352,  353,  354,  355,  356,   -1,   -1,   -1,   -1,  430,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,  369,   -1,  371,
   -1,  373,   -1,  375,  376,  377,   -1,   -1,   -1,   -1,
   -1,  383,  384,  385,  386,   -1,   -1,   -1,  390,  391,
   -1,   -1,  256,   -1,   -1,  397,  398,  399,  400,  401,
  402,   -1,   -1,   -1,   -1,   -1,  339,   -1,   -1,   -1,
   -1,  344,  414,  346,  347,  348,  349,  350,  351,  352,
  353,  354,  355,  356,   -1,   -1,   -1,   -1,  430,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,  369,   -1,  371,   -1,
  373,   -1,  375,  376,  377,   -1,   -1,   -1,   -1,   -1,
  383,  384,  385,  386,  256,   -1,   -1,  390,  391,   -1,
  262,   -1,   -1,   -1,  397,  398,  399,  400,  401,  402,
   -1,   -1,   -1,   -1,   -1,  339,   -1,   -1,   -1,   -1,
  344,  414,  346,  347,  348,  349,  350,  351,  352,  353,
  354,  355,  356,   -1,   -1,   -1,  298,  430,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,  369,   -1,  371,   -1,  373,
   -1,  375,  376,  377,   -1,   -1,   -1,   -1,   -1,  383,
  384,  385,  386,   -1,   -1,   -1,  390,  391,   -1,   -1,
   -1,   -1,   -1,  397,  398,  399,  400,  401,  402,   -1,
   -1,  256,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
  414,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,  364,   -1,   -1,   -1,  430,  369,   -1,   -1,
  372,   -1,  374,  375,   -1,   -1,   -1,  379,  380,   -1,
   -1,  383,  384,  385,  386,  387,  388,  389,  390,  391,
   -1,  393,  394,  395,  396,  397,  398,  399,  400,  401,
  402,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
  256,  413,  414,   -1,   -1,   -1,   -1,   -1,   -1,  421,
   -1,   -1,  424,   -1,  339,   -1,   -1,   -1,  430,  344,
   -1,  346,  347,  348,  349,  350,  351,  352,  353,  354,
  355,  356,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,  369,   -1,  371,   -1,  373,   -1,
  375,  376,  377,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
  385,  386,   -1,   -1,   -1,  390,  391,   -1,   -1,  256,
   -1,   -1,   -1,   -1,  399,  400,  401,  402,   -1,   -1,
   -1,   -1,   -1,  339,   -1,   -1,   -1,   -1,  344,  414,
  346,  347,  348,  349,  350,  351,  352,  353,  354,  355,
  356,   -1,   -1,   -1,   -1,  430,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,  369,   -1,  371,   -1,  373,   -1,  375,
  376,  377,   -1,   -1,   -1,   -1,   -1,   -1,   -1,  385,
  386,   -1,   -1,   -1,  390,  391,   -1,   -1,  256,   -1,
   -1,   -1,   -1,  399,  400,  401,  402,   -1,   -1,   -1,
   -1,   -1,  339,   -1,   -1,   -1,   -1,  344,  414,  346,
  347,  348,  349,  350,  351,  352,  353,  354,  355,  356,
   -1,   -1,   -1,   -1,  430,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,  369,   -1,  371,   -1,  373,   -1,  375,  376,
  377,   -1,   -1,   -1,   -1,   -1,   -1,   -1,  385,  386,
   -1,   -1,   -1,  390,  391,   -1,   -1,  256,   -1,   -1,
   -1,   -1,  399,  400,  401,  402,   -1,   -1,   -1,   -1,
   -1,  339,   -1,   -1,   -1,   -1,  344,  414,  346,  347,
  348,  349,  350,  351,  352,  353,  354,  355,  356,   -1,
   -1,   -1,   -1,  430,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,  369,   -1,  371,   -1,  373,   -1,  375,  376,  377,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,  385,  386,   -1,
   -1,   -1,  390,  391,   -1,   -1,  256,   -1,   -1,   -1,
   -1,   -1,   -1,  401,  402,   -1,   -1,   -1,   -1,   -1,
  339,   -1,   -1,   -1,   -1,  344,  414,  346,  347,  348,
  349,  350,  351,  352,  353,  354,  355,  356,   -1,   -1,
   -1,   -1,  430,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
  369,   -1,  371,   -1,  373,   -1,  375,  376,  377,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,  385,  386,   -1,   -1,
   -1,  390,  391,   -1,   -1,  256,   -1,   -1,   -1,   -1,
   -1,   -1,  401,  402,   -1,   -1,   -1,   -1,   -1,  339,
   -1,   -1,   -1,   -1,  344,  414,  346,  347,  348,  349,
  350,  351,  352,  353,  354,  355,  356,   -1,   -1,   -1,
   -1,  430,   -1,   -1,   -1,   -1,   -1,   -1,   -1,  369,
   -1,  371,   -1,  373,   -1,  375,  376,  377,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,  386,   -1,   -1,   -1,
  390,  391,   -1,   -1,  256,   -1,   -1,   -1,   -1,   -1,
   -1,  401,  402,   -1,   -1,   -1,   -1,   -1,  339,   -1,
   -1,   -1,   -1,  344,  414,  346,  347,  348,  349,  350,
  351,  352,  353,  354,  355,  356,   -1,   -1,   -1,   -1,
  430,   -1,   -1,   -1,   -1,   -1,   -1,   -1,  369,   -1,
  371,   -1,  373,   -1,  375,  376,  377,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,  386,   -1,   -1,   -1,  390,
  391,   -1,   -1,  256,   -1,   -1,   -1,   -1,   -1,   -1,
  401,  402,   -1,   -1,   -1,   -1,   -1,  339,   -1,   -1,
   -1,   -1,  344,  414,  346,  347,  348,  349,  350,  351,
  352,  353,  354,  355,  356,   -1,   -1,   -1,   -1,  430,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,  369,   -1,  371,
   -1,  373,   -1,  375,  376,  377,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,  386,   -1,   -1,   -1,   -1,  391,
   -1,   -1,  256,   -1,   -1,   -1,   -1,   -1,   -1,  401,
  402,   -1,   -1,   -1,   -1,   -1,  339,   -1,   -1,   -1,
   -1,  344,  414,  346,  347,  348,  349,  350,  351,  352,
  353,  354,  355,  356,   -1,   -1,   -1,   -1,  430,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,  369,   -1,  371,   -1,
  373,   -1,  375,  376,  377,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,  386,   -1,   -1,   -1,   -1,  391,   -1,
   -1,  256,   -1,   -1,   -1,   -1,   -1,   -1,  401,  402,
   -1,   -1,   -1,   -1,   -1,  339,   -1,   -1,   -1,   -1,
  344,  414,  346,  347,  348,  349,  350,  351,  352,  353,
  354,  355,  356,   -1,   -1,   -1,   -1,  430,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,  369,   -1,  371,   -1,  373,
   -1,  375,  376,  377,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,  391,   -1,   -1,
  256,   -1,   -1,   -1,   -1,   -1,   -1,  401,  402,   -1,
   -1,   -1,   -1,   -1,  339,   -1,   -1,   -1,   -1,  344,
  414,  346,  347,  348,  349,  350,  351,  352,  353,  354,
  355,  356,   -1,   -1,   -1,   -1,  430,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,  369,   -1,  371,   -1,  373,   -1,
  375,  376,  377,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,  391,   -1,   -1,  256,
   -1,   -1,   -1,   -1,   -1,   -1,  401,  402,   -1,   -1,
   -1,   -1,   -1,  339,   -1,   -1,   -1,   -1,  344,  414,
  346,  347,  348,  349,  350,  351,  352,  353,  354,  355,
  356,   -1,   -1,   -1,   -1,  430,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,  369,   -1,  371,   -1,  373,   -1,  375,
  376,  377,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,  391,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,  402,   -1,   -1,   -1,
   -1,   -1,  339,   -1,   -1,   -1,   -1,  344,  414,  346,
  347,  348,  349,  350,  351,  352,  353,  354,  355,  356,
   -1,   -1,   -1,   -1,  430,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,  369,   -1,  371,   -1,  373,   -1,  375,  376,
  377,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,  256,   -1,  391,   -1,   -1,   -1,   -1,   -1,
  264,  265,  266,  267,  268,  402,  270,  271,   -1,  273,
  274,  275,  276,  277,  278,  279,   -1,  414,   -1,   -1,
   -1,  285,   -1,  287,  288,  289,  290,  291,  292,   -1,
   -1,  295,   -1,  430,   -1,  299,  300,   -1,  302,  303,
  304,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
  314,   -1,  316,   -1,  318,  319,   -1,   -1,  322,   -1,
  324,  325,  326,  327,  328,  329,  330,  331,  332,  333,
  334,  335,   -1,  337,   -1,   -1,  340,  341,   -1,   -1,
  344,  345,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,  359,  360,  361,  362,  363,
   -1,   -1,   -1,   -1,  368,   -1,   -1,   -1,  372,   -1,
   -1,   -1,   -1,  377,  378,  379,  380,  381,   -1,   -1,
   -1,  385,   -1,  387,   -1,   -1,   -1,   -1,   -1,  393,
  394,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,  256,   -1,  418,  419,  420,  421,   -1,  423,
  264,  265,  266,  267,   -1,   -1,  270,  271,   -1,  273,
  274,  275,  276,  277,  278,  279,   -1,   -1,   -1,   -1,
   -1,  285,   -1,  287,  288,  289,  290,  291,  292,   -1,
   -1,  295,   -1,   -1,   -1,  299,  300,   -1,  302,  303,
  304,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
  314,   -1,  316,   -1,  318,  319,   -1,   -1,  322,   -1,
  324,  325,  326,  327,  328,  329,  330,  331,  332,  333,
  334,  335,   -1,  337,   -1,   -1,  340,  341,   -1,   -1,
  344,  345,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,  359,  360,  361,  362,  363,
   -1,   -1,   -1,   -1,  368,   -1,   -1,   -1,  372,   -1,
   -1,   -1,   -1,  377,  378,  379,  380,  381,   -1,   -1,
   -1,  385,   -1,  387,   -1,   -1,   -1,   -1,   -1,  393,
  394,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
  256,   -1,   -1,   -1,  418,  419,  420,  421,  264,  265,
  266,  267,   -1,   -1,  270,  271,   -1,  273,  274,  275,
  276,  277,  278,  279,   -1,   -1,   -1,   -1,   -1,  285,
   -1,  287,  288,  289,  290,  291,  292,   -1,   -1,  295,
   -1,   -1,   -1,  299,  300,   -1,  302,  303,  304,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,  314,   -1,
  316,   -1,  318,  319,   -1,   -1,  322,   -1,  324,  325,
  326,  327,  328,  329,  330,  331,  332,  333,  334,  335,
   -1,  337,   -1,   -1,  340,  341,   -1,   -1,  344,  345,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,  359,  360,  361,  362,  363,   -1,   -1,
   -1,   -1,  368,   -1,   -1,   -1,  372,   -1,   -1,   -1,
   -1,  377,  378,  379,  380,  381,   -1,   -1,   -1,  385,
   -1,  387,   -1,   -1,   -1,   -1,   -1,  393,  394,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,  256,   -1,
   -1,   -1,  418,  419,  420,  421,  264,  265,  266,  267,
   -1,   -1,  270,  271,   -1,  273,  274,  275,  276,  277,
  278,  279,   -1,   -1,   -1,   -1,   -1,  285,   -1,  287,
  288,  289,  290,  291,  292,   -1,   -1,  295,   -1,   -1,
   -1,  299,  300,   -1,  302,  303,  304,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,  314,   -1,  316,   -1,
  318,  319,   -1,   -1,  322,   -1,  324,  325,  326,  327,
  328,  329,  330,  331,  332,  333,  334,  335,   -1,  337,
   -1,   -1,  340,  341,   -1,   -1,  344,  345,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,  359,  360,  361,  362,  363,   -1,   -1,   -1,   -1,
  368,   -1,   -1,   -1,  372,   -1,   -1,   -1,   -1,  377,
  378,  379,  380,  381,   -1,   -1,   -1,  385,   -1,  387,
   -1,   -1,   -1,   -1,   -1,  393,  394,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,  256,   -1,   -1,   -1,
  418,  419,  420,  421,  264,  265,  266,  267,   -1,   -1,
  270,  271,   -1,  273,  274,  275,  276,  277,  278,  279,
   -1,   -1,   -1,   -1,   -1,  285,   -1,  287,  288,  289,
  290,  291,  292,   -1,   -1,  295,   -1,   -1,   -1,  299,
  300,   -1,  302,  303,  304,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,  314,   -1,  316,   -1,  318,  319,
   -1,   -1,  322,   -1,  324,  325,  326,  327,  328,  329,
  330,  331,  332,  333,  334,  335,   -1,  337,   -1,   -1,
  340,  341,   -1,   -1,  344,  345,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,  359,
  360,  361,  362,  363,   -1,   -1,   -1,   -1,  368,   -1,
   -1,   -1,  372,   -1,   -1,   -1,   -1,  377,  378,  379,
  380,  381,   -1,   -1,   -1,  385,   -1,  387,   -1,   -1,
   -1,   -1,   -1,  393,  394,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,  256,   -1,   -1,   -1,  418,  419,
  420,  421,  264,  265,   -1,  267,   -1,   -1,  270,  271,
   -1,   -1,   -1,  275,  276,  277,   -1,  279,   -1,   -1,
  265,   -1,  267,  285,   -1,  270,  288,   -1,   -1,   -1,
  275,   -1,   -1,  295,  279,   -1,   -1,   -1,  300,   -1,
  302,  303,  304,  288,  306,   -1,   -1,   -1,   -1,   -1,
  295,  313,   -1,   -1,  316,  300,  318,  319,   -1,  304,
  322,   -1,   -1,  325,   -1,  327,   -1,  329,  330,  331,
  332,  316,  334,  318,   -1,   -1,   -1,  322,   -1,  341,
   -1,   -1,  344,  345,   -1,  330,  331,   -1,   -1,  334,
   -1,   -1,  337,   -1,   -1,   -1,   -1,  359,  360,  361,
  362,  363,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
  372,   -1,   -1,  375,   -1,   -1,  378,  379,  380,  381,
   -1,   -1,   -1,  385,   -1,  387,   -1,   -1,  373,   -1,
   -1,  393,  394,   -1,   -1,   -1,   -1,   -1,   -1,  264,
  265,   -1,  267,   -1,   -1,  270,  271,   -1,   -1,   -1,
  275,  276,  277,   -1,  279,   -1,  418,  419,  420,  421,
  285,   -1,   -1,  288,   -1,   -1,   -1,   -1,   -1,   -1,
  295,   -1,   -1,   -1,  419,  300,   -1,  302,  303,  304,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,  316,   -1,  318,  319,   -1,   -1,  322,   -1,   -1,
  325,   -1,  327,   -1,  329,  330,  331,  332,   -1,  334,
   -1,   -1,   -1,   -1,   -1,   -1,  341,   -1,   -1,  344,
  345,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,  359,  360,  361,  362,  363,   -1,
   -1,   -1,   -1,  368,  369,   -1,   -1,  372,   -1,   -1,
   -1,   -1,   -1,  378,  379,  380,  381,   -1,   -1,   -1,
  385,   -1,  387,   -1,   -1,   -1,   -1,   -1,  393,  394,
   -1,   -1,   -1,   -1,   -1,   -1,  264,  265,   -1,  267,
   -1,   -1,  270,  271,   -1,   -1,   -1,  275,  276,  277,
   -1,  279,   -1,  418,  419,  420,  421,  285,   -1,  424,
  288,   -1,   -1,   -1,  429,   -1,   -1,  295,   -1,   -1,
   -1,   -1,  300,   -1,  302,  303,  304,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,  316,   -1,
  318,  319,   -1,   -1,  322,   -1,   -1,  325,   -1,  327,
   -1,  329,  330,  331,  332,   -1,  334,   -1,   -1,   -1,
   -1,   -1,   -1,  341,   -1,   -1,  344,  345,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,  359,  360,  361,  362,  363,   -1,   -1,   -1,   -1,
  368,   -1,   -1,   -1,  372,   -1,   -1,   -1,   -1,   -1,
  378,  379,  380,  381,   -1,   -1,   -1,  385,   -1,  387,
   -1,   -1,   -1,   -1,   -1,  393,  394,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,  256,
  418,  419,  420,  421,   -1,   -1,  424,  264,  265,   -1,
  267,  429,   -1,  270,  271,   -1,   -1,   -1,  275,  276,
  277,   -1,  279,   -1,   -1,  265,   -1,  267,  285,   -1,
  270,  288,   -1,   -1,   -1,  275,   -1,   -1,  295,  279,
   -1,   -1,   -1,  300,   -1,  302,  303,  304,  288,   -1,
   -1,   -1,   -1,   -1,   -1,  295,   -1,   -1,   -1,  316,
  300,  318,  319,   -1,  304,  322,   -1,   -1,  325,   -1,
  327,   -1,  329,  330,  331,  332,  316,  334,  318,   -1,
   -1,   -1,  322,   -1,  341,   -1,   -1,  344,  345,   -1,
  330,  331,   -1,   -1,  334,   -1,   -1,  337,   -1,   -1,
   -1,   -1,  359,  360,  361,  362,  363,   -1,   -1,   -1,
   -1,  368,  369,   -1,   -1,  372,   -1,   -1,   -1,   -1,
   -1,  378,  379,  380,  381,   -1,   -1,   -1,  385,   -1,
  387,  371,   -1,   -1,   -1,   -1,  393,  394,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,  256,   -1,   -1,
   -1,  418,  419,  420,  421,  264,  265,   -1,  267,   -1,
   -1,  270,  271,   -1,   -1,   -1,  275,  276,  277,  419,
  279,   -1,   -1,  265,   -1,  267,  285,   -1,  270,  288,
   -1,   -1,   -1,  275,   -1,   -1,  295,  279,   -1,   -1,
   -1,  300,   -1,  302,  303,  304,  288,  306,   -1,   -1,
   -1,   -1,   -1,  295,  313,   -1,   -1,  316,  300,  318,
  319,   -1,  304,  322,   -1,   -1,  325,   -1,  327,   -1,
  329,  330,  331,  332,  316,  334,  318,   -1,   -1,   -1,
  322,   -1,  341,   -1,   -1,  344,  345,   -1,  330,  331,
   -1,   -1,  334,   -1,   -1,  337,   -1,   -1,   -1,   -1,
  359,  360,  361,  362,  363,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,  372,   -1,   -1,   -1,   -1,   -1,  378,
  379,  380,  381,   -1,   -1,   -1,  385,   -1,  387,   -1,
   -1,   -1,   -1,   -1,  393,  394,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,  256,   -1,   -1,   -1,  418,
  419,  420,  421,  264,  265,   -1,  267,   -1,   -1,  270,
  271,   -1,   -1,   -1,  275,  276,  277,  419,  279,   -1,
   -1,  265,   -1,  267,  285,   -1,  270,  288,   -1,   -1,
   -1,  275,   -1,   -1,  295,  279,   -1,   -1,   -1,  300,
   -1,  302,  303,  304,  288,   -1,   -1,   -1,   -1,   -1,
   -1,  295,   -1,   -1,   -1,  316,  300,  318,  319,  320,
  304,  322,   -1,   -1,  325,   -1,  327,   -1,  329,  330,
  331,  332,  316,  334,  318,   -1,   -1,   -1,  322,   -1,
  341,   -1,   -1,  344,  345,   -1,  330,  331,   -1,   -1,
  334,   -1,   -1,  337,   -1,   -1,   -1,   -1,  359,  360,
  361,  362,  363,   -1,   -1,   -1,   -1,  368,   -1,   -1,
   -1,  372,   -1,   -1,   -1,   -1,   -1,  378,  379,  380,
  381,   -1,   -1,   -1,  385,   -1,  387,   -1,   -1,   -1,
   -1,   -1,  393,  394,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,  256,   -1,   -1,   -1,  418,  419,  420,
  421,  264,  265,   -1,  267,   -1,   -1,  270,  271,   -1,
   -1,   -1,  275,  276,  277,  419,  279,   -1,   -1,  265,
   -1,  267,  285,   -1,  270,  288,   -1,   -1,   -1,  275,
   -1,   -1,  295,  279,   -1,   -1,   -1,  300,   -1,  302,
  303,  304,  288,   -1,   -1,   -1,   -1,   -1,   -1,  295,
   -1,   -1,   -1,  316,  300,  318,  319,   -1,  304,  322,
   -1,   -1,  325,   -1,  327,   -1,  329,  330,  331,  332,
  316,  334,  318,   -1,  337,   -1,  322,   -1,  341,   -1,
   -1,  344,  345,   -1,  330,  331,   -1,   -1,  334,   -1,
   -1,  337,   -1,   -1,   -1,   -1,  359,  360,  361,  362,
  363,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,  372,
   -1,   -1,   -1,   -1,   -1,  378,  379,  380,  381,   -1,
   -1,   -1,  385,   -1,  387,   -1,   -1,   -1,   -1,   -1,
  393,  394,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,  256,   -1,   -1,   -1,  418,  419,  420,  421,  264,
  265,   -1,  267,   -1,   -1,  270,  271,   -1,   -1,   -1,
  275,  276,  277,  419,  279,   -1,   -1,   -1,   -1,   -1,
  285,   -1,   -1,  288,   -1,   -1,   -1,   -1,   -1,   -1,
  295,   -1,   -1,   -1,   -1,  300,   -1,  302,  303,  304,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,  316,   -1,  318,  319,   -1,   -1,  322,   -1,   -1,
  325,   -1,  327,   -1,  329,  330,  331,  332,   -1,  334,
   -1,   -1,   -1,   -1,   -1,   -1,  341,   -1,   -1,  344,
  345,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,  359,  360,  361,  362,  363,   -1,
   -1,   -1,   -1,  368,   -1,   -1,   -1,  372,   -1,   -1,
   -1,   -1,   -1,  378,  379,  380,  381,   -1,   -1,   -1,
  385,   -1,  387,   -1,   -1,   -1,   -1,   -1,  393,  394,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,  256,   -1,  418,  419,  420,  421,  262,   -1,  264,
  265,   -1,  267,   -1,   -1,  270,  271,   -1,   -1,   -1,
  275,  276,  277,   -1,  279,   -1,   -1,   -1,   -1,   -1,
  285,   -1,   -1,  288,   -1,   -1,   -1,   -1,   -1,   -1,
  295,   -1,   -1,  298,   -1,  300,   -1,  302,  303,  304,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,  316,   -1,  318,  319,   -1,   -1,  322,   -1,   -1,
  325,   -1,  327,   -1,  329,  330,  331,  332,   -1,  334,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,  343,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,  359,  360,  361,  362,  363,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,  372,   -1,  374,
   -1,   -1,   -1,  378,  379,  380,  381,  382,   -1,   -1,
  385,   -1,  387,  256,   -1,   -1,   -1,   -1,  393,  394,
   -1,  264,  265,   -1,  267,   -1,   -1,  270,  271,   -1,
   -1,   -1,  275,  276,  277,   -1,  279,   -1,   -1,   -1,
   -1,   -1,  285,  418,  419,  288,  421,   -1,   -1,   -1,
   -1,   -1,  295,   -1,   -1,   -1,   -1,  300,   -1,  302,
  303,  304,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,  316,   -1,  318,  319,   -1,   -1,  322,
   -1,   -1,  325,   -1,  327,   -1,  329,  330,  331,  332,
   -1,  334,   -1,   -1,   -1,   -1,   -1,   -1,  341,   -1,
   -1,  344,  345,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,  359,  360,  361,  362,
  363,   -1,   -1,   -1,   -1,   -1,  369,   -1,   -1,  372,
   -1,   -1,   -1,   -1,   -1,  378,  379,  380,  381,   -1,
   -1,   -1,  385,   -1,  387,   -1,   -1,   -1,   -1,   -1,
  393,  394,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,  256,   -1,   -1,   -1,  418,  419,  420,  421,  264,
  265,   -1,  267,   -1,   -1,  270,  271,   -1,   -1,   -1,
  275,  276,  277,   -1,  279,   -1,   -1,  265,   -1,  267,
  285,   -1,  270,  288,   -1,   -1,   -1,  275,   -1,   -1,
  295,  279,   -1,   -1,   -1,  300,   -1,  302,  303,  304,
  288,   -1,   -1,   -1,   -1,   -1,   -1,  295,   -1,   -1,
   -1,  316,  300,  318,  319,   -1,  304,  322,   -1,   -1,
  325,   -1,  327,   -1,  329,  330,  331,  332,  316,  334,
  318,   -1,   -1,   -1,  322,   -1,  341,   -1,   -1,  344,
  345,   -1,  330,  331,   -1,   -1,  334,   -1,   -1,  337,
   -1,   -1,   -1,   -1,  359,  360,  361,  362,  363,   -1,
   -1,   -1,   -1,   -1,  369,   -1,   -1,  372,   -1,   -1,
   -1,   -1,   -1,  378,  379,  380,  381,   -1,   -1,   -1,
  385,   -1,  387,   -1,   -1,   -1,   -1,   -1,  393,  394,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,  256,
   -1,   -1,   -1,  418,  419,  420,  421,  264,  265,   -1,
  267,   -1,   -1,  270,  271,   -1,   -1,   -1,  275,  276,
  277,  419,  279,   -1,   -1,  265,   -1,  267,  285,   -1,
  270,  288,   -1,   -1,   -1,  275,   -1,   -1,  295,  279,
   -1,   -1,   -1,  300,   -1,  302,  303,  304,  288,   -1,
   -1,   -1,   -1,   -1,   -1,  295,   -1,   -1,   -1,  316,
  300,  318,  319,   -1,  304,  322,   -1,   -1,  325,   -1,
  327,   -1,  329,  330,  331,  332,  316,  334,  318,   -1,
   -1,   -1,  322,   -1,  341,   -1,   -1,  344,  345,   -1,
  330,  331,   -1,   -1,  334,   -1,   -1,  337,   -1,   -1,
   -1,   -1,  359,  360,  361,  362,  363,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,  372,   -1,   -1,   -1,   -1,
   -1,  378,  379,  380,  381,   -1,   -1,   -1,  385,   -1,
  387,   -1,   -1,   -1,   -1,   -1,  393,  394,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,  256,   -1,   -1,
   -1,  418,  419,  420,  421,  264,  265,   -1,  267,   -1,
   -1,  270,  271,   -1,   -1,   -1,  275,  276,  277,  419,
  279,   -1,   -1,   -1,   -1,   -1,  285,   -1,   -1,  288,
   -1,   -1,   -1,   -1,   -1,   -1,  295,   -1,   -1,   -1,
   -1,  300,   -1,  302,  303,  304,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,  316,   -1,  318,
  319,   -1,   -1,  322,   -1,   -1,  325,   -1,  327,   -1,
  329,  330,  331,  332,   -1,  334,   -1,   -1,   -1,   -1,
   -1,   -1,  341,   -1,   -1,  344,  345,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
  359,  360,  361,  362,  363,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,  372,   -1,   -1,   -1,   -1,   -1,  378,
  379,  380,  381,   -1,   -1,   -1,  385,   -1,  387,   -1,
   -1,   -1,   -1,   -1,  393,  394,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,  256,   -1,  418,
  419,  420,  421,  262,   -1,  264,  265,   -1,  267,   -1,
   -1,  270,  271,   -1,   -1,   -1,  275,  276,  277,   -1,
  279,   -1,   -1,   -1,   -1,   -1,  285,   -1,   -1,  288,
   -1,   -1,   -1,   -1,   -1,   -1,  295,   -1,   -1,  298,
   -1,  300,   -1,  302,  303,  304,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,  316,   -1,  318,
  319,   -1,   -1,  322,   -1,   -1,  325,   -1,  327,   -1,
  329,  330,  331,  332,   -1,  334,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,  343,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
  359,  360,  361,  362,  363,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,  372,   -1,  374,   -1,   -1,   -1,  378,
  379,  380,  381,   -1,   -1,   -1,  385,   -1,  387,  256,
   -1,   -1,   -1,   -1,  393,  394,   -1,  264,  265,   -1,
  267,   -1,   -1,  270,  271,   -1,   -1,   -1,  275,  276,
  277,   -1,  279,   -1,   -1,   -1,   -1,   -1,  285,  418,
  419,  288,  421,   -1,   -1,   -1,   -1,   -1,  295,   -1,
   -1,   -1,   -1,  300,   -1,  302,  303,  304,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,  316,
   -1,  318,  319,   -1,   -1,  322,   -1,   -1,  325,   -1,
  327,   -1,  329,  330,  331,  332,   -1,  334,   -1,   -1,
   -1,   -1,   -1,   -1,  341,   -1,   -1,  344,  345,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,  359,  360,  361,  362,  363,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,  372,   -1,   -1,   -1,   -1,
   -1,  378,  379,  380,  381,   -1,   -1,   -1,  385,   -1,
  387,   -1,   -1,   -1,   -1,   -1,  393,  394,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,  256,   -1,   -1,
   -1,  418,  419,  420,  421,  264,  265,   -1,  267,   -1,
   -1,  270,  271,   -1,   -1,   -1,  275,  276,  277,   -1,
  279,   -1,   -1,  265,   -1,  267,  285,   -1,  270,  288,
   -1,   -1,   -1,  275,   -1,   -1,  295,  279,   -1,   -1,
   -1,  300,   -1,  302,  303,  304,  288,   -1,   -1,   -1,
   -1,   -1,   -1,  295,   -1,   -1,   -1,  316,  300,  318,
  319,   -1,  304,  322,   -1,   -1,  325,   -1,  327,   -1,
  329,  330,  331,  332,  316,  334,  318,   -1,   -1,   -1,
  322,   -1,  341,   -1,   -1,  344,  345,   -1,  330,  331,
   -1,   -1,  334,   -1,   -1,  337,   -1,   -1,   -1,   -1,
  359,  360,  361,  362,  363,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,  372,   -1,   -1,   -1,   -1,   -1,  378,
  379,  380,  381,   -1,   -1,   -1,  385,   -1,  387,   -1,
   -1,   -1,   -1,   -1,  393,  394,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,  256,   -1,   -1,   -1,  418,
  419,  420,  421,  264,  265,   -1,  267,   -1,   -1,  270,
  271,   -1,   -1,   -1,  275,  276,  277,  419,  279,   -1,
   -1,  265,   -1,  267,  285,   -1,  270,  288,   -1,   -1,
   -1,  275,   -1,   -1,  295,  279,   -1,   -1,   -1,  300,
   -1,  302,  303,  304,  288,   -1,   -1,   -1,   -1,   -1,
   -1,  295,   -1,   -1,   -1,  316,  300,  318,  319,   -1,
  304,  322,   -1,   -1,  325,   -1,  327,   -1,  329,  330,
  331,  332,  316,  334,  318,   -1,   -1,   -1,  322,   -1,
  341,   -1,   -1,  344,  345,   -1,  330,  331,   -1,   -1,
  334,   -1,   -1,  337,   -1,   -1,   -1,   -1,  359,  360,
  361,  362,  363,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,  372,   -1,   -1,   -1,   -1,   -1,  378,  379,  380,
  381,   -1,   -1,   -1,  385,   -1,  387,   -1,   -1,   -1,
   -1,   -1,  393,  394,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,  256,   -1,   -1,   -1,  418,  419,  420,
  421,  264,  265,   -1,  267,   -1,   -1,  270,  271,   -1,
   -1,   -1,  275,  276,  277,  419,  279,   -1,   -1,   -1,
   -1,   -1,  285,   -1,   -1,  288,   -1,   -1,   -1,   -1,
   -1,   -1,  295,   -1,   -1,   -1,   -1,  300,   -1,  302,
  303,  304,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,  316,   -1,  318,  319,   -1,   -1,  322,
   -1,   -1,  325,   -1,  327,   -1,  329,  330,  331,  332,
   -1,  334,   -1,   -1,   -1,   -1,   -1,   -1,  341,   -1,
   -1,  344,  345,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,  359,  360,  361,  362,
  363,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,  372,
   -1,   -1,   -1,   -1,   -1,  378,  379,  380,  381,   -1,
   -1,   -1,  385,   -1,  387,   -1,   -1,   -1,   -1,   -1,
  393,  394,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,  256,   -1,  418,  419,  420,  421,  262,
   -1,  264,  265,   -1,  267,   -1,   -1,  270,  271,   -1,
   -1,   -1,  275,  276,  277,   -1,  279,   -1,   -1,   -1,
   -1,   -1,  285,   -1,   -1,  288,   -1,   -1,   -1,   -1,
   -1,   -1,  295,   -1,   -1,  298,   -1,  300,   -1,  302,
  303,  304,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,  316,   -1,  318,  319,   -1,   -1,  322,
   -1,   -1,  325,   -1,  327,   -1,  329,  330,  331,  332,
   -1,  334,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,  359,  360,  361,  362,
  363,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,  372,
   -1,  374,   -1,   -1,   -1,  378,  379,  380,  381,   -1,
   -1,   -1,  385,   -1,  387,  256,   -1,   -1,   -1,   -1,
  393,  394,   -1,  264,  265,   -1,  267,   -1,   -1,  270,
  271,   -1,   -1,   -1,  275,  276,  277,   -1,  279,   -1,
   -1,   -1,   -1,   -1,  285,  418,  419,  288,  421,   -1,
   -1,   -1,   -1,   -1,  295,   -1,   -1,   -1,   -1,  300,
   -1,  302,  303,  304,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,  316,   -1,  318,  319,   -1,
   -1,  322,   -1,   -1,  325,   -1,  327,   -1,  329,  330,
  331,  332,   -1,  334,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,  359,  360,
  361,  362,  363,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,  372,   -1,  374,   -1,   -1,   -1,  378,  379,  380,
  381,   -1,   -1,   -1,  385,   -1,  387,  256,   -1,   -1,
   -1,   -1,  393,  394,   -1,  264,  265,   -1,  267,   -1,
   -1,  270,  271,   -1,   -1,   -1,  275,  276,  277,   -1,
  279,   -1,   -1,   -1,   -1,   -1,  285,  418,  419,  288,
  421,   -1,   -1,   -1,   -1,   -1,  295,   -1,   -1,   -1,
   -1,  300,   -1,  302,  303,  304,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,  316,   -1,  318,
  319,   -1,   -1,  322,   -1,   -1,  325,   -1,  327,   -1,
  329,  330,  331,  332,   -1,  334,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
  359,  360,  361,  362,  363,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,  372,   -1,   -1,   -1,   -1,   -1,  378,
  379,  380,  381,   -1,   -1,   -1,  385,   -1,  387,  256,
   -1,   -1,   -1,   -1,  393,  394,   -1,  264,  265,   -1,
  267,   -1,   -1,  270,  271,   -1,   -1,   -1,  275,  276,
  277,   -1,  279,   -1,   -1,   -1,   -1,   -1,  285,  418,
  419,  288,  421,   -1,   -1,   -1,   -1,   -1,  295,   -1,
   -1,   -1,   -1,  300,   -1,  302,  303,  304,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,  316,
   -1,  318,  319,   -1,   -1,  322,   -1,   -1,  325,   -1,
  327,   -1,  329,  330,  331,  332,   -1,  334,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,  359,  360,  361,  362,  363,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,  372,   -1,   -1,   -1,   -1,
   -1,  378,  379,  380,  381,   -1,   -1,   -1,  385,   -1,
  387,  256,   -1,   -1,   -1,   -1,  393,  394,   -1,  264,
  265,   -1,  267,   -1,   -1,  270,  271,   -1,   -1,   -1,
  275,  276,  277,   -1,  279,   -1,   -1,   -1,   -1,   -1,
  285,  418,  419,  288,  421,   -1,   -1,   -1,   -1,   -1,
  295,   -1,   -1,   -1,   -1,  300,   -1,  302,  303,  304,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,  316,   -1,  318,  319,   -1,   -1,  322,   -1,   -1,
  325,   -1,  327,   -1,  329,  330,  331,  332,   -1,  334,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,  359,  360,  361,  362,  363,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,  372,   -1,   -1,
   -1,   -1,   -1,  378,  379,  380,  381,   -1,   -1,   -1,
  385,   -1,  387,  256,   -1,   -1,   -1,   -1,  393,  394,
   -1,  264,  265,   -1,  267,   -1,   -1,  270,  271,   -1,
   -1,   -1,  275,  276,  277,   -1,  279,   -1,   -1,   -1,
   -1,   -1,  285,  418,  419,  288,  421,   -1,   -1,   -1,
   -1,   -1,  295,   -1,   -1,   -1,   -1,  300,   -1,  302,
  303,  304,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,  316,   -1,  318,  319,   -1,   -1,  322,
   -1,   -1,  325,   -1,  327,   -1,  329,  330,  331,  332,
   -1,  334,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,  359,  360,  361,  362,
  363,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,  372,
   -1,   -1,   -1,   -1,   -1,  378,  379,  380,  381,   -1,
   -1,   -1,  385,   -1,  387,  256,   -1,   -1,   -1,   -1,
  393,  394,   -1,  264,  265,   -1,  267,   -1,   -1,  270,
  271,   -1,   -1,   -1,  275,  276,  277,   -1,  279,   -1,
   -1,   -1,   -1,   -1,  285,  418,  419,  288,  421,   -1,
   -1,   -1,   -1,   -1,  295,   -1,   -1,   -1,   -1,  300,
   -1,  302,  303,  304,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,  316,   -1,  318,  319,   -1,
   -1,  322,   -1,   -1,  325,   -1,  327,   -1,  329,  330,
  331,  332,   -1,  334,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,  359,  360,
  361,  362,  363,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,  372,   -1,   -1,   -1,   -1,   -1,  378,  379,  380,
  381,   -1,   -1,   -1,  385,   -1,  387,  256,   -1,   -1,
   -1,   -1,  393,  394,   -1,  264,  265,   -1,  267,   -1,
   -1,  270,  271,   -1,   -1,   -1,  275,  276,  277,   -1,
  279,   -1,   -1,   -1,   -1,   -1,  285,  418,  419,  288,
  421,   -1,   -1,   -1,   -1,   -1,  295,   -1,   -1,   -1,
   -1,  300,   -1,  302,  303,  304,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,  316,   -1,  318,
  319,   -1,   -1,  322,   -1,   -1,  325,   -1,  327,   -1,
  329,  330,  331,  332,   -1,  334,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
  359,  360,  361,  362,  363,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,  372,   -1,   -1,   -1,   -1,   -1,  378,
  379,  380,  381,   -1,   -1,   -1,  385,   -1,  387,  256,
   -1,   -1,   -1,   -1,  393,  394,   -1,  264,  265,   -1,
  267,   -1,   -1,  270,  271,   -1,   -1,   -1,  275,  276,
  277,   -1,  279,   -1,   -1,   -1,   -1,   -1,  285,  418,
  419,  288,  421,   -1,   -1,   -1,   -1,   -1,  295,   -1,
   -1,   -1,   -1,  300,   -1,  302,  303,  304,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,  316,
   -1,  318,  319,   -1,   -1,  322,   -1,   -1,  325,   -1,
  327,   -1,  329,  330,  331,  332,   -1,  334,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,  359,  360,  361,  362,  363,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,  372,   -1,   -1,   -1,   -1,
   -1,  378,  379,  380,  381,   -1,   -1,   -1,  385,   -1,
  387,  256,   -1,   -1,   -1,   -1,  393,  394,   -1,  264,
  265,   -1,  267,   -1,   -1,  270,  271,   -1,   -1,   -1,
  275,  276,  277,   -1,  279,   -1,   -1,   -1,   -1,   -1,
  285,  418,  419,  288,  421,   -1,   -1,   -1,   -1,   -1,
  295,   -1,   -1,   -1,   -1,  300,   -1,  302,  303,  304,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,  316,   -1,  318,  319,   -1,   -1,  322,   -1,   -1,
  325,   -1,  327,   -1,  329,  330,  331,  332,   -1,  334,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,  359,  360,  361,  362,  363,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,  372,   -1,   -1,
   -1,   -1,   -1,  378,  379,  380,  381,   -1,   -1,   -1,
  385,   -1,  387,  256,   -1,   -1,   -1,   -1,  393,  394,
   -1,  264,  265,   -1,  267,   -1,   -1,  270,  271,   -1,
   -1,   -1,  275,  276,  277,   -1,  279,   -1,   -1,   -1,
   -1,   -1,  285,  418,  419,  288,  421,   -1,   -1,   -1,
   -1,   -1,  295,   -1,   -1,   -1,   -1,  300,   -1,  302,
  303,  304,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,  316,   -1,  318,  319,   -1,   -1,  322,
   -1,   -1,  325,   -1,  327,   -1,  329,  330,  331,  332,
   -1,  334,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,  359,  360,  361,  362,
  363,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,  372,
   -1,   -1,   -1,   -1,   -1,  378,  379,  380,  381,   -1,
   -1,   -1,  385,   -1,  387,  256,   -1,   -1,   -1,   -1,
  393,  394,   -1,  264,  265,   -1,  267,   -1,   -1,  270,
  271,   -1,   -1,   -1,  275,  276,  277,   -1,  279,   -1,
   -1,   -1,   -1,   -1,  285,  418,  419,  288,  421,   -1,
   -1,   -1,   -1,   -1,  295,   -1,   -1,   -1,   -1,  300,
   -1,  302,  303,  304,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,  316,   -1,  318,  319,   -1,
   -1,  322,   -1,   -1,  325,   -1,  327,   -1,  329,  330,
  331,  332,   -1,  334,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,  359,  360,
  361,  362,  363,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,  372,   -1,   -1,   -1,   -1,   -1,  378,  379,  380,
  381,   -1,   -1,   -1,  385,   -1,  387,  256,   -1,   -1,
   -1,   -1,  393,  394,   -1,  264,  265,   -1,  267,   -1,
   -1,  270,  271,   -1,   -1,   -1,  275,  276,  277,   -1,
  279,   -1,   -1,   -1,   -1,   -1,  285,  418,  419,  288,
  421,   -1,   -1,   -1,   -1,   -1,  295,   -1,   -1,   -1,
   -1,  300,   -1,  302,  303,  304,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,  316,   -1,  318,
  319,   -1,   -1,  322,   -1,   -1,  325,   -1,  327,   -1,
  329,  330,  331,  332,   -1,  334,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
  359,  360,  361,  362,  363,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,  372,   -1,   -1,   -1,   -1,   -1,  378,
  379,  380,  381,   -1,   -1,   -1,  385,   -1,  387,  256,
   -1,   -1,   -1,   -1,  393,  394,   -1,  264,  265,   -1,
  267,   -1,   -1,  270,  271,   -1,   -1,   -1,  275,  276,
  277,   -1,  279,   -1,   -1,   -1,   -1,   -1,  285,  418,
  419,  288,  421,   -1,   -1,   -1,   -1,   -1,  295,   -1,
   -1,   -1,   -1,  300,   -1,  302,  303,  304,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,  316,
   -1,  318,  319,   -1,   -1,  322,   -1,   -1,  325,   -1,
  327,   -1,  329,  330,  331,  332,   -1,  334,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,  359,  360,  361,  362,  363,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,  372,   -1,   -1,   -1,   -1,
   -1,  378,  379,  380,  381,   -1,   -1,   -1,  385,   -1,
  387,  256,   -1,   -1,   -1,   -1,  393,  394,   -1,  264,
  265,   -1,  267,   -1,   -1,  270,  271,   -1,   -1,   -1,
  275,  276,  277,   -1,  279,   -1,   -1,   -1,   -1,   -1,
  285,  418,  419,  288,  421,   -1,   -1,   -1,   -1,   -1,
  295,   -1,   -1,   -1,   -1,  300,   -1,  302,  303,  304,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,  316,   -1,  318,  319,   -1,   -1,  322,   -1,   -1,
  325,   -1,  327,   -1,  329,  330,  331,  332,   -1,  334,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,  359,  360,  361,  362,  363,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,  372,   -1,   -1,
   -1,   -1,   -1,  378,  379,  380,  381,   -1,   -1,   -1,
  385,   -1,  387,  256,   -1,   -1,   -1,   -1,  393,  394,
   -1,  264,  265,   -1,  267,   -1,   -1,  270,  271,   -1,
   -1,   -1,  275,  276,  277,   -1,  279,   -1,   -1,   -1,
   -1,   -1,  285,  418,  419,  288,  421,   -1,   -1,   -1,
   -1,   -1,  295,   -1,   -1,   -1,   -1,  300,   -1,  302,
  303,  304,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,  316,   -1,  318,  319,   -1,   -1,  322,
   -1,   -1,  325,   -1,  327,   -1,  329,  330,  331,  332,
   -1,  334,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,  359,  360,  361,  362,
  363,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,  372,
   -1,   -1,   -1,   -1,   -1,  378,  379,  380,  381,   -1,
   -1,   -1,  385,   -1,  387,  256,   -1,   -1,   -1,   -1,
  393,  394,   -1,  264,  265,   -1,  267,   -1,   -1,  270,
  271,   -1,   -1,   -1,  275,  276,  277,   -1,  279,   -1,
   -1,   -1,   -1,   -1,  285,  418,  419,  288,  421,   -1,
   -1,   -1,   -1,   -1,  295,   -1,   -1,   -1,   -1,  300,
   -1,  302,  303,  304,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,  316,   -1,  318,  319,   -1,
   -1,  322,   -1,   -1,  325,   -1,  327,   -1,  329,  330,
  331,  332,   -1,  334,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,  359,  360,
  361,  362,  363,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,  372,   -1,   -1,   -1,   -1,   -1,  378,  379,  380,
  381,   -1,   -1,   -1,  385,   -1,  387,  256,   -1,   -1,
   -1,   -1,  393,  394,   -1,  264,  265,   -1,  267,   -1,
   -1,  270,  271,   -1,   -1,   -1,  275,  276,  277,   -1,
  279,   -1,   -1,   -1,   -1,   -1,  285,  418,  419,  288,
  421,   -1,   -1,   -1,   -1,   -1,  295,   -1,   -1,   -1,
   -1,  300,   -1,  302,  303,  304,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,  316,   -1,  318,
  319,   -1,   -1,  322,   -1,   -1,  325,   -1,  327,   -1,
  329,  330,  331,  332,   -1,  334,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
  359,  360,  361,  362,  363,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,  372,   -1,   -1,   -1,   -1,   -1,  378,
  379,  380,  381,   -1,   -1,   -1,  385,   -1,  387,  256,
   -1,   -1,   -1,   -1,  393,  394,   -1,  264,  265,   -1,
  267,   -1,   -1,  270,  271,   -1,   -1,   -1,  275,  276,
  277,   -1,  279,   -1,   -1,   -1,   -1,   -1,  285,  418,
  419,  288,  421,   -1,   -1,   -1,   -1,   -1,  295,   -1,
   -1,   -1,   -1,  300,   -1,  302,  303,  304,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,  316,
   -1,  318,  319,   -1,   -1,  322,   -1,   -1,  325,   -1,
  327,   -1,  329,  330,  331,  332,   -1,  334,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,  359,  360,  361,  362,  363,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,  372,   -1,   -1,   -1,   -1,
   -1,  378,  379,  380,  381,   -1,   -1,   -1,  385,   -1,
  387,  256,   -1,   -1,   -1,   -1,  393,  394,   -1,  264,
  265,   -1,  267,   -1,   -1,  270,  271,   -1,   -1,   -1,
  275,  276,  277,   -1,  279,   -1,   -1,   -1,   -1,   -1,
  285,  418,  419,  288,  421,   -1,   -1,   -1,   -1,   -1,
  295,   -1,   -1,   -1,   -1,  300,   -1,  302,  303,  304,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,  316,   -1,  318,  319,   -1,   -1,  322,   -1,   -1,
  325,   -1,  327,   -1,  329,  330,  331,  332,   -1,  334,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,  359,  360,  361,  362,  363,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,  372,   -1,   -1,
   -1,   -1,   -1,  378,  379,  380,  381,   -1,   -1,   -1,
  385,   -1,  387,  256,   -1,   -1,   -1,   -1,  393,  394,
   -1,  264,  265,   -1,  267,   -1,   -1,  270,  271,   -1,
   -1,   -1,  275,  276,  277,   -1,  279,   -1,   -1,   -1,
   -1,   -1,  285,  418,  419,  288,  421,   -1,   -1,   -1,
   -1,   -1,  295,   -1,   -1,   -1,   -1,  300,   -1,  302,
  303,  304,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,  316,   -1,  318,  319,   -1,   -1,  322,
   -1,   -1,  325,   -1,  327,   -1,  329,  330,  331,  332,
   -1,  334,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,  359,  360,  361,  362,
  363,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,  372,
   -1,   -1,   -1,   -1,   -1,  378,  379,  380,  381,   -1,
   -1,   -1,  385,   -1,  387,  256,   -1,   -1,   -1,   -1,
  393,  394,   -1,  264,  265,   -1,  267,   -1,   -1,  270,
  271,   -1,   -1,   -1,  275,  276,  277,   -1,  279,   -1,
   -1,   -1,   -1,   -1,  285,  418,  419,  288,  421,   -1,
   -1,   -1,   -1,   -1,  295,   -1,   -1,   -1,   -1,  300,
   -1,  302,  303,  304,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,  316,   -1,  318,  319,   -1,
   -1,  322,   -1,   -1,  325,   -1,  327,   -1,  329,  330,
  331,  332,   -1,  334,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,  359,  360,
  361,  362,  363,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,  372,   -1,   -1,   -1,   -1,   -1,  378,  379,  380,
  381,   -1,   -1,   -1,  385,   -1,  387,  256,   -1,   -1,
   -1,   -1,  393,  394,   -1,  264,  265,   -1,  267,   -1,
   -1,  270,  271,   -1,   -1,   -1,  275,  276,  277,   -1,
  279,   -1,   -1,   -1,   -1,   -1,  285,  418,  419,  288,
  421,   -1,   -1,   -1,   -1,   -1,  295,   -1,   -1,   -1,
   -1,  300,   -1,  302,  303,  304,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,  316,   -1,  318,
  319,   -1,   -1,  322,   -1,   -1,  325,   -1,  327,   -1,
  329,  330,  331,  332,   -1,  334,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
  359,  360,  361,  362,  363,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,  372,   -1,   -1,   -1,   -1,   -1,  378,
  379,  380,  381,   -1,   -1,   -1,  385,   -1,  387,  256,
   -1,   -1,   -1,   -1,  393,  394,   -1,  264,  265,   -1,
  267,   -1,   -1,  270,  271,   -1,   -1,   -1,  275,  276,
  277,   -1,  279,   -1,   -1,   -1,   -1,   -1,  285,  418,
  419,  288,  421,   -1,   -1,   -1,   -1,   -1,  295,   -1,
   -1,   -1,   -1,  300,   -1,  302,  303,  304,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,  316,
   -1,  318,  319,   -1,   -1,  322,   -1,   -1,  325,   -1,
  327,   -1,  329,  330,  331,  332,   -1,  334,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,  359,  360,  361,  362,  363,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,  372,   -1,   -1,   -1,   -1,
   -1,  378,  379,  380,  381,   -1,   -1,   -1,  385,   -1,
  387,  256,   -1,   -1,   -1,   -1,  393,  394,   -1,  264,
  265,   -1,  267,   -1,   -1,  270,  271,   -1,   -1,   -1,
  275,  276,  277,   -1,  279,   -1,   -1,   -1,   -1,   -1,
  285,  418,  419,  288,  421,   -1,   -1,   -1,   -1,   -1,
  295,   -1,   -1,   -1,   -1,  300,   -1,  302,  303,  304,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,  316,   -1,  318,  319,   -1,   -1,  322,   -1,   -1,
  325,   -1,  327,   -1,  329,  330,  331,  332,   -1,  334,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,  359,  360,  361,  362,  363,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,  372,   -1,   -1,
   -1,   -1,   -1,  378,  379,  380,  381,   -1,   -1,   -1,
  385,   -1,  387,  256,   -1,   -1,   -1,   -1,  393,  394,
   -1,  264,  265,   -1,  267,   -1,   -1,  270,  271,   -1,
   -1,   -1,  275,  276,  277,   -1,  279,   -1,   -1,   -1,
   -1,   -1,  285,  418,  419,  288,  421,   -1,   -1,   -1,
   -1,   -1,  295,   -1,   -1,   -1,   -1,  300,   -1,  302,
  303,  304,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,  316,   -1,  318,  319,   -1,   -1,  322,
   -1,   -1,  325,   -1,  327,   -1,  329,  330,  331,  332,
   -1,  334,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,  359,  360,  361,  362,
  363,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,  372,
   -1,   -1,   -1,   -1,   -1,  378,  379,  380,  381,   -1,
   -1,   -1,  385,   -1,  387,  256,   -1,   -1,   -1,   -1,
  393,  394,   -1,  264,  265,   -1,  267,   -1,   -1,  270,
  271,   -1,   -1,   -1,  275,  276,  277,   -1,  279,   -1,
   -1,   -1,   -1,   -1,  285,  418,  419,  288,  421,   -1,
   -1,   -1,   -1,   -1,  295,   -1,   -1,   -1,   -1,  300,
   -1,  302,  303,  304,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,  316,   -1,  318,  319,   -1,
   -1,  322,   -1,   -1,  325,   -1,  327,   -1,  329,  330,
  331,  332,   -1,  334,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,  359,  360,
  361,  362,  363,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,  372,   -1,   -1,   -1,   -1,   -1,  378,  379,  380,
  381,   -1,   -1,   -1,  385,   -1,  387,  256,   -1,   -1,
   -1,   -1,  393,  394,   -1,  264,  265,   -1,  267,   -1,
   -1,  270,  271,   -1,   -1,   -1,  275,  276,  277,   -1,
  279,   -1,   -1,   -1,   -1,   -1,  285,  418,  419,  288,
  421,   -1,   -1,   -1,   -1,   -1,  295,   -1,   -1,   -1,
   -1,  300,   -1,  302,  303,  304,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,  316,   -1,  318,
  319,   -1,   -1,  322,   -1,   -1,  325,   -1,  327,   -1,
  329,  330,  331,  332,   -1,  334,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
  359,  360,  361,  362,  363,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,  372,   -1,   -1,   -1,   -1,   -1,  378,
  379,  380,  381,   -1,   -1,   -1,  385,   -1,  387,  256,
   -1,   -1,   -1,   -1,  393,  394,   -1,  264,  265,   -1,
  267,   -1,   -1,  270,  271,   -1,   -1,   -1,  275,  276,
  277,   -1,  279,   -1,   -1,   -1,   -1,   -1,  285,  418,
  419,  288,  421,   -1,   -1,   -1,   -1,   -1,  295,   -1,
   -1,   -1,   -1,  300,   -1,  302,  303,  304,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,  316,
   -1,  318,  319,   -1,   -1,  322,   -1,   -1,  325,   -1,
  327,   -1,  329,  330,  331,  332,   -1,  334,  265,   -1,
  267,   -1,   -1,  270,   -1,   -1,   -1,   -1,  275,   -1,
   -1,   -1,  279,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,  288,  359,  360,  361,  362,  363,   -1,  295,   -1,
   -1,   -1,   -1,  300,   -1,  372,   -1,  304,   -1,   -1,
   -1,  378,  379,  380,  381,   -1,   -1,   -1,  385,  316,
  387,  318,   -1,   -1,   -1,  322,  393,  394,   -1,   -1,
   -1,   -1,   -1,  330,  331,   -1,   -1,  334,   -1,  256,
  337,   -1,   -1,   -1,  261,   -1,   -1,   -1,  265,   -1,
  267,  418,  419,  270,  421,  272,  273,   -1,  275,   -1,
  277,   -1,  279,   -1,  281,  282,  283,  284,   -1,   -1,
  287,  288,   -1,   -1,   -1,   -1,  293,   -1,  295,  296,
  297,   -1,   -1,  300,   -1,  302,   -1,  304,   -1,   -1,
  307,   -1,  309,  310,  311,  312,   -1,   -1,   -1,  316,
  317,  318,   -1,   -1,  321,  322,  323,   -1,   -1,   -1,
   -1,   -1,   -1,  330,  331,   -1,  333,  334,  256,  336,
  337,  338,  419,   -1,   -1,  342,  264,  265,   -1,  267,
   -1,   -1,  270,  271,   -1,   -1,   -1,  275,  276,  277,
   -1,  279,   -1,   -1,   -1,  362,   -1,  285,   -1,   -1,
  288,  368,  369,  370,   -1,   -1,   -1,  295,   -1,   -1,
   -1,  378,  300,   -1,  302,  303,  304,   -1,   -1,   -1,
   -1,   -1,  262,   -1,   -1,   -1,   -1,   -1,  316,   -1,
  318,  319,   -1,   -1,  322,   -1,   -1,  325,   -1,  327,
  261,  329,  330,  331,  332,   -1,  334,   -1,   -1,   -1,
   -1,   -1,  419,   -1,   -1,   -1,   -1,   -1,  298,   -1,
   -1,   -1,   -1,  284,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,  359,  360,  361,  362,  363,  297,   -1,   -1,   -1,
  301,  302,   -1,   -1,  372,   -1,  307,   -1,  309,  310,
  311,  312,   -1,   -1,   -1,   -1,  317,   -1,   -1,   -1,
  321,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,  333,   -1,   -1,  336,   -1,  338,   -1,   -1,
   -1,   -1,   -1,   -1,  364,   -1,   -1,   -1,   -1,   -1,
  418,  419,  372,  373,  374,  375,  376,   -1,   -1,  379,
  380,  362,   -1,  383,  384,  385,  386,  387,  388,  389,
  390,  391,   -1,  393,  394,  395,  396,  397,  398,  399,
  400,  401,  402,  403,  404,  405,  406,  407,  408,  409,
  410,  411,  412,  413,  414,   -1,  261,   -1,  263,   -1,
  265,  421,  267,   -1,  424,  270,   -1,  272,  273,   -1,
  275,   -1,  277,   -1,  279,   -1,  281,  282,  283,  284,
   -1,   -1,  287,  288,   -1,   -1,   -1,   -1,  293,  294,
  295,  296,  297,   -1,   -1,  300,   -1,  302,   -1,  304,
   -1,  306,  307,   -1,  309,  310,  311,  312,   -1,   -1,
  315,  316,  317,  318,   -1,   -1,  321,  322,  323,   -1,
   -1,   -1,   -1,   -1,   -1,  330,  331,   -1,  333,  334,
   -1,  336,  337,  338,   -1,   -1,   -1,  342,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,  362,   -1,   -1,
  365,  366,  261,   -1,   -1,   -1,  265,   -1,  267,   -1,
   -1,  270,   -1,  272,  273,   -1,  275,   -1,  277,   -1,
  279,   -1,  281,  282,  283,  284,   -1,   -1,  287,  288,
   -1,   -1,   -1,   -1,  293,   -1,  295,  296,  297,   -1,
   -1,  300,   -1,  302,   -1,  304,   -1,   -1,  307,   -1,
  309,  310,  311,  312,  419,   -1,   -1,  316,  317,  318,
   -1,   -1,  321,  322,  323,   -1,   -1,   -1,   -1,   -1,
   -1,  330,  331,   -1,  333,  334,   -1,  336,  337,  338,
   -1,   -1,   -1,  342,   -1,   -1,  261,   -1,   -1,   -1,
  265,   -1,  267,   -1,   -1,  270,   -1,  272,  273,   -1,
  275,   -1,  277,  362,  279,   -1,  281,  282,  283,  284,
  369,   -1,  287,  288,   -1,   -1,   -1,   -1,  293,  378,
  295,  296,  297,   -1,   -1,  300,   -1,  302,   -1,  304,
   -1,   -1,  307,   -1,  309,  310,  311,  312,   -1,   -1,
   -1,  316,  317,  318,   -1,   -1,  321,  322,  323,   -1,
   -1,   -1,   -1,   -1,   -1,  330,  331,   -1,  333,  334,
  419,  336,  337,  338,   -1,   -1,   -1,  342,   -1,   -1,
  261,   -1,   -1,   -1,  265,   -1,  267,   -1,   -1,  270,
   -1,  272,  273,   -1,  275,   -1,  277,  362,  279,   -1,
  281,  282,  283,  284,  369,   -1,  287,  288,   -1,   -1,
   -1,   -1,  293,  378,  295,  296,  297,   -1,   -1,  300,
   -1,  302,   -1,  304,   -1,   -1,  307,   -1,  309,  310,
  311,  312,   -1,   -1,   -1,  316,  317,  318,   -1,   -1,
  321,  322,  323,   -1,   -1,   -1,   -1,   -1,   -1,  330,
  331,   -1,  333,  334,  419,  336,  337,  338,   -1,   -1,
   -1,  342,   -1,   -1,  261,   -1,   -1,   -1,  265,   -1,
  267,   -1,   -1,  270,   -1,  272,  273,   -1,  275,   -1,
  277,  362,  279,   -1,  281,  282,  283,  284,   -1,   -1,
  287,  288,   -1,   -1,   -1,   -1,  293,  378,  295,  296,
  297,   -1,   -1,  300,   -1,  302,   -1,  304,   -1,   -1,
  307,   -1,  309,  310,  311,  312,   -1,   -1,   -1,  316,
  317,  318,   -1,   -1,  321,  322,  323,   -1,   -1,   -1,
   -1,   -1,   -1,  330,  331,   -1,  333,  334,  419,  336,
  337,  338,   -1,   -1,   -1,  342,   -1,   -1,  261,   -1,
   -1,   -1,  265,   -1,  267,   -1,   -1,  270,   -1,  272,
  273,   -1,  275,   -1,  277,  362,  279,   -1,  281,  282,
  283,  284,  369,   -1,  287,  288,   -1,   -1,   -1,   -1,
  293,   -1,  295,  296,  297,   -1,   -1,  300,   -1,  302,
  261,  304,   -1,   -1,  307,   -1,  309,  310,  311,  312,
   -1,   -1,   -1,  316,  317,  318,   -1,   -1,  321,  322,
  323,   -1,   -1,  284,   -1,   -1,   -1,  330,  331,   -1,
  333,  334,  419,  336,  337,  338,  297,   -1,   -1,  342,
   -1,  302,   -1,   -1,  305,   -1,  307,   -1,  309,  310,
  311,  312,   -1,   -1,   -1,   -1,  317,   -1,   -1,  362,
  321,   -1,   -1,   -1,  325,   -1,  369,   -1,   -1,   -1,
   -1,   -1,  333,   -1,   -1,  336,   -1,  338,   -1,  264,
  265,   -1,  267,   -1,   -1,  270,  271,   -1,   -1,   -1,
  275,  276,  277,   -1,  279,   -1,  357,   -1,   -1,   -1,
  285,  362,   -1,  288,   -1,   -1,   -1,   -1,  369,  370,
  295,  372,   -1,  374,   -1,  300,  419,  302,  303,  304,
   -1,  306,   -1,   -1,   -1,   -1,  387,   -1,  313,   -1,
   -1,  316,   -1,  318,  319,   -1,   -1,  322,   -1,   -1,
  325,   -1,  327,   -1,  329,  330,  331,  332,   -1,  334,
   -1,   -1,   -1,   -1,   -1,   -1,  341,   -1,  419,  344,
  345,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,  359,  360,  361,  362,  363,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,  372,  373,   -1,
  375,   -1,   -1,  378,  379,  380,  381,   -1,   -1,   -1,
  385,   -1,  387,   -1,   -1,   -1,   -1,   -1,  393,  394,
   -1,   -1,   -1,   -1,   -1,   -1,  264,  265,   -1,  267,
   -1,   -1,  270,  271,   -1,   -1,   -1,  275,  276,  277,
   -1,  279,   -1,  418,  419,  420,  421,  285,   -1,   -1,
  288,   -1,   -1,   -1,   -1,   -1,   -1,  295,   -1,   -1,
   -1,   -1,  300,   -1,  302,  303,  304,   -1,  306,   -1,
   -1,   -1,   -1,   -1,   -1,  313,   -1,   -1,  316,   -1,
  318,  319,   -1,   -1,  322,   -1,   -1,  325,   -1,  327,
   -1,  329,  330,  331,  332,   -1,  334,   -1,   -1,   -1,
   -1,   -1,   -1,  341,   -1,   -1,  344,  345,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,  359,  360,  361,  362,  363,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,  372,   -1,   -1,  375,   -1,   -1,
  378,  379,  380,  381,   -1,   -1,   -1,  385,   -1,  387,
   -1,   -1,   -1,   -1,   -1,  393,  394,   -1,   -1,   -1,
   -1,   -1,   -1,  264,  265,   -1,  267,   -1,   -1,  270,
  271,   -1,   -1,   -1,  275,  276,  277,   -1,  279,   -1,
  418,  419,  420,  421,  285,   -1,   -1,  288,   -1,   -1,
   -1,   -1,   -1,   -1,  295,   -1,   -1,   -1,   -1,  300,
   -1,  302,  303,  304,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,  316,   -1,  318,  319,   -1,
   -1,  322,   -1,   -1,  325,   -1,  327,   -1,  329,  330,
  331,  332,   -1,  334,   -1,   -1,  337,   -1,   -1,   -1,
  341,   -1,   -1,  344,  345,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,  359,  360,
  361,  362,  363,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,  372,   -1,   -1,   -1,   -1,   -1,  378,  379,  380,
  381,   -1,   -1,   -1,  385,   -1,  387,   -1,   -1,   -1,
   -1,   -1,  393,  394,   -1,   -1,   -1,   -1,   -1,   -1,
  264,  265,   -1,  267,   -1,   -1,  270,  271,   -1,   -1,
   -1,  275,  276,  277,   -1,  279,   -1,  418,  419,  420,
  421,  285,   -1,   -1,  288,   -1,   -1,   -1,   -1,   -1,
   -1,  295,   -1,   -1,   -1,   -1,  300,   -1,  302,  303,
  304,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,  316,   -1,  318,  319,   -1,   -1,  322,   -1,
   -1,  325,   -1,  327,   -1,  329,  330,  331,  332,   -1,
  334,   -1,   -1,   -1,   -1,   -1,   -1,  341,   -1,   -1,
  344,  345,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,  359,  360,  361,  362,  363,
   -1,   -1,   -1,   -1,  368,   -1,   -1,   -1,  372,   -1,
   -1,   -1,   -1,   -1,  378,  379,  380,  381,   -1,   -1,
   -1,  385,   -1,  387,   -1,   -1,   -1,   -1,   -1,  393,
  394,   -1,   -1,   -1,   -1,   -1,   -1,  264,  265,   -1,
  267,   -1,   -1,  270,  271,   -1,   -1,   -1,  275,  276,
  277,   -1,  279,   -1,  418,  419,  420,  421,  285,   -1,
   -1,  288,   -1,   -1,   -1,   -1,   -1,   -1,  295,   -1,
   -1,   -1,   -1,  300,   -1,  302,  303,  304,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,  316,
   -1,  318,  319,   -1,   -1,  322,   -1,   -1,  325,   -1,
  327,   -1,  329,  330,  331,  332,   -1,  334,   -1,   -1,
   -1,   -1,   -1,   -1,  341,   -1,   -1,  344,  345,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,  359,  360,  361,  362,  363,   -1,   -1,   -1,
   -1,  368,   -1,   -1,   -1,  372,   -1,   -1,   -1,   -1,
   -1,  378,  379,  380,  381,   -1,   -1,   -1,  385,   -1,
  387,   -1,   -1,   -1,   -1,   -1,  393,  394,   -1,   -1,
   -1,   -1,   -1,   -1,  264,  265,   -1,  267,   -1,   -1,
  270,  271,   -1,   -1,   -1,  275,  276,  277,   -1,  279,
   -1,  418,  419,  420,  421,  285,   -1,   -1,  288,   -1,
   -1,   -1,   -1,   -1,   -1,  295,   -1,   -1,   -1,   -1,
  300,   -1,  302,  303,  304,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,  316,   -1,  318,  319,
   -1,   -1,  322,   -1,   -1,  325,   -1,  327,   -1,  329,
  330,  331,  332,   -1,  334,   -1,   -1,   -1,   -1,   -1,
   -1,  341,   -1,   -1,  344,  345,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,  359,
  360,  361,  362,  363,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,  372,   -1,   -1,   -1,   -1,   -1,  378,  379,
  380,  381,   -1,   -1,   -1,  385,   -1,  387,   -1,   -1,
   -1,   -1,   -1,  393,  394,   -1,   -1,   -1,   -1,   -1,
   -1,  264,  265,   -1,  267,   -1,   -1,  270,  271,   -1,
   -1,   -1,  275,  276,  277,   -1,  279,   -1,  418,  419,
  420,  421,  285,   -1,   -1,  288,   -1,   -1,   -1,   -1,
   -1,   -1,  295,   -1,   -1,   -1,   -1,  300,   -1,  302,
  303,  304,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,  316,   -1,  318,  319,   -1,   -1,  322,
   -1,   -1,  325,   -1,  327,   -1,  329,  330,  331,  332,
   -1,  334,   -1,   -1,   -1,   -1,   -1,   -1,  341,   -1,
   -1,  344,  345,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,  359,  360,  361,  362,
  363,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,  372,
   -1,   -1,   -1,   -1,   -1,  378,  379,  380,  381,   -1,
   -1,   -1,  385,   -1,  387,   -1,   -1,   -1,   -1,   -1,
  393,  394,   -1,   -1,   -1,   -1,   -1,   -1,  264,  265,
   -1,  267,   -1,   -1,  270,  271,   -1,   -1,   -1,  275,
  276,  277,   -1,  279,   -1,  418,  419,  420,  421,  285,
   -1,   -1,  288,   -1,   -1,   -1,   -1,   -1,   -1,  295,
   -1,   -1,   -1,   -1,  300,   -1,  302,  303,  304,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
  316,   -1,  318,  319,   -1,   -1,  322,   -1,   -1,  325,
   -1,  327,   -1,  329,  330,  331,  332,   -1,  334,   -1,
   -1,   -1,   -1,   -1,   -1,  341,   -1,   -1,  344,  345,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,  359,  360,  361,  362,  363,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,  372,   -1,   -1,   -1,
   -1,   -1,  378,  379,  380,  381,   -1,   -1,   -1,  385,
   -1,  387,   -1,   -1,   -1,   -1,   -1,  393,  394,   -1,
   -1,   -1,   -1,   -1,   -1,  264,  265,   -1,  267,   -1,
   -1,  270,  271,   -1,   -1,   -1,  275,  276,  277,   -1,
  279,   -1,  418,  419,  420,  421,  285,   -1,   -1,  288,
   -1,   -1,   -1,   -1,   -1,   -1,  295,   -1,   -1,   -1,
   -1,  300,   -1,  302,  303,  304,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,  316,   -1,  318,
  319,   -1,   -1,  322,   -1,   -1,  325,   -1,  327,   -1,
  329,  330,  331,  332,   -1,  334,   -1,   -1,   -1,   -1,
   -1,   -1,  341,   -1,   -1,  344,  345,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
  359,  360,  361,  362,  363,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,  372,   -1,   -1,   -1,   -1,   -1,  378,
  379,  380,  381,   -1,   -1,   -1,  385,   -1,  387,   -1,
   -1,   -1,   -1,   -1,  393,  394,   -1,   -1,   -1,   -1,
   -1,   -1,  264,  265,   -1,  267,   -1,   -1,  270,  271,
   -1,   -1,   -1,  275,  276,  277,   -1,  279,   -1,  418,
  419,  420,  421,  285,   -1,   -1,  288,   -1,   -1,   -1,
   -1,   -1,   -1,  295,   -1,   -1,   -1,   -1,  300,   -1,
  302,  303,  304,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,  316,   -1,  318,  319,   -1,   -1,
  322,   -1,   -1,  325,   -1,  327,   -1,  329,  330,  331,
  332,   -1,  334,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,  359,  360,  361,
  362,  363,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
  372,   -1,   -1,   -1,   -1,   -1,  378,  379,  380,  381,
   -1,   -1,   -1,  385,   -1,  387,   -1,   -1,   -1,   -1,
   -1,  393,  394,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,  263,   -1,  265,   -1,  267,  418,  419,  270,  421,
  272,  273,   -1,  275,   -1,  277,   -1,  279,   -1,  281,
  282,  283,   -1,   -1,   -1,  287,  288,   -1,   -1,   -1,
   -1,  293,   -1,  295,  296,   -1,   -1,   -1,  300,   -1,
   -1,   -1,  304,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,  315,  316,   -1,  318,   -1,   -1,   -1,
  322,  323,   -1,   -1,   -1,   -1,   -1,   -1,  330,  331,
  264,  265,  334,  267,   -1,  337,  270,  271,   -1,   -1,
  342,  275,  276,  277,   -1,  279,   -1,   -1,   -1,   -1,
   -1,  285,   -1,   -1,  288,   -1,   -1,   -1,   -1,   -1,
   -1,  295,   -1,  365,  366,   -1,  300,   -1,  302,  303,
  304,   -1,   -1,   -1,   -1,   -1,  378,   -1,   -1,   -1,
   -1,   -1,  316,   -1,  318,  319,   -1,   -1,  322,   -1,
   -1,  325,   -1,  327,   -1,  329,  330,  331,  332,   -1,
  334,   -1,   -1,  337,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,  419,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,  359,  360,  361,  362,  363,
   -1,   -1,   -1,   -1,   -1,  265,   -1,  267,  372,   -1,
  270,   -1,  272,  273,   -1,  275,   -1,  277,   -1,  279,
   -1,  281,  282,  283,   -1,   -1,   -1,  287,  288,   -1,
   -1,   -1,   -1,  293,   -1,  295,  296,   -1,   -1,   -1,
  300,   -1,   -1,   -1,  304,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,  418,  419,  316,   -1,  318,   -1,
   -1,   -1,  322,  323,   -1,   -1,   -1,   -1,   -1,   -1,
  330,  331,   -1,  265,  334,  267,   -1,  337,  270,   -1,
  272,  273,  342,  275,   -1,  277,   -1,  279,   -1,  281,
  282,  283,   -1,   -1,   -1,  287,  288,   -1,   -1,   -1,
   -1,  293,   -1,  295,  296,  265,   -1,  267,  300,   -1,
  270,   -1,  304,  273,   -1,  275,   -1,  277,  378,  279,
   -1,  281,  282,  283,  316,   -1,  318,  287,  288,   -1,
  322,  323,   -1,  293,   -1,  295,   -1,   -1,  330,  331,
  300,   -1,  334,   -1,  304,  337,   -1,   -1,   -1,   -1,
  342,   -1,   -1,   -1,   -1,   -1,  316,   -1,  318,  419,
   -1,   -1,  322,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
  330,  331,   -1,  265,  334,  267,   -1,  337,  270,   -1,
   -1,  273,  342,  275,   -1,  277,   -1,  279,   -1,  281,
  282,  283,   -1,   -1,   -1,  287,  288,   -1,   -1,   -1,
   -1,  293,   -1,  295,   -1,  265,   -1,  267,  300,   -1,
  270,   -1,  304,   -1,   -1,  275,   -1,   -1,  378,  279,
   -1,   -1,   -1,   -1,  316,   -1,  318,  419,  288,   -1,
  322,   -1,   -1,   -1,   -1,  295,   -1,   -1,  330,  331,
  300,   -1,  334,   -1,  304,  337,  306,   -1,  308,   -1,
  342,   -1,   -1,  313,   -1,   -1,  316,   -1,  318,  419,
   -1,   -1,  322,   -1,   -1,  325,   -1,   -1,   -1,   -1,
  330,  331,   -1,  265,  334,  267,   -1,  337,  270,   -1,
   -1,   -1,   -1,  275,   -1,   -1,   -1,  279,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,  288,   -1,   -1,   -1,
   -1,   -1,   -1,  295,   -1,  265,   -1,  267,  300,   -1,
  270,   -1,  304,  373,  306,  275,  308,   -1,   -1,  279,
   -1,  313,   -1,   -1,  316,   -1,  318,  419,  288,   -1,
  322,   -1,   -1,  325,   -1,  295,   -1,   -1,  330,  331,
  300,   -1,  334,   -1,  304,  337,  306,   -1,   -1,   -1,
   -1,   -1,   -1,  313,   -1,   -1,  316,   -1,  318,  419,
   -1,   -1,  322,   -1,   -1,  325,   -1,   -1,   -1,   -1,
  330,  331,   -1,   -1,  334,   -1,   -1,  337,  265,  371,
  267,   -1,   -1,  270,   -1,   -1,   -1,   -1,  275,   -1,
   -1,   -1,  279,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,  288,   -1,  363,   -1,   -1,   -1,   -1,  295,   -1,
  265,   -1,  267,  300,   -1,  270,   -1,  304,   -1,  306,
  275,  308,   -1,   -1,  279,   -1,  313,  419,   -1,  316,
   -1,  318,   -1,  288,   -1,  322,   -1,   -1,  325,   -1,
  295,   -1,   -1,  330,  331,  300,   -1,  334,   -1,  304,
  337,  306,   -1,  308,   -1,  265,   -1,  267,  313,  419,
  270,  316,   -1,  318,   -1,  275,   -1,  322,   -1,  279,
  325,   -1,   -1,  283,   -1,  330,  331,   -1,  288,  334,
   -1,   -1,  337,  293,   -1,  295,   -1,   -1,   -1,   -1,
  300,   -1,   -1,   -1,  304,  305,   -1,   -1,   -1,   -1,
  265,   -1,  267,   -1,   -1,  270,  316,  272,  318,   -1,
  275,   -1,  322,   -1,  279,   -1,   -1,   -1,   -1,   -1,
  330,  331,   -1,  288,  334,   -1,   -1,  337,   -1,   -1,
  295,   -1,  419,   -1,   -1,  300,   -1,  302,  265,  304,
  267,   -1,   -1,  270,   -1,   -1,   -1,   -1,  275,   -1,
   -1,  316,  279,  318,   -1,   -1,   -1,  322,  323,   -1,
   -1,  288,   -1,   -1,  419,  330,  331,   -1,  295,  334,
   -1,   -1,  337,  300,   -1,   -1,   -1,  304,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,  316,
   -1,  318,   -1,   -1,   -1,  322,   -1,  261,   -1,   -1,
   -1,   -1,   -1,  330,  331,   -1,   -1,  334,  272,  419,
  337,   -1,   -1,  277,   -1,   -1,   -1,  281,   -1,   -1,
  284,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,  296,  297,   -1,   -1,  363,  301,  302,   -1,
  261,   -1,   -1,  307,   -1,  309,  310,  311,  312,   -1,
   -1,  272,   -1,  317,  419,   -1,  277,  321,   -1,  323,
  281,   -1,   -1,  284,   -1,   -1,   -1,   -1,   -1,  333,
   -1,  335,  336,   -1,  338,  296,  297,   -1,  342,   -1,
  301,  302,   -1,   -1,  261,   -1,  307,   -1,  309,  310,
  311,  312,  419,   -1,   -1,   -1,  317,   -1,  362,   -1,
  321,   -1,  323,   -1,   -1,  369,  370,  284,   -1,   -1,
   -1,   -1,  333,   -1,  261,  336,  263,  338,   -1,   -1,
  297,  342,   -1,   -1,   -1,  302,   -1,   -1,   -1,   -1,
  307,   -1,  309,  310,  311,  312,   -1,  284,  315,   -1,
  317,  362,   -1,   -1,  321,   -1,   -1,   -1,  369,  370,
  297,   -1,   -1,   -1,   -1,  302,  333,   -1,   -1,  336,
  307,  338,  309,  310,  311,  312,   -1,   -1,   -1,   -1,
  317,   -1,   -1,   -1,  321,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,  261,  362,  333,   -1,   -1,  336,
   -1,  338,  369,  370,   -1,  272,   -1,   -1,   -1,   -1,
  277,   -1,   -1,   -1,  281,   -1,   -1,  284,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,  362,   -1,   -1,   -1,  296,
  297,   -1,  369,  370,  301,  302,   -1,  261,   -1,   -1,
  307,   -1,  309,  310,  311,  312,   -1,   -1,  272,   -1,
  317,   -1,   -1,  277,  321,   -1,  323,  281,   -1,   -1,
  284,   -1,   -1,   -1,   -1,   -1,  333,   -1,   -1,  336,
   -1,  338,  296,  297,   -1,  342,   -1,  301,  302,   -1,
  261,   -1,   -1,  307,   -1,  309,  310,  311,  312,   -1,
   -1,   -1,   -1,  317,   -1,  362,   -1,  321,   -1,  323,
   -1,   -1,  369,  284,   -1,   -1,   -1,   -1,   -1,  333,
   -1,   -1,  336,   -1,  338,   -1,  297,   -1,  342,   -1,
  261,  302,   -1,   -1,   -1,   -1,  307,   -1,  309,  310,
  311,  312,   -1,   -1,   -1,   -1,  317,   -1,  362,   -1,
  321,   -1,   -1,  284,   -1,  369,   -1,   -1,   -1,   -1,
   -1,   -1,  333,   -1,   -1,  336,  297,  338,   -1,   -1,
  261,  302,   -1,   -1,   -1,   -1,  307,   -1,  309,  310,
  311,  312,   -1,   -1,   -1,   -1,  317,   -1,   -1,   -1,
  321,  362,   -1,  284,  365,  366,   -1,   -1,  369,   -1,
   -1,   -1,  333,   -1,   -1,  336,  297,  338,   -1,   -1,
  261,  302,  263,   -1,   -1,   -1,  307,   -1,  309,  310,
  311,  312,   -1,   -1,  315,   -1,  317,   -1,   -1,   -1,
  321,  362,   -1,  284,  365,  366,   -1,   -1,  369,   -1,
  261,   -1,  333,   -1,   -1,  336,  297,  338,   -1,   -1,
   -1,  302,   -1,   -1,   -1,   -1,  307,   -1,  309,  310,
  311,  312,   -1,  284,   -1,   -1,  317,   -1,   -1,   -1,
  321,  362,   -1,   -1,   -1,   -1,  297,   -1,  369,   -1,
   -1,  302,  333,   -1,   -1,  336,  307,  338,  309,  310,
  311,  312,   -1,   -1,   -1,   -1,  317,   -1,   -1,   -1,
  321,  261,   -1,  263,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,  362,  333,   -1,   -1,  336,   -1,  338,  369,   -1,
   -1,   -1,   -1,   -1,  284,   -1,   -1,   -1,   -1,   -1,
   -1,  261,   -1,   -1,   -1,   -1,   -1,  297,   -1,   -1,
   -1,  362,  302,   -1,  365,  366,   -1,  307,   -1,  309,
  310,  311,  312,   -1,  284,  315,   -1,  317,   -1,   -1,
   -1,  321,   -1,   -1,   -1,   -1,   -1,  297,   -1,   -1,
   -1,   -1,  302,  333,   -1,   -1,  336,  307,  338,  309,
  310,  311,  312,   -1,   -1,   -1,   -1,  317,   -1,   -1,
   -1,  321,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,  362,  333,   -1,   -1,  336,   -1,  338,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,  362,
  };

#line 7110 "cs-parser.jay"

// <summary>
//  A class used to hold info about an operator declarator
// </summary>
class OperatorDeclaration {
	public readonly Operator.OpType optype;
	public readonly FullNamedExpression ret_type;
	public readonly Location location;

	public OperatorDeclaration (Operator.OpType op, FullNamedExpression ret_type, Location location)
	{
		optype = op;
		this.ret_type = ret_type;
		this.location = location;
	}
}

void Error_ExpectingTypeName (Expression expr)
{
	if (expr is Invocation){
		report.Error (1002, expr.Location, "Expecting `;'");
	} else {
		expr.Error_InvalidExpressionStatement (report);
	}
}

void Error_ParameterModifierNotValid (string modifier, Location loc)
{
	report.Error (631, loc, "The parameter modifier `{0}' is not valid in this context",
			              modifier);
}

void Error_DuplicateParameterModifier (Location loc, Parameter.Modifier mod)
{
	report.Error (1107, loc, "Duplicate parameter modifier `{0}'",
  		Parameter.GetModifierSignature (mod));
}

void Error_TypeExpected (Location loc)
{
	report.Error (1031, loc, "Type expected");
}

void Error_UnsafeCodeNotAllowed (Location loc)
{
	report.Error (227, loc, "Unsafe code requires the `unsafe' command line option to be specified");
}

void Warning_EmptyStatement (Location loc)
{
	report.Warning (642, 3, loc, "Possible mistaken empty statement");
}

void Error_NamedArgumentExpected (NamedArgument a)
{
	report.Error (1738, a.Location, "Named arguments must appear after the positional arguments");
}

void Error_MissingInitializer (Location loc)
{
	report.Error (210, loc, "You must provide an initializer in a fixed or using statement declaration");
}

object Error_AwaitAsIdentifier (object token)
{
	if (async_block) {
		report.Error (4003, GetLocation (token), "`await' cannot be used as an identifier within an async method or lambda expression");
		return new LocatedToken ("await", GetLocation (token));
	}

	return token;
}

void push_current_container (TypeDefinition tc, object partial_token)
{
	if (module.Evaluator != null){
		tc.Definition.Modifiers = tc.ModFlags = (tc.ModFlags & ~Modifiers.AccessibilityMask) | Modifiers.PUBLIC;
		if (undo == null)
			undo = new Undo ();

		undo.AddTypeContainer (current_container, tc);
	}
	
	if (partial_token != null)
		current_container.AddPartial (tc);
	else
		current_container.AddTypeContainer (tc);
		
	++lexer.parsing_declaration;
	current_container = tc;
	current_type = tc;
}

TypeContainer pop_current_class ()
{
	var retval = current_container;

	current_container = current_container.Parent;
	current_type = current_type.Parent as TypeDefinition;

	return retval;
}

[System.Diagnostics.Conditional ("FULL_AST")]
void StoreModifierLocation (object token, Location loc)
{
	if (lbag == null)
		return;

	if (mod_locations == null)
  		mod_locations = new List<Tuple<Modifiers, Location>> ();

	mod_locations.Add (Tuple.Create ((Modifiers) token, loc));
}

[System.Diagnostics.Conditional ("FULL_AST")]
void PushLocation (Location loc)
{
	if (location_stack == null)
		location_stack = new Stack<Location> ();

	location_stack.Push (loc);
}

Location PopLocation ()
{
	if (location_stack == null)
		return Location.Null;

	return location_stack.Pop ();
}

string CheckAttributeTarget (int token, string a, Location l)
{
	switch (a) {
	case "assembly" : case "module" : case "field" : case "method" : case "param" : case "property" : case "type" :
			return a;
	}

	if (!Tokenizer.IsValidIdentifier (a)) {
		Error_SyntaxError (token);
	} else {
		report.Warning (658, 1, l,
			 "`{0}' is invalid attribute target. All attributes in this attribute section will be ignored", a);
	}

	return string.Empty;
}

static bool IsUnaryOperator (Operator.OpType op)
{
	switch (op) {
		
	case Operator.OpType.LogicalNot: 
	case Operator.OpType.OnesComplement: 
	case Operator.OpType.Increment:
	case Operator.OpType.Decrement:
	case Operator.OpType.True: 
	case Operator.OpType.False: 
	case Operator.OpType.UnaryPlus: 
	case Operator.OpType.UnaryNegation:
		return true;
	}
	return false;
}

void syntax_error (Location l, string msg)
{
	report.Error (1003, l, "Syntax error, " + msg);
}

Tokenizer lexer;

public Tokenizer Lexer {
	get {
		return lexer;
	}
}		   

public CSharpParser (SeekableStreamReader reader, CompilationSourceFile file, ParserSession session)
	: this (reader, file, file.Compiler.Report, session)
{
}

public CSharpParser (SeekableStreamReader reader, CompilationSourceFile file, Report report, ParserSession session)
{
	this.file = file;
	current_container = current_namespace = file;
	
	this.module = file.Module;
	this.compiler = file.Compiler;
	this.settings = compiler.Settings;
	this.report = report;
	
	lang_version = settings.Version;
	yacc_verbose_flag = settings.VerboseParserFlag;
	doc_support = settings.DocumentationFile != null;
	lexer = new Tokenizer (reader, file, session, report);
	oob_stack = new Stack<object> ();
	lbag = session.LocationsBag;
	use_global_stacks = session.UseJayGlobalArrays;
	parameters_bucket = session.ParametersStack;
}

public void parse ()
{
	eof_token = Token.EOF;
	
	try {
		if (yacc_verbose_flag > 1)
			yyparse (lexer, new yydebug.yyDebugSimple ());
		else
			yyparse (lexer);
			
		Tokenizer tokenizer = lexer as Tokenizer;
		tokenizer.cleanup ();		
	} catch (Exception e){
	  	if (e is yyParser.yyUnexpectedEof) {
			Error_SyntaxError (yyToken);
			UnexpectedEOF = true;
			return;
		}
			
		if (e is yyParser.yyException) {
			if (report.Errors == 0)
				report.Error (-25, lexer.Location, "Parsing error");
		} else {
			// Used by compiler-tester to test internal errors
			if (yacc_verbose_flag > 0 || e is FatalException)
				throw;
		
			report.Error (589, lexer.Location, "Internal compiler error during parsing" + e);
		}
	}
}

void CheckToken (int error, int yyToken, string msg, Location loc)
{
	if (yyToken >= Token.FIRST_KEYWORD && yyToken <= Token.LAST_KEYWORD)
		report.Error (error, loc, "{0}: `{1}' is a keyword", msg, GetTokenName (yyToken));
	else
		report.Error (error, loc, msg);
}

string ConsumeStoredComment ()
{
	string s = tmpComment;
	tmpComment = null;
	Lexer.doc_state = XmlCommentState.Allowed;
	return s;
}

void FeatureIsNotAvailable (Location loc, string feature)
{
	report.FeatureIsNotAvailable (compiler, loc, feature);
}

Location GetLocation (object obj)
{
	var lt = obj as LocatedToken;
	if (lt != null)
		return lt.Location;
		
	var mn = obj as MemberName;
	if (mn != null)
		return mn.Location;
		
	var expr = obj as Expression;
	if (expr != null)
		return expr.Location;

	return lexer.Location;
}

void start_block (Location loc)
{
	if (current_block == null) {
		current_block = new ToplevelBlock (compiler, current_local_parameters, loc);
		parsing_anonymous_method = false;
	} else if (parsing_anonymous_method) {
		current_block = new ParametersBlock (current_block, current_local_parameters, loc);
		parsing_anonymous_method = false;
	} else {
		current_block = new ExplicitBlock (current_block, loc, Location.Null);
	}
}

Block
end_block (Location loc)
{
	Block retval = current_block.Explicit;
	retval.SetEndLocation (loc);
	current_block = retval.Parent;
	return retval;
}

void start_anonymous (bool isLambda, ParametersCompiled parameters, bool isAsync, Location loc)
{
	oob_stack.Push (current_anonymous_method);
	oob_stack.Push (current_local_parameters);
	oob_stack.Push (current_variable);
	oob_stack.Push (async_block);

	current_local_parameters = parameters;
	if (isLambda) {
		if (lang_version <= LanguageVersion.ISO_2)
			FeatureIsNotAvailable (loc, "lambda expressions");

		current_anonymous_method = new LambdaExpression (loc);
	} else {
		if (lang_version == LanguageVersion.ISO_1)
			FeatureIsNotAvailable (loc, "anonymous methods");
			
		current_anonymous_method = new AnonymousMethodExpression (loc);
	}

	async_block = isAsync;
	// Force the next block to be created as a ToplevelBlock
	parsing_anonymous_method = true;
}

/*
 * Completes the anonymous method processing, if lambda_expr is null, this
 * means that we have a Statement instead of an Expression embedded 
 */
AnonymousMethodExpression end_anonymous (ParametersBlock anon_block)
{
	AnonymousMethodExpression retval;

	if (async_block)
		anon_block.IsAsync = true;

	current_anonymous_method.Block = anon_block;
	retval = current_anonymous_method;

	async_block = (bool) oob_stack.Pop ();
	current_variable = (BlockVariable) oob_stack.Pop ();
	current_local_parameters = (ParametersCompiled) oob_stack.Pop ();
	current_anonymous_method = (AnonymousMethodExpression) oob_stack.Pop ();

	return retval;
}

void Error_SyntaxError (int token)
{
	Error_SyntaxError (0, token);
}

void Error_SyntaxError (int error_code, int token)
{
	Error_SyntaxError (error_code, token, "Unexpected symbol");
}

void Error_SyntaxError (int error_code, int token, string msg)
{
	Lexer.CompleteOnEOF = false;

	// An error message has been reported by tokenizer
	if (token == Token.ERROR)
		return;
	
	// Avoid duplicit error message after unterminated string literals
	if (token == Token.LITERAL && lexer.Location.Column == 0)
		return;

	string symbol = GetSymbolName (token);
	string expecting = GetExpecting ();
	var loc = lexer.Location - symbol.Length;
	
	if (error_code == 0) {
		if (expecting == "`identifier'") {
			if (token > Token.FIRST_KEYWORD && token < Token.LAST_KEYWORD) {
				report.Error (1041, loc, "Identifier expected, `{0}' is a keyword", symbol);
				return;
			}
			
			error_code = 1001;
			expecting = "identifier";
		} else if (expecting == "`)'") {
			error_code = 1026;
		} else {
			error_code = 1525;
		}
	}
	
	if (string.IsNullOrEmpty (expecting))
		report.Error (error_code, loc, "{1} `{0}'", symbol, msg);
	else
		report.Error (error_code, loc, "{2} `{0}', expecting {1}", symbol, expecting, msg);	  
}

string GetExpecting ()
{
	int [] tokens = yyExpectingTokens (yyExpectingState);
	var names = new List<string> (tokens.Length);
	bool has_type = false;
	bool has_identifier = false;
	for (int i = 0; i < tokens.Length; i++){
		int token = tokens [i];
		has_identifier |= token == Token.IDENTIFIER;
		
		string name = GetTokenName (token);
		if (name == "<internal>")
			continue;
			
		has_type |= name == "type";
		if (names.Contains (name))
			continue;
		
		names.Add (name);
	}

	//
	// Too many tokens to enumerate
	//
	if (names.Count > 8)
		return null;

	if (has_type && has_identifier)
		names.Remove ("identifier");

	if (names.Count == 1)
		return "`" + GetTokenName (tokens [0]) + "'";
	
	StringBuilder sb = new StringBuilder ();
	names.Sort ();
	int count = names.Count;
	for (int i = 0; i < count; i++){
		bool last = i + 1 == count;
		if (last)
			sb.Append ("or ");
		sb.Append ('`');
		sb.Append (names [i]);
		sb.Append (last ? "'" : count < 3 ? "' " : "', ");
	}
	return sb.ToString ();
}


string GetSymbolName (int token)
{
	switch (token){
	case Token.LITERAL:
		return ((Constant)lexer.Value).GetValue ().ToString ();
	case Token.IDENTIFIER:
		return ((LocatedToken)lexer.Value).Value;

	case Token.BOOL:
		return "bool";
	case Token.BYTE:
		return "byte";
	case Token.CHAR:
		return "char";
	case Token.VOID:
		return "void";
	case Token.DECIMAL:
		return "decimal";
	case Token.DOUBLE:
		return "double";
	case Token.FLOAT:
		return "float";
	case Token.INT:
		return "int";
	case Token.LONG:
		return "long";
	case Token.SBYTE:
		return "sbyte";
	case Token.SHORT:
		return "short";
	case Token.STRING:
		return "string";
	case Token.UINT:
		return "uint";
	case Token.ULONG:
		return "ulong";
	case Token.USHORT:
		return "ushort";
	case Token.OBJECT:
		return "object";
		
	case Token.PLUS:
		return "+";
	case Token.UMINUS:
	case Token.MINUS:
		return "-";
	case Token.BANG:
		return "!";
	case Token.BITWISE_AND:
		return "&";
	case Token.BITWISE_OR:
		return "|";
	case Token.STAR:
		return "*";
	case Token.PERCENT:
		return "%";
	case Token.DIV:
		return "/";
	case Token.CARRET:
		return "^";
	case Token.OP_INC:
		return "++";
	case Token.OP_DEC:
		return "--";
	case Token.OP_SHIFT_LEFT:
		return "<<";
	case Token.OP_SHIFT_RIGHT:
		return ">>";
	case Token.OP_LT:
		return "<";
	case Token.OP_GT:
		return ">";
	case Token.OP_LE:
		return "<=";
	case Token.OP_GE:
		return ">=";
	case Token.OP_EQ:
		return "==";
	case Token.OP_NE:
		return "!=";
	case Token.OP_AND:
		return "&&";
	case Token.OP_OR:
		return "||";
	case Token.OP_PTR:
		return "->";
	case Token.OP_COALESCING:	
		return "??";
	case Token.OP_MULT_ASSIGN:
		return "*=";
	case Token.OP_DIV_ASSIGN:
		return "/=";
	case Token.OP_MOD_ASSIGN:
		return "%=";
	case Token.OP_ADD_ASSIGN:
		return "+=";
	case Token.OP_SUB_ASSIGN:
		return "-=";
	case Token.OP_SHIFT_LEFT_ASSIGN:
		return "<<=";
	case Token.OP_SHIFT_RIGHT_ASSIGN:
		return ">>=";
	case Token.OP_AND_ASSIGN:
		return "&=";
	case Token.OP_XOR_ASSIGN:
		return "^=";
	case Token.OP_OR_ASSIGN:
		return "|=";
	}

	return GetTokenName (token);
}

static string GetTokenName (int token)
{
	switch (token){
	case Token.ABSTRACT:
		return "abstract";
	case Token.AS:
		return "as";
	case Token.ADD:
		return "add";
	case Token.ASYNC:
		return "async";
	case Token.BASE:
		return "base";
	case Token.BREAK:
		return "break";
	case Token.CASE:
		return "case";
	case Token.CATCH:
		return "catch";
	case Token.CHECKED:
		return "checked";
	case Token.CLASS:
		return "class";
	case Token.CONST:
		return "const";
	case Token.CONTINUE:
		return "continue";
	case Token.DEFAULT:
		return "default";
	case Token.DELEGATE:
		return "delegate";
	case Token.DO:
		return "do";
	case Token.ELSE:
		return "else";
	case Token.ENUM:
		return "enum";
	case Token.EVENT:
		return "event";
	case Token.EXPLICIT:
		return "explicit";
	case Token.EXTERN:
	case Token.EXTERN_ALIAS:
		return "extern";
	case Token.FALSE:
		return "false";
	case Token.FINALLY:
		return "finally";
	case Token.FIXED:
		return "fixed";
	case Token.FOR:
		return "for";
	case Token.FOREACH:
		return "foreach";
	case Token.GOTO:
		return "goto";
	case Token.IF:
		return "if";
	case Token.IMPLICIT:
		return "implicit";
	case Token.IN:
		return "in";
	case Token.INTERFACE:
		return "interface";
	case Token.INTERNAL:
		return "internal";
	case Token.IS:
		return "is";
	case Token.LOCK:
		return "lock";
	case Token.NAMESPACE:
		return "namespace";
	case Token.NEW:
		return "new";
	case Token.NULL:
		return "null";
	case Token.OPERATOR:
		return "operator";
	case Token.OUT:
		return "out";
	case Token.OVERRIDE:
		return "override";
	case Token.PARAMS:
		return "params";
	case Token.PRIVATE:
		return "private";
	case Token.PROTECTED:
		return "protected";
	case Token.PUBLIC:
		return "public";
	case Token.READONLY:
		return "readonly";
	case Token.REF:
		return "ref";
	case Token.RETURN:
		return "return";
	case Token.REMOVE:
		return "remove";
	case Token.SEALED:
		return "sealed";
	case Token.SIZEOF:
		return "sizeof";
	case Token.STACKALLOC:
		return "stackalloc";
	case Token.STATIC:
		return "static";
	case Token.STRUCT:
		return "struct";
	case Token.SWITCH:
		return "switch";
	case Token.THIS:
		return "this";
	case Token.THROW:
		return "throw";
	case Token.TRUE:
		return "true";
	case Token.TRY:
		return "try";
	case Token.TYPEOF:
		return "typeof";
	case Token.UNCHECKED:
		return "unchecked";
	case Token.UNSAFE:
		return "unsafe";
	case Token.USING:
		return "using";
	case Token.VIRTUAL:
		return "virtual";
	case Token.VOLATILE:
		return "volatile";
	case Token.WHERE:
		return "where";
	case Token.WHILE:
		return "while";
	case Token.ARGLIST:
		return "__arglist";
	case Token.REFVALUE:
		return "__refvalue";
	case Token.REFTYPE:
		return "__reftype";
	case Token.MAKEREF:
		return "__makeref";
	case Token.PARTIAL:
		return "partial";
	case Token.ARROW:
		return "=>";
	case Token.FROM:
	case Token.FROM_FIRST:
		return "from";
	case Token.JOIN:
		return "join";
	case Token.ON:
		return "on";
	case Token.EQUALS:
		return "equals";
	case Token.SELECT:
		return "select";
	case Token.GROUP:
		return "group";
	case Token.BY:
		return "by";
	case Token.LET:
		return "let";
	case Token.ORDERBY:
		return "orderby";
	case Token.ASCENDING:
		return "ascending";
	case Token.DESCENDING:
		return "descending";
	case Token.INTO:
		return "into";
	case Token.GET:
		return "get";
	case Token.SET:
		return "set";
	case Token.OPEN_BRACE:
		return "{";
	case Token.CLOSE_BRACE:
		return "}";
	case Token.OPEN_BRACKET:
	case Token.OPEN_BRACKET_EXPR:
		return "[";
	case Token.CLOSE_BRACKET:
		return "]";
	case Token.OPEN_PARENS_CAST:
	case Token.OPEN_PARENS_LAMBDA:
	case Token.OPEN_PARENS:
		return "(";
	case Token.CLOSE_PARENS:
		return ")";
	case Token.DOT:
		return ".";
	case Token.COMMA:
		return ",";
	case Token.DEFAULT_COLON:
		return "default:";
	case Token.COLON:
		return ":";
	case Token.SEMICOLON:
		return ";";
	case Token.TILDE:
		return "~";
		
	case Token.PLUS:
	case Token.UMINUS:
	case Token.MINUS:
	case Token.BANG:
	case Token.OP_LT:
	case Token.OP_GT:
	case Token.BITWISE_AND:
	case Token.BITWISE_OR:
	case Token.STAR:
	case Token.PERCENT:
	case Token.DIV:
	case Token.CARRET:
	case Token.OP_INC:
	case Token.OP_DEC:
	case Token.OP_SHIFT_LEFT:
	case Token.OP_SHIFT_RIGHT:
	case Token.OP_LE:
	case Token.OP_GE:
	case Token.OP_EQ:
	case Token.OP_NE:
	case Token.OP_AND:
	case Token.OP_OR:
	case Token.OP_PTR:
	case Token.OP_COALESCING:	
	case Token.OP_MULT_ASSIGN:
	case Token.OP_DIV_ASSIGN:
	case Token.OP_MOD_ASSIGN:
	case Token.OP_ADD_ASSIGN:
	case Token.OP_SUB_ASSIGN:
	case Token.OP_SHIFT_LEFT_ASSIGN:
	case Token.OP_SHIFT_RIGHT_ASSIGN:
	case Token.OP_AND_ASSIGN:
	case Token.OP_XOR_ASSIGN:
	case Token.OP_OR_ASSIGN:
		return "<operator>";

	case Token.BOOL:
	case Token.BYTE:
	case Token.CHAR:
	case Token.VOID:
	case Token.DECIMAL:
	case Token.DOUBLE:
	case Token.FLOAT:
	case Token.INT:
	case Token.LONG:
	case Token.SBYTE:
	case Token.SHORT:
	case Token.STRING:
	case Token.UINT:
	case Token.ULONG:
	case Token.USHORT:
	case Token.OBJECT:
		return "type";
	
	case Token.ASSIGN:
		return "=";
	case Token.OP_GENERICS_LT:
	case Token.GENERIC_DIMENSION:
		return "<";
	case Token.OP_GENERICS_GT:
		return ">";
	case Token.INTERR:
	case Token.INTERR_NULLABLE:
		return "?";
	case Token.DOUBLE_COLON:
		return "::";
	case Token.LITERAL:
		return "value";
	case Token.IDENTIFIER:
	case Token.AWAIT:
		return "identifier";

	case Token.EOF:
		return "end-of-file";

		// All of these are internal.
	case Token.NONE:
	case Token.ERROR:
	case Token.FIRST_KEYWORD:
	case Token.EVAL_COMPILATION_UNIT_PARSER:
	case Token.EVAL_USING_DECLARATIONS_UNIT_PARSER:
	case Token.EVAL_STATEMENT_PARSER:
	case Token.LAST_KEYWORD:
	case Token.GENERATE_COMPLETION:
	case Token.COMPLETE_COMPLETION:
		return "<internal>";

		// A bit more robust.
	default:
		return yyNames [token];
        }
}

/* end end end */
}
#line default
namespace yydebug {
        using System;
	 internal interface yyDebug {
		 void push (int state, Object value);
		 void lex (int state, int token, string name, Object value);
		 void shift (int from, int to, int errorFlag);
		 void pop (int state);
		 void discard (int state, int token, string name, Object value);
		 void reduce (int from, int to, int rule, string text, int len);
		 void shift (int from, int to);
		 void accept (Object value);
		 void error (string message);
		 void reject ();
	 }
	 
	 class yyDebugSimple : yyDebug {
		 void println (string s){
			 Console.Error.WriteLine (s);
		 }
		 
		 public void push (int state, Object value) {
			 println ("push\tstate "+state+"\tvalue "+value);
		 }
		 
		 public void lex (int state, int token, string name, Object value) {
			 println("lex\tstate "+state+"\treading "+name+"\tvalue "+value);
		 }
		 
		 public void shift (int from, int to, int errorFlag) {
			 switch (errorFlag) {
			 default:				// normally
				 println("shift\tfrom state "+from+" to "+to);
				 break;
			 case 0: case 1: case 2:		// in error recovery
				 println("shift\tfrom state "+from+" to "+to
					     +"\t"+errorFlag+" left to recover");
				 break;
			 case 3:				// normally
				 println("shift\tfrom state "+from+" to "+to+"\ton error");
				 break;
			 }
		 }
		 
		 public void pop (int state) {
			 println("pop\tstate "+state+"\ton error");
		 }
		 
		 public void discard (int state, int token, string name, Object value) {
			 println("discard\tstate "+state+"\ttoken "+name+"\tvalue "+value);
		 }
		 
		 public void reduce (int from, int to, int rule, string text, int len) {
			 println("reduce\tstate "+from+"\tuncover "+to
				     +"\trule ("+rule+") "+text);
		 }
		 
		 public void shift (int from, int to) {
			 println("goto\tfrom state "+from+" to "+to);
		 }
		 
		 public void accept (Object value) {
			 println("accept\tvalue "+value);
		 }
		 
		 public void error (string message) {
			 println("error\t"+message);
		 }
		 
		 public void reject () {
			 println("reject");
		 }
		 
	 }
}
// %token constants
 class Token {
  public const int EOF = 257;
  public const int NONE = 258;
  public const int ERROR = 259;
  public const int FIRST_KEYWORD = 260;
  public const int ABSTRACT = 261;
  public const int AS = 262;
  public const int ADD = 263;
  public const int BASE = 264;
  public const int BOOL = 265;
  public const int BREAK = 266;
  public const int BYTE = 267;
  public const int CASE = 268;
  public const int CATCH = 269;
  public const int CHAR = 270;
  public const int CHECKED = 271;
  public const int CLASS = 272;
  public const int CONST = 273;
  public const int CONTINUE = 274;
  public const int DECIMAL = 275;
  public const int DEFAULT = 276;
  public const int DELEGATE = 277;
  public const int DO = 278;
  public const int DOUBLE = 279;
  public const int ELSE = 280;
  public const int ENUM = 281;
  public const int EVENT = 282;
  public const int EXPLICIT = 283;
  public const int EXTERN = 284;
  public const int FALSE = 285;
  public const int FINALLY = 286;
  public const int FIXED = 287;
  public const int FLOAT = 288;
  public const int FOR = 289;
  public const int FOREACH = 290;
  public const int GOTO = 291;
  public const int IF = 292;
  public const int IMPLICIT = 293;
  public const int IN = 294;
  public const int INT = 295;
  public const int INTERFACE = 296;
  public const int INTERNAL = 297;
  public const int IS = 298;
  public const int LOCK = 299;
  public const int LONG = 300;
  public const int NAMESPACE = 301;
  public const int NEW = 302;
  public const int NULL = 303;
  public const int OBJECT = 304;
  public const int OPERATOR = 305;
  public const int OUT = 306;
  public const int OVERRIDE = 307;
  public const int PARAMS = 308;
  public const int PRIVATE = 309;
  public const int PROTECTED = 310;
  public const int PUBLIC = 311;
  public const int READONLY = 312;
  public const int REF = 313;
  public const int RETURN = 314;
  public const int REMOVE = 315;
  public const int SBYTE = 316;
  public const int SEALED = 317;
  public const int SHORT = 318;
  public const int SIZEOF = 319;
  public const int STACKALLOC = 320;
  public const int STATIC = 321;
  public const int STRING = 322;
  public const int STRUCT = 323;
  public const int SWITCH = 324;
  public const int THIS = 325;
  public const int THROW = 326;
  public const int TRUE = 327;
  public const int TRY = 328;
  public const int TYPEOF = 329;
  public const int UINT = 330;
  public const int ULONG = 331;
  public const int UNCHECKED = 332;
  public const int UNSAFE = 333;
  public const int USHORT = 334;
  public const int USING = 335;
  public const int VIRTUAL = 336;
  public const int VOID = 337;
  public const int VOLATILE = 338;
  public const int WHERE = 339;
  public const int WHILE = 340;
  public const int ARGLIST = 341;
  public const int PARTIAL = 342;
  public const int ARROW = 343;
  public const int FROM = 344;
  public const int FROM_FIRST = 345;
  public const int JOIN = 346;
  public const int ON = 347;
  public const int EQUALS = 348;
  public const int SELECT = 349;
  public const int GROUP = 350;
  public const int BY = 351;
  public const int LET = 352;
  public const int ORDERBY = 353;
  public const int ASCENDING = 354;
  public const int DESCENDING = 355;
  public const int INTO = 356;
  public const int INTERR_NULLABLE = 357;
  public const int EXTERN_ALIAS = 358;
  public const int REFVALUE = 359;
  public const int REFTYPE = 360;
  public const int MAKEREF = 361;
  public const int ASYNC = 362;
  public const int AWAIT = 363;
  public const int INTERR_OPERATOR = 364;
  public const int GET = 365;
  public const int SET = 366;
  public const int LAST_KEYWORD = 367;
  public const int OPEN_BRACE = 368;
  public const int CLOSE_BRACE = 369;
  public const int OPEN_BRACKET = 370;
  public const int CLOSE_BRACKET = 371;
  public const int OPEN_PARENS = 372;
  public const int CLOSE_PARENS = 373;
  public const int DOT = 374;
  public const int COMMA = 375;
  public const int COLON = 376;
  public const int SEMICOLON = 377;
  public const int TILDE = 378;
  public const int PLUS = 379;
  public const int MINUS = 380;
  public const int BANG = 381;
  public const int ASSIGN = 382;
  public const int OP_LT = 383;
  public const int OP_GT = 384;
  public const int BITWISE_AND = 385;
  public const int BITWISE_OR = 386;
  public const int STAR = 387;
  public const int PERCENT = 388;
  public const int DIV = 389;
  public const int CARRET = 390;
  public const int INTERR = 391;
  public const int DOUBLE_COLON = 392;
  public const int OP_INC = 393;
  public const int OP_DEC = 394;
  public const int OP_SHIFT_LEFT = 395;
  public const int OP_SHIFT_RIGHT = 396;
  public const int OP_LE = 397;
  public const int OP_GE = 398;
  public const int OP_EQ = 399;
  public const int OP_NE = 400;
  public const int OP_AND = 401;
  public const int OP_OR = 402;
  public const int OP_MULT_ASSIGN = 403;
  public const int OP_DIV_ASSIGN = 404;
  public const int OP_MOD_ASSIGN = 405;
  public const int OP_ADD_ASSIGN = 406;
  public const int OP_SUB_ASSIGN = 407;
  public const int OP_SHIFT_LEFT_ASSIGN = 408;
  public const int OP_SHIFT_RIGHT_ASSIGN = 409;
  public const int OP_AND_ASSIGN = 410;
  public const int OP_XOR_ASSIGN = 411;
  public const int OP_OR_ASSIGN = 412;
  public const int OP_PTR = 413;
  public const int OP_COALESCING = 414;
  public const int OP_GENERICS_LT = 415;
  public const int OP_GENERICS_LT_DECL = 416;
  public const int OP_GENERICS_GT = 417;
  public const int LITERAL = 418;
  public const int IDENTIFIER = 419;
  public const int OPEN_PARENS_LAMBDA = 420;
  public const int OPEN_PARENS_CAST = 421;
  public const int GENERIC_DIMENSION = 422;
  public const int DEFAULT_COLON = 423;
  public const int OPEN_BRACKET_EXPR = 424;
  public const int EVAL_STATEMENT_PARSER = 425;
  public const int EVAL_COMPILATION_UNIT_PARSER = 426;
  public const int EVAL_USING_DECLARATIONS_UNIT_PARSER = 427;
  public const int DOC_SEE = 428;
  public const int GENERATE_COMPLETION = 429;
  public const int COMPLETE_COMPLETION = 430;
  public const int UMINUS = 431;
  public const int yyErrorCode = 256;
 }
 namespace yyParser {
  using System;
  /** thrown for irrecoverable syntax errors and stack overflow.
    */
  internal class yyException : System.Exception {
    public yyException (string message) : base (message) {
    }
  }
  internal class yyUnexpectedEof : yyException {
    public yyUnexpectedEof (string message) : base (message) {
    }
    public yyUnexpectedEof () : base ("") {
    }
  }

  /** must be implemented by a scanner object to supply input to the parser.
    */
  internal interface yyInput {
    /** move on to next token.
        @return false if positioned beyond tokens.
        @throws IOException on input error.
      */
    bool advance (); // throws java.io.IOException;
    /** classifies current token.
        Should not be called if advance() returned false.
        @return current %token or single character.
      */
    int token ();
    /** associated with current token.
        Should not be called if advance() returned false.
        @return value for token().
      */
    Object value ();
  }
 }
} // close outermost namespace, that MUST HAVE BEEN opened in the prolog
